/*
 * GParamSpec methods tests
 * Testing GParamSpec methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;

/*
 * Name: g_param_value_defaults
 * Params: GParamSpec *pspec, GValue *value
 * Returns: gboolean
 * Assertion: Checks whether value contains the default value as specified in pspec.
 *            pspec :   a valid GParamSpec
 *            value : a GValue of correct type for pspec
 *            Returns :   whether value contains the canonical default for this pspec
 * Params Values: G_TYPE_STRING, g_value_set_string, "Hello", "Hello"
 * Expected: TRUE  
 */
static void test_purpose_1()
{
    #define VAL_TYPE    G_TYPE_STRING
    #define SET_VAL     g_value_set_string
    #define DEF_VAL     "Hello"
    #define VAL_VAL     "Hello"
    #define EXP_RET     TRUE
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GParamSpec* pspec = g_param_spec_string("TestString", "String", "The default test", DEF_VAL, G_PARAM_READWRITE);
    GValue value = {0, };
    g_value_init(&value, VAL_TYPE);
    SET_VAL(&value, VAL_VAL);
    if (g_param_value_defaults(pspec, &value) != EXP_RET){
        TEST_FAIL("g_param_value_defaults: failed", NULL);
    }
    
    #undef VAL_TYPE
    #undef SET_VAL
    #undef DEF_VAL
    #undef VAL_VAL
    #undef EXP_RET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_param_value_defaults
 * Params: GParamSpec *pspec, GValue *value
 * Returns: gboolean
 * Assertion: Checks whether value contains the default value as specified in pspec.
 *            pspec :   a valid GParamSpec
 *            value : a GValue of correct type for pspec
 *            Returns :   whether value contains the canonical default for this pspec
 * Params Values: G_TYPE_STRING, g_value_set_string, "Hello", "HEllo"
 * Expected: FALSE  
 */
static void test_purpose_2()
{
    #define VAL_TYPE    G_TYPE_STRING
    #define SET_VAL     g_value_set_string
    #define DEF_VAL     "Hello"
    #define VAL_VAL     "HEllo"
    #define EXP_RET     FALSE
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GParamSpec* pspec = g_param_spec_string("TestString", "String", "The default test", DEF_VAL, G_PARAM_READWRITE);
    GValue value = {0, };
    g_value_init(&value, VAL_TYPE);
    SET_VAL(&value, VAL_VAL);
    if (g_param_value_defaults(pspec, &value) != EXP_RET){
        TEST_FAIL("g_param_value_defaults: failed", NULL);
    }
    
    #undef VAL_TYPE
    #undef SET_VAL
    #undef DEF_VAL
    #undef VAL_VAL
    #undef EXP_RET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_param_spec_get_name
 * Params: GParamSpec *pspec
 * Returns: const gchar*
 * Assertion: Returns the name of a GParamSpec.
 *            pspec :  a valid GParamSpec
 *            Returns :   the name of pspec.
 * Params Values: "Test getting name"
 * Expected: "Test-getting-name"  
 */
static void test_purpose_3()
{
    #define NAME        "Test getting name"
    #define EXP_NAME    "Test-getting-name"
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GParamSpec* pspec = g_param_spec_string(NAME, "String", "The name test", "Hello", G_PARAM_READWRITE);
    if (strcmp(g_param_spec_get_name(pspec), EXP_NAME) != 0){
        TEST_FAIL("g_param_spec_get_name: name should be %s", EXP_NAME);
    }
    #undef NAME
    #undef EXP_NAME
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GParamSpec ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {NULL,0}
};
