/*
 * GdkCursors methods tests
 * Testing GdkCursors methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;


/*
 * Name: gdk_cursor_new
 * Params: GdkCursorType cursor_type
 * Returns: GdkCursor*
 * Assertion: Creates a new cursor from the set of builtin cursors for the default display.
 * Params Values: cursor to create
 * Expected: a new GdkCursor  
 */
static void test_purpose_1()
{
    #define CURSOR_TYPE GDK_X_CURSOR
    
    GdkCursor *cursor;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    cursor = gdk_cursor_new (CURSOR_TYPE);
    
    if (!cursor)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    #undef CURSOR_TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_cursor_new
 * Params: GdkCursorType cursor_type
 * Returns: GdkCursor*
 * Assertion: Creates a new cursor from the set of builtin cursors for the default display.
 * Params Values: cursor to create
 * Expected: a new GdkCursor  
 */
static void test_purpose_2()
{
    #define CURSOR_TYPE GDK_ARROW
    
    GdkCursor *cursor;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    cursor = gdk_cursor_new (CURSOR_TYPE);
    
    if (!cursor)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    #undef CURSOR_TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_cursor_new
 * Params: GdkCursorType cursor_type
 * Returns: GdkCursor*
 * Assertion: Creates a new cursor from the set of builtin cursors for the default display.
 * Params Values: cursor to create
 * Expected: a new GdkCursor  
 */
static void test_purpose_3()
{
    #define CURSOR_TYPE GDK_BASED_ARROW_DOWN
    
    GdkCursor *cursor;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    cursor = gdk_cursor_new (CURSOR_TYPE);
    
    if (!cursor)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    #undef CURSOR_TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_cursor_new
 * Params: GdkCursorType cursor_type
 * Returns: GdkCursor*
 * Assertion: Creates a new cursor from the set of builtin cursors for the default display.
 * Params Values: cursor to create
 * Expected: a new GdkCursor  
 */
static void test_purpose_4()
{
    #define CURSOR_TYPE GDK_BASED_ARROW_UP
    
    GdkCursor *cursor;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    cursor = gdk_cursor_new (CURSOR_TYPE);
    
    if (!cursor)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    #undef CURSOR_TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_cursor_new
 * Params: GdkCursorType cursor_type
 * Returns: GdkCursor*
 * Assertion: Creates a new cursor from the set of builtin cursors for the default display.
 * Params Values: cursor to create
 * Expected: a new GdkCursor  
 */
static void test_purpose_5()
{
    #define CURSOR_TYPE GDK_CENTER_PTR
    
    GdkCursor *cursor;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    cursor = gdk_cursor_new (CURSOR_TYPE);
    
    if (!cursor)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    #undef CURSOR_TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_cursor_new
 * Params: GdkCursorType cursor_type
 * Returns: GdkCursor*
 * Assertion: Creates a new cursor from the set of builtin cursors for the default display.
 * Params Values: cursor to create
 * Expected: a new GdkCursor  
 */
static void test_purpose_6()
{
    #define CURSOR_TYPE GDK_CIRCLE
    
    GdkCursor *cursor;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    cursor = gdk_cursor_new (CURSOR_TYPE);
    
    if (!cursor)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    #undef CURSOR_TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_cursor_new
 * Params: GdkCursorType cursor_type
 * Returns: GdkCursor*
 * Assertion: Creates a new cursor from the set of builtin cursors for the default display.
 * Params Values: cursor to create
 * Expected: a new GdkCursor  
 */
static void test_purpose_7()
{
    #define CURSOR_TYPE GDK_HEART
    
    GdkCursor *cursor;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    cursor = gdk_cursor_new (CURSOR_TYPE);
    
    if (!cursor)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    #undef CURSOR_TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_cursor_new
 * Params: GdkCursorType cursor_type
 * Returns: GdkCursor*
 * Assertion: Creates a new cursor from the set of builtin cursors for the default display.
 * Params Values: cursor to create
 * Expected: a new GdkCursor  
 */
static void test_purpose_8()
{
    #define CURSOR_TYPE GDK_WATCH
    
    GdkCursor *cursor;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    cursor = gdk_cursor_new (CURSOR_TYPE);
    
    if (!cursor)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    #undef CURSOR_TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_cursor_ref
 * Params: GdkCursor *cursor
 * Returns: GdkCursor*
 * Assertion: Adds a reference to cursor.
 * Params Values: a GdkCursor
 * Expected: Same cursor that was passed in  
 */
static void test_purpose_9()
{
    #define CURSOR_TYPE GDK_X_CURSOR
    #define NUM 1
    
    GdkCursor *cursor;
    guint i;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    cursor = gdk_cursor_new (CURSOR_TYPE);
    
    if (!cursor)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    // bug 2589 - in 2.16.0, gdk started to cache font and named cursors
    // count could already have a value before the test starts
    guint start_ref;
    start_ref = cursor->ref_count;
    
    for (i = 0; i < NUM; i++)
        gdk_cursor_ref (cursor);
    
    if (cursor->ref_count != NUM + start_ref)
        TEST_FAIL ("reference count of cursor should be %u, not %u", NUM + start_ref, cursor->ref_count, NULL);
    
    #undef CURSOR_TYPE
    #undef NUM
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_cursor_ref
 * Params: GdkCursor *cursor
 * Returns: GdkCursor*
 * Assertion: Adds a reference to cursor.
 * Params Values: a GdkCursor
 * Expected: Same cursor that was passed in  
 */
static void test_purpose_10()
{
    #define CURSOR_TYPE GDK_ARROW
    #define NUM 2
    
    GdkCursor *cursor;
    guint i;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    cursor = gdk_cursor_new (CURSOR_TYPE);
    
    if (!cursor)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    // bug 2589 - in 2.16.0, gdk started to cache font and named cursors
    // count could already have a value before the test starts
    guint start_ref;
    start_ref = cursor->ref_count;
    
    for (i = 0; i < NUM; i++)
        gdk_cursor_ref (cursor);
    
    if (cursor->ref_count != NUM + start_ref)
        TEST_FAIL ("reference count of cursor should be %u, not %u", NUM + start_ref, cursor->ref_count, NULL);
    
    #undef CURSOR_TYPE
    #undef NUM
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_cursor_ref
 * Params: GdkCursor *cursor
 * Returns: GdkCursor*
 * Assertion: Adds a reference to cursor.
 * Params Values: a GdkCursor
 * Expected: Same cursor that was passed in  
 */
static void test_purpose_11()
{
    #define CURSOR_TYPE GDK_BASED_ARROW_DOWN
    #define NUM 3
    
    GdkCursor *cursor;
    guint i;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    cursor = gdk_cursor_new (CURSOR_TYPE);
    
    if (!cursor)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    // bug 2589 - in 2.16.0, gdk started to cache font and named cursors
    // count could already have a value before the test starts
    guint start_ref;
    start_ref = cursor->ref_count;
    
    for (i = 0; i < NUM; i++)
        gdk_cursor_ref (cursor);
    
    if (cursor->ref_count != NUM + start_ref)
        TEST_FAIL ("reference count of cursor should be %u, not %u", NUM + start_ref, cursor->ref_count, NULL);
    
    #undef CURSOR_TYPE
    #undef NUM
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_cursor_ref
 * Params: GdkCursor *cursor
 * Returns: GdkCursor*
 * Assertion: Adds a reference to cursor.
 * Params Values: a GdkCursor
 * Expected: Same cursor that was passed in  
 */
static void test_purpose_12()
{
    #define CURSOR_TYPE GDK_BASED_ARROW_UP
    #define NUM 4
    
    GdkCursor *cursor;
    guint i;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    cursor = gdk_cursor_new (CURSOR_TYPE);
    
    if (!cursor)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    // bug 2589 - in 2.16.0, gdk started to cache font and named cursors
    // count could already have a value before the test starts
    guint start_ref;
    start_ref = cursor->ref_count;
    
    for (i = 0; i < NUM; i++)
        gdk_cursor_ref (cursor);
    
    if (cursor->ref_count != NUM + start_ref)
        TEST_FAIL ("reference count of cursor should be %u, not %u", NUM + start_ref, cursor->ref_count, NULL);
    
    #undef CURSOR_TYPE
    #undef NUM
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_cursor_ref
 * Params: GdkCursor *cursor
 * Returns: GdkCursor*
 * Assertion: Adds a reference to cursor.
 * Params Values: a GdkCursor
 * Expected: Same cursor that was passed in  
 */
static void test_purpose_13()
{
    #define CURSOR_TYPE GDK_CENTER_PTR
    #define NUM 5
    
    GdkCursor *cursor;
    guint i;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    cursor = gdk_cursor_new (CURSOR_TYPE);
    
    if (!cursor)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    // bug 2589 - in 2.16.0, gdk started to cache font and named cursors
    // count could already have a value before the test starts
    guint start_ref;
    start_ref = cursor->ref_count;
    
    for (i = 0; i < NUM; i++)
        gdk_cursor_ref (cursor);
    
    if (cursor->ref_count != NUM + start_ref)
        TEST_FAIL ("reference count of cursor should be %u, not %u", NUM + start_ref, cursor->ref_count, NULL);
    
    #undef CURSOR_TYPE
    #undef NUM
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_cursor_ref
 * Params: GdkCursor *cursor
 * Returns: GdkCursor*
 * Assertion: Adds a reference to cursor.
 * Params Values: a GdkCursor
 * Expected: Same cursor that was passed in  
 */
static void test_purpose_14()
{
    #define CURSOR_TYPE GDK_CIRCLE
    #define NUM 6
    
    GdkCursor *cursor;
    guint i;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    cursor = gdk_cursor_new (CURSOR_TYPE);
    
    if (!cursor)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    // bug 2589 - in 2.16.0, gdk started to cache font and named cursors
    // count could already have a value before the test starts
    guint start_ref;
    start_ref = cursor->ref_count;
    
    for (i = 0; i < NUM; i++)
        gdk_cursor_ref (cursor);
    
    if (cursor->ref_count != NUM + start_ref)
        TEST_FAIL ("reference count of cursor should be %u, not %u", NUM + start_ref, cursor->ref_count, NULL);
    
    #undef CURSOR_TYPE
    #undef NUM
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_cursor_ref
 * Params: GdkCursor *cursor
 * Returns: GdkCursor*
 * Assertion: Adds a reference to cursor.
 * Params Values: a GdkCursor
 * Expected: Same cursor that was passed in  
 */
static void test_purpose_15()
{
    #define CURSOR_TYPE GDK_HEART
    #define NUM 7
    
    GdkCursor *cursor;
    guint i;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    cursor = gdk_cursor_new (CURSOR_TYPE);
    
    if (!cursor)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    // bug 2589 - in 2.16.0, gdk started to cache font and named cursors
    // count could already have a value before the test starts
    guint start_ref;
    start_ref = cursor->ref_count;
    
    for (i = 0; i < NUM; i++)
        gdk_cursor_ref (cursor);
    
    if (cursor->ref_count != NUM + start_ref)
        TEST_FAIL ("reference count of cursor should be %u, not %u", NUM + start_ref, cursor->ref_count, NULL);
    
    #undef CURSOR_TYPE
    #undef NUM
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_cursor_ref
 * Params: GdkCursor *cursor
 * Returns: GdkCursor*
 * Assertion: Adds a reference to cursor.
 * Params Values: a GdkCursor
 * Expected: Same cursor that was passed in  
 */
static void test_purpose_16()
{
    #define CURSOR_TYPE GDK_WATCH
    #define NUM 8
    
    GdkCursor *cursor;
    guint i;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    cursor = gdk_cursor_new (CURSOR_TYPE);
    
    if (!cursor)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    // bug 2589 - in 2.16.0, gdk started to cache font and named cursors
    // count could already have a value before the test starts
    guint start_ref;
    start_ref = cursor->ref_count;
    
    for (i = 0; i < NUM; i++)
        gdk_cursor_ref (cursor);
    
    if (cursor->ref_count != NUM + start_ref)
        TEST_FAIL ("reference count of cursor should be %u, not %u", NUM + start_ref, cursor->ref_count, NULL);
    
    #undef CURSOR_TYPE
    #undef NUM
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_cursor_unref
 * Params: GdkCursor *cursor
 * Returns: void
 * Assertion: Removes a reference from cursor, deallocating the cursor if no references remain.
 * Params Values: a GdkCursor
 * Expected: void  
 */
static void test_purpose_17()
{
    #define CURSOR_TYPE GDK_X_CURSOR
    #define NUM 1
    
    GdkCursor *cursor;
    guint i;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    cursor = gdk_cursor_new (CURSOR_TYPE);
    
    if (!cursor)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    // bug 2589 - in 2.16.0, gdk started to cache font and named cursors
    // count could already have a value before the test starts
    guint start_ref;
    start_ref = cursor->ref_count;
    
    for (i = 0; i < NUM; i++)
        gdk_cursor_ref (cursor);
    
    if (cursor->ref_count != NUM + start_ref)
        TEST_FAIL ("reference count of cursor should be %u, not %u", NUM + start_ref, cursor->ref_count, NULL);
    
    for (i = 0; i < NUM; i++)
        gdk_cursor_unref (cursor);
    
    if (cursor->ref_count != start_ref)
        TEST_FAIL ("reference count of cursor should be %u, not %u", start_ref, cursor->ref_count, NULL);
    
    #undef CURSOR_TYPE
    #undef NUM
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_cursor_unref
 * Params: GdkCursor *cursor
 * Returns: void
 * Assertion: Removes a reference from cursor, deallocating the cursor if no references remain.
 * Params Values: a GdkCursor
 * Expected: void  
 */
static void test_purpose_18()
{
    #define CURSOR_TYPE GDK_ARROW
    #define NUM 2
    
    GdkCursor *cursor;
    guint i;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    cursor = gdk_cursor_new (CURSOR_TYPE);
    
    if (!cursor)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    // bug 2589 - in 2.16.0, gdk started to cache font and named cursors
    // count could already have a value before the test starts
    guint start_ref;
    start_ref = cursor->ref_count;
    
    for (i = 0; i < NUM; i++)
        gdk_cursor_ref (cursor);
    
    if (cursor->ref_count != NUM + start_ref)
        TEST_FAIL ("reference count of cursor should be %u, not %u", NUM + start_ref, cursor->ref_count, NULL);
    
    for (i = 0; i < NUM; i++)
        gdk_cursor_unref (cursor);
    
    if (cursor->ref_count != start_ref)
        TEST_FAIL ("reference count of cursor should be %u, not %u", start_ref, cursor->ref_count, NULL);
    
    #undef CURSOR_TYPE
    #undef NUM
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_cursor_unref
 * Params: GdkCursor *cursor
 * Returns: void
 * Assertion: Removes a reference from cursor, deallocating the cursor if no references remain.
 * Params Values: a GdkCursor
 * Expected: void  
 */
static void test_purpose_19()
{
    #define CURSOR_TYPE GDK_BASED_ARROW_DOWN
    #define NUM 3
    
    GdkCursor *cursor;
    guint i;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    cursor = gdk_cursor_new (CURSOR_TYPE);
    
    if (!cursor)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    // bug 2589 - in 2.16.0, gdk started to cache font and named cursors
    // count could already have a value before the test starts
    guint start_ref;
    start_ref = cursor->ref_count;
    
    for (i = 0; i < NUM; i++)
        gdk_cursor_ref (cursor);
    
    if (cursor->ref_count != NUM + start_ref)
        TEST_FAIL ("reference count of cursor should be %u, not %u", NUM + start_ref, cursor->ref_count, NULL);
    
    for (i = 0; i < NUM; i++)
        gdk_cursor_unref (cursor);
    
    if (cursor->ref_count != start_ref)
        TEST_FAIL ("reference count of cursor should be %u, not %u", start_ref, cursor->ref_count, NULL);
    
    #undef CURSOR_TYPE
    #undef NUM
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_cursor_unref
 * Params: GdkCursor *cursor
 * Returns: void
 * Assertion: Removes a reference from cursor, deallocating the cursor if no references remain.
 * Params Values: a GdkCursor
 * Expected: void  
 */
static void test_purpose_20()
{
    #define CURSOR_TYPE GDK_BASED_ARROW_UP
    #define NUM 4
    
    GdkCursor *cursor;
    guint i;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    cursor = gdk_cursor_new (CURSOR_TYPE);
    
    if (!cursor)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    // bug 2589 - in 2.16.0, gdk started to cache font and named cursors
    // count could already have a value before the test starts
    guint start_ref;
    start_ref = cursor->ref_count;
    
    for (i = 0; i < NUM; i++)
        gdk_cursor_ref (cursor);
    
    if (cursor->ref_count != NUM + start_ref)
        TEST_FAIL ("reference count of cursor should be %u, not %u", NUM + start_ref, cursor->ref_count, NULL);
    
    for (i = 0; i < NUM; i++)
        gdk_cursor_unref (cursor);
    
    if (cursor->ref_count != start_ref)
        TEST_FAIL ("reference count of cursor should be %u, not %u", start_ref, cursor->ref_count, NULL);
    
    #undef CURSOR_TYPE
    #undef NUM
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_cursor_unref
 * Params: GdkCursor *cursor
 * Returns: void
 * Assertion: Removes a reference from cursor, deallocating the cursor if no references remain.
 * Params Values: a GdkCursor
 * Expected: void  
 */
static void test_purpose_21()
{
    #define CURSOR_TYPE GDK_CENTER_PTR
    #define NUM 5
    
    GdkCursor *cursor;
    guint i;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    cursor = gdk_cursor_new (CURSOR_TYPE);
    
    if (!cursor)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    // bug 2589 - in 2.16.0, gdk started to cache font and named cursors
    // count could already have a value before the test starts
    guint start_ref;
    start_ref = cursor->ref_count;
    
    for (i = 0; i < NUM; i++)
        gdk_cursor_ref (cursor);
    
    if (cursor->ref_count != NUM + start_ref)
        TEST_FAIL ("reference count of cursor should be %u, not %u", NUM + start_ref, cursor->ref_count, NULL);
    
    for (i = 0; i < NUM; i++)
        gdk_cursor_unref (cursor);
    
    if (cursor->ref_count != start_ref)
        TEST_FAIL ("reference count of cursor should be %u, not %u", start_ref, cursor->ref_count, NULL);
    
    #undef CURSOR_TYPE
    #undef NUM
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_cursor_unref
 * Params: GdkCursor *cursor
 * Returns: void
 * Assertion: Removes a reference from cursor, deallocating the cursor if no references remain.
 * Params Values: a GdkCursor
 * Expected: void  
 */
static void test_purpose_22()
{
    #define CURSOR_TYPE GDK_CIRCLE
    #define NUM 6
    
    GdkCursor *cursor;
    guint i;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    cursor = gdk_cursor_new (CURSOR_TYPE);
    
    if (!cursor)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    // bug 2589 - in 2.16.0, gdk started to cache font and named cursors
    // count could already have a value before the test starts
    guint start_ref;
    start_ref = cursor->ref_count;
    
    for (i = 0; i < NUM; i++)
        gdk_cursor_ref (cursor);
    
    if (cursor->ref_count != NUM + start_ref)
        TEST_FAIL ("reference count of cursor should be %u, not %u", NUM + start_ref, cursor->ref_count, NULL);
    
    for (i = 0; i < NUM; i++)
        gdk_cursor_unref (cursor);
    
    if (cursor->ref_count != start_ref)
        TEST_FAIL ("reference count of cursor should be %u, not %u", start_ref, cursor->ref_count, NULL);
    
    #undef CURSOR_TYPE
    #undef NUM
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_cursor_unref
 * Params: GdkCursor *cursor
 * Returns: void
 * Assertion: Removes a reference from cursor, deallocating the cursor if no references remain.
 * Params Values: a GdkCursor
 * Expected: void  
 */
static void test_purpose_23()
{
    #define CURSOR_TYPE GDK_HEART
    #define NUM 7
    
    GdkCursor *cursor;
    guint i;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    cursor = gdk_cursor_new (CURSOR_TYPE);
    
    if (!cursor)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    // bug 2589 - in 2.16.0, gdk started to cache font and named cursors
    // count could already have a value before the test starts
    guint start_ref;
    start_ref = cursor->ref_count;
    
    for (i = 0; i < NUM; i++)
        gdk_cursor_ref (cursor);
    
    if (cursor->ref_count != NUM + start_ref)
        TEST_FAIL ("reference count of cursor should be %u, not %u", NUM + start_ref, cursor->ref_count, NULL);
    
    for (i = 0; i < NUM; i++)
        gdk_cursor_unref (cursor);
    
    if (cursor->ref_count != start_ref)
        TEST_FAIL ("reference count of cursor should be %u, not %u", start_ref, cursor->ref_count, NULL);
    
    #undef CURSOR_TYPE
    #undef NUM
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_cursor_unref
 * Params: GdkCursor *cursor
 * Returns: void
 * Assertion: Removes a reference from cursor, deallocating the cursor if no references remain.
 * Params Values: a GdkCursor
 * Expected: void  
 */
static void test_purpose_24()
{
    #define CURSOR_TYPE GDK_WATCH
    #define NUM 8
    
    GdkCursor *cursor;
    guint i;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    cursor = gdk_cursor_new (CURSOR_TYPE);
    
    if (!cursor)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    // bug 2589 - in 2.16.0, gdk started to cache font and named cursors
    // count could already have a value before the test starts
    guint start_ref;
    start_ref = cursor->ref_count;
    
    for (i = 0; i < NUM; i++)
        gdk_cursor_ref (cursor);
    
    if (cursor->ref_count != NUM + start_ref)
        TEST_FAIL ("reference count of cursor should be %u, not %u", NUM + start_ref, cursor->ref_count, NULL);
    
    for (i = 0; i < NUM; i++)
        gdk_cursor_unref (cursor);
    
    if (cursor->ref_count != start_ref)
        TEST_FAIL ("reference count of cursor should be %u, not %u", start_ref, cursor->ref_count, NULL);
    
    #undef CURSOR_TYPE
    #undef NUM
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GdkCursors ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {test_purpose_11, 1},
    {test_purpose_12, 1},
    {test_purpose_13, 1},
    {test_purpose_14, 1},
    {test_purpose_15, 1},
    {test_purpose_16, 1},
    {test_purpose_17, 1},
    {test_purpose_18, 1},
    {test_purpose_19, 1},
    {test_purpose_20, 1},
    {test_purpose_21, 1},
    {test_purpose_22, 1},
    {test_purpose_23, 1},
    {test_purpose_24, 1},
    {NULL,0}
};
