/*
 * GdkPixbufFileSaving methods tests
 * Testing GdkPixbufFileSaving methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;
gchar * filename = NULL;

gchar * no_such_file(){
	return "no_such_file";
}

gchar * gen_filename(gchar * fname){
	gchar * tet_root = NULL;
	tet_root = getenv("TET_ROOT");
	filename = (gchar *)malloc(128);
	memset(filename,0,128);
	strcpy(filename,tet_root);
	strcat(filename,"/gtkvts/src/tests/functions/GdkPixbuf/tmpfile/");
	strcat(filename,fname);
	return filename;
};

gchar * read_in_file(){
	return gen_filename("original.jpg");
};
gchar * read_in_small_file(){
	return gen_filename("small.png");
};
gchar * file_ico(){
	return gen_filename("file_new.ico");
}
gchar * file_ico_large(){
	return gen_filename("file_large_new.ico");
}
gchar * file_ico_16(){
	return gen_filename("file_16_new.ico");
}
gchar * file_ico_24(){
	return gen_filename("file_24_new.ico");
}
gchar * file_ico_32(){
	return gen_filename("file_32_new.ico");
}
gchar * file_ico_cur(){
	return gen_filename("file_cur_new.ico");
}
gchar * file_jpeg(){
	return gen_filename("file_new.jpeg");
}
gchar * file_jpeg_quality(){
	return gen_filename("file_quality_new.jpeg");
}
gchar * file_png(){
	return gen_filename("file_new.png");
}
gchar * file_png_text(){
	return gen_filename("file_text_new.png");
}
gchar * file_xxx(){
	return gen_filename("file_new.xxx");
}

void free_filename(){
	if(filename)
		free(filename);
	filename = NULL;
}

/*
 * Name: gdk_pixbuf_save
 * Params: GdkPixbuf * pixbuf, const char * filename, const char * type, GError ** error
 * Returns: gboolean
 * Assertion: Saves pixbuf to a file in format type. By default, "jpeg", "png" and "ico" are possible file formats to save in, but more formats may be installed. The list of all writable formats can be determined in the following way.
 * Params values: pixbuf : a GdkPixbuf, filename : name of file to save, type : name of file format, error : return location for error, or NULL 
 * Expected: whether an error was set
 *   
 */
static void test_purpose_1()
{
    #define WITHOPT				0
    #define OPTVALUE			""
    #define FILENAME			file_jpeg()
    #define FORMAT 				"jpeg"
    #define EXP_RES				TRUE
    #define EXP_ERR				0
    
    GdkPixbuf * pixbuf = NULL;
    gboolean ret = FALSE;
    GError * perrorbuf = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if(strcmp(FORMAT,"ico") == 0 && EXP_RES == TRUE)
    	pixbuf = gdk_pixbuf_new_from_file(read_in_small_file(),NULL);
    else
    	pixbuf = gdk_pixbuf_new_from_file(read_in_file(),NULL);
    if(pixbuf == NULL){
    	TEST_FAIL ("\"gdk_pixbuf_save\":pixbuf is NULL!", NULL);
    	return;
    }
    free_filename();
    
    if(WITHOPT == 0){//no optional params
    	ret = gdk_pixbuf_save(pixbuf,FILENAME,FORMAT,&perrorbuf,NULL);
    }
    if(WITHOPT == 6){//with quality
    	ret = gdk_pixbuf_save(pixbuf,FILENAME,FORMAT,&perrorbuf,"quality",OPTVALUE,NULL);
    }
    if(WITHOPT == 7){//with tEXt::key
    	ret = gdk_pixbuf_save(pixbuf,FILENAME,FORMAT,&perrorbuf,"tEXt::key",OPTVALUE,NULL);
    }
    if(WITHOPT == 8){//with tEXt::key
    	ret = gdk_pixbuf_save(pixbuf,FILENAME,FORMAT,&perrorbuf,"depth",OPTVALUE,NULL);
    }
    if(WITHOPT == 9){//with tEXt::key
    	ret = gdk_pixbuf_save(pixbuf,FILENAME,FORMAT,&perrorbuf,"x_hot",OPTVALUE,"y_hot",OPTVALUE,NULL);
    }
    if(EXP_RES == TRUE){
    	if(ret == FALSE){
    		TEST_FAIL ("\"gdk_pixbuf_save\":error happened!", NULL);
    		return;
    	}
    }else{
    	if(ret == TRUE){
    		TEST_FAIL ("\"gdk_pixbuf_save\":error expected, but do not happen!", NULL);
    		return;
    	}
    	if(perrorbuf == NULL){
    		TEST_FAIL ("\"gdk_pixbuf_save\":error expected, but do not happen!", NULL);
    		return;
    	}
    	if(perrorbuf->domain != EXP_ERR){
    		TEST_FAIL ("\"gdk_pixbuf_save\":not expected error domain!", NULL);
    		return;
    	}
    }
    
    if(pixbuf)
    	g_object_unref(pixbuf);
    if(perrorbuf)
    	g_error_free(perrorbuf);
    free_filename();
    #undef WITHOPT
    #undef OPTVALUE
    #undef FILENAME
    #undef FORMAT
    #undef EXP_RES
    #undef EXP_ERR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_pixbuf_save
 * Params: GdkPixbuf * pixbuf, const char * filename, const char * type, GError ** error
 * Returns: gboolean
 * Assertion: Saves pixbuf to a file in format type. By default, "jpeg", "png" and "ico" are possible file formats to save in, but more formats may be installed. The list of all writable formats can be determined in the following way.
 * Params values: pixbuf : a GdkPixbuf, filename : name of file to save, type : name of file format, error : return location for error, or NULL 
 * Expected: whether an error was set
 *   
 */
static void test_purpose_2()
{
    #define WITHOPT				0
    #define OPTVALUE			""
    #define FILENAME			file_png()
    #define FORMAT 				"png"
    #define EXP_RES				TRUE
    #define EXP_ERR				0
    
    GdkPixbuf * pixbuf = NULL;
    gboolean ret = FALSE;
    GError * perrorbuf = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if(strcmp(FORMAT,"ico") == 0 && EXP_RES == TRUE)
    	pixbuf = gdk_pixbuf_new_from_file(read_in_small_file(),NULL);
    else
    	pixbuf = gdk_pixbuf_new_from_file(read_in_file(),NULL);
    if(pixbuf == NULL){
    	TEST_FAIL ("\"gdk_pixbuf_save\":pixbuf is NULL!", NULL);
    	return;
    }
    free_filename();
    
    if(WITHOPT == 0){//no optional params
    	ret = gdk_pixbuf_save(pixbuf,FILENAME,FORMAT,&perrorbuf,NULL);
    }
    if(WITHOPT == 6){//with quality
    	ret = gdk_pixbuf_save(pixbuf,FILENAME,FORMAT,&perrorbuf,"quality",OPTVALUE,NULL);
    }
    if(WITHOPT == 7){//with tEXt::key
    	ret = gdk_pixbuf_save(pixbuf,FILENAME,FORMAT,&perrorbuf,"tEXt::key",OPTVALUE,NULL);
    }
    if(WITHOPT == 8){//with tEXt::key
    	ret = gdk_pixbuf_save(pixbuf,FILENAME,FORMAT,&perrorbuf,"depth",OPTVALUE,NULL);
    }
    if(WITHOPT == 9){//with tEXt::key
    	ret = gdk_pixbuf_save(pixbuf,FILENAME,FORMAT,&perrorbuf,"x_hot",OPTVALUE,"y_hot",OPTVALUE,NULL);
    }
    if(EXP_RES == TRUE){
    	if(ret == FALSE){
    		TEST_FAIL ("\"gdk_pixbuf_save\":error happened!", NULL);
    		return;
    	}
    }else{
    	if(ret == TRUE){
    		TEST_FAIL ("\"gdk_pixbuf_save\":error expected, but do not happen!", NULL);
    		return;
    	}
    	if(perrorbuf == NULL){
    		TEST_FAIL ("\"gdk_pixbuf_save\":error expected, but do not happen!", NULL);
    		return;
    	}
    	if(perrorbuf->domain != EXP_ERR){
    		TEST_FAIL ("\"gdk_pixbuf_save\":not expected error domain!", NULL);
    		return;
    	}
    }
    
    if(pixbuf)
    	g_object_unref(pixbuf);
    if(perrorbuf)
    	g_error_free(perrorbuf);
    free_filename();
    #undef WITHOPT
    #undef OPTVALUE
    #undef FILENAME
    #undef FORMAT
    #undef EXP_RES
    #undef EXP_ERR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_pixbuf_save
 * Params: GdkPixbuf * pixbuf, const char * filename, const char * type, GError ** error
 * Returns: gboolean
 * Assertion: Saves pixbuf to a file in format type. By default, "jpeg", "png" and "ico" are possible file formats to save in, but more formats may be installed. The list of all writable formats can be determined in the following way.
 * Params values: pixbuf : a GdkPixbuf, filename : name of file to save, type : name of file format, error : return location for error, or NULL 
 * Expected: whether an error was set
 *   
 */
static void test_purpose_3()
{
    #define WITHOPT				0
    #define OPTVALUE			""
    #define FILENAME			file_ico()
    #define FORMAT 				"ico"
    #define EXP_RES				TRUE
    #define EXP_ERR				0
    
    GdkPixbuf * pixbuf = NULL;
    gboolean ret = FALSE;
    GError * perrorbuf = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if(strcmp(FORMAT,"ico") == 0 && EXP_RES == TRUE)
    	pixbuf = gdk_pixbuf_new_from_file(read_in_small_file(),NULL);
    else
    	pixbuf = gdk_pixbuf_new_from_file(read_in_file(),NULL);
    if(pixbuf == NULL){
    	TEST_FAIL ("\"gdk_pixbuf_save\":pixbuf is NULL!", NULL);
    	return;
    }
    free_filename();
    
    if(WITHOPT == 0){//no optional params
    	ret = gdk_pixbuf_save(pixbuf,FILENAME,FORMAT,&perrorbuf,NULL);
    }
    if(WITHOPT == 6){//with quality
    	ret = gdk_pixbuf_save(pixbuf,FILENAME,FORMAT,&perrorbuf,"quality",OPTVALUE,NULL);
    }
    if(WITHOPT == 7){//with tEXt::key
    	ret = gdk_pixbuf_save(pixbuf,FILENAME,FORMAT,&perrorbuf,"tEXt::key",OPTVALUE,NULL);
    }
    if(WITHOPT == 8){//with tEXt::key
    	ret = gdk_pixbuf_save(pixbuf,FILENAME,FORMAT,&perrorbuf,"depth",OPTVALUE,NULL);
    }
    if(WITHOPT == 9){//with tEXt::key
    	ret = gdk_pixbuf_save(pixbuf,FILENAME,FORMAT,&perrorbuf,"x_hot",OPTVALUE,"y_hot",OPTVALUE,NULL);
    }
    if(EXP_RES == TRUE){
    	if(ret == FALSE){
    		TEST_FAIL ("\"gdk_pixbuf_save\":error happened!", NULL);
    		return;
    	}
    }else{
    	if(ret == TRUE){
    		TEST_FAIL ("\"gdk_pixbuf_save\":error expected, but do not happen!", NULL);
    		return;
    	}
    	if(perrorbuf == NULL){
    		TEST_FAIL ("\"gdk_pixbuf_save\":error expected, but do not happen!", NULL);
    		return;
    	}
    	if(perrorbuf->domain != EXP_ERR){
    		TEST_FAIL ("\"gdk_pixbuf_save\":not expected error domain!", NULL);
    		return;
    	}
    }
    
    if(pixbuf)
    	g_object_unref(pixbuf);
    if(perrorbuf)
    	g_error_free(perrorbuf);
    free_filename();
    #undef WITHOPT
    #undef OPTVALUE
    #undef FILENAME
    #undef FORMAT
    #undef EXP_RES
    #undef EXP_ERR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_pixbuf_save
 * Params: GdkPixbuf * pixbuf, const char * filename, const char * type, GError ** error
 * Returns: gboolean
 * Assertion: Saves pixbuf to a file in format type. By default, "jpeg", "png" and "ico" are possible file formats to save in, but more formats may be installed. The list of all writable formats can be determined in the following way.
 * Params values: pixbuf : a GdkPixbuf, filename : name of file to save, type : name of file format, error : return location for error, or NULL 
 * Expected: whether an error was set
 *   
 */
static void test_purpose_4()
{
    #define WITHOPT				0
    #define OPTVALUE			""
    #define FILENAME			file_ico_large()
    #define FORMAT 				"ico"
    #define EXP_RES				FALSE
    #define EXP_ERR				GDK_PIXBUF_ERROR
    
    GdkPixbuf * pixbuf = NULL;
    gboolean ret = FALSE;
    GError * perrorbuf = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if(strcmp(FORMAT,"ico") == 0 && EXP_RES == TRUE)
    	pixbuf = gdk_pixbuf_new_from_file(read_in_small_file(),NULL);
    else
    	pixbuf = gdk_pixbuf_new_from_file(read_in_file(),NULL);
    if(pixbuf == NULL){
    	TEST_FAIL ("\"gdk_pixbuf_save\":pixbuf is NULL!", NULL);
    	return;
    }
    free_filename();
    
    if(WITHOPT == 0){//no optional params
    	ret = gdk_pixbuf_save(pixbuf,FILENAME,FORMAT,&perrorbuf,NULL);
    }
    if(WITHOPT == 6){//with quality
    	ret = gdk_pixbuf_save(pixbuf,FILENAME,FORMAT,&perrorbuf,"quality",OPTVALUE,NULL);
    }
    if(WITHOPT == 7){//with tEXt::key
    	ret = gdk_pixbuf_save(pixbuf,FILENAME,FORMAT,&perrorbuf,"tEXt::key",OPTVALUE,NULL);
    }
    if(WITHOPT == 8){//with tEXt::key
    	ret = gdk_pixbuf_save(pixbuf,FILENAME,FORMAT,&perrorbuf,"depth",OPTVALUE,NULL);
    }
    if(WITHOPT == 9){//with tEXt::key
    	ret = gdk_pixbuf_save(pixbuf,FILENAME,FORMAT,&perrorbuf,"x_hot",OPTVALUE,"y_hot",OPTVALUE,NULL);
    }
    if(EXP_RES == TRUE){
    	if(ret == FALSE){
    		TEST_FAIL ("\"gdk_pixbuf_save\":error happened!", NULL);
    		return;
    	}
    }else{
    	if(ret == TRUE){
    		TEST_FAIL ("\"gdk_pixbuf_save\":error expected, but do not happen!", NULL);
    		return;
    	}
    	if(perrorbuf == NULL){
    		TEST_FAIL ("\"gdk_pixbuf_save\":error expected, but do not happen!", NULL);
    		return;
    	}
    	if(perrorbuf->domain != EXP_ERR){
    		TEST_FAIL ("\"gdk_pixbuf_save\":not expected error domain!", NULL);
    		return;
    	}
    }
    
    if(pixbuf)
    	g_object_unref(pixbuf);
    if(perrorbuf)
    	g_error_free(perrorbuf);
    free_filename();
    #undef WITHOPT
    #undef OPTVALUE
    #undef FILENAME
    #undef FORMAT
    #undef EXP_RES
    #undef EXP_ERR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_pixbuf_save
 * Params: GdkPixbuf * pixbuf, const char * filename, const char * type, GError ** error
 * Returns: gboolean
 * Assertion: Saves pixbuf to a file in format type. By default, "jpeg", "png" and "ico" are possible file formats to save in, but more formats may be installed. The list of all writable formats can be determined in the following way.
 * Params values: pixbuf : a GdkPixbuf, filename : name of file to save, type : name of file format, error : return location for error, or NULL 
 * Expected: whether an error was set
 *   
 */
static void test_purpose_5()
{
    #define WITHOPT				0
    #define OPTVALUE			""
    #define FILENAME			file_xxx()
    #define FORMAT 				"xxx"
    #define EXP_RES				FALSE
    #define EXP_ERR				GDK_PIXBUF_ERROR
    
    GdkPixbuf * pixbuf = NULL;
    gboolean ret = FALSE;
    GError * perrorbuf = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if(strcmp(FORMAT,"ico") == 0 && EXP_RES == TRUE)
    	pixbuf = gdk_pixbuf_new_from_file(read_in_small_file(),NULL);
    else
    	pixbuf = gdk_pixbuf_new_from_file(read_in_file(),NULL);
    if(pixbuf == NULL){
    	TEST_FAIL ("\"gdk_pixbuf_save\":pixbuf is NULL!", NULL);
    	return;
    }
    free_filename();
    
    if(WITHOPT == 0){//no optional params
    	ret = gdk_pixbuf_save(pixbuf,FILENAME,FORMAT,&perrorbuf,NULL);
    }
    if(WITHOPT == 6){//with quality
    	ret = gdk_pixbuf_save(pixbuf,FILENAME,FORMAT,&perrorbuf,"quality",OPTVALUE,NULL);
    }
    if(WITHOPT == 7){//with tEXt::key
    	ret = gdk_pixbuf_save(pixbuf,FILENAME,FORMAT,&perrorbuf,"tEXt::key",OPTVALUE,NULL);
    }
    if(WITHOPT == 8){//with tEXt::key
    	ret = gdk_pixbuf_save(pixbuf,FILENAME,FORMAT,&perrorbuf,"depth",OPTVALUE,NULL);
    }
    if(WITHOPT == 9){//with tEXt::key
    	ret = gdk_pixbuf_save(pixbuf,FILENAME,FORMAT,&perrorbuf,"x_hot",OPTVALUE,"y_hot",OPTVALUE,NULL);
    }
    if(EXP_RES == TRUE){
    	if(ret == FALSE){
    		TEST_FAIL ("\"gdk_pixbuf_save\":error happened!", NULL);
    		return;
    	}
    }else{
    	if(ret == TRUE){
    		TEST_FAIL ("\"gdk_pixbuf_save\":error expected, but do not happen!", NULL);
    		return;
    	}
    	if(perrorbuf == NULL){
    		TEST_FAIL ("\"gdk_pixbuf_save\":error expected, but do not happen!", NULL);
    		return;
    	}
    	if(perrorbuf->domain != EXP_ERR){
    		TEST_FAIL ("\"gdk_pixbuf_save\":not expected error domain!", NULL);
    		return;
    	}
    }
    
    if(pixbuf)
    	g_object_unref(pixbuf);
    if(perrorbuf)
    	g_error_free(perrorbuf);
    free_filename();
    #undef WITHOPT
    #undef OPTVALUE
    #undef FILENAME
    #undef FORMAT
    #undef EXP_RES
    #undef EXP_ERR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_pixbuf_save
 * Params: GdkPixbuf * pixbuf, const char * filename, const char * type, GError ** error
 * Returns: gboolean
 * Assertion: Saves pixbuf to a file in format type. By default, "jpeg", "png" and "ico" are possible file formats to save in, but more formats may be installed. The list of all writable formats can be determined in the following way.
 * Params values: pixbuf : a GdkPixbuf, filename : name of file to save, type : name of file format, error : return location for error, or NULL 
 * Expected: whether an error was set
 *   
 */
static void test_purpose_6()
{
    #define WITHOPT				6
    #define OPTVALUE			"90"
    #define FILENAME			file_jpeg_quality()
    #define FORMAT 				"jpeg"
    #define EXP_RES				TRUE
    #define EXP_ERR				0
    
    GdkPixbuf * pixbuf = NULL;
    gboolean ret = FALSE;
    GError * perrorbuf = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if(strcmp(FORMAT,"ico") == 0 && EXP_RES == TRUE)
    	pixbuf = gdk_pixbuf_new_from_file(read_in_small_file(),NULL);
    else
    	pixbuf = gdk_pixbuf_new_from_file(read_in_file(),NULL);
    if(pixbuf == NULL){
    	TEST_FAIL ("\"gdk_pixbuf_save\":pixbuf is NULL!", NULL);
    	return;
    }
    free_filename();
    
    if(WITHOPT == 0){//no optional params
    	ret = gdk_pixbuf_save(pixbuf,FILENAME,FORMAT,&perrorbuf,NULL);
    }
    if(WITHOPT == 6){//with quality
    	ret = gdk_pixbuf_save(pixbuf,FILENAME,FORMAT,&perrorbuf,"quality",OPTVALUE,NULL);
    }
    if(WITHOPT == 7){//with tEXt::key
    	ret = gdk_pixbuf_save(pixbuf,FILENAME,FORMAT,&perrorbuf,"tEXt::key",OPTVALUE,NULL);
    }
    if(WITHOPT == 8){//with tEXt::key
    	ret = gdk_pixbuf_save(pixbuf,FILENAME,FORMAT,&perrorbuf,"depth",OPTVALUE,NULL);
    }
    if(WITHOPT == 9){//with tEXt::key
    	ret = gdk_pixbuf_save(pixbuf,FILENAME,FORMAT,&perrorbuf,"x_hot",OPTVALUE,"y_hot",OPTVALUE,NULL);
    }
    if(EXP_RES == TRUE){
    	if(ret == FALSE){
    		TEST_FAIL ("\"gdk_pixbuf_save\":error happened!", NULL);
    		return;
    	}
    }else{
    	if(ret == TRUE){
    		TEST_FAIL ("\"gdk_pixbuf_save\":error expected, but do not happen!", NULL);
    		return;
    	}
    	if(perrorbuf == NULL){
    		TEST_FAIL ("\"gdk_pixbuf_save\":error expected, but do not happen!", NULL);
    		return;
    	}
    	if(perrorbuf->domain != EXP_ERR){
    		TEST_FAIL ("\"gdk_pixbuf_save\":not expected error domain!", NULL);
    		return;
    	}
    }
    
    if(pixbuf)
    	g_object_unref(pixbuf);
    if(perrorbuf)
    	g_error_free(perrorbuf);
    free_filename();
    #undef WITHOPT
    #undef OPTVALUE
    #undef FILENAME
    #undef FORMAT
    #undef EXP_RES
    #undef EXP_ERR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_pixbuf_save
 * Params: GdkPixbuf * pixbuf, const char * filename, const char * type, GError ** error
 * Returns: gboolean
 * Assertion: Saves pixbuf to a file in format type. By default, "jpeg", "png" and "ico" are possible file formats to save in, but more formats may be installed. The list of all writable formats can be determined in the following way.
 * Params values: pixbuf : a GdkPixbuf, filename : name of file to save, type : name of file format, error : return location for error, or NULL 
 * Expected: whether an error was set
 *   
 */
static void test_purpose_7()
{
    #define WITHOPT				7
    #define OPTVALUE			"70"
    #define FILENAME			file_png_text()
    #define FORMAT 				"png"
    #define EXP_RES				TRUE
    #define EXP_ERR				0
    
    GdkPixbuf * pixbuf = NULL;
    gboolean ret = FALSE;
    GError * perrorbuf = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if(strcmp(FORMAT,"ico") == 0 && EXP_RES == TRUE)
    	pixbuf = gdk_pixbuf_new_from_file(read_in_small_file(),NULL);
    else
    	pixbuf = gdk_pixbuf_new_from_file(read_in_file(),NULL);
    if(pixbuf == NULL){
    	TEST_FAIL ("\"gdk_pixbuf_save\":pixbuf is NULL!", NULL);
    	return;
    }
    free_filename();
    
    if(WITHOPT == 0){//no optional params
    	ret = gdk_pixbuf_save(pixbuf,FILENAME,FORMAT,&perrorbuf,NULL);
    }
    if(WITHOPT == 6){//with quality
    	ret = gdk_pixbuf_save(pixbuf,FILENAME,FORMAT,&perrorbuf,"quality",OPTVALUE,NULL);
    }
    if(WITHOPT == 7){//with tEXt::key
    	ret = gdk_pixbuf_save(pixbuf,FILENAME,FORMAT,&perrorbuf,"tEXt::key",OPTVALUE,NULL);
    }
    if(WITHOPT == 8){//with tEXt::key
    	ret = gdk_pixbuf_save(pixbuf,FILENAME,FORMAT,&perrorbuf,"depth",OPTVALUE,NULL);
    }
    if(WITHOPT == 9){//with tEXt::key
    	ret = gdk_pixbuf_save(pixbuf,FILENAME,FORMAT,&perrorbuf,"x_hot",OPTVALUE,"y_hot",OPTVALUE,NULL);
    }
    if(EXP_RES == TRUE){
    	if(ret == FALSE){
    		TEST_FAIL ("\"gdk_pixbuf_save\":error happened!", NULL);
    		return;
    	}
    }else{
    	if(ret == TRUE){
    		TEST_FAIL ("\"gdk_pixbuf_save\":error expected, but do not happen!", NULL);
    		return;
    	}
    	if(perrorbuf == NULL){
    		TEST_FAIL ("\"gdk_pixbuf_save\":error expected, but do not happen!", NULL);
    		return;
    	}
    	if(perrorbuf->domain != EXP_ERR){
    		TEST_FAIL ("\"gdk_pixbuf_save\":not expected error domain!", NULL);
    		return;
    	}
    }
    
    if(pixbuf)
    	g_object_unref(pixbuf);
    if(perrorbuf)
    	g_error_free(perrorbuf);
    free_filename();
    #undef WITHOPT
    #undef OPTVALUE
    #undef FILENAME
    #undef FORMAT
    #undef EXP_RES
    #undef EXP_ERR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_pixbuf_save
 * Params: GdkPixbuf * pixbuf, const char * filename, const char * type, GError ** error
 * Returns: gboolean
 * Assertion: Saves pixbuf to a file in format type. By default, "jpeg", "png" and "ico" are possible file formats to save in, but more formats may be installed. The list of all writable formats can be determined in the following way.
 * Params values: pixbuf : a GdkPixbuf, filename : name of file to save, type : name of file format, error : return location for error, or NULL 
 * Expected: whether an error was set
 *   
 */
static void test_purpose_8()
{
    #define WITHOPT				8
    #define OPTVALUE			"16"
    #define FILENAME			file_ico_16()
    #define FORMAT 				"ico"
    #define EXP_RES				TRUE
    #define EXP_ERR				0
    
    GdkPixbuf * pixbuf = NULL;
    gboolean ret = FALSE;
    GError * perrorbuf = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if(strcmp(FORMAT,"ico") == 0 && EXP_RES == TRUE)
    	pixbuf = gdk_pixbuf_new_from_file(read_in_small_file(),NULL);
    else
    	pixbuf = gdk_pixbuf_new_from_file(read_in_file(),NULL);
    if(pixbuf == NULL){
    	TEST_FAIL ("\"gdk_pixbuf_save\":pixbuf is NULL!", NULL);
    	return;
    }
    free_filename();
    
    if(WITHOPT == 0){//no optional params
    	ret = gdk_pixbuf_save(pixbuf,FILENAME,FORMAT,&perrorbuf,NULL);
    }
    if(WITHOPT == 6){//with quality
    	ret = gdk_pixbuf_save(pixbuf,FILENAME,FORMAT,&perrorbuf,"quality",OPTVALUE,NULL);
    }
    if(WITHOPT == 7){//with tEXt::key
    	ret = gdk_pixbuf_save(pixbuf,FILENAME,FORMAT,&perrorbuf,"tEXt::key",OPTVALUE,NULL);
    }
    if(WITHOPT == 8){//with tEXt::key
    	ret = gdk_pixbuf_save(pixbuf,FILENAME,FORMAT,&perrorbuf,"depth",OPTVALUE,NULL);
    }
    if(WITHOPT == 9){//with tEXt::key
    	ret = gdk_pixbuf_save(pixbuf,FILENAME,FORMAT,&perrorbuf,"x_hot",OPTVALUE,"y_hot",OPTVALUE,NULL);
    }
    if(EXP_RES == TRUE){
    	if(ret == FALSE){
    		TEST_FAIL ("\"gdk_pixbuf_save\":error happened!", NULL);
    		return;
    	}
    }else{
    	if(ret == TRUE){
    		TEST_FAIL ("\"gdk_pixbuf_save\":error expected, but do not happen!", NULL);
    		return;
    	}
    	if(perrorbuf == NULL){
    		TEST_FAIL ("\"gdk_pixbuf_save\":error expected, but do not happen!", NULL);
    		return;
    	}
    	if(perrorbuf->domain != EXP_ERR){
    		TEST_FAIL ("\"gdk_pixbuf_save\":not expected error domain!", NULL);
    		return;
    	}
    }
    
    if(pixbuf)
    	g_object_unref(pixbuf);
    if(perrorbuf)
    	g_error_free(perrorbuf);
    free_filename();
    #undef WITHOPT
    #undef OPTVALUE
    #undef FILENAME
    #undef FORMAT
    #undef EXP_RES
    #undef EXP_ERR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_pixbuf_save
 * Params: GdkPixbuf * pixbuf, const char * filename, const char * type, GError ** error
 * Returns: gboolean
 * Assertion: Saves pixbuf to a file in format type. By default, "jpeg", "png" and "ico" are possible file formats to save in, but more formats may be installed. The list of all writable formats can be determined in the following way.
 * Params values: pixbuf : a GdkPixbuf, filename : name of file to save, type : name of file format, error : return location for error, or NULL 
 * Expected: whether an error was set
 *   
 */
static void test_purpose_9()
{
    #define WITHOPT				8
    #define OPTVALUE			"24"
    #define FILENAME			file_ico_24()
    #define FORMAT 				"ico"
    #define EXP_RES				TRUE
    #define EXP_ERR				0
    
    GdkPixbuf * pixbuf = NULL;
    gboolean ret = FALSE;
    GError * perrorbuf = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if(strcmp(FORMAT,"ico") == 0 && EXP_RES == TRUE)
    	pixbuf = gdk_pixbuf_new_from_file(read_in_small_file(),NULL);
    else
    	pixbuf = gdk_pixbuf_new_from_file(read_in_file(),NULL);
    if(pixbuf == NULL){
    	TEST_FAIL ("\"gdk_pixbuf_save\":pixbuf is NULL!", NULL);
    	return;
    }
    free_filename();
    
    if(WITHOPT == 0){//no optional params
    	ret = gdk_pixbuf_save(pixbuf,FILENAME,FORMAT,&perrorbuf,NULL);
    }
    if(WITHOPT == 6){//with quality
    	ret = gdk_pixbuf_save(pixbuf,FILENAME,FORMAT,&perrorbuf,"quality",OPTVALUE,NULL);
    }
    if(WITHOPT == 7){//with tEXt::key
    	ret = gdk_pixbuf_save(pixbuf,FILENAME,FORMAT,&perrorbuf,"tEXt::key",OPTVALUE,NULL);
    }
    if(WITHOPT == 8){//with tEXt::key
    	ret = gdk_pixbuf_save(pixbuf,FILENAME,FORMAT,&perrorbuf,"depth",OPTVALUE,NULL);
    }
    if(WITHOPT == 9){//with tEXt::key
    	ret = gdk_pixbuf_save(pixbuf,FILENAME,FORMAT,&perrorbuf,"x_hot",OPTVALUE,"y_hot",OPTVALUE,NULL);
    }
    if(EXP_RES == TRUE){
    	if(ret == FALSE){
    		TEST_FAIL ("\"gdk_pixbuf_save\":error happened!", NULL);
    		return;
    	}
    }else{
    	if(ret == TRUE){
    		TEST_FAIL ("\"gdk_pixbuf_save\":error expected, but do not happen!", NULL);
    		return;
    	}
    	if(perrorbuf == NULL){
    		TEST_FAIL ("\"gdk_pixbuf_save\":error expected, but do not happen!", NULL);
    		return;
    	}
    	if(perrorbuf->domain != EXP_ERR){
    		TEST_FAIL ("\"gdk_pixbuf_save\":not expected error domain!", NULL);
    		return;
    	}
    }
    
    if(pixbuf)
    	g_object_unref(pixbuf);
    if(perrorbuf)
    	g_error_free(perrorbuf);
    free_filename();
    #undef WITHOPT
    #undef OPTVALUE
    #undef FILENAME
    #undef FORMAT
    #undef EXP_RES
    #undef EXP_ERR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_pixbuf_save
 * Params: GdkPixbuf * pixbuf, const char * filename, const char * type, GError ** error
 * Returns: gboolean
 * Assertion: Saves pixbuf to a file in format type. By default, "jpeg", "png" and "ico" are possible file formats to save in, but more formats may be installed. The list of all writable formats can be determined in the following way.
 * Params values: pixbuf : a GdkPixbuf, filename : name of file to save, type : name of file format, error : return location for error, or NULL 
 * Expected: whether an error was set
 *   
 */
static void test_purpose_10()
{
    #define WITHOPT				8
    #define OPTVALUE			"32"
    #define FILENAME			file_ico_32()
    #define FORMAT 				"ico"
    #define EXP_RES				TRUE
    #define EXP_ERR				0
    
    GdkPixbuf * pixbuf = NULL;
    gboolean ret = FALSE;
    GError * perrorbuf = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if(strcmp(FORMAT,"ico") == 0 && EXP_RES == TRUE)
    	pixbuf = gdk_pixbuf_new_from_file(read_in_small_file(),NULL);
    else
    	pixbuf = gdk_pixbuf_new_from_file(read_in_file(),NULL);
    if(pixbuf == NULL){
    	TEST_FAIL ("\"gdk_pixbuf_save\":pixbuf is NULL!", NULL);
    	return;
    }
    free_filename();
    
    if(WITHOPT == 0){//no optional params
    	ret = gdk_pixbuf_save(pixbuf,FILENAME,FORMAT,&perrorbuf,NULL);
    }
    if(WITHOPT == 6){//with quality
    	ret = gdk_pixbuf_save(pixbuf,FILENAME,FORMAT,&perrorbuf,"quality",OPTVALUE,NULL);
    }
    if(WITHOPT == 7){//with tEXt::key
    	ret = gdk_pixbuf_save(pixbuf,FILENAME,FORMAT,&perrorbuf,"tEXt::key",OPTVALUE,NULL);
    }
    if(WITHOPT == 8){//with tEXt::key
    	ret = gdk_pixbuf_save(pixbuf,FILENAME,FORMAT,&perrorbuf,"depth",OPTVALUE,NULL);
    }
    if(WITHOPT == 9){//with tEXt::key
    	ret = gdk_pixbuf_save(pixbuf,FILENAME,FORMAT,&perrorbuf,"x_hot",OPTVALUE,"y_hot",OPTVALUE,NULL);
    }
    if(EXP_RES == TRUE){
    	if(ret == FALSE){
    		TEST_FAIL ("\"gdk_pixbuf_save\":error happened!", NULL);
    		return;
    	}
    }else{
    	if(ret == TRUE){
    		TEST_FAIL ("\"gdk_pixbuf_save\":error expected, but do not happen!", NULL);
    		return;
    	}
    	if(perrorbuf == NULL){
    		TEST_FAIL ("\"gdk_pixbuf_save\":error expected, but do not happen!", NULL);
    		return;
    	}
    	if(perrorbuf->domain != EXP_ERR){
    		TEST_FAIL ("\"gdk_pixbuf_save\":not expected error domain!", NULL);
    		return;
    	}
    }
    
    if(pixbuf)
    	g_object_unref(pixbuf);
    if(perrorbuf)
    	g_error_free(perrorbuf);
    free_filename();
    #undef WITHOPT
    #undef OPTVALUE
    #undef FILENAME
    #undef FORMAT
    #undef EXP_RES
    #undef EXP_ERR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_pixbuf_save
 * Params: GdkPixbuf * pixbuf, const char * filename, const char * type, GError ** error
 * Returns: gboolean
 * Assertion: Saves pixbuf to a file in format type. By default, "jpeg", "png" and "ico" are possible file formats to save in, but more formats may be installed. The list of all writable formats can be determined in the following way.
 * Params values: pixbuf : a GdkPixbuf, filename : name of file to save, type : name of file format, error : return location for error, or NULL 
 * Expected: whether an error was set
 *   
 */
static void test_purpose_11()
{
    #define WITHOPT				9
    #define OPTVALUE			"10"
    #define FILENAME			file_ico_cur()
    #define FORMAT 				"ico"
    #define EXP_RES				TRUE
    #define EXP_ERR				0
    
    GdkPixbuf * pixbuf = NULL;
    gboolean ret = FALSE;
    GError * perrorbuf = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if(strcmp(FORMAT,"ico") == 0 && EXP_RES == TRUE)
    	pixbuf = gdk_pixbuf_new_from_file(read_in_small_file(),NULL);
    else
    	pixbuf = gdk_pixbuf_new_from_file(read_in_file(),NULL);
    if(pixbuf == NULL){
    	TEST_FAIL ("\"gdk_pixbuf_save\":pixbuf is NULL!", NULL);
    	return;
    }
    free_filename();
    
    if(WITHOPT == 0){//no optional params
    	ret = gdk_pixbuf_save(pixbuf,FILENAME,FORMAT,&perrorbuf,NULL);
    }
    if(WITHOPT == 6){//with quality
    	ret = gdk_pixbuf_save(pixbuf,FILENAME,FORMAT,&perrorbuf,"quality",OPTVALUE,NULL);
    }
    if(WITHOPT == 7){//with tEXt::key
    	ret = gdk_pixbuf_save(pixbuf,FILENAME,FORMAT,&perrorbuf,"tEXt::key",OPTVALUE,NULL);
    }
    if(WITHOPT == 8){//with tEXt::key
    	ret = gdk_pixbuf_save(pixbuf,FILENAME,FORMAT,&perrorbuf,"depth",OPTVALUE,NULL);
    }
    if(WITHOPT == 9){//with tEXt::key
    	ret = gdk_pixbuf_save(pixbuf,FILENAME,FORMAT,&perrorbuf,"x_hot",OPTVALUE,"y_hot",OPTVALUE,NULL);
    }
    if(EXP_RES == TRUE){
    	if(ret == FALSE){
    		TEST_FAIL ("\"gdk_pixbuf_save\":error happened!", NULL);
    		return;
    	}
    }else{
    	if(ret == TRUE){
    		TEST_FAIL ("\"gdk_pixbuf_save\":error expected, but do not happen!", NULL);
    		return;
    	}
    	if(perrorbuf == NULL){
    		TEST_FAIL ("\"gdk_pixbuf_save\":error expected, but do not happen!", NULL);
    		return;
    	}
    	if(perrorbuf->domain != EXP_ERR){
    		TEST_FAIL ("\"gdk_pixbuf_save\":not expected error domain!", NULL);
    		return;
    	}
    }
    
    if(pixbuf)
    	g_object_unref(pixbuf);
    if(perrorbuf)
    	g_error_free(perrorbuf);
    free_filename();
    #undef WITHOPT
    #undef OPTVALUE
    #undef FILENAME
    #undef FORMAT
    #undef EXP_RES
    #undef EXP_ERR
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GdkPixbufFileSaving ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {test_purpose_11, 1},
    {NULL,0}
};
