/*
 * GtkAccelLabel methods tests
 * Testing GtkAccelLabel methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;

static gint global_result;

void
global_set_result ()
{
    global_result++;
}  


/*
 * Name: gtk_accel_label_new
 * Params: const gchar *string
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkAccelLabel.
 * Params Values: 	    ""
 * Expected: GtkAccelLabel*  
 */
static void test_purpose_1()
{
    #define STRING  	    ""
    
    gchar *string;
    GtkWidget *widget;
    GtkWidget *window; 
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    string = STRING;
    
    widget = gtk_accel_label_new (STRING);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_ACCEL_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STRING 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accel_label_new
 * Params: const gchar *string
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkAccelLabel.
 * Params Values: 	    " "
 * Expected: GtkAccelLabel*  
 */
static void test_purpose_2()
{
    #define STRING  	    " "
    
    gchar *string;
    GtkWidget *widget;
    GtkWidget *window; 
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    string = STRING;
    
    widget = gtk_accel_label_new (STRING);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_ACCEL_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STRING 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accel_label_new
 * Params: const gchar *string
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkAccelLabel.
 * Params Values: 	    "   "
 * Expected: GtkAccelLabel*  
 */
static void test_purpose_3()
{
    #define STRING  	    "   "
    
    gchar *string;
    GtkWidget *widget;
    GtkWidget *window; 
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    string = STRING;
    
    widget = gtk_accel_label_new (STRING);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_ACCEL_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STRING 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accel_label_new
 * Params: const gchar *string
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkAccelLabel.
 * Params Values: 	    "Label String"
 * Expected: GtkAccelLabel*  
 */
static void test_purpose_4()
{
    #define STRING  	    "Label String"
    
    gchar *string;
    GtkWidget *widget;
    GtkWidget *window; 
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    string = STRING;
    
    widget = gtk_accel_label_new (STRING);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_ACCEL_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STRING 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accel_label_new
 * Params: const gchar *string
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkAccelLabel.
 * Params Values: 	    "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
 * Expected: GtkAccelLabel*  
 */
static void test_purpose_5()
{
    #define STRING  	    "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    
    gchar *string;
    GtkWidget *widget;
    GtkWidget *window; 
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    string = STRING;
    
    widget = gtk_accel_label_new (STRING);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_ACCEL_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STRING 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accel_label_new
 * Params: const gchar *string
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkAccelLabel.
 * Params Values: 	    "!@#$%^&*()_+|~=\";:'?<>`/"
 * Expected: GtkAccelLabel*  
 */
static void test_purpose_6()
{
    #define STRING  	    "!@#$%^&*()_+|~=\";:'?<>`/"
    
    gchar *string;
    GtkWidget *widget;
    GtkWidget *window; 
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    string = STRING;
    
    widget = gtk_accel_label_new (STRING);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_ACCEL_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STRING 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accel_label_new
 * Params: const gchar *string
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkAccelLabel.
 * Params Values: 	    "_a_b"
 * Expected: GtkAccelLabel*  
 */
static void test_purpose_7()
{
    #define STRING  	    "_a_b"
    
    gchar *string;
    GtkWidget *widget;
    GtkWidget *window; 
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    string = STRING;
    
    widget = gtk_accel_label_new (STRING);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_ACCEL_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STRING 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accel_label_new
 * Params: const gchar *string
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkAccelLabel.
 * Params Values: 	    "\n\t\""
 * Expected: GtkAccelLabel*  
 */
static void test_purpose_8()
{
    #define STRING  	    "\n\t\""
    
    gchar *string;
    GtkWidget *widget;
    GtkWidget *window; 
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    string = STRING;
    
    widget = gtk_accel_label_new (STRING);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_ACCEL_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STRING 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accel_label_new
 * Params: const gchar *string
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkAccelLabel.
 * Params Values: 	    "_\n\t\""
 * Expected: GtkAccelLabel*  
 */
static void test_purpose_9()
{
    #define STRING  	    "_\n\t\""
    
    gchar *string;
    GtkWidget *widget;
    GtkWidget *window; 
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    string = STRING;
    
    widget = gtk_accel_label_new (STRING);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_ACCEL_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STRING 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accel_label_new
 * Params: const gchar *string
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkAccelLabel.
 * Params Values: 	    "\b"
 * Expected: GtkAccelLabel*  
 */
static void test_purpose_10()
{
    #define STRING  	    "\b"
    
    gchar *string;
    GtkWidget *widget;
    GtkWidget *window; 
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    string = STRING;
    
    widget = gtk_accel_label_new (STRING);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_ACCEL_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STRING 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accel_label_new
 * Params: const gchar *string
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkAccelLabel.
 * Params Values: 	    "_\b"
 * Expected: GtkAccelLabel*  
 */
static void test_purpose_11()
{
    #define STRING  	    "_\b"
    
    gchar *string;
    GtkWidget *widget;
    GtkWidget *window; 
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    string = STRING;
    
    widget = gtk_accel_label_new (STRING);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_ACCEL_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STRING 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accel_label_refetch
 * Params: GtkAccelLabel *accel_label
 * Returns: gboolean
 * Assertion: Recreates the string representing the accelerator keys. 
 * Params Values: newly ceated GtkAccelLabel*
 * Expected:   
 */
static void test_purpose_12()
{
    #define STRING 	    ""
    
    GtkWidget* widget;
    GtkWidget *window; 
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_accel_label_new (STRING);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_ACCEL_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
      
    gtk_accel_label_refetch (GTK_ACCEL_LABEL (widget));
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STRING 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accel_label_get_accel_width
 * Params: GtkAccelLabel *accel_label
 * Returns: guint
 * Assertion: Returns the width needed to display the accelerator key(s).
 * Params Values: a newly created GtkAccelLabel*
 * Expected: guint  
 */
static void test_purpose_13()
{
    gchar *string;
    GtkWidget* widget;
    guint width;
    GtkWidget *window; 
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_accel_label_new ("qw");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_ACCEL_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
      
    width = gtk_accel_label_get_accel_width (GTK_ACCEL_LABEL (widget));
    if (width < 0)
    {
        TEST_FAIL ("width = %d but should be not less than 0", width);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accel_label_set_accel_widget
 * Params: GtkAccelLabel *accel_label, GtkWidget *accel_widget
 * Returns: void
 * Assertion: Sets the widget to be monitored by this accelerator label.
 * Params Values: GtkAccelLabel*, a newly created GtkWidget*
 * Expected: void
 * 
 * Name: gtk_accel_label_get_accel_widget
 * Params: GtkAccelLabel *accel_label
 * Returns: GtkWidget*
 * Assertion: Fetches the widget monitored by this accelerator label.
 * Params Values: a GtkAccelLabel*
 * Expected: GtkWidget* set by gtk_accel_label_set_accel_widget()  
 */
static void test_purpose_14()
{
    #define WIDGET gtk_accel_label_new ("text");
    
    gchar *string;
    GtkWidget* widget;
    GtkWidget* accel_widget;
    GtkWidget* real_accel_widget;
    GtkWidget *window; 
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_accel_label_new ("qw");
    accel_widget = WIDGET;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_ACCEL_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
      
    gtk_accel_label_set_accel_widget (GTK_ACCEL_LABEL (widget), accel_widget);
    real_accel_widget = gtk_accel_label_get_accel_widget (GTK_ACCEL_LABEL (widget));
    if (real_accel_widget != accel_widget)
    {
        TEST_FAIL ("real_accel_widget != accel_widget", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accel_label_set_accel_widget
 * Params: GtkAccelLabel *accel_label, GtkWidget *accel_widget
 * Returns: void
 * Assertion: Sets the widget to be monitored by this accelerator label.
 * Params Values: GtkAccelLabel*, a newly created GtkWidget*
 * Expected: void
 * 
 * Name: gtk_accel_label_get_accel_widget
 * Params: GtkAccelLabel *accel_label
 * Returns: GtkWidget*
 * Assertion: Fetches the widget monitored by this accelerator label.
 * Params Values: a GtkAccelLabel*
 * Expected: GtkWidget* set by gtk_accel_label_set_accel_widget()  
 */
static void test_purpose_15()
{
    #define WIDGET gtk_label_new ("text");
    
    gchar *string;
    GtkWidget* widget;
    GtkWidget* accel_widget;
    GtkWidget* real_accel_widget;
    GtkWidget *window; 
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_accel_label_new ("qw");
    accel_widget = WIDGET;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_ACCEL_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
      
    gtk_accel_label_set_accel_widget (GTK_ACCEL_LABEL (widget), accel_widget);
    real_accel_widget = gtk_accel_label_get_accel_widget (GTK_ACCEL_LABEL (widget));
    if (real_accel_widget != accel_widget)
    {
        TEST_FAIL ("real_accel_widget != accel_widget", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accel_label_set_accel_widget
 * Params: GtkAccelLabel *accel_label, GtkWidget *accel_widget
 * Returns: void
 * Assertion: Sets the widget to be monitored by this accelerator label.
 * Params Values: GtkAccelLabel*, a newly created GtkWidget*
 * Expected: void
 * 
 * Name: gtk_accel_label_get_accel_widget
 * Params: GtkAccelLabel *accel_label
 * Returns: GtkWidget*
 * Assertion: Fetches the widget monitored by this accelerator label.
 * Params Values: a GtkAccelLabel*
 * Expected: GtkWidget* set by gtk_accel_label_set_accel_widget()  
 */
static void test_purpose_16()
{
    #define WIDGET gtk_button_new ();
    
    gchar *string;
    GtkWidget* widget;
    GtkWidget* accel_widget;
    GtkWidget* real_accel_widget;
    GtkWidget *window; 
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_accel_label_new ("qw");
    accel_widget = WIDGET;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_ACCEL_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
      
    gtk_accel_label_set_accel_widget (GTK_ACCEL_LABEL (widget), accel_widget);
    real_accel_widget = gtk_accel_label_get_accel_widget (GTK_ACCEL_LABEL (widget));
    if (real_accel_widget != accel_widget)
    {
        TEST_FAIL ("real_accel_widget != accel_widget", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accel_label_set_accel_widget
 * Params: GtkAccelLabel *accel_label, GtkWidget *accel_widget
 * Returns: void
 * Assertion: Sets the widget to be monitored by this accelerator label.
 * Params Values: GtkAccelLabel*, a newly created GtkWidget*
 * Expected: void
 * 
 * Name: gtk_accel_label_get_accel_widget
 * Params: GtkAccelLabel *accel_label
 * Returns: GtkWidget*
 * Assertion: Fetches the widget monitored by this accelerator label.
 * Params Values: a GtkAccelLabel*
 * Expected: GtkWidget* set by gtk_accel_label_set_accel_widget()  
 */
static void test_purpose_17()
{
    #define WIDGET gtk_color_selection_dialog_new ("text");
    
    gchar *string;
    GtkWidget* widget;
    GtkWidget* accel_widget;
    GtkWidget* real_accel_widget;
    GtkWidget *window; 
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_accel_label_new ("qw");
    accel_widget = WIDGET;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_ACCEL_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
      
    gtk_accel_label_set_accel_widget (GTK_ACCEL_LABEL (widget), accel_widget);
    real_accel_widget = gtk_accel_label_get_accel_widget (GTK_ACCEL_LABEL (widget));
    if (real_accel_widget != accel_widget)
    {
        TEST_FAIL ("real_accel_widget != accel_widget", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accel_label_set_accel_widget
 * Params: GtkAccelLabel *accel_label, GtkWidget *accel_widget
 * Returns: void
 * Assertion: Sets the widget to be monitored by this accelerator label.
 * Params Values: GtkAccelLabel*, a newly created GtkWidget*
 * Expected: void
 * 
 * Name: gtk_accel_label_get_accel_widget
 * Params: GtkAccelLabel *accel_label
 * Returns: GtkWidget*
 * Assertion: Fetches the widget monitored by this accelerator label.
 * Params Values: a GtkAccelLabel*
 * Expected: GtkWidget* set by gtk_accel_label_set_accel_widget()  
 */
static void test_purpose_18()
{
    #define WIDGET gtk_tearoff_menu_item_new ();
    
    gchar *string;
    GtkWidget* widget;
    GtkWidget* accel_widget;
    GtkWidget* real_accel_widget;
    GtkWidget *window; 
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_accel_label_new ("qw");
    accel_widget = WIDGET;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_ACCEL_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
      
    gtk_accel_label_set_accel_widget (GTK_ACCEL_LABEL (widget), accel_widget);
    real_accel_widget = gtk_accel_label_get_accel_widget (GTK_ACCEL_LABEL (widget));
    if (real_accel_widget != accel_widget)
    {
        TEST_FAIL ("real_accel_widget != accel_widget", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_accel_label_set_accel_closure
 * Params: GtkAccelLabel *accel_label, GClosure *accel_closure
 * Returns: void
 * Assertion: Sets the closure to be monitored by this accelerator label. 
 * Params Values: GtkAccelLabel*, GClosure*
 * Expected: void  
 */
static void test_purpose_19()
{
    #define WIDGET <%0%>
    
    gchar *string;
    GtkWidget* widget;
    GClosure* closure;
    GClosure* real_closure;
    GtkAccelGroup* group;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_result = 0;
    
    widget = gtk_accel_label_new ("Text");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_ACCEL_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    group = gtk_accel_group_new ();
    gtk_window_add_accel_group (GTK_WINDOW (window), group);
    
    
    closure = g_cclosure_new ((GCallback)global_set_result, NULL, NULL);
    
    gtk_accel_group_connect (group, GDK_1,0, GTK_ACCEL_VISIBLE, closure);
    
    
    gtk_accel_label_set_accel_closure (GTK_ACCEL_LABEL (widget), closure);
    
    g_object_get (G_OBJECT (widget),"accel-closure",&real_closure,NULL);
    if (closure != real_closure)
    {
        TEST_FAIL ("Wrong closure",NULL);
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GtkAccelLabel ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {test_purpose_11, 1},
    {test_purpose_12, 1},
    {test_purpose_13, 1},
    {test_purpose_14, 1},
    {test_purpose_15, 1},
    {test_purpose_16, 1},
    {test_purpose_17, 1},
    {test_purpose_18, 1},
    {test_purpose_19, 1},
    {NULL,0}
};
