/*
 * GtkArrow methods tests
 * Testing GtkArrow methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;

/*
 * Name: gtk_arrow_new
 * Params: GtkArrowType arrow_type, GtkShadowType shadow_type
 * Returns: GtkArrow*
 * Assertion: Creates a new arrow widget. 
 * Params Values: GTK_ARROW_UP, GTK_SHADOW_NONE
 * Expected: GtkArrow with arrow_type = GTK_ARROW_UP, shadow_type = GTK_SHADOW_NONE  
 */
static void test_purpose_1()
{
    #define ARROW_TYPE GTK_ARROW_UP
    #define SHADOW_TYPE GTK_SHADOW_NONE
    
    GtkArrowType real_arrow_type;
    GtkShadowType real_shadow_type;
    
    GtkWidget *widget;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_arrow_new (ARROW_TYPE, SHADOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ARROW (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get (GTK_OBJECT (widget), "arrow-type", &real_arrow_type, NULL);
    
    if (real_arrow_type != ARROW_TYPE)
    {
        TEST_FAIL ("real_arrow_type = %d, should be %d", real_arrow_type, ARROW_TYPE);
    }
    if (!(real_arrow_type >= GTK_ARROW_UP 
          && real_arrow_type <= GTK_ARROW_RIGHT))
    {
        TEST_FAIL ("real_arrow_type should be %d <= real_arrow_type <= %d", 
                   GTK_ARROW_UP, GTK_ARROW_RIGHT);
    }
    
    
    g_object_get (GTK_OBJECT (widget), "shadow-type", &real_shadow_type, NULL);
    
    if (real_shadow_type != SHADOW_TYPE)
    {
        TEST_FAIL ("real_shadow_type = %d, should be %d", real_shadow_type, SHADOW_TYPE);
    }
    
    if (!(real_shadow_type >= GTK_SHADOW_NONE
          && real_shadow_type <= GTK_SHADOW_ETCHED_OUT))
    {
        TEST_FAIL ("real_shadow_type should be %d <= real_shadow_type <= %d", 
                   GTK_SHADOW_NONE, GTK_SHADOW_ETCHED_OUT);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef ARROW_TYPE
    #undef SHADOW_TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_arrow_new
 * Params: GtkArrowType arrow_type, GtkShadowType shadow_type
 * Returns: GtkArrow*
 * Assertion: Creates a new arrow widget. 
 * Params Values: GTK_ARROW_DOWN, GTK_SHADOW_NONE
 * Expected: GtkArrow with arrow_type = GTK_ARROW_DOWN, shadow_type = GTK_SHADOW_NONE  
 */
static void test_purpose_2()
{
    #define ARROW_TYPE GTK_ARROW_DOWN
    #define SHADOW_TYPE GTK_SHADOW_NONE
    
    GtkArrowType real_arrow_type;
    GtkShadowType real_shadow_type;
    
    GtkWidget *widget;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_arrow_new (ARROW_TYPE, SHADOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ARROW (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get (GTK_OBJECT (widget), "arrow-type", &real_arrow_type, NULL);
    
    if (real_arrow_type != ARROW_TYPE)
    {
        TEST_FAIL ("real_arrow_type = %d, should be %d", real_arrow_type, ARROW_TYPE);
    }
    if (!(real_arrow_type >= GTK_ARROW_UP 
          && real_arrow_type <= GTK_ARROW_RIGHT))
    {
        TEST_FAIL ("real_arrow_type should be %d <= real_arrow_type <= %d", 
                   GTK_ARROW_UP, GTK_ARROW_RIGHT);
    }
    
    
    g_object_get (GTK_OBJECT (widget), "shadow-type", &real_shadow_type, NULL);
    
    if (real_shadow_type != SHADOW_TYPE)
    {
        TEST_FAIL ("real_shadow_type = %d, should be %d", real_shadow_type, SHADOW_TYPE);
    }
    
    if (!(real_shadow_type >= GTK_SHADOW_NONE
          && real_shadow_type <= GTK_SHADOW_ETCHED_OUT))
    {
        TEST_FAIL ("real_shadow_type should be %d <= real_shadow_type <= %d", 
                   GTK_SHADOW_NONE, GTK_SHADOW_ETCHED_OUT);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef ARROW_TYPE
    #undef SHADOW_TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_arrow_new
 * Params: GtkArrowType arrow_type, GtkShadowType shadow_type
 * Returns: GtkArrow*
 * Assertion: Creates a new arrow widget. 
 * Params Values: GTK_ARROW_LEFT, GTK_SHADOW_NONE
 * Expected: GtkArrow with arrow_type = GTK_ARROW_LEFT, shadow_type = GTK_SHADOW_NONE  
 */
static void test_purpose_3()
{
    #define ARROW_TYPE GTK_ARROW_LEFT
    #define SHADOW_TYPE GTK_SHADOW_NONE
    
    GtkArrowType real_arrow_type;
    GtkShadowType real_shadow_type;
    
    GtkWidget *widget;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_arrow_new (ARROW_TYPE, SHADOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ARROW (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get (GTK_OBJECT (widget), "arrow-type", &real_arrow_type, NULL);
    
    if (real_arrow_type != ARROW_TYPE)
    {
        TEST_FAIL ("real_arrow_type = %d, should be %d", real_arrow_type, ARROW_TYPE);
    }
    if (!(real_arrow_type >= GTK_ARROW_UP 
          && real_arrow_type <= GTK_ARROW_RIGHT))
    {
        TEST_FAIL ("real_arrow_type should be %d <= real_arrow_type <= %d", 
                   GTK_ARROW_UP, GTK_ARROW_RIGHT);
    }
    
    
    g_object_get (GTK_OBJECT (widget), "shadow-type", &real_shadow_type, NULL);
    
    if (real_shadow_type != SHADOW_TYPE)
    {
        TEST_FAIL ("real_shadow_type = %d, should be %d", real_shadow_type, SHADOW_TYPE);
    }
    
    if (!(real_shadow_type >= GTK_SHADOW_NONE
          && real_shadow_type <= GTK_SHADOW_ETCHED_OUT))
    {
        TEST_FAIL ("real_shadow_type should be %d <= real_shadow_type <= %d", 
                   GTK_SHADOW_NONE, GTK_SHADOW_ETCHED_OUT);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef ARROW_TYPE
    #undef SHADOW_TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_arrow_new
 * Params: GtkArrowType arrow_type, GtkShadowType shadow_type
 * Returns: GtkArrow*
 * Assertion: Creates a new arrow widget. 
 * Params Values: GTK_ARROW_RIGHT, GTK_SHADOW_NONE
 * Expected: GtkArrow with arrow_type = GTK_ARROW_RIGHT, shadow_type = GTK_SHADOW_NONE  
 */
static void test_purpose_4()
{
    #define ARROW_TYPE GTK_ARROW_RIGHT
    #define SHADOW_TYPE GTK_SHADOW_NONE
    
    GtkArrowType real_arrow_type;
    GtkShadowType real_shadow_type;
    
    GtkWidget *widget;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_arrow_new (ARROW_TYPE, SHADOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ARROW (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get (GTK_OBJECT (widget), "arrow-type", &real_arrow_type, NULL);
    
    if (real_arrow_type != ARROW_TYPE)
    {
        TEST_FAIL ("real_arrow_type = %d, should be %d", real_arrow_type, ARROW_TYPE);
    }
    if (!(real_arrow_type >= GTK_ARROW_UP 
          && real_arrow_type <= GTK_ARROW_RIGHT))
    {
        TEST_FAIL ("real_arrow_type should be %d <= real_arrow_type <= %d", 
                   GTK_ARROW_UP, GTK_ARROW_RIGHT);
    }
    
    
    g_object_get (GTK_OBJECT (widget), "shadow-type", &real_shadow_type, NULL);
    
    if (real_shadow_type != SHADOW_TYPE)
    {
        TEST_FAIL ("real_shadow_type = %d, should be %d", real_shadow_type, SHADOW_TYPE);
    }
    
    if (!(real_shadow_type >= GTK_SHADOW_NONE
          && real_shadow_type <= GTK_SHADOW_ETCHED_OUT))
    {
        TEST_FAIL ("real_shadow_type should be %d <= real_shadow_type <= %d", 
                   GTK_SHADOW_NONE, GTK_SHADOW_ETCHED_OUT);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef ARROW_TYPE
    #undef SHADOW_TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_arrow_new
 * Params: GtkArrowType arrow_type, GtkShadowType shadow_type
 * Returns: GtkArrow*
 * Assertion: Creates a new arrow widget. 
 * Params Values: GTK_ARROW_UP, GTK_SHADOW_NONE
 * Expected: GtkArrow with arrow_type = GTK_ARROW_UP, shadow_type = GTK_SHADOW_NONE  
 */
static void test_purpose_5()
{
    #define ARROW_TYPE GTK_ARROW_UP
    #define SHADOW_TYPE GTK_SHADOW_NONE
    
    GtkArrowType real_arrow_type;
    GtkShadowType real_shadow_type;
    
    GtkWidget *widget;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_arrow_new (ARROW_TYPE, SHADOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ARROW (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get (GTK_OBJECT (widget), "arrow-type", &real_arrow_type, NULL);
    
    if (real_arrow_type != ARROW_TYPE)
    {
        TEST_FAIL ("real_arrow_type = %d, should be %d", real_arrow_type, ARROW_TYPE);
    }
    if (!(real_arrow_type >= GTK_ARROW_UP 
          && real_arrow_type <= GTK_ARROW_RIGHT))
    {
        TEST_FAIL ("real_arrow_type should be %d <= real_arrow_type <= %d", 
                   GTK_ARROW_UP, GTK_ARROW_RIGHT);
    }
    
    
    g_object_get (GTK_OBJECT (widget), "shadow-type", &real_shadow_type, NULL);
    
    if (real_shadow_type != SHADOW_TYPE)
    {
        TEST_FAIL ("real_shadow_type = %d, should be %d", real_shadow_type, SHADOW_TYPE);
    }
    
    if (!(real_shadow_type >= GTK_SHADOW_NONE
          && real_shadow_type <= GTK_SHADOW_ETCHED_OUT))
    {
        TEST_FAIL ("real_shadow_type should be %d <= real_shadow_type <= %d", 
                   GTK_SHADOW_NONE, GTK_SHADOW_ETCHED_OUT);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef ARROW_TYPE
    #undef SHADOW_TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_arrow_new
 * Params: GtkArrowType arrow_type, GtkShadowType shadow_type
 * Returns: GtkArrow*
 * Assertion: Creates a new arrow widget. 
 * Params Values: GTK_ARROW_UP, GTK_SHADOW_IN
 * Expected: GtkArrow with arrow_type = GTK_ARROW_UP, shadow_type = GTK_SHADOW_IN  
 */
static void test_purpose_6()
{
    #define ARROW_TYPE GTK_ARROW_UP
    #define SHADOW_TYPE GTK_SHADOW_IN
    
    GtkArrowType real_arrow_type;
    GtkShadowType real_shadow_type;
    
    GtkWidget *widget;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_arrow_new (ARROW_TYPE, SHADOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ARROW (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get (GTK_OBJECT (widget), "arrow-type", &real_arrow_type, NULL);
    
    if (real_arrow_type != ARROW_TYPE)
    {
        TEST_FAIL ("real_arrow_type = %d, should be %d", real_arrow_type, ARROW_TYPE);
    }
    if (!(real_arrow_type >= GTK_ARROW_UP 
          && real_arrow_type <= GTK_ARROW_RIGHT))
    {
        TEST_FAIL ("real_arrow_type should be %d <= real_arrow_type <= %d", 
                   GTK_ARROW_UP, GTK_ARROW_RIGHT);
    }
    
    
    g_object_get (GTK_OBJECT (widget), "shadow-type", &real_shadow_type, NULL);
    
    if (real_shadow_type != SHADOW_TYPE)
    {
        TEST_FAIL ("real_shadow_type = %d, should be %d", real_shadow_type, SHADOW_TYPE);
    }
    
    if (!(real_shadow_type >= GTK_SHADOW_NONE
          && real_shadow_type <= GTK_SHADOW_ETCHED_OUT))
    {
        TEST_FAIL ("real_shadow_type should be %d <= real_shadow_type <= %d", 
                   GTK_SHADOW_NONE, GTK_SHADOW_ETCHED_OUT);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef ARROW_TYPE
    #undef SHADOW_TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_arrow_new
 * Params: GtkArrowType arrow_type, GtkShadowType shadow_type
 * Returns: GtkArrow*
 * Assertion: Creates a new arrow widget. 
 * Params Values: GTK_ARROW_UP, GTK_SHADOW_OUT
 * Expected: GtkArrow with arrow_type = GTK_ARROW_UP, shadow_type = GTK_SHADOW_OUT  
 */
static void test_purpose_7()
{
    #define ARROW_TYPE GTK_ARROW_UP
    #define SHADOW_TYPE GTK_SHADOW_OUT
    
    GtkArrowType real_arrow_type;
    GtkShadowType real_shadow_type;
    
    GtkWidget *widget;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_arrow_new (ARROW_TYPE, SHADOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ARROW (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get (GTK_OBJECT (widget), "arrow-type", &real_arrow_type, NULL);
    
    if (real_arrow_type != ARROW_TYPE)
    {
        TEST_FAIL ("real_arrow_type = %d, should be %d", real_arrow_type, ARROW_TYPE);
    }
    if (!(real_arrow_type >= GTK_ARROW_UP 
          && real_arrow_type <= GTK_ARROW_RIGHT))
    {
        TEST_FAIL ("real_arrow_type should be %d <= real_arrow_type <= %d", 
                   GTK_ARROW_UP, GTK_ARROW_RIGHT);
    }
    
    
    g_object_get (GTK_OBJECT (widget), "shadow-type", &real_shadow_type, NULL);
    
    if (real_shadow_type != SHADOW_TYPE)
    {
        TEST_FAIL ("real_shadow_type = %d, should be %d", real_shadow_type, SHADOW_TYPE);
    }
    
    if (!(real_shadow_type >= GTK_SHADOW_NONE
          && real_shadow_type <= GTK_SHADOW_ETCHED_OUT))
    {
        TEST_FAIL ("real_shadow_type should be %d <= real_shadow_type <= %d", 
                   GTK_SHADOW_NONE, GTK_SHADOW_ETCHED_OUT);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef ARROW_TYPE
    #undef SHADOW_TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_arrow_new
 * Params: GtkArrowType arrow_type, GtkShadowType shadow_type
 * Returns: GtkArrow*
 * Assertion: Creates a new arrow widget. 
 * Params Values: GTK_ARROW_UP, GTK_SHADOW_ETCHED_IN
 * Expected: GtkArrow with arrow_type = GTK_ARROW_UP, shadow_type = GTK_SHADOW_ETCHED_IN  
 */
static void test_purpose_8()
{
    #define ARROW_TYPE GTK_ARROW_UP
    #define SHADOW_TYPE GTK_SHADOW_ETCHED_IN
    
    GtkArrowType real_arrow_type;
    GtkShadowType real_shadow_type;
    
    GtkWidget *widget;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_arrow_new (ARROW_TYPE, SHADOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ARROW (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get (GTK_OBJECT (widget), "arrow-type", &real_arrow_type, NULL);
    
    if (real_arrow_type != ARROW_TYPE)
    {
        TEST_FAIL ("real_arrow_type = %d, should be %d", real_arrow_type, ARROW_TYPE);
    }
    if (!(real_arrow_type >= GTK_ARROW_UP 
          && real_arrow_type <= GTK_ARROW_RIGHT))
    {
        TEST_FAIL ("real_arrow_type should be %d <= real_arrow_type <= %d", 
                   GTK_ARROW_UP, GTK_ARROW_RIGHT);
    }
    
    
    g_object_get (GTK_OBJECT (widget), "shadow-type", &real_shadow_type, NULL);
    
    if (real_shadow_type != SHADOW_TYPE)
    {
        TEST_FAIL ("real_shadow_type = %d, should be %d", real_shadow_type, SHADOW_TYPE);
    }
    
    if (!(real_shadow_type >= GTK_SHADOW_NONE
          && real_shadow_type <= GTK_SHADOW_ETCHED_OUT))
    {
        TEST_FAIL ("real_shadow_type should be %d <= real_shadow_type <= %d", 
                   GTK_SHADOW_NONE, GTK_SHADOW_ETCHED_OUT);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef ARROW_TYPE
    #undef SHADOW_TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_arrow_new
 * Params: GtkArrowType arrow_type, GtkShadowType shadow_type
 * Returns: GtkArrow*
 * Assertion: Creates a new arrow widget. 
 * Params Values: GTK_ARROW_UP, GTK_SHADOW_ETCHED_OUT
 * Expected: GtkArrow with arrow_type = GTK_ARROW_UP, shadow_type = GTK_SHADOW_ETCHED_OUT  
 */
static void test_purpose_9()
{
    #define ARROW_TYPE GTK_ARROW_UP
    #define SHADOW_TYPE GTK_SHADOW_ETCHED_OUT
    
    GtkArrowType real_arrow_type;
    GtkShadowType real_shadow_type;
    
    GtkWidget *widget;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_arrow_new (ARROW_TYPE, SHADOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ARROW (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get (GTK_OBJECT (widget), "arrow-type", &real_arrow_type, NULL);
    
    if (real_arrow_type != ARROW_TYPE)
    {
        TEST_FAIL ("real_arrow_type = %d, should be %d", real_arrow_type, ARROW_TYPE);
    }
    if (!(real_arrow_type >= GTK_ARROW_UP 
          && real_arrow_type <= GTK_ARROW_RIGHT))
    {
        TEST_FAIL ("real_arrow_type should be %d <= real_arrow_type <= %d", 
                   GTK_ARROW_UP, GTK_ARROW_RIGHT);
    }
    
    
    g_object_get (GTK_OBJECT (widget), "shadow-type", &real_shadow_type, NULL);
    
    if (real_shadow_type != SHADOW_TYPE)
    {
        TEST_FAIL ("real_shadow_type = %d, should be %d", real_shadow_type, SHADOW_TYPE);
    }
    
    if (!(real_shadow_type >= GTK_SHADOW_NONE
          && real_shadow_type <= GTK_SHADOW_ETCHED_OUT))
    {
        TEST_FAIL ("real_shadow_type should be %d <= real_shadow_type <= %d", 
                   GTK_SHADOW_NONE, GTK_SHADOW_ETCHED_OUT);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef ARROW_TYPE
    #undef SHADOW_TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_arrow_set
 * Params: GtkArrow *arrow, GtkArrowType arrow_type, GtkShadowType shadow_type
 * Returns: void
 * Assertion: Sets the direction and style of the GtkArrow, arrow. 
 * Params Values: newly created GtkArrow*, GTK_ARROW_UP, GTK_SHADOW_NONE
 * Expected: GtkArrow with arrow_type = GTK_ARROW_UP, shadow_type = GTK_SHADOW_NONE  
 */
static void test_purpose_10()
{
    #define ARROW_TYPE GTK_ARROW_UP
    #define SHADOW_TYPE GTK_SHADOW_NONE
    
    GtkArrowType real_arrow_type;
    GtkShadowType real_shadow_type;
    
    GtkWidget *widget;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_arrow_new (GTK_ARROW_UP, GTK_SHADOW_OUT);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_ARROW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    gtk_arrow_set (GTK_ARROW (widget), ARROW_TYPE, SHADOW_TYPE);
    
    g_object_get (GTK_OBJECT (widget), "arrow-type", &real_arrow_type, NULL);
    
    if (real_arrow_type != ARROW_TYPE)
    {
        TEST_FAIL("GtkArrow arrow type = %i, should be %i", real_arrow_type, ARROW_TYPE);
    }
    
    g_object_get (GTK_OBJECT (widget), "shadow-type", &real_shadow_type, NULL);
    
    if (real_shadow_type != SHADOW_TYPE)
    {
        TEST_FAIL("GtkArrow shadow type = %i, should be %i", real_shadow_type, SHADOW_TYPE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef ARROW_TYPE
    #undef SHADOW_TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_arrow_set
 * Params: GtkArrow *arrow, GtkArrowType arrow_type, GtkShadowType shadow_type
 * Returns: void
 * Assertion: Sets the direction and style of the GtkArrow, arrow. 
 * Params Values: newly created GtkArrow*, GTK_ARROW_DOWN, GTK_SHADOW_NONE
 * Expected: GtkArrow with arrow_type = GTK_ARROW_DOWN, shadow_type = GTK_SHADOW_NONE  
 */
static void test_purpose_11()
{
    #define ARROW_TYPE GTK_ARROW_DOWN
    #define SHADOW_TYPE GTK_SHADOW_NONE
    
    GtkArrowType real_arrow_type;
    GtkShadowType real_shadow_type;
    
    GtkWidget *widget;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_arrow_new (GTK_ARROW_UP, GTK_SHADOW_OUT);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_ARROW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    gtk_arrow_set (GTK_ARROW (widget), ARROW_TYPE, SHADOW_TYPE);
    
    g_object_get (GTK_OBJECT (widget), "arrow-type", &real_arrow_type, NULL);
    
    if (real_arrow_type != ARROW_TYPE)
    {
        TEST_FAIL("GtkArrow arrow type = %i, should be %i", real_arrow_type, ARROW_TYPE);
    }
    
    g_object_get (GTK_OBJECT (widget), "shadow-type", &real_shadow_type, NULL);
    
    if (real_shadow_type != SHADOW_TYPE)
    {
        TEST_FAIL("GtkArrow shadow type = %i, should be %i", real_shadow_type, SHADOW_TYPE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef ARROW_TYPE
    #undef SHADOW_TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_arrow_set
 * Params: GtkArrow *arrow, GtkArrowType arrow_type, GtkShadowType shadow_type
 * Returns: void
 * Assertion: Sets the direction and style of the GtkArrow, arrow. 
 * Params Values: newly created GtkArrow*, GTK_ARROW_LEFT, GTK_SHADOW_NONE
 * Expected: GtkArrow with arrow_type = GTK_ARROW_LEFT, shadow_type = GTK_SHADOW_NONE  
 */
static void test_purpose_12()
{
    #define ARROW_TYPE GTK_ARROW_LEFT
    #define SHADOW_TYPE GTK_SHADOW_NONE
    
    GtkArrowType real_arrow_type;
    GtkShadowType real_shadow_type;
    
    GtkWidget *widget;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_arrow_new (GTK_ARROW_UP, GTK_SHADOW_OUT);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_ARROW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    gtk_arrow_set (GTK_ARROW (widget), ARROW_TYPE, SHADOW_TYPE);
    
    g_object_get (GTK_OBJECT (widget), "arrow-type", &real_arrow_type, NULL);
    
    if (real_arrow_type != ARROW_TYPE)
    {
        TEST_FAIL("GtkArrow arrow type = %i, should be %i", real_arrow_type, ARROW_TYPE);
    }
    
    g_object_get (GTK_OBJECT (widget), "shadow-type", &real_shadow_type, NULL);
    
    if (real_shadow_type != SHADOW_TYPE)
    {
        TEST_FAIL("GtkArrow shadow type = %i, should be %i", real_shadow_type, SHADOW_TYPE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef ARROW_TYPE
    #undef SHADOW_TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_arrow_set
 * Params: GtkArrow *arrow, GtkArrowType arrow_type, GtkShadowType shadow_type
 * Returns: void
 * Assertion: Sets the direction and style of the GtkArrow, arrow. 
 * Params Values: newly created GtkArrow*, GTK_ARROW_RIGHT, GTK_SHADOW_NONE
 * Expected: GtkArrow with arrow_type = GTK_ARROW_RIGHT, shadow_type = GTK_SHADOW_NONE  
 */
static void test_purpose_13()
{
    #define ARROW_TYPE GTK_ARROW_RIGHT
    #define SHADOW_TYPE GTK_SHADOW_NONE
    
    GtkArrowType real_arrow_type;
    GtkShadowType real_shadow_type;
    
    GtkWidget *widget;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_arrow_new (GTK_ARROW_UP, GTK_SHADOW_OUT);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_ARROW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    gtk_arrow_set (GTK_ARROW (widget), ARROW_TYPE, SHADOW_TYPE);
    
    g_object_get (GTK_OBJECT (widget), "arrow-type", &real_arrow_type, NULL);
    
    if (real_arrow_type != ARROW_TYPE)
    {
        TEST_FAIL("GtkArrow arrow type = %i, should be %i", real_arrow_type, ARROW_TYPE);
    }
    
    g_object_get (GTK_OBJECT (widget), "shadow-type", &real_shadow_type, NULL);
    
    if (real_shadow_type != SHADOW_TYPE)
    {
        TEST_FAIL("GtkArrow shadow type = %i, should be %i", real_shadow_type, SHADOW_TYPE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef ARROW_TYPE
    #undef SHADOW_TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_arrow_set
 * Params: GtkArrow *arrow, GtkArrowType arrow_type, GtkShadowType shadow_type
 * Returns: void
 * Assertion: Sets the direction and style of the GtkArrow, arrow. 
 * Params Values: newly created GtkArrow*, GTK_ARROW_UP, GTK_SHADOW_NONE
 * Expected: GtkArrow with arrow_type = GTK_ARROW_UP, shadow_type = GTK_SHADOW_NONE  
 */
static void test_purpose_14()
{
    #define ARROW_TYPE GTK_ARROW_UP
    #define SHADOW_TYPE GTK_SHADOW_NONE
    
    GtkArrowType real_arrow_type;
    GtkShadowType real_shadow_type;
    
    GtkWidget *widget;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_arrow_new (GTK_ARROW_UP, GTK_SHADOW_OUT);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_ARROW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    gtk_arrow_set (GTK_ARROW (widget), ARROW_TYPE, SHADOW_TYPE);
    
    g_object_get (GTK_OBJECT (widget), "arrow-type", &real_arrow_type, NULL);
    
    if (real_arrow_type != ARROW_TYPE)
    {
        TEST_FAIL("GtkArrow arrow type = %i, should be %i", real_arrow_type, ARROW_TYPE);
    }
    
    g_object_get (GTK_OBJECT (widget), "shadow-type", &real_shadow_type, NULL);
    
    if (real_shadow_type != SHADOW_TYPE)
    {
        TEST_FAIL("GtkArrow shadow type = %i, should be %i", real_shadow_type, SHADOW_TYPE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef ARROW_TYPE
    #undef SHADOW_TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_arrow_set
 * Params: GtkArrow *arrow, GtkArrowType arrow_type, GtkShadowType shadow_type
 * Returns: void
 * Assertion: Sets the direction and style of the GtkArrow, arrow. 
 * Params Values: newly created GtkArrow*, GTK_ARROW_UP, GTK_SHADOW_IN
 * Expected: GtkArrow with arrow_type = GTK_ARROW_UP, shadow_type = GTK_SHADOW_IN  
 */
static void test_purpose_15()
{
    #define ARROW_TYPE GTK_ARROW_UP
    #define SHADOW_TYPE GTK_SHADOW_IN
    
    GtkArrowType real_arrow_type;
    GtkShadowType real_shadow_type;
    
    GtkWidget *widget;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_arrow_new (GTK_ARROW_UP, GTK_SHADOW_OUT);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_ARROW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    gtk_arrow_set (GTK_ARROW (widget), ARROW_TYPE, SHADOW_TYPE);
    
    g_object_get (GTK_OBJECT (widget), "arrow-type", &real_arrow_type, NULL);
    
    if (real_arrow_type != ARROW_TYPE)
    {
        TEST_FAIL("GtkArrow arrow type = %i, should be %i", real_arrow_type, ARROW_TYPE);
    }
    
    g_object_get (GTK_OBJECT (widget), "shadow-type", &real_shadow_type, NULL);
    
    if (real_shadow_type != SHADOW_TYPE)
    {
        TEST_FAIL("GtkArrow shadow type = %i, should be %i", real_shadow_type, SHADOW_TYPE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef ARROW_TYPE
    #undef SHADOW_TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_arrow_set
 * Params: GtkArrow *arrow, GtkArrowType arrow_type, GtkShadowType shadow_type
 * Returns: void
 * Assertion: Sets the direction and style of the GtkArrow, arrow. 
 * Params Values: newly created GtkArrow*, GTK_ARROW_UP, GTK_SHADOW_OUT
 * Expected: GtkArrow with arrow_type = GTK_ARROW_UP, shadow_type = GTK_SHADOW_OUT  
 */
static void test_purpose_16()
{
    #define ARROW_TYPE GTK_ARROW_UP
    #define SHADOW_TYPE GTK_SHADOW_OUT
    
    GtkArrowType real_arrow_type;
    GtkShadowType real_shadow_type;
    
    GtkWidget *widget;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_arrow_new (GTK_ARROW_UP, GTK_SHADOW_OUT);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_ARROW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    gtk_arrow_set (GTK_ARROW (widget), ARROW_TYPE, SHADOW_TYPE);
    
    g_object_get (GTK_OBJECT (widget), "arrow-type", &real_arrow_type, NULL);
    
    if (real_arrow_type != ARROW_TYPE)
    {
        TEST_FAIL("GtkArrow arrow type = %i, should be %i", real_arrow_type, ARROW_TYPE);
    }
    
    g_object_get (GTK_OBJECT (widget), "shadow-type", &real_shadow_type, NULL);
    
    if (real_shadow_type != SHADOW_TYPE)
    {
        TEST_FAIL("GtkArrow shadow type = %i, should be %i", real_shadow_type, SHADOW_TYPE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef ARROW_TYPE
    #undef SHADOW_TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_arrow_set
 * Params: GtkArrow *arrow, GtkArrowType arrow_type, GtkShadowType shadow_type
 * Returns: void
 * Assertion: Sets the direction and style of the GtkArrow, arrow. 
 * Params Values: newly created GtkArrow*, GTK_ARROW_UP, GTK_SHADOW_ETCHED_IN
 * Expected: GtkArrow with arrow_type = GTK_ARROW_UP, shadow_type = GTK_SHADOW_ETCHED_IN  
 */
static void test_purpose_17()
{
    #define ARROW_TYPE GTK_ARROW_UP
    #define SHADOW_TYPE GTK_SHADOW_ETCHED_IN
    
    GtkArrowType real_arrow_type;
    GtkShadowType real_shadow_type;
    
    GtkWidget *widget;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_arrow_new (GTK_ARROW_UP, GTK_SHADOW_OUT);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_ARROW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    gtk_arrow_set (GTK_ARROW (widget), ARROW_TYPE, SHADOW_TYPE);
    
    g_object_get (GTK_OBJECT (widget), "arrow-type", &real_arrow_type, NULL);
    
    if (real_arrow_type != ARROW_TYPE)
    {
        TEST_FAIL("GtkArrow arrow type = %i, should be %i", real_arrow_type, ARROW_TYPE);
    }
    
    g_object_get (GTK_OBJECT (widget), "shadow-type", &real_shadow_type, NULL);
    
    if (real_shadow_type != SHADOW_TYPE)
    {
        TEST_FAIL("GtkArrow shadow type = %i, should be %i", real_shadow_type, SHADOW_TYPE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef ARROW_TYPE
    #undef SHADOW_TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_arrow_set
 * Params: GtkArrow *arrow, GtkArrowType arrow_type, GtkShadowType shadow_type
 * Returns: void
 * Assertion: Sets the direction and style of the GtkArrow, arrow. 
 * Params Values: newly created GtkArrow*, GTK_ARROW_UP, GTK_SHADOW_ETCHED_OUT
 * Expected: GtkArrow with arrow_type = GTK_ARROW_UP, shadow_type = GTK_SHADOW_ETCHED_OUT  
 */
static void test_purpose_18()
{
    #define ARROW_TYPE GTK_ARROW_UP
    #define SHADOW_TYPE GTK_SHADOW_ETCHED_OUT
    
    GtkArrowType real_arrow_type;
    GtkShadowType real_shadow_type;
    
    GtkWidget *widget;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_arrow_new (GTK_ARROW_UP, GTK_SHADOW_OUT);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_ARROW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    gtk_arrow_set (GTK_ARROW (widget), ARROW_TYPE, SHADOW_TYPE);
    
    g_object_get (GTK_OBJECT (widget), "arrow-type", &real_arrow_type, NULL);
    
    if (real_arrow_type != ARROW_TYPE)
    {
        TEST_FAIL("GtkArrow arrow type = %i, should be %i", real_arrow_type, ARROW_TYPE);
    }
    
    g_object_get (GTK_OBJECT (widget), "shadow-type", &real_shadow_type, NULL);
    
    if (real_shadow_type != SHADOW_TYPE)
    {
        TEST_FAIL("GtkArrow shadow type = %i, should be %i", real_shadow_type, SHADOW_TYPE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef ARROW_TYPE
    #undef SHADOW_TYPE
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GtkArrow ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {test_purpose_11, 1},
    {test_purpose_12, 1},
    {test_purpose_13, 1},
    {test_purpose_14, 1},
    {test_purpose_15, 1},
    {test_purpose_16, 1},
    {test_purpose_17, 1},
    {test_purpose_18, 1},
    {NULL,0}
};
