/*
 * GtkAspectFrame methods tests
 * Testing GtkAspectFrame methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;

/*
 * Name: gtk_aspect_frame_new
 * Params: const gchar *label, gfloat xalign, gfloat yalign, gfloat ratio, gboolean obey_child
 * Returns: GtkAspectFrame*
 * Assertion: Create a new GtkAspectFrame.
 * Params Values: "Text", 0.0, 0.0, 0.0001, TRUE
 * Expected: GtkAspectFrame* with label = ""Text"", xalign = <%5%>, yalign = <%6%>, ratio = 0.0001, obey_child = TRUE  
 */
static void test_purpose_1()
{
    #define LABEL "Text"
    #define XALIGN 0.0
    #define YALIGN 0.0
    #define RATIO 0.0001
    #define OBEY_CHILD TRUE
    
    GtkWidget *widget;
    
    gfloat real_xalign;
    gfloat real_yalign;
    gfloat real_ratio;
    gboolean real_obey_child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_aspect_frame_new (LABEL, XALIGN, YALIGN, RATIO, OBEY_CHILD);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ASPECT_FRAME (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::xalign", &real_xalign, NULL);
    if (real_xalign != (float) XALIGN)
    {
        TEST_FAIL ("real_xalign is %d, should be %d", real_xalign, XALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::yalign", &real_yalign, NULL);
    if (real_yalign != (float) YALIGN)
    {
        TEST_FAIL ("real_yalign is %d, should be %d", real_yalign, YALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::ratio", &real_ratio, NULL);
    if (real_ratio != (float) RATIO)
    {
        TEST_FAIL ("real_ratio is %d, should be %d", real_ratio, RATIO);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::obey-child", &real_obey_child, NULL);
    if (real_obey_child != OBEY_CHILD)
    {
        TEST_FAIL ("real_obey_child is %d, should be %d", real_obey_child, OBEY_CHILD);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    #undef XALIGN
    #undef YALIGN
    #undef RATIO
    #undef OBEY_CHILD
    
    #undef CORRECT_XALIGN
    #undef CORRECT_YALIGN
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_aspect_frame_new
 * Params: const gchar *label, gfloat xalign, gfloat yalign, gfloat ratio, gboolean obey_child
 * Returns: GtkAspectFrame*
 * Assertion: Create a new GtkAspectFrame.
 * Params Values: "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890", 0.0, 0.0, 0.0001, TRUE
 * Expected: GtkAspectFrame* with label = ""abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"", xalign = <%5%>, yalign = <%6%>, ratio = 0.0001, obey_child = TRUE  
 */
static void test_purpose_2()
{
    #define LABEL "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    #define XALIGN 0.0
    #define YALIGN 0.0
    #define RATIO 0.0001
    #define OBEY_CHILD TRUE
    
    GtkWidget *widget;
    
    gfloat real_xalign;
    gfloat real_yalign;
    gfloat real_ratio;
    gboolean real_obey_child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_aspect_frame_new (LABEL, XALIGN, YALIGN, RATIO, OBEY_CHILD);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ASPECT_FRAME (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::xalign", &real_xalign, NULL);
    if (real_xalign != (float) XALIGN)
    {
        TEST_FAIL ("real_xalign is %d, should be %d", real_xalign, XALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::yalign", &real_yalign, NULL);
    if (real_yalign != (float) YALIGN)
    {
        TEST_FAIL ("real_yalign is %d, should be %d", real_yalign, YALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::ratio", &real_ratio, NULL);
    if (real_ratio != (float) RATIO)
    {
        TEST_FAIL ("real_ratio is %d, should be %d", real_ratio, RATIO);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::obey-child", &real_obey_child, NULL);
    if (real_obey_child != OBEY_CHILD)
    {
        TEST_FAIL ("real_obey_child is %d, should be %d", real_obey_child, OBEY_CHILD);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    #undef XALIGN
    #undef YALIGN
    #undef RATIO
    #undef OBEY_CHILD
    
    #undef CORRECT_XALIGN
    #undef CORRECT_YALIGN
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_aspect_frame_new
 * Params: const gchar *label, gfloat xalign, gfloat yalign, gfloat ratio, gboolean obey_child
 * Returns: GtkAspectFrame*
 * Assertion: Create a new GtkAspectFrame.
 * Params Values: "!@#$%^&*()_+|~=\";:'?<>`/", 0.0, 0.0, 0.0001, TRUE
 * Expected: GtkAspectFrame* with label = ""!@#$%^&*()_+|~=\";:'?<>`/"", xalign = <%5%>, yalign = <%6%>, ratio = 0.0001, obey_child = TRUE  
 */
static void test_purpose_3()
{
    #define LABEL "!@#$%^&*()_+|~=\";:'?<>`/"
    #define XALIGN 0.0
    #define YALIGN 0.0
    #define RATIO 0.0001
    #define OBEY_CHILD TRUE
    
    GtkWidget *widget;
    
    gfloat real_xalign;
    gfloat real_yalign;
    gfloat real_ratio;
    gboolean real_obey_child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_aspect_frame_new (LABEL, XALIGN, YALIGN, RATIO, OBEY_CHILD);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ASPECT_FRAME (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::xalign", &real_xalign, NULL);
    if (real_xalign != (float) XALIGN)
    {
        TEST_FAIL ("real_xalign is %d, should be %d", real_xalign, XALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::yalign", &real_yalign, NULL);
    if (real_yalign != (float) YALIGN)
    {
        TEST_FAIL ("real_yalign is %d, should be %d", real_yalign, YALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::ratio", &real_ratio, NULL);
    if (real_ratio != (float) RATIO)
    {
        TEST_FAIL ("real_ratio is %d, should be %d", real_ratio, RATIO);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::obey-child", &real_obey_child, NULL);
    if (real_obey_child != OBEY_CHILD)
    {
        TEST_FAIL ("real_obey_child is %d, should be %d", real_obey_child, OBEY_CHILD);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    #undef XALIGN
    #undef YALIGN
    #undef RATIO
    #undef OBEY_CHILD
    
    #undef CORRECT_XALIGN
    #undef CORRECT_YALIGN
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_aspect_frame_new
 * Params: const gchar *label, gfloat xalign, gfloat yalign, gfloat ratio, gboolean obey_child
 * Returns: GtkAspectFrame*
 * Assertion: Create a new GtkAspectFrame.
 * Params Values: "\b\n\t", 0.0, 0.0, 0.0001, TRUE
 * Expected: GtkAspectFrame* with label = ""\b\n\t"", xalign = <%5%>, yalign = <%6%>, ratio = 0.0001, obey_child = TRUE  
 */
static void test_purpose_4()
{
    #define LABEL "\b\n\t"
    #define XALIGN 0.0
    #define YALIGN 0.0
    #define RATIO 0.0001
    #define OBEY_CHILD TRUE
    
    GtkWidget *widget;
    
    gfloat real_xalign;
    gfloat real_yalign;
    gfloat real_ratio;
    gboolean real_obey_child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_aspect_frame_new (LABEL, XALIGN, YALIGN, RATIO, OBEY_CHILD);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ASPECT_FRAME (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::xalign", &real_xalign, NULL);
    if (real_xalign != (float) XALIGN)
    {
        TEST_FAIL ("real_xalign is %d, should be %d", real_xalign, XALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::yalign", &real_yalign, NULL);
    if (real_yalign != (float) YALIGN)
    {
        TEST_FAIL ("real_yalign is %d, should be %d", real_yalign, YALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::ratio", &real_ratio, NULL);
    if (real_ratio != (float) RATIO)
    {
        TEST_FAIL ("real_ratio is %d, should be %d", real_ratio, RATIO);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::obey-child", &real_obey_child, NULL);
    if (real_obey_child != OBEY_CHILD)
    {
        TEST_FAIL ("real_obey_child is %d, should be %d", real_obey_child, OBEY_CHILD);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    #undef XALIGN
    #undef YALIGN
    #undef RATIO
    #undef OBEY_CHILD
    
    #undef CORRECT_XALIGN
    #undef CORRECT_YALIGN
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_aspect_frame_new
 * Params: const gchar *label, gfloat xalign, gfloat yalign, gfloat ratio, gboolean obey_child
 * Returns: GtkAspectFrame*
 * Assertion: Create a new GtkAspectFrame.
 * Params Values: " ", 0.0, 0.0, 0.0001, TRUE
 * Expected: GtkAspectFrame* with label = "" "", xalign = <%5%>, yalign = <%6%>, ratio = 0.0001, obey_child = TRUE  
 */
static void test_purpose_5()
{
    #define LABEL " "
    #define XALIGN 0.0
    #define YALIGN 0.0
    #define RATIO 0.0001
    #define OBEY_CHILD TRUE
    
    GtkWidget *widget;
    
    gfloat real_xalign;
    gfloat real_yalign;
    gfloat real_ratio;
    gboolean real_obey_child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_aspect_frame_new (LABEL, XALIGN, YALIGN, RATIO, OBEY_CHILD);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ASPECT_FRAME (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::xalign", &real_xalign, NULL);
    if (real_xalign != (float) XALIGN)
    {
        TEST_FAIL ("real_xalign is %d, should be %d", real_xalign, XALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::yalign", &real_yalign, NULL);
    if (real_yalign != (float) YALIGN)
    {
        TEST_FAIL ("real_yalign is %d, should be %d", real_yalign, YALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::ratio", &real_ratio, NULL);
    if (real_ratio != (float) RATIO)
    {
        TEST_FAIL ("real_ratio is %d, should be %d", real_ratio, RATIO);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::obey-child", &real_obey_child, NULL);
    if (real_obey_child != OBEY_CHILD)
    {
        TEST_FAIL ("real_obey_child is %d, should be %d", real_obey_child, OBEY_CHILD);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    #undef XALIGN
    #undef YALIGN
    #undef RATIO
    #undef OBEY_CHILD
    
    #undef CORRECT_XALIGN
    #undef CORRECT_YALIGN
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_aspect_frame_new
 * Params: const gchar *label, gfloat xalign, gfloat yalign, gfloat ratio, gboolean obey_child
 * Returns: GtkAspectFrame*
 * Assertion: Create a new GtkAspectFrame.
 * Params Values: "", 0.0, 0.0, 0.0001, TRUE
 * Expected: GtkAspectFrame* with label = """", xalign = <%5%>, yalign = <%6%>, ratio = 0.0001, obey_child = TRUE  
 */
static void test_purpose_6()
{
    #define LABEL ""
    #define XALIGN 0.0
    #define YALIGN 0.0
    #define RATIO 0.0001
    #define OBEY_CHILD TRUE
    
    GtkWidget *widget;
    
    gfloat real_xalign;
    gfloat real_yalign;
    gfloat real_ratio;
    gboolean real_obey_child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_aspect_frame_new (LABEL, XALIGN, YALIGN, RATIO, OBEY_CHILD);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ASPECT_FRAME (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::xalign", &real_xalign, NULL);
    if (real_xalign != (float) XALIGN)
    {
        TEST_FAIL ("real_xalign is %d, should be %d", real_xalign, XALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::yalign", &real_yalign, NULL);
    if (real_yalign != (float) YALIGN)
    {
        TEST_FAIL ("real_yalign is %d, should be %d", real_yalign, YALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::ratio", &real_ratio, NULL);
    if (real_ratio != (float) RATIO)
    {
        TEST_FAIL ("real_ratio is %d, should be %d", real_ratio, RATIO);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::obey-child", &real_obey_child, NULL);
    if (real_obey_child != OBEY_CHILD)
    {
        TEST_FAIL ("real_obey_child is %d, should be %d", real_obey_child, OBEY_CHILD);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    #undef XALIGN
    #undef YALIGN
    #undef RATIO
    #undef OBEY_CHILD
    
    #undef CORRECT_XALIGN
    #undef CORRECT_YALIGN
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_aspect_frame_new
 * Params: const gchar *label, gfloat xalign, gfloat yalign, gfloat ratio, gboolean obey_child
 * Returns: GtkAspectFrame*
 * Assertion: Create a new GtkAspectFrame.
 * Params Values: NULL, 0.0, 0.0, 0.0001, TRUE
 * Expected: GtkAspectFrame* with label = "NULL", xalign = <%5%>, yalign = <%6%>, ratio = 0.0001, obey_child = TRUE  
 */
static void test_purpose_7()
{
    #define LABEL NULL
    #define XALIGN 0.0
    #define YALIGN 0.0
    #define RATIO 0.0001
    #define OBEY_CHILD TRUE
    
    GtkWidget *widget;
    
    gfloat real_xalign;
    gfloat real_yalign;
    gfloat real_ratio;
    gboolean real_obey_child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_aspect_frame_new (LABEL, XALIGN, YALIGN, RATIO, OBEY_CHILD);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ASPECT_FRAME (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::xalign", &real_xalign, NULL);
    if (real_xalign != (float) XALIGN)
    {
        TEST_FAIL ("real_xalign is %d, should be %d", real_xalign, XALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::yalign", &real_yalign, NULL);
    if (real_yalign != (float) YALIGN)
    {
        TEST_FAIL ("real_yalign is %d, should be %d", real_yalign, YALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::ratio", &real_ratio, NULL);
    if (real_ratio != (float) RATIO)
    {
        TEST_FAIL ("real_ratio is %d, should be %d", real_ratio, RATIO);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::obey-child", &real_obey_child, NULL);
    if (real_obey_child != OBEY_CHILD)
    {
        TEST_FAIL ("real_obey_child is %d, should be %d", real_obey_child, OBEY_CHILD);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    #undef XALIGN
    #undef YALIGN
    #undef RATIO
    #undef OBEY_CHILD
    
    #undef CORRECT_XALIGN
    #undef CORRECT_YALIGN
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_aspect_frame_new
 * Params: const gchar *label, gfloat xalign, gfloat yalign, gfloat ratio, gboolean obey_child
 * Returns: GtkAspectFrame*
 * Assertion: Create a new GtkAspectFrame.
 * Params Values: "", 0.5, 0.0, 0.0001, TRUE
 * Expected: GtkAspectFrame* with label = """", xalign = <%5%>, yalign = <%6%>, ratio = 0.0001, obey_child = TRUE  
 */
static void test_purpose_8()
{
    #define LABEL ""
    #define XALIGN 0.5
    #define YALIGN 0.0
    #define RATIO 0.0001
    #define OBEY_CHILD TRUE
    
    GtkWidget *widget;
    
    gfloat real_xalign;
    gfloat real_yalign;
    gfloat real_ratio;
    gboolean real_obey_child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_aspect_frame_new (LABEL, XALIGN, YALIGN, RATIO, OBEY_CHILD);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ASPECT_FRAME (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::xalign", &real_xalign, NULL);
    if (real_xalign != (float) XALIGN)
    {
        TEST_FAIL ("real_xalign is %d, should be %d", real_xalign, XALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::yalign", &real_yalign, NULL);
    if (real_yalign != (float) YALIGN)
    {
        TEST_FAIL ("real_yalign is %d, should be %d", real_yalign, YALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::ratio", &real_ratio, NULL);
    if (real_ratio != (float) RATIO)
    {
        TEST_FAIL ("real_ratio is %d, should be %d", real_ratio, RATIO);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::obey-child", &real_obey_child, NULL);
    if (real_obey_child != OBEY_CHILD)
    {
        TEST_FAIL ("real_obey_child is %d, should be %d", real_obey_child, OBEY_CHILD);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    #undef XALIGN
    #undef YALIGN
    #undef RATIO
    #undef OBEY_CHILD
    
    #undef CORRECT_XALIGN
    #undef CORRECT_YALIGN
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_aspect_frame_new
 * Params: const gchar *label, gfloat xalign, gfloat yalign, gfloat ratio, gboolean obey_child
 * Returns: GtkAspectFrame*
 * Assertion: Create a new GtkAspectFrame.
 * Params Values: "", 1.0, 0.0, 0.0001, TRUE
 * Expected: GtkAspectFrame* with label = """", xalign = <%5%>, yalign = <%6%>, ratio = 0.0001, obey_child = TRUE  
 */
static void test_purpose_9()
{
    #define LABEL ""
    #define XALIGN 1.0
    #define YALIGN 0.0
    #define RATIO 0.0001
    #define OBEY_CHILD TRUE
    
    GtkWidget *widget;
    
    gfloat real_xalign;
    gfloat real_yalign;
    gfloat real_ratio;
    gboolean real_obey_child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_aspect_frame_new (LABEL, XALIGN, YALIGN, RATIO, OBEY_CHILD);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ASPECT_FRAME (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::xalign", &real_xalign, NULL);
    if (real_xalign != (float) XALIGN)
    {
        TEST_FAIL ("real_xalign is %d, should be %d", real_xalign, XALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::yalign", &real_yalign, NULL);
    if (real_yalign != (float) YALIGN)
    {
        TEST_FAIL ("real_yalign is %d, should be %d", real_yalign, YALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::ratio", &real_ratio, NULL);
    if (real_ratio != (float) RATIO)
    {
        TEST_FAIL ("real_ratio is %d, should be %d", real_ratio, RATIO);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::obey-child", &real_obey_child, NULL);
    if (real_obey_child != OBEY_CHILD)
    {
        TEST_FAIL ("real_obey_child is %d, should be %d", real_obey_child, OBEY_CHILD);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    #undef XALIGN
    #undef YALIGN
    #undef RATIO
    #undef OBEY_CHILD
    
    #undef CORRECT_XALIGN
    #undef CORRECT_YALIGN
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_aspect_frame_new
 * Params: const gchar *label, gfloat xalign, gfloat yalign, gfloat ratio, gboolean obey_child
 * Returns: GtkAspectFrame*
 * Assertion: Create a new GtkAspectFrame.
 * Params Values: "", 0.0, 0.5, 0.0001, TRUE
 * Expected: GtkAspectFrame* with label = """", xalign = <%5%>, yalign = <%6%>, ratio = 0.0001, obey_child = TRUE  
 */
static void test_purpose_10()
{
    #define LABEL ""
    #define XALIGN 0.0
    #define YALIGN 0.5
    #define RATIO 0.0001
    #define OBEY_CHILD TRUE
    
    GtkWidget *widget;
    
    gfloat real_xalign;
    gfloat real_yalign;
    gfloat real_ratio;
    gboolean real_obey_child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_aspect_frame_new (LABEL, XALIGN, YALIGN, RATIO, OBEY_CHILD);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ASPECT_FRAME (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::xalign", &real_xalign, NULL);
    if (real_xalign != (float) XALIGN)
    {
        TEST_FAIL ("real_xalign is %d, should be %d", real_xalign, XALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::yalign", &real_yalign, NULL);
    if (real_yalign != (float) YALIGN)
    {
        TEST_FAIL ("real_yalign is %d, should be %d", real_yalign, YALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::ratio", &real_ratio, NULL);
    if (real_ratio != (float) RATIO)
    {
        TEST_FAIL ("real_ratio is %d, should be %d", real_ratio, RATIO);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::obey-child", &real_obey_child, NULL);
    if (real_obey_child != OBEY_CHILD)
    {
        TEST_FAIL ("real_obey_child is %d, should be %d", real_obey_child, OBEY_CHILD);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    #undef XALIGN
    #undef YALIGN
    #undef RATIO
    #undef OBEY_CHILD
    
    #undef CORRECT_XALIGN
    #undef CORRECT_YALIGN
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_aspect_frame_new
 * Params: const gchar *label, gfloat xalign, gfloat yalign, gfloat ratio, gboolean obey_child
 * Returns: GtkAspectFrame*
 * Assertion: Create a new GtkAspectFrame.
 * Params Values: "", 0.0, 1.0, 0.0001, TRUE
 * Expected: GtkAspectFrame* with label = """", xalign = <%5%>, yalign = <%6%>, ratio = 0.0001, obey_child = TRUE  
 */
static void test_purpose_11()
{
    #define LABEL ""
    #define XALIGN 0.0
    #define YALIGN 1.0
    #define RATIO 0.0001
    #define OBEY_CHILD TRUE
    
    GtkWidget *widget;
    
    gfloat real_xalign;
    gfloat real_yalign;
    gfloat real_ratio;
    gboolean real_obey_child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_aspect_frame_new (LABEL, XALIGN, YALIGN, RATIO, OBEY_CHILD);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ASPECT_FRAME (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::xalign", &real_xalign, NULL);
    if (real_xalign != (float) XALIGN)
    {
        TEST_FAIL ("real_xalign is %d, should be %d", real_xalign, XALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::yalign", &real_yalign, NULL);
    if (real_yalign != (float) YALIGN)
    {
        TEST_FAIL ("real_yalign is %d, should be %d", real_yalign, YALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::ratio", &real_ratio, NULL);
    if (real_ratio != (float) RATIO)
    {
        TEST_FAIL ("real_ratio is %d, should be %d", real_ratio, RATIO);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::obey-child", &real_obey_child, NULL);
    if (real_obey_child != OBEY_CHILD)
    {
        TEST_FAIL ("real_obey_child is %d, should be %d", real_obey_child, OBEY_CHILD);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    #undef XALIGN
    #undef YALIGN
    #undef RATIO
    #undef OBEY_CHILD
    
    #undef CORRECT_XALIGN
    #undef CORRECT_YALIGN
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_aspect_frame_new
 * Params: const gchar *label, gfloat xalign, gfloat yalign, gfloat ratio, gboolean obey_child
 * Returns: GtkAspectFrame*
 * Assertion: Create a new GtkAspectFrame.
 * Params Values: " ", 0.0, 0.0, 1.0, TRUE
 * Expected: GtkAspectFrame* with label = "" "", xalign = <%5%>, yalign = <%6%>, ratio = 1.0, obey_child = TRUE  
 */
static void test_purpose_12()
{
    #define LABEL " "
    #define XALIGN 0.0
    #define YALIGN 0.0
    #define RATIO 1.0
    #define OBEY_CHILD TRUE
    
    GtkWidget *widget;
    
    gfloat real_xalign;
    gfloat real_yalign;
    gfloat real_ratio;
    gboolean real_obey_child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_aspect_frame_new (LABEL, XALIGN, YALIGN, RATIO, OBEY_CHILD);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ASPECT_FRAME (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::xalign", &real_xalign, NULL);
    if (real_xalign != (float) XALIGN)
    {
        TEST_FAIL ("real_xalign is %d, should be %d", real_xalign, XALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::yalign", &real_yalign, NULL);
    if (real_yalign != (float) YALIGN)
    {
        TEST_FAIL ("real_yalign is %d, should be %d", real_yalign, YALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::ratio", &real_ratio, NULL);
    if (real_ratio != (float) RATIO)
    {
        TEST_FAIL ("real_ratio is %d, should be %d", real_ratio, RATIO);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::obey-child", &real_obey_child, NULL);
    if (real_obey_child != OBEY_CHILD)
    {
        TEST_FAIL ("real_obey_child is %d, should be %d", real_obey_child, OBEY_CHILD);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    #undef XALIGN
    #undef YALIGN
    #undef RATIO
    #undef OBEY_CHILD
    
    #undef CORRECT_XALIGN
    #undef CORRECT_YALIGN
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_aspect_frame_new
 * Params: const gchar *label, gfloat xalign, gfloat yalign, gfloat ratio, gboolean obey_child
 * Returns: GtkAspectFrame*
 * Assertion: Create a new GtkAspectFrame.
 * Params Values: " ", 0.0, 0.0, 100.0, TRUE
 * Expected: GtkAspectFrame* with label = "" "", xalign = <%5%>, yalign = <%6%>, ratio = 100.0, obey_child = TRUE  
 */
static void test_purpose_13()
{
    #define LABEL " "
    #define XALIGN 0.0
    #define YALIGN 0.0
    #define RATIO 100.0
    #define OBEY_CHILD TRUE
    
    GtkWidget *widget;
    
    gfloat real_xalign;
    gfloat real_yalign;
    gfloat real_ratio;
    gboolean real_obey_child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_aspect_frame_new (LABEL, XALIGN, YALIGN, RATIO, OBEY_CHILD);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ASPECT_FRAME (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::xalign", &real_xalign, NULL);
    if (real_xalign != (float) XALIGN)
    {
        TEST_FAIL ("real_xalign is %d, should be %d", real_xalign, XALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::yalign", &real_yalign, NULL);
    if (real_yalign != (float) YALIGN)
    {
        TEST_FAIL ("real_yalign is %d, should be %d", real_yalign, YALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::ratio", &real_ratio, NULL);
    if (real_ratio != (float) RATIO)
    {
        TEST_FAIL ("real_ratio is %d, should be %d", real_ratio, RATIO);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::obey-child", &real_obey_child, NULL);
    if (real_obey_child != OBEY_CHILD)
    {
        TEST_FAIL ("real_obey_child is %d, should be %d", real_obey_child, OBEY_CHILD);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    #undef XALIGN
    #undef YALIGN
    #undef RATIO
    #undef OBEY_CHILD
    
    #undef CORRECT_XALIGN
    #undef CORRECT_YALIGN
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_aspect_frame_new
 * Params: const gchar *label, gfloat xalign, gfloat yalign, gfloat ratio, gboolean obey_child
 * Returns: GtkAspectFrame*
 * Assertion: Create a new GtkAspectFrame.
 * Params Values: " ", 0.0, 0.0, 10000.0, TRUE
 * Expected: GtkAspectFrame* with label = "" "", xalign = <%5%>, yalign = <%6%>, ratio = 10000.0, obey_child = TRUE  
 */
static void test_purpose_14()
{
    #define LABEL " "
    #define XALIGN 0.0
    #define YALIGN 0.0
    #define RATIO 10000.0
    #define OBEY_CHILD TRUE
    
    GtkWidget *widget;
    
    gfloat real_xalign;
    gfloat real_yalign;
    gfloat real_ratio;
    gboolean real_obey_child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_aspect_frame_new (LABEL, XALIGN, YALIGN, RATIO, OBEY_CHILD);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ASPECT_FRAME (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::xalign", &real_xalign, NULL);
    if (real_xalign != (float) XALIGN)
    {
        TEST_FAIL ("real_xalign is %d, should be %d", real_xalign, XALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::yalign", &real_yalign, NULL);
    if (real_yalign != (float) YALIGN)
    {
        TEST_FAIL ("real_yalign is %d, should be %d", real_yalign, YALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::ratio", &real_ratio, NULL);
    if (real_ratio != (float) RATIO)
    {
        TEST_FAIL ("real_ratio is %d, should be %d", real_ratio, RATIO);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::obey-child", &real_obey_child, NULL);
    if (real_obey_child != OBEY_CHILD)
    {
        TEST_FAIL ("real_obey_child is %d, should be %d", real_obey_child, OBEY_CHILD);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    #undef XALIGN
    #undef YALIGN
    #undef RATIO
    #undef OBEY_CHILD
    
    #undef CORRECT_XALIGN
    #undef CORRECT_YALIGN
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_aspect_frame_new
 * Params: const gchar *label, gfloat xalign, gfloat yalign, gfloat ratio, gboolean obey_child
 * Returns: GtkAspectFrame*
 * Assertion: Create a new GtkAspectFrame.
 * Params Values: "", 0.0, 0.0, 0.0001, FALSE
 * Expected: GtkAspectFrame* with label = """", xalign = <%5%>, yalign = <%6%>, ratio = 0.0001, obey_child = FALSE  
 */
static void test_purpose_15()
{
    #define LABEL ""
    #define XALIGN 0.0
    #define YALIGN 0.0
    #define RATIO 0.0001
    #define OBEY_CHILD FALSE
    
    GtkWidget *widget;
    
    gfloat real_xalign;
    gfloat real_yalign;
    gfloat real_ratio;
    gboolean real_obey_child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_aspect_frame_new (LABEL, XALIGN, YALIGN, RATIO, OBEY_CHILD);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ASPECT_FRAME (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::xalign", &real_xalign, NULL);
    if (real_xalign != (float) XALIGN)
    {
        TEST_FAIL ("real_xalign is %d, should be %d", real_xalign, XALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::yalign", &real_yalign, NULL);
    if (real_yalign != (float) YALIGN)
    {
        TEST_FAIL ("real_yalign is %d, should be %d", real_yalign, YALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::ratio", &real_ratio, NULL);
    if (real_ratio != (float) RATIO)
    {
        TEST_FAIL ("real_ratio is %d, should be %d", real_ratio, RATIO);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::obey-child", &real_obey_child, NULL);
    if (real_obey_child != OBEY_CHILD)
    {
        TEST_FAIL ("real_obey_child is %d, should be %d", real_obey_child, OBEY_CHILD);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    #undef XALIGN
    #undef YALIGN
    #undef RATIO
    #undef OBEY_CHILD
    
    #undef CORRECT_XALIGN
    #undef CORRECT_YALIGN
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_aspect_frame_set
 * Params: GtkAspectFrame *aspect_frame, gfloat xalign, gfloat yalign, gfloat ratio, gboolean obey_child
 * Returns: void
 * Assertion: Set parameters for an existing GtkAspectFrame.
 * Params Values:a newly created gtkAspectFrame*, 0.0, 0.0, 0.0001, TRUE
 * Expected: void  
 */
static void test_purpose_16()
{
    #define XALIGN 0.0
    #define YALIGN 0.0
    #define RATIO 0.0001
    #define OBEY_CHILD TRUE
    
    #define CORRECT_XALIGN 1.0
    #define CORRECT_YALIGN 1.0
    #define CORRECT_RATIO 0.001
    #define CORRECT_OBEY_CHILD FALSE
    
    
    GtkWidget *widget;
    
    gfloat real_xalign;
    gfloat real_yalign;
    gfloat real_ratio;
    gboolean real_obey_child;
    
    gfloat real_xalign_c;
    gfloat real_yalign_c;
    gfloat real_ratio_c;
    gboolean real_obey_child_c;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_aspect_frame_new ("", XALIGN, YALIGN, RATIO, OBEY_CHILD);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_ASPECT_FRAME (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::xalign", &real_xalign, NULL);
    if (real_xalign != (float) XALIGN)
    {
        TEST_FAIL ("xalign = %d, should be %d", 
                   real_xalign, XALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::yalign", &real_yalign, NULL);
    if (real_yalign != (float) YALIGN)
    {
        TEST_FAIL ("yalign = %d, should be %d", 
                   real_yalign, YALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::ratio", &real_ratio, NULL);
    if (real_ratio != (float) RATIO)
    {
        TEST_FAIL ("ratio = %d, should be %d", 
                   real_ratio, RATIO);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::obey-child", &real_obey_child, NULL);
    if (real_obey_child != OBEY_CHILD)
    {
        TEST_FAIL ("obey_child = %d, should be %d", 
                   real_obey_child, OBEY_CHILD);
    }
    
    
    
    gtk_aspect_frame_set (GTK_ASPECT_FRAME (widget), 
                          CORRECT_XALIGN, 
                          CORRECT_YALIGN, 
                          CORRECT_RATIO, 
                          CORRECT_OBEY_CHILD);
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::xalign", &real_xalign_c, NULL);
    if (real_xalign_c != (float) CORRECT_XALIGN)
    {
        TEST_FAIL ("xalign = %d, should be %d", 
                   real_xalign_c, CORRECT_XALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::yalign", &real_yalign_c, NULL);
    if (real_yalign_c != (float) CORRECT_YALIGN)
    {
        TEST_FAIL ("yalign = %d, should be %d", 
                   real_yalign_c, CORRECT_YALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::ratio", &real_ratio_c, NULL);
    if (real_ratio_c != (float) CORRECT_RATIO)
    {
        TEST_FAIL ("ratio = %d, should be %d", 
                   real_ratio_c, CORRECT_RATIO);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::obey-child", &real_obey_child_c, NULL);
    if (real_obey_child_c != CORRECT_OBEY_CHILD)
    {
        TEST_FAIL ("obey_child = %d, should be %d", 
                   real_obey_child_c, CORRECT_OBEY_CHILD);
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef XALIGN
    #undef YALIGN
    #undef RATIO
    #undef OBEY_CHILD
    
    #undef CORRECT_XALIGN
    #undef CORRECT_YALIGN
    #undef CORRECT_RATIO
    #undef CORRECT_OBEY_CHILD
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_aspect_frame_set
 * Params: GtkAspectFrame *aspect_frame, gfloat xalign, gfloat yalign, gfloat ratio, gboolean obey_child
 * Returns: void
 * Assertion: Set parameters for an existing GtkAspectFrame.
 * Params Values:a newly created gtkAspectFrame*, 0.0, 0.0, 0.0001, TRUE
 * Expected: void  
 */
static void test_purpose_17()
{
    #define XALIGN 0.0
    #define YALIGN 0.0
    #define RATIO 0.0001
    #define OBEY_CHILD TRUE
    
    #define CORRECT_XALIGN 0.0
    #define CORRECT_YALIGN 0.0
    #define CORRECT_RATIO 0.0001
    #define CORRECT_OBEY_CHILD TRUE
    
    
    GtkWidget *widget;
    
    gfloat real_xalign;
    gfloat real_yalign;
    gfloat real_ratio;
    gboolean real_obey_child;
    
    gfloat real_xalign_c;
    gfloat real_yalign_c;
    gfloat real_ratio_c;
    gboolean real_obey_child_c;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_aspect_frame_new ("", XALIGN, YALIGN, RATIO, OBEY_CHILD);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_ASPECT_FRAME (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::xalign", &real_xalign, NULL);
    if (real_xalign != (float) XALIGN)
    {
        TEST_FAIL ("xalign = %d, should be %d", 
                   real_xalign, XALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::yalign", &real_yalign, NULL);
    if (real_yalign != (float) YALIGN)
    {
        TEST_FAIL ("yalign = %d, should be %d", 
                   real_yalign, YALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::ratio", &real_ratio, NULL);
    if (real_ratio != (float) RATIO)
    {
        TEST_FAIL ("ratio = %d, should be %d", 
                   real_ratio, RATIO);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::obey-child", &real_obey_child, NULL);
    if (real_obey_child != OBEY_CHILD)
    {
        TEST_FAIL ("obey_child = %d, should be %d", 
                   real_obey_child, OBEY_CHILD);
    }
    
    
    
    gtk_aspect_frame_set (GTK_ASPECT_FRAME (widget), 
                          CORRECT_XALIGN, 
                          CORRECT_YALIGN, 
                          CORRECT_RATIO, 
                          CORRECT_OBEY_CHILD);
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::xalign", &real_xalign_c, NULL);
    if (real_xalign_c != (float) CORRECT_XALIGN)
    {
        TEST_FAIL ("xalign = %d, should be %d", 
                   real_xalign_c, CORRECT_XALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::yalign", &real_yalign_c, NULL);
    if (real_yalign_c != (float) CORRECT_YALIGN)
    {
        TEST_FAIL ("yalign = %d, should be %d", 
                   real_yalign_c, CORRECT_YALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::ratio", &real_ratio_c, NULL);
    if (real_ratio_c != (float) CORRECT_RATIO)
    {
        TEST_FAIL ("ratio = %d, should be %d", 
                   real_ratio_c, CORRECT_RATIO);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::obey-child", &real_obey_child_c, NULL);
    if (real_obey_child_c != CORRECT_OBEY_CHILD)
    {
        TEST_FAIL ("obey_child = %d, should be %d", 
                   real_obey_child_c, CORRECT_OBEY_CHILD);
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef XALIGN
    #undef YALIGN
    #undef RATIO
    #undef OBEY_CHILD
    
    #undef CORRECT_XALIGN
    #undef CORRECT_YALIGN
    #undef CORRECT_RATIO
    #undef CORRECT_OBEY_CHILD
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_aspect_frame_set
 * Params: GtkAspectFrame *aspect_frame, gfloat xalign, gfloat yalign, gfloat ratio, gboolean obey_child
 * Returns: void
 * Assertion: Set parameters for an existing GtkAspectFrame.
 * Params Values:a newly created gtkAspectFrame*, 0.0, 0.0, 0.0001, TRUE
 * Expected: void  
 */
static void test_purpose_18()
{
    #define XALIGN 0.0
    #define YALIGN 0.0
    #define RATIO 0.0001
    #define OBEY_CHILD TRUE
    
    #define CORRECT_XALIGN 1.0
    #define CORRECT_YALIGN 0.0
    #define CORRECT_RATIO 0.0001
    #define CORRECT_OBEY_CHILD TRUE
    
    
    GtkWidget *widget;
    
    gfloat real_xalign;
    gfloat real_yalign;
    gfloat real_ratio;
    gboolean real_obey_child;
    
    gfloat real_xalign_c;
    gfloat real_yalign_c;
    gfloat real_ratio_c;
    gboolean real_obey_child_c;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_aspect_frame_new ("", XALIGN, YALIGN, RATIO, OBEY_CHILD);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_ASPECT_FRAME (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::xalign", &real_xalign, NULL);
    if (real_xalign != (float) XALIGN)
    {
        TEST_FAIL ("xalign = %d, should be %d", 
                   real_xalign, XALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::yalign", &real_yalign, NULL);
    if (real_yalign != (float) YALIGN)
    {
        TEST_FAIL ("yalign = %d, should be %d", 
                   real_yalign, YALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::ratio", &real_ratio, NULL);
    if (real_ratio != (float) RATIO)
    {
        TEST_FAIL ("ratio = %d, should be %d", 
                   real_ratio, RATIO);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::obey-child", &real_obey_child, NULL);
    if (real_obey_child != OBEY_CHILD)
    {
        TEST_FAIL ("obey_child = %d, should be %d", 
                   real_obey_child, OBEY_CHILD);
    }
    
    
    
    gtk_aspect_frame_set (GTK_ASPECT_FRAME (widget), 
                          CORRECT_XALIGN, 
                          CORRECT_YALIGN, 
                          CORRECT_RATIO, 
                          CORRECT_OBEY_CHILD);
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::xalign", &real_xalign_c, NULL);
    if (real_xalign_c != (float) CORRECT_XALIGN)
    {
        TEST_FAIL ("xalign = %d, should be %d", 
                   real_xalign_c, CORRECT_XALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::yalign", &real_yalign_c, NULL);
    if (real_yalign_c != (float) CORRECT_YALIGN)
    {
        TEST_FAIL ("yalign = %d, should be %d", 
                   real_yalign_c, CORRECT_YALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::ratio", &real_ratio_c, NULL);
    if (real_ratio_c != (float) CORRECT_RATIO)
    {
        TEST_FAIL ("ratio = %d, should be %d", 
                   real_ratio_c, CORRECT_RATIO);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::obey-child", &real_obey_child_c, NULL);
    if (real_obey_child_c != CORRECT_OBEY_CHILD)
    {
        TEST_FAIL ("obey_child = %d, should be %d", 
                   real_obey_child_c, CORRECT_OBEY_CHILD);
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef XALIGN
    #undef YALIGN
    #undef RATIO
    #undef OBEY_CHILD
    
    #undef CORRECT_XALIGN
    #undef CORRECT_YALIGN
    #undef CORRECT_RATIO
    #undef CORRECT_OBEY_CHILD
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_aspect_frame_set
 * Params: GtkAspectFrame *aspect_frame, gfloat xalign, gfloat yalign, gfloat ratio, gboolean obey_child
 * Returns: void
 * Assertion: Set parameters for an existing GtkAspectFrame.
 * Params Values:a newly created gtkAspectFrame*, 0.0, 0.0, 0.0001, TRUE
 * Expected: void  
 */
static void test_purpose_19()
{
    #define XALIGN 0.0
    #define YALIGN 0.0
    #define RATIO 0.0001
    #define OBEY_CHILD TRUE
    
    #define CORRECT_XALIGN 0.0
    #define CORRECT_YALIGN 1.0
    #define CORRECT_RATIO 0.0001
    #define CORRECT_OBEY_CHILD TRUE
    
    
    GtkWidget *widget;
    
    gfloat real_xalign;
    gfloat real_yalign;
    gfloat real_ratio;
    gboolean real_obey_child;
    
    gfloat real_xalign_c;
    gfloat real_yalign_c;
    gfloat real_ratio_c;
    gboolean real_obey_child_c;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_aspect_frame_new ("", XALIGN, YALIGN, RATIO, OBEY_CHILD);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_ASPECT_FRAME (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::xalign", &real_xalign, NULL);
    if (real_xalign != (float) XALIGN)
    {
        TEST_FAIL ("xalign = %d, should be %d", 
                   real_xalign, XALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::yalign", &real_yalign, NULL);
    if (real_yalign != (float) YALIGN)
    {
        TEST_FAIL ("yalign = %d, should be %d", 
                   real_yalign, YALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::ratio", &real_ratio, NULL);
    if (real_ratio != (float) RATIO)
    {
        TEST_FAIL ("ratio = %d, should be %d", 
                   real_ratio, RATIO);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::obey-child", &real_obey_child, NULL);
    if (real_obey_child != OBEY_CHILD)
    {
        TEST_FAIL ("obey_child = %d, should be %d", 
                   real_obey_child, OBEY_CHILD);
    }
    
    
    
    gtk_aspect_frame_set (GTK_ASPECT_FRAME (widget), 
                          CORRECT_XALIGN, 
                          CORRECT_YALIGN, 
                          CORRECT_RATIO, 
                          CORRECT_OBEY_CHILD);
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::xalign", &real_xalign_c, NULL);
    if (real_xalign_c != (float) CORRECT_XALIGN)
    {
        TEST_FAIL ("xalign = %d, should be %d", 
                   real_xalign_c, CORRECT_XALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::yalign", &real_yalign_c, NULL);
    if (real_yalign_c != (float) CORRECT_YALIGN)
    {
        TEST_FAIL ("yalign = %d, should be %d", 
                   real_yalign_c, CORRECT_YALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::ratio", &real_ratio_c, NULL);
    if (real_ratio_c != (float) CORRECT_RATIO)
    {
        TEST_FAIL ("ratio = %d, should be %d", 
                   real_ratio_c, CORRECT_RATIO);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::obey-child", &real_obey_child_c, NULL);
    if (real_obey_child_c != CORRECT_OBEY_CHILD)
    {
        TEST_FAIL ("obey_child = %d, should be %d", 
                   real_obey_child_c, CORRECT_OBEY_CHILD);
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef XALIGN
    #undef YALIGN
    #undef RATIO
    #undef OBEY_CHILD
    
    #undef CORRECT_XALIGN
    #undef CORRECT_YALIGN
    #undef CORRECT_RATIO
    #undef CORRECT_OBEY_CHILD
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_aspect_frame_set
 * Params: GtkAspectFrame *aspect_frame, gfloat xalign, gfloat yalign, gfloat ratio, gboolean obey_child
 * Returns: void
 * Assertion: Set parameters for an existing GtkAspectFrame.
 * Params Values:a newly created gtkAspectFrame*, 0.0, 0.0, 0.0001, TRUE
 * Expected: void  
 */
static void test_purpose_20()
{
    #define XALIGN 0.0
    #define YALIGN 0.0
    #define RATIO 0.0001
    #define OBEY_CHILD TRUE
    
    #define CORRECT_XALIGN 0.0
    #define CORRECT_YALIGN 0.0
    #define CORRECT_RATIO 0.01
    #define CORRECT_OBEY_CHILD TRUE
    
    
    GtkWidget *widget;
    
    gfloat real_xalign;
    gfloat real_yalign;
    gfloat real_ratio;
    gboolean real_obey_child;
    
    gfloat real_xalign_c;
    gfloat real_yalign_c;
    gfloat real_ratio_c;
    gboolean real_obey_child_c;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_aspect_frame_new ("", XALIGN, YALIGN, RATIO, OBEY_CHILD);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_ASPECT_FRAME (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::xalign", &real_xalign, NULL);
    if (real_xalign != (float) XALIGN)
    {
        TEST_FAIL ("xalign = %d, should be %d", 
                   real_xalign, XALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::yalign", &real_yalign, NULL);
    if (real_yalign != (float) YALIGN)
    {
        TEST_FAIL ("yalign = %d, should be %d", 
                   real_yalign, YALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::ratio", &real_ratio, NULL);
    if (real_ratio != (float) RATIO)
    {
        TEST_FAIL ("ratio = %d, should be %d", 
                   real_ratio, RATIO);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::obey-child", &real_obey_child, NULL);
    if (real_obey_child != OBEY_CHILD)
    {
        TEST_FAIL ("obey_child = %d, should be %d", 
                   real_obey_child, OBEY_CHILD);
    }
    
    
    
    gtk_aspect_frame_set (GTK_ASPECT_FRAME (widget), 
                          CORRECT_XALIGN, 
                          CORRECT_YALIGN, 
                          CORRECT_RATIO, 
                          CORRECT_OBEY_CHILD);
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::xalign", &real_xalign_c, NULL);
    if (real_xalign_c != (float) CORRECT_XALIGN)
    {
        TEST_FAIL ("xalign = %d, should be %d", 
                   real_xalign_c, CORRECT_XALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::yalign", &real_yalign_c, NULL);
    if (real_yalign_c != (float) CORRECT_YALIGN)
    {
        TEST_FAIL ("yalign = %d, should be %d", 
                   real_yalign_c, CORRECT_YALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::ratio", &real_ratio_c, NULL);
    if (real_ratio_c != (float) CORRECT_RATIO)
    {
        TEST_FAIL ("ratio = %d, should be %d", 
                   real_ratio_c, CORRECT_RATIO);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::obey-child", &real_obey_child_c, NULL);
    if (real_obey_child_c != CORRECT_OBEY_CHILD)
    {
        TEST_FAIL ("obey_child = %d, should be %d", 
                   real_obey_child_c, CORRECT_OBEY_CHILD);
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef XALIGN
    #undef YALIGN
    #undef RATIO
    #undef OBEY_CHILD
    
    #undef CORRECT_XALIGN
    #undef CORRECT_YALIGN
    #undef CORRECT_RATIO
    #undef CORRECT_OBEY_CHILD
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_aspect_frame_set
 * Params: GtkAspectFrame *aspect_frame, gfloat xalign, gfloat yalign, gfloat ratio, gboolean obey_child
 * Returns: void
 * Assertion: Set parameters for an existing GtkAspectFrame.
 * Params Values:a newly created gtkAspectFrame*, 0.0, 0.0, 0.0001, TRUE
 * Expected: void  
 */
static void test_purpose_21()
{
    #define XALIGN 0.0
    #define YALIGN 0.0
    #define RATIO 0.0001
    #define OBEY_CHILD TRUE
    
    #define CORRECT_XALIGN 0.0
    #define CORRECT_YALIGN 0.0
    #define CORRECT_RATIO 0.0001
    #define CORRECT_OBEY_CHILD FALSE
    
    
    GtkWidget *widget;
    
    gfloat real_xalign;
    gfloat real_yalign;
    gfloat real_ratio;
    gboolean real_obey_child;
    
    gfloat real_xalign_c;
    gfloat real_yalign_c;
    gfloat real_ratio_c;
    gboolean real_obey_child_c;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_aspect_frame_new ("", XALIGN, YALIGN, RATIO, OBEY_CHILD);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_ASPECT_FRAME (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::xalign", &real_xalign, NULL);
    if (real_xalign != (float) XALIGN)
    {
        TEST_FAIL ("xalign = %d, should be %d", 
                   real_xalign, XALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::yalign", &real_yalign, NULL);
    if (real_yalign != (float) YALIGN)
    {
        TEST_FAIL ("yalign = %d, should be %d", 
                   real_yalign, YALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::ratio", &real_ratio, NULL);
    if (real_ratio != (float) RATIO)
    {
        TEST_FAIL ("ratio = %d, should be %d", 
                   real_ratio, RATIO);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::obey-child", &real_obey_child, NULL);
    if (real_obey_child != OBEY_CHILD)
    {
        TEST_FAIL ("obey_child = %d, should be %d", 
                   real_obey_child, OBEY_CHILD);
    }
    
    
    
    gtk_aspect_frame_set (GTK_ASPECT_FRAME (widget), 
                          CORRECT_XALIGN, 
                          CORRECT_YALIGN, 
                          CORRECT_RATIO, 
                          CORRECT_OBEY_CHILD);
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::xalign", &real_xalign_c, NULL);
    if (real_xalign_c != (float) CORRECT_XALIGN)
    {
        TEST_FAIL ("xalign = %d, should be %d", 
                   real_xalign_c, CORRECT_XALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::yalign", &real_yalign_c, NULL);
    if (real_yalign_c != (float) CORRECT_YALIGN)
    {
        TEST_FAIL ("yalign = %d, should be %d", 
                   real_yalign_c, CORRECT_YALIGN);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::ratio", &real_ratio_c, NULL);
    if (real_ratio_c != (float) CORRECT_RATIO)
    {
        TEST_FAIL ("ratio = %d, should be %d", 
                   real_ratio_c, CORRECT_RATIO);
    }
    
    g_object_get(GTK_OBJECT(widget), "GtkAspectFrame::obey-child", &real_obey_child_c, NULL);
    if (real_obey_child_c != CORRECT_OBEY_CHILD)
    {
        TEST_FAIL ("obey_child = %d, should be %d", 
                   real_obey_child_c, CORRECT_OBEY_CHILD);
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef XALIGN
    #undef YALIGN
    #undef RATIO
    #undef OBEY_CHILD
    
    #undef CORRECT_XALIGN
    #undef CORRECT_YALIGN
    #undef CORRECT_RATIO
    #undef CORRECT_OBEY_CHILD
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GtkAspectFrame ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {test_purpose_11, 1},
    {test_purpose_12, 1},
    {test_purpose_13, 1},
    {test_purpose_14, 1},
    {test_purpose_15, 1},
    {test_purpose_16, 1},
    {test_purpose_17, 1},
    {test_purpose_18, 1},
    {test_purpose_19, 1},
    {test_purpose_20, 1},
    {test_purpose_21, 1},
    {NULL,0}
};
