/*
 * GtkHandleBox methods tests
 * Testing GtkHandleBox methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;

/*
 * Name: gtk_handle_box_new
 * Params: void
 * Returns: GtkWidget*
 * Assertion: Create a new handle box.
 * Params Values: void
 * Expected: GtkHandleBox*  
 */
static void test_purpose_1()
{
    GtkWidget* widget;
    GtkShadowType shadow;
    GtkPositionType handle_position;
    GtkPositionType snap_edge;
    gboolean snap_edge_set;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_handle_box_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_HANDLE_BOX (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get (GTK_OBJECT (widget), "shadow", &shadow, NULL);
    if (shadow != GTK_SHADOW_OUT)
    {
        TEST_FAIL ("shadow type = %d, should be GTK_SHADOW_TYPE", shadow);
    }
    
    g_object_get (GTK_OBJECT (widget), "handle-position", &handle_position, NULL);
    if (handle_position != GTK_POS_LEFT)
    {
        TEST_FAIL ("handle_position = %d, should be GTK_POS_LEFT", 
                   handle_position);
    }
    
    g_object_get (GTK_OBJECT (widget), "snap-edge-set", &snap_edge_set, NULL);
    if (snap_edge_set != FALSE)
    {
        TEST_FAIL ("snap_edge_set = %d, should be %d", snap_edge_set, FALSE);
    }
    
    g_object_get (GTK_OBJECT (widget), "snap-edge", &snap_edge, NULL);
    if (snap_edge != GTK_POS_TOP)
    {
        TEST_FAIL ("snap_edge = %d, should be %d", snap_edge, GTK_POS_TOP);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_handle_box_set_shadow_type
 * Params: GtkHandleBox *handle_box,  GtkShadowType type
 * Returns: void
 * Assertion: Sets the type of shadow to be drawn around the border of the handle box.
 * Params Values: a newly created GtkHandleBox,  GTK_SHADOW_NONE
 * Expected: void  
 */
static void test_purpose_2()
{
    #define SHADOW_TYPE GTK_SHADOW_NONE
    
    GtkWidget* widget;
    GtkShadowType shadow;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_handle_box_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_HANDLE_BOX (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_handle_box_set_shadow_type (GTK_HANDLE_BOX (widget), SHADOW_TYPE);
    g_object_get (GTK_OBJECT (widget), "shadow", &shadow, NULL);
    if (shadow != SHADOW_TYPE)
    {
        TEST_FAIL ("shadow type is %d, should be %d", shadow, SHADOW_TYPE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef SHADOW_TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_handle_box_set_shadow_type
 * Params: GtkHandleBox *handle_box,  GtkShadowType type
 * Returns: void
 * Assertion: Sets the type of shadow to be drawn around the border of the handle box.
 * Params Values: a newly created GtkHandleBox,  GTK_SHADOW_IN
 * Expected: void  
 */
static void test_purpose_3()
{
    #define SHADOW_TYPE GTK_SHADOW_IN
    
    GtkWidget* widget;
    GtkShadowType shadow;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_handle_box_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_HANDLE_BOX (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_handle_box_set_shadow_type (GTK_HANDLE_BOX (widget), SHADOW_TYPE);
    g_object_get (GTK_OBJECT (widget), "shadow", &shadow, NULL);
    if (shadow != SHADOW_TYPE)
    {
        TEST_FAIL ("shadow type is %d, should be %d", shadow, SHADOW_TYPE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef SHADOW_TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_handle_box_set_shadow_type
 * Params: GtkHandleBox *handle_box,  GtkShadowType type
 * Returns: void
 * Assertion: Sets the type of shadow to be drawn around the border of the handle box.
 * Params Values: a newly created GtkHandleBox,  GTK_SHADOW_OUT
 * Expected: void  
 */
static void test_purpose_4()
{
    #define SHADOW_TYPE GTK_SHADOW_OUT
    
    GtkWidget* widget;
    GtkShadowType shadow;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_handle_box_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_HANDLE_BOX (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_handle_box_set_shadow_type (GTK_HANDLE_BOX (widget), SHADOW_TYPE);
    g_object_get (GTK_OBJECT (widget), "shadow", &shadow, NULL);
    if (shadow != SHADOW_TYPE)
    {
        TEST_FAIL ("shadow type is %d, should be %d", shadow, SHADOW_TYPE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef SHADOW_TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_handle_box_set_shadow_type
 * Params: GtkHandleBox *handle_box,  GtkShadowType type
 * Returns: void
 * Assertion: Sets the type of shadow to be drawn around the border of the handle box.
 * Params Values: a newly created GtkHandleBox,  GTK_SHADOW_ETCHED_IN
 * Expected: void  
 */
static void test_purpose_5()
{
    #define SHADOW_TYPE GTK_SHADOW_ETCHED_IN
    
    GtkWidget* widget;
    GtkShadowType shadow;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_handle_box_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_HANDLE_BOX (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_handle_box_set_shadow_type (GTK_HANDLE_BOX (widget), SHADOW_TYPE);
    g_object_get (GTK_OBJECT (widget), "shadow", &shadow, NULL);
    if (shadow != SHADOW_TYPE)
    {
        TEST_FAIL ("shadow type is %d, should be %d", shadow, SHADOW_TYPE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef SHADOW_TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_handle_box_set_shadow_type
 * Params: GtkHandleBox *handle_box,  GtkShadowType type
 * Returns: void
 * Assertion: Sets the type of shadow to be drawn around the border of the handle box.
 * Params Values: a newly created GtkHandleBox,  GTK_SHADOW_ETCHED_OUT
 * Expected: void  
 */
static void test_purpose_6()
{
    #define SHADOW_TYPE GTK_SHADOW_ETCHED_OUT
    
    GtkWidget* widget;
    GtkShadowType shadow;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_handle_box_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_HANDLE_BOX (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_handle_box_set_shadow_type (GTK_HANDLE_BOX (widget), SHADOW_TYPE);
    g_object_get (GTK_OBJECT (widget), "shadow", &shadow, NULL);
    if (shadow != SHADOW_TYPE)
    {
        TEST_FAIL ("shadow type is %d, should be %d", shadow, SHADOW_TYPE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef SHADOW_TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_handle_box_get_shadow_type
 * Params: GtkHandleBox *handle_box
 * Returns: GtkShadowType type
 * Assertion: Gets the type of shadow drawn around the handle box.
 * Params Values: a newly created GtkHandleBox
 * Expected: GTK_SHADOW_NONE  
 */
static void test_purpose_7()
{
    #define SHADOW_TYPE GTK_SHADOW_NONE
    
    GtkWidget* widget;
    GtkShadowType shadow;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_handle_box_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_HANDLE_BOX (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_set (GTK_OBJECT (widget), "shadow", SHADOW_TYPE, NULL);
    shadow = gtk_handle_box_get_shadow_type (GTK_HANDLE_BOX (widget));
    if (shadow != SHADOW_TYPE)
    {
        TEST_FAIL ("shadow type is %d, should be %d", shadow, SHADOW_TYPE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef SHADOW_TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_handle_box_get_shadow_type
 * Params: GtkHandleBox *handle_box
 * Returns: GtkShadowType type
 * Assertion: Gets the type of shadow drawn around the handle box.
 * Params Values: a newly created GtkHandleBox
 * Expected: GTK_SHADOW_IN  
 */
static void test_purpose_8()
{
    #define SHADOW_TYPE GTK_SHADOW_IN
    
    GtkWidget* widget;
    GtkShadowType shadow;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_handle_box_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_HANDLE_BOX (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_set (GTK_OBJECT (widget), "shadow", SHADOW_TYPE, NULL);
    shadow = gtk_handle_box_get_shadow_type (GTK_HANDLE_BOX (widget));
    if (shadow != SHADOW_TYPE)
    {
        TEST_FAIL ("shadow type is %d, should be %d", shadow, SHADOW_TYPE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef SHADOW_TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_handle_box_get_shadow_type
 * Params: GtkHandleBox *handle_box
 * Returns: GtkShadowType type
 * Assertion: Gets the type of shadow drawn around the handle box.
 * Params Values: a newly created GtkHandleBox
 * Expected: GTK_SHADOW_OUT  
 */
static void test_purpose_9()
{
    #define SHADOW_TYPE GTK_SHADOW_OUT
    
    GtkWidget* widget;
    GtkShadowType shadow;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_handle_box_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_HANDLE_BOX (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_set (GTK_OBJECT (widget), "shadow", SHADOW_TYPE, NULL);
    shadow = gtk_handle_box_get_shadow_type (GTK_HANDLE_BOX (widget));
    if (shadow != SHADOW_TYPE)
    {
        TEST_FAIL ("shadow type is %d, should be %d", shadow, SHADOW_TYPE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef SHADOW_TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_handle_box_get_shadow_type
 * Params: GtkHandleBox *handle_box
 * Returns: GtkShadowType type
 * Assertion: Gets the type of shadow drawn around the handle box.
 * Params Values: a newly created GtkHandleBox
 * Expected: GTK_SHADOW_ETCHED_IN  
 */
static void test_purpose_10()
{
    #define SHADOW_TYPE GTK_SHADOW_ETCHED_IN
    
    GtkWidget* widget;
    GtkShadowType shadow;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_handle_box_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_HANDLE_BOX (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_set (GTK_OBJECT (widget), "shadow", SHADOW_TYPE, NULL);
    shadow = gtk_handle_box_get_shadow_type (GTK_HANDLE_BOX (widget));
    if (shadow != SHADOW_TYPE)
    {
        TEST_FAIL ("shadow type is %d, should be %d", shadow, SHADOW_TYPE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef SHADOW_TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_handle_box_get_shadow_type
 * Params: GtkHandleBox *handle_box
 * Returns: GtkShadowType type
 * Assertion: Gets the type of shadow drawn around the handle box.
 * Params Values: a newly created GtkHandleBox
 * Expected: GTK_SHADOW_ETCHED_OUT  
 */
static void test_purpose_11()
{
    #define SHADOW_TYPE GTK_SHADOW_ETCHED_OUT
    
    GtkWidget* widget;
    GtkShadowType shadow;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_handle_box_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_HANDLE_BOX (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_set (GTK_OBJECT (widget), "shadow", SHADOW_TYPE, NULL);
    shadow = gtk_handle_box_get_shadow_type (GTK_HANDLE_BOX (widget));
    if (shadow != SHADOW_TYPE)
    {
        TEST_FAIL ("shadow type is %d, should be %d", shadow, SHADOW_TYPE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef SHADOW_TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_handle_box_set_handle_position
 * Params: GtkHandleBox *handle_box,  GtkPositionType position
 * Returns: void
 * Assertion: Sets the side of the handlebox where the handle is drawn.
 * Params Values: a newly created GtkHandleBox,  GTK_POS_LEFT
 * Expected: void  
 */
static void test_purpose_12()
{
    #define HANDLE_POSITION GTK_POS_LEFT
    
    GtkWidget* widget;
    GtkPositionType position;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_handle_box_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_HANDLE_BOX (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_handle_box_set_handle_position (GTK_HANDLE_BOX (widget), HANDLE_POSITION);
    g_object_get (GTK_OBJECT (widget), "handle-position", &position, NULL);
    if (position != HANDLE_POSITION)
    {
        TEST_FAIL ("handle position is %d, should be %d", 
                   position, HANDLE_POSITION);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef HANDLE_POSITION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_handle_box_set_handle_position
 * Params: GtkHandleBox *handle_box,  GtkPositionType position
 * Returns: void
 * Assertion: Sets the side of the handlebox where the handle is drawn.
 * Params Values: a newly created GtkHandleBox,  GTK_POS_RIGHT
 * Expected: void  
 */
static void test_purpose_13()
{
    #define HANDLE_POSITION GTK_POS_RIGHT
    
    GtkWidget* widget;
    GtkPositionType position;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_handle_box_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_HANDLE_BOX (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_handle_box_set_handle_position (GTK_HANDLE_BOX (widget), HANDLE_POSITION);
    g_object_get (GTK_OBJECT (widget), "handle-position", &position, NULL);
    if (position != HANDLE_POSITION)
    {
        TEST_FAIL ("handle position is %d, should be %d", 
                   position, HANDLE_POSITION);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef HANDLE_POSITION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_handle_box_set_handle_position
 * Params: GtkHandleBox *handle_box,  GtkPositionType position
 * Returns: void
 * Assertion: Sets the side of the handlebox where the handle is drawn.
 * Params Values: a newly created GtkHandleBox,  GTK_POS_TOP
 * Expected: void  
 */
static void test_purpose_14()
{
    #define HANDLE_POSITION GTK_POS_TOP
    
    GtkWidget* widget;
    GtkPositionType position;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_handle_box_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_HANDLE_BOX (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_handle_box_set_handle_position (GTK_HANDLE_BOX (widget), HANDLE_POSITION);
    g_object_get (GTK_OBJECT (widget), "handle-position", &position, NULL);
    if (position != HANDLE_POSITION)
    {
        TEST_FAIL ("handle position is %d, should be %d", 
                   position, HANDLE_POSITION);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef HANDLE_POSITION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_handle_box_set_handle_position
 * Params: GtkHandleBox *handle_box,  GtkPositionType position
 * Returns: void
 * Assertion: Sets the side of the handlebox where the handle is drawn.
 * Params Values: a newly created GtkHandleBox,  GTK_POS_BOTTOM
 * Expected: void  
 */
static void test_purpose_15()
{
    #define HANDLE_POSITION GTK_POS_BOTTOM
    
    GtkWidget* widget;
    GtkPositionType position;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_handle_box_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_HANDLE_BOX (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_handle_box_set_handle_position (GTK_HANDLE_BOX (widget), HANDLE_POSITION);
    g_object_get (GTK_OBJECT (widget), "handle-position", &position, NULL);
    if (position != HANDLE_POSITION)
    {
        TEST_FAIL ("handle position is %d, should be %d", 
                   position, HANDLE_POSITION);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef HANDLE_POSITION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_handle_box_get_handle_position
 * Params: GtkHandleBox *handle_box
 * Returns: GtkPositionType position
 * Assertion: Gets the handle position of the handle box.
 * Params Values: a newly created GtkHandleBox
 * Expected: GTK_POS_LEFT  
 */
static void test_purpose_16()
{
    #define HANDLE_POSITION GTK_POS_LEFT
    
    GtkWidget* widget;
    GtkPositionType position;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_handle_box_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_HANDLE_BOX (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_set (GTK_OBJECT (widget), "handle-position", HANDLE_POSITION, NULL);
    position = gtk_handle_box_get_handle_position (GTK_HANDLE_BOX (widget));
    if (position != HANDLE_POSITION)
    {
        TEST_FAIL ("handle position is %d, should be %d", 
                   position, HANDLE_POSITION);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef HANDLE_POSITION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_handle_box_get_handle_position
 * Params: GtkHandleBox *handle_box
 * Returns: GtkPositionType position
 * Assertion: Gets the handle position of the handle box.
 * Params Values: a newly created GtkHandleBox
 * Expected: GTK_POS_RIGHT  
 */
static void test_purpose_17()
{
    #define HANDLE_POSITION GTK_POS_RIGHT
    
    GtkWidget* widget;
    GtkPositionType position;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_handle_box_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_HANDLE_BOX (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_set (GTK_OBJECT (widget), "handle-position", HANDLE_POSITION, NULL);
    position = gtk_handle_box_get_handle_position (GTK_HANDLE_BOX (widget));
    if (position != HANDLE_POSITION)
    {
        TEST_FAIL ("handle position is %d, should be %d", 
                   position, HANDLE_POSITION);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef HANDLE_POSITION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_handle_box_get_handle_position
 * Params: GtkHandleBox *handle_box
 * Returns: GtkPositionType position
 * Assertion: Gets the handle position of the handle box.
 * Params Values: a newly created GtkHandleBox
 * Expected: GTK_POS_TOP  
 */
static void test_purpose_18()
{
    #define HANDLE_POSITION GTK_POS_TOP
    
    GtkWidget* widget;
    GtkPositionType position;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_handle_box_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_HANDLE_BOX (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_set (GTK_OBJECT (widget), "handle-position", HANDLE_POSITION, NULL);
    position = gtk_handle_box_get_handle_position (GTK_HANDLE_BOX (widget));
    if (position != HANDLE_POSITION)
    {
        TEST_FAIL ("handle position is %d, should be %d", 
                   position, HANDLE_POSITION);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef HANDLE_POSITION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_handle_box_get_handle_position
 * Params: GtkHandleBox *handle_box
 * Returns: GtkPositionType position
 * Assertion: Gets the handle position of the handle box.
 * Params Values: a newly created GtkHandleBox
 * Expected: GTK_POS_BOTTOM  
 */
static void test_purpose_19()
{
    #define HANDLE_POSITION GTK_POS_BOTTOM
    
    GtkWidget* widget;
    GtkPositionType position;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_handle_box_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_HANDLE_BOX (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_set (GTK_OBJECT (widget), "handle-position", HANDLE_POSITION, NULL);
    position = gtk_handle_box_get_handle_position (GTK_HANDLE_BOX (widget));
    if (position != HANDLE_POSITION)
    {
        TEST_FAIL ("handle position is %d, should be %d", 
                   position, HANDLE_POSITION);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef HANDLE_POSITION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_handle_box_set_snap_edge
 * Params: GtkHandleBox *handle_box,  GtkPositionType edge
 * Returns: void
 * Assertion: Sets the snap edge of a handlebox.
 * Params Values: a newly created GtkHandleBox,  GTK_POS_LEFT
 * Expected: void  
 */
static void test_purpose_20()
{
    #define SNAP_EDGE GTK_POS_LEFT
    
    GtkWidget* widget;
    GtkPositionType edge;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_handle_box_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_HANDLE_BOX (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_handle_box_set_snap_edge (GTK_HANDLE_BOX (widget), SNAP_EDGE);
    g_object_get (GTK_OBJECT (widget), "snap-edge", &edge, NULL);
    if (edge != SNAP_EDGE)
    {
        TEST_FAIL ("snap edge is %d, should be %d", edge, SNAP_EDGE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef SNAP_EDGE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_handle_box_set_snap_edge
 * Params: GtkHandleBox *handle_box,  GtkPositionType edge
 * Returns: void
 * Assertion: Sets the snap edge of a handlebox.
 * Params Values: a newly created GtkHandleBox,  GTK_POS_RIGHT
 * Expected: void  
 */
static void test_purpose_21()
{
    #define SNAP_EDGE GTK_POS_RIGHT
    
    GtkWidget* widget;
    GtkPositionType edge;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_handle_box_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_HANDLE_BOX (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_handle_box_set_snap_edge (GTK_HANDLE_BOX (widget), SNAP_EDGE);
    g_object_get (GTK_OBJECT (widget), "snap-edge", &edge, NULL);
    if (edge != SNAP_EDGE)
    {
        TEST_FAIL ("snap edge is %d, should be %d", edge, SNAP_EDGE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef SNAP_EDGE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_handle_box_set_snap_edge
 * Params: GtkHandleBox *handle_box,  GtkPositionType edge
 * Returns: void
 * Assertion: Sets the snap edge of a handlebox.
 * Params Values: a newly created GtkHandleBox,  GTK_POS_TOP
 * Expected: void  
 */
static void test_purpose_22()
{
    #define SNAP_EDGE GTK_POS_TOP
    
    GtkWidget* widget;
    GtkPositionType edge;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_handle_box_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_HANDLE_BOX (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_handle_box_set_snap_edge (GTK_HANDLE_BOX (widget), SNAP_EDGE);
    g_object_get (GTK_OBJECT (widget), "snap-edge", &edge, NULL);
    if (edge != SNAP_EDGE)
    {
        TEST_FAIL ("snap edge is %d, should be %d", edge, SNAP_EDGE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef SNAP_EDGE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_handle_box_set_snap_edge
 * Params: GtkHandleBox *handle_box,  GtkPositionType edge
 * Returns: void
 * Assertion: Sets the snap edge of a handlebox.
 * Params Values: a newly created GtkHandleBox,  GTK_POS_BOTTOM
 * Expected: void  
 */
static void test_purpose_23()
{
    #define SNAP_EDGE GTK_POS_BOTTOM
    
    GtkWidget* widget;
    GtkPositionType edge;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_handle_box_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_HANDLE_BOX (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_handle_box_set_snap_edge (GTK_HANDLE_BOX (widget), SNAP_EDGE);
    g_object_get (GTK_OBJECT (widget), "snap-edge", &edge, NULL);
    if (edge != SNAP_EDGE)
    {
        TEST_FAIL ("snap edge is %d, should be %d", edge, SNAP_EDGE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef SNAP_EDGE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_handle_box_get_snap_edge
 * Params: GtkHandleBox *handle_box,  GtkPositionType edge
 * Returns: void
 * Assertion: Gets the edge used for determining reattachment of the handle box.
 * Params Values: a newly created GtkHandleBox
 * Expected: GTK_POS_LEFT  
 */
static void test_purpose_24()
{
    #define SNAP_EDGE GTK_POS_LEFT
    
    GtkWidget* widget;
    GtkPositionType edge;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_handle_box_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_HANDLE_BOX (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_set (GTK_OBJECT (widget), "snap-edge", SNAP_EDGE, NULL);
    edge = gtk_handle_box_get_snap_edge (GTK_HANDLE_BOX (widget));
    if (edge != SNAP_EDGE)
    {
        TEST_FAIL ("snap edge is %d, should be %d", edge, SNAP_EDGE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef SNAP_EDGE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_handle_box_get_snap_edge
 * Params: GtkHandleBox *handle_box,  GtkPositionType edge
 * Returns: void
 * Assertion: Gets the edge used for determining reattachment of the handle box.
 * Params Values: a newly created GtkHandleBox
 * Expected: GTK_POS_RIGHT  
 */
static void test_purpose_25()
{
    #define SNAP_EDGE GTK_POS_RIGHT
    
    GtkWidget* widget;
    GtkPositionType edge;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_handle_box_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_HANDLE_BOX (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_set (GTK_OBJECT (widget), "snap-edge", SNAP_EDGE, NULL);
    edge = gtk_handle_box_get_snap_edge (GTK_HANDLE_BOX (widget));
    if (edge != SNAP_EDGE)
    {
        TEST_FAIL ("snap edge is %d, should be %d", edge, SNAP_EDGE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef SNAP_EDGE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_handle_box_get_snap_edge
 * Params: GtkHandleBox *handle_box,  GtkPositionType edge
 * Returns: void
 * Assertion: Gets the edge used for determining reattachment of the handle box.
 * Params Values: a newly created GtkHandleBox
 * Expected: GTK_POS_TOP  
 */
static void test_purpose_26()
{
    #define SNAP_EDGE GTK_POS_TOP
    
    GtkWidget* widget;
    GtkPositionType edge;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_handle_box_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_HANDLE_BOX (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_set (GTK_OBJECT (widget), "snap-edge", SNAP_EDGE, NULL);
    edge = gtk_handle_box_get_snap_edge (GTK_HANDLE_BOX (widget));
    if (edge != SNAP_EDGE)
    {
        TEST_FAIL ("snap edge is %d, should be %d", edge, SNAP_EDGE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef SNAP_EDGE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_handle_box_get_snap_edge
 * Params: GtkHandleBox *handle_box,  GtkPositionType edge
 * Returns: void
 * Assertion: Gets the edge used for determining reattachment of the handle box.
 * Params Values: a newly created GtkHandleBox
 * Expected: GTK_POS_BOTTOM  
 */
static void test_purpose_27()
{
    #define SNAP_EDGE GTK_POS_BOTTOM
    
    GtkWidget* widget;
    GtkPositionType edge;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_handle_box_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_HANDLE_BOX (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_set (GTK_OBJECT (widget), "snap-edge", SNAP_EDGE, NULL);
    edge = gtk_handle_box_get_snap_edge (GTK_HANDLE_BOX (widget));
    if (edge != SNAP_EDGE)
    {
        TEST_FAIL ("snap edge is %d, should be %d", edge, SNAP_EDGE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef SNAP_EDGE
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GtkHandleBox ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {test_purpose_11, 1},
    {test_purpose_12, 1},
    {test_purpose_13, 1},
    {test_purpose_14, 1},
    {test_purpose_15, 1},
    {test_purpose_16, 1},
    {test_purpose_17, 1},
    {test_purpose_18, 1},
    {test_purpose_19, 1},
    {test_purpose_20, 1},
    {test_purpose_21, 1},
    {test_purpose_22, 1},
    {test_purpose_23, 1},
    {test_purpose_24, 1},
    {test_purpose_25, 1},
    {test_purpose_26, 1},
    {test_purpose_27, 1},
    {NULL,0}
};
