/*
 * GtkMenuShell methods tests
 * Testing GtkMenuShell methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;
gint global_counter;
gboolean activate;
gboolean deactivate;
gboolean selection;

void global_activate_signal (GtkMenuShell *menushell,
                             gboolean force_hide,
                             gpointer user_data)
{
    activate = TRUE;
}

void global_deactivate_signal (GtkMenuShell *menushell,
                               gpointer user_data)
{
    deactivate = TRUE;
}

void global_select_signal (GtkMenuShell *menushell,
                           gpointer user_data)
{
    selection = TRUE;
}


/*
 * Name: gtk_menu_shell_append
 * Params: GtkMenuShell *menu_shell,GtkWidget *child
 * Returns: void
 * Assertion: Adds a new GtkMenuItem to the end of the menu shell's item list.'
 * Params Values: GtkMenuShell*, GtkWidget*
 * Expected: void  
 */
static void test_purpose_1()
{
    #define N 0
    
    GtkWidget *widget;
    GtkWidget *child;
    GtkWidget *real_child;
    GList* children;
    gint i;
    gint len;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_menu_new ();
    child = gtk_menu_item_new ();
    gtk_widget_show (child);
    
    for (i = 0; i < N; i++)
    {
        GtkWidget* item = gtk_menu_item_new_with_label ("Item");
        gtk_menu_shell_append (GTK_MENU_SHELL (widget), item);
        gtk_widget_show (item);
    }
    
    children = gtk_container_get_children (GTK_CONTAINER (widget));
    len = g_list_length (children);
    if (len != N)
    {
        TEST_FAIL ("1: %d children were added, lenght of it's children list is %d", 
                   N, len);
    }
    
    gtk_menu_shell_append (GTK_MENU_SHELL (widget), child);
    
    children = gtk_container_get_children (GTK_CONTAINER (widget));
    len = g_list_length (children);
    if (len != N + 1)
    {
        TEST_FAIL ("2: %d children were added, lenght of it's children list is %d", 
                   N + 1, len);
    }
    real_child = (GtkWidget*) g_list_nth_data (children, len - 1);
    if (real_child != child)
    {
        TEST_FAIL ("last elem. in the children list differs from the one was appended to the menushell ", NULL);
    }
    
    gtk_menu_popup (GTK_MENU (widget), NULL, NULL, NULL, NULL, 0, GDK_CURRENT_TIME);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef N
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_menu_shell_append
 * Params: GtkMenuShell *menu_shell,GtkWidget *child
 * Returns: void
 * Assertion: Adds a new GtkMenuItem to the end of the menu shell's item list.'
 * Params Values: GtkMenuShell*, GtkWidget*
 * Expected: void  
 */
static void test_purpose_2()
{
    #define N 1
    
    GtkWidget *widget;
    GtkWidget *child;
    GtkWidget *real_child;
    GList* children;
    gint i;
    gint len;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_menu_new ();
    child = gtk_menu_item_new ();
    gtk_widget_show (child);
    
    for (i = 0; i < N; i++)
    {
        GtkWidget* item = gtk_menu_item_new_with_label ("Item");
        gtk_menu_shell_append (GTK_MENU_SHELL (widget), item);
        gtk_widget_show (item);
    }
    
    children = gtk_container_get_children (GTK_CONTAINER (widget));
    len = g_list_length (children);
    if (len != N)
    {
        TEST_FAIL ("1: %d children were added, lenght of it's children list is %d", 
                   N, len);
    }
    
    gtk_menu_shell_append (GTK_MENU_SHELL (widget), child);
    
    children = gtk_container_get_children (GTK_CONTAINER (widget));
    len = g_list_length (children);
    if (len != N + 1)
    {
        TEST_FAIL ("2: %d children were added, lenght of it's children list is %d", 
                   N + 1, len);
    }
    real_child = (GtkWidget*) g_list_nth_data (children, len - 1);
    if (real_child != child)
    {
        TEST_FAIL ("last elem. in the children list differs from the one was appended to the menushell ", NULL);
    }
    
    gtk_menu_popup (GTK_MENU (widget), NULL, NULL, NULL, NULL, 0, GDK_CURRENT_TIME);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef N
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_menu_shell_append
 * Params: GtkMenuShell *menu_shell,GtkWidget *child
 * Returns: void
 * Assertion: Adds a new GtkMenuItem to the end of the menu shell's item list.'
 * Params Values: GtkMenuShell*, GtkWidget*
 * Expected: void  
 */
static void test_purpose_3()
{
    #define N 10
    
    GtkWidget *widget;
    GtkWidget *child;
    GtkWidget *real_child;
    GList* children;
    gint i;
    gint len;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_menu_new ();
    child = gtk_menu_item_new ();
    gtk_widget_show (child);
    
    for (i = 0; i < N; i++)
    {
        GtkWidget* item = gtk_menu_item_new_with_label ("Item");
        gtk_menu_shell_append (GTK_MENU_SHELL (widget), item);
        gtk_widget_show (item);
    }
    
    children = gtk_container_get_children (GTK_CONTAINER (widget));
    len = g_list_length (children);
    if (len != N)
    {
        TEST_FAIL ("1: %d children were added, lenght of it's children list is %d", 
                   N, len);
    }
    
    gtk_menu_shell_append (GTK_MENU_SHELL (widget), child);
    
    children = gtk_container_get_children (GTK_CONTAINER (widget));
    len = g_list_length (children);
    if (len != N + 1)
    {
        TEST_FAIL ("2: %d children were added, lenght of it's children list is %d", 
                   N + 1, len);
    }
    real_child = (GtkWidget*) g_list_nth_data (children, len - 1);
    if (real_child != child)
    {
        TEST_FAIL ("last elem. in the children list differs from the one was appended to the menushell ", NULL);
    }
    
    gtk_menu_popup (GTK_MENU (widget), NULL, NULL, NULL, NULL, 0, GDK_CURRENT_TIME);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef N
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_menu_shell_append
 * Params: GtkMenuShell *menu_shell,GtkWidget *child
 * Returns: void
 * Assertion: Adds a new GtkMenuItem to the end of the menu shell's item list.'
 * Params Values: GtkMenuShell*, GtkWidget*
 * Expected: void  
 */
static void test_purpose_4()
{
    #define N 5000
    
    GtkWidget *widget;
    GtkWidget *child;
    GtkWidget *real_child;
    GList* children;
    gint i;
    gint len;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_menu_new ();
    child = gtk_menu_item_new ();
    gtk_widget_show (child);
    
    for (i = 0; i < N; i++)
    {
        GtkWidget* item = gtk_menu_item_new_with_label ("Item");
        gtk_menu_shell_append (GTK_MENU_SHELL (widget), item);
        gtk_widget_show (item);
    }
    
    children = gtk_container_get_children (GTK_CONTAINER (widget));
    len = g_list_length (children);
    if (len != N)
    {
        TEST_FAIL ("1: %d children were added, lenght of it's children list is %d", 
                   N, len);
    }
    
    gtk_menu_shell_append (GTK_MENU_SHELL (widget), child);
    
    children = gtk_container_get_children (GTK_CONTAINER (widget));
    len = g_list_length (children);
    if (len != N + 1)
    {
        TEST_FAIL ("2: %d children were added, lenght of it's children list is %d", 
                   N + 1, len);
    }
    real_child = (GtkWidget*) g_list_nth_data (children, len - 1);
    if (real_child != child)
    {
        TEST_FAIL ("last elem. in the children list differs from the one was appended to the menushell ", NULL);
    }
    
    gtk_menu_popup (GTK_MENU (widget), NULL, NULL, NULL, NULL, 0, GDK_CURRENT_TIME);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef N
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_menu_shell_prepend
 * Params: GtkMenuShell *menu_shell, GtkWidget *child
 * Returns: void
 * Assertion: Adds a new GtkMenuItem to the beginning of the menu shell's item list.'
 * Params Values: GtkMenuShell *menu_shell, GtkMenuItem*
 * Expected: GtkMenuShell*  
 */
static void test_purpose_5()
{
    #define N 0
    
    GtkWidget *widget;
    GtkWidget *child;
    GtkWidget *real_child;
    GList* children;
    gint i;
    gint len;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_menu_new ();
    child = gtk_menu_item_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_MENU (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_widget_show (child);
    
    for (i = 0; i < N; i++)
    {
        GtkWidget* item = gtk_menu_item_new_with_label ("Item");
        gtk_menu_shell_append (GTK_MENU_SHELL (widget), item);
        gtk_widget_show (item);
    }
    
    children = gtk_container_get_children (GTK_CONTAINER (widget));
    len = g_list_length (children);
    if (len != N)
    {
        TEST_FAIL ("1: %d children were added, lenght of it's children list is %d", 
                   N, len);
    }
    
    gtk_menu_shell_prepend (GTK_MENU_SHELL (widget), child);
    
    children = gtk_container_get_children (GTK_CONTAINER (widget));
    len = g_list_length (children);
    if (len != N + 1)
    {
        TEST_FAIL ("2: %d children were added, lenght of it's children list is %d", 
                   N + 1, len);
    }
    real_child = (GtkWidget*) g_list_nth_data (children, 0);
    if (real_child != child)
    {
        TEST_FAIL ("first elem. in the children list differs from the one was appended to the menu shell", NULL);
    }
    
    gtk_menu_popup (GTK_MENU (widget), NULL, NULL, NULL, NULL, 0, GDK_CURRENT_TIME);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef N
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_menu_shell_prepend
 * Params: GtkMenuShell *menu_shell, GtkWidget *child
 * Returns: void
 * Assertion: Adds a new GtkMenuItem to the beginning of the menu shell's item list.'
 * Params Values: GtkMenuShell *menu_shell, GtkMenuItem*
 * Expected: GtkMenuShell*  
 */
static void test_purpose_6()
{
    #define N 1
    
    GtkWidget *widget;
    GtkWidget *child;
    GtkWidget *real_child;
    GList* children;
    gint i;
    gint len;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_menu_new ();
    child = gtk_menu_item_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_MENU (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_widget_show (child);
    
    for (i = 0; i < N; i++)
    {
        GtkWidget* item = gtk_menu_item_new_with_label ("Item");
        gtk_menu_shell_append (GTK_MENU_SHELL (widget), item);
        gtk_widget_show (item);
    }
    
    children = gtk_container_get_children (GTK_CONTAINER (widget));
    len = g_list_length (children);
    if (len != N)
    {
        TEST_FAIL ("1: %d children were added, lenght of it's children list is %d", 
                   N, len);
    }
    
    gtk_menu_shell_prepend (GTK_MENU_SHELL (widget), child);
    
    children = gtk_container_get_children (GTK_CONTAINER (widget));
    len = g_list_length (children);
    if (len != N + 1)
    {
        TEST_FAIL ("2: %d children were added, lenght of it's children list is %d", 
                   N + 1, len);
    }
    real_child = (GtkWidget*) g_list_nth_data (children, 0);
    if (real_child != child)
    {
        TEST_FAIL ("first elem. in the children list differs from the one was appended to the menu shell", NULL);
    }
    
    gtk_menu_popup (GTK_MENU (widget), NULL, NULL, NULL, NULL, 0, GDK_CURRENT_TIME);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef N
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_menu_shell_prepend
 * Params: GtkMenuShell *menu_shell, GtkWidget *child
 * Returns: void
 * Assertion: Adds a new GtkMenuItem to the beginning of the menu shell's item list.'
 * Params Values: GtkMenuShell *menu_shell, GtkMenuItem*
 * Expected: GtkMenuShell*  
 */
static void test_purpose_7()
{
    #define N 5000
    
    GtkWidget *widget;
    GtkWidget *child;
    GtkWidget *real_child;
    GList* children;
    gint i;
    gint len;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_menu_new ();
    child = gtk_menu_item_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_MENU (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_widget_show (child);
    
    for (i = 0; i < N; i++)
    {
        GtkWidget* item = gtk_menu_item_new_with_label ("Item");
        gtk_menu_shell_append (GTK_MENU_SHELL (widget), item);
        gtk_widget_show (item);
    }
    
    children = gtk_container_get_children (GTK_CONTAINER (widget));
    len = g_list_length (children);
    if (len != N)
    {
        TEST_FAIL ("1: %d children were added, lenght of it's children list is %d", 
                   N, len);
    }
    
    gtk_menu_shell_prepend (GTK_MENU_SHELL (widget), child);
    
    children = gtk_container_get_children (GTK_CONTAINER (widget));
    len = g_list_length (children);
    if (len != N + 1)
    {
        TEST_FAIL ("2: %d children were added, lenght of it's children list is %d", 
                   N + 1, len);
    }
    real_child = (GtkWidget*) g_list_nth_data (children, 0);
    if (real_child != child)
    {
        TEST_FAIL ("first elem. in the children list differs from the one was appended to the menu shell", NULL);
    }
    
    gtk_menu_popup (GTK_MENU (widget), NULL, NULL, NULL, NULL, 0, GDK_CURRENT_TIME);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef N
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_menu_shell_insert
 * Params: GtkMenuShell *menu_shell, GtkWidget *child
 * Returns: void
 * Assertion: Adds a new GtkMenuItem to the menu shell's item list at the position indicated by position.' 
 * Params Values: GtkMenuShell *menu_shell, GtkMenuItem*
 * Expected: GtkMenuShell*  
 */
static void test_purpose_8()
{
    #define N 0
    #define POS 0
    
    GtkWidget *widget;
    GtkWidget *child;
    GtkWidget *real_child;
    GList* children;
    gint i;
    gint len;
    gint real_pos;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_menu_new ();
    child = gtk_menu_item_new ();
    
    if (POS > N)
    {
        real_pos = N;
    } else {
        real_pos = POS;
    }
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_MENU_SHELL (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_widget_show (child);
    
    for (i = 0; i < N; i++)
    {
        GtkWidget* item = gtk_menu_item_new_with_label ("Item");
        gtk_menu_shell_append (GTK_MENU_SHELL (widget), item);
        gtk_widget_show (item);
    }
    
    children = gtk_container_get_children (GTK_CONTAINER (widget));
    len = g_list_length (children);
    if (len != N)
    {
        TEST_FAIL ("1: %d children were added, lenght of it's children list is %d", 
                   N, len);
    }
    
    gtk_menu_shell_insert (GTK_MENU_SHELL (widget), child, POS);
    
    children = gtk_container_get_children (GTK_CONTAINER (widget));
    len = g_list_length (children);
    if (len != N + 1)
    {
        TEST_FAIL ("2: %d children were added, lenght of it's children list is %d", 
                   N + 1, len);
    }
    real_child = (GtkWidget*) g_list_nth_data (children, real_pos);
    if (real_child != child)
    {
        TEST_FAIL ("elem. no. %d in the children list differs from the one was appended to the menu shell", real_pos);
    }
    
    gtk_menu_popup (GTK_MENU (widget), NULL, NULL, NULL, NULL, 0, GDK_CURRENT_TIME);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef N
    #undef POS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_menu_shell_insert
 * Params: GtkMenuShell *menu_shell, GtkWidget *child
 * Returns: void
 * Assertion: Adds a new GtkMenuItem to the menu shell's item list at the position indicated by position.' 
 * Params Values: GtkMenuShell *menu_shell, GtkMenuItem*
 * Expected: GtkMenuShell*  
 */
static void test_purpose_9()
{
    #define N 1
    #define POS 0
    
    GtkWidget *widget;
    GtkWidget *child;
    GtkWidget *real_child;
    GList* children;
    gint i;
    gint len;
    gint real_pos;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_menu_new ();
    child = gtk_menu_item_new ();
    
    if (POS > N)
    {
        real_pos = N;
    } else {
        real_pos = POS;
    }
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_MENU_SHELL (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_widget_show (child);
    
    for (i = 0; i < N; i++)
    {
        GtkWidget* item = gtk_menu_item_new_with_label ("Item");
        gtk_menu_shell_append (GTK_MENU_SHELL (widget), item);
        gtk_widget_show (item);
    }
    
    children = gtk_container_get_children (GTK_CONTAINER (widget));
    len = g_list_length (children);
    if (len != N)
    {
        TEST_FAIL ("1: %d children were added, lenght of it's children list is %d", 
                   N, len);
    }
    
    gtk_menu_shell_insert (GTK_MENU_SHELL (widget), child, POS);
    
    children = gtk_container_get_children (GTK_CONTAINER (widget));
    len = g_list_length (children);
    if (len != N + 1)
    {
        TEST_FAIL ("2: %d children were added, lenght of it's children list is %d", 
                   N + 1, len);
    }
    real_child = (GtkWidget*) g_list_nth_data (children, real_pos);
    if (real_child != child)
    {
        TEST_FAIL ("elem. no. %d in the children list differs from the one was appended to the menu shell", real_pos);
    }
    
    gtk_menu_popup (GTK_MENU (widget), NULL, NULL, NULL, NULL, 0, GDK_CURRENT_TIME);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef N
    #undef POS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_menu_shell_insert
 * Params: GtkMenuShell *menu_shell, GtkWidget *child
 * Returns: void
 * Assertion: Adds a new GtkMenuItem to the menu shell's item list at the position indicated by position.' 
 * Params Values: GtkMenuShell *menu_shell, GtkMenuItem*
 * Expected: GtkMenuShell*  
 */
static void test_purpose_10()
{
    #define N 10
    #define POS 0
    
    GtkWidget *widget;
    GtkWidget *child;
    GtkWidget *real_child;
    GList* children;
    gint i;
    gint len;
    gint real_pos;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_menu_new ();
    child = gtk_menu_item_new ();
    
    if (POS > N)
    {
        real_pos = N;
    } else {
        real_pos = POS;
    }
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_MENU_SHELL (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_widget_show (child);
    
    for (i = 0; i < N; i++)
    {
        GtkWidget* item = gtk_menu_item_new_with_label ("Item");
        gtk_menu_shell_append (GTK_MENU_SHELL (widget), item);
        gtk_widget_show (item);
    }
    
    children = gtk_container_get_children (GTK_CONTAINER (widget));
    len = g_list_length (children);
    if (len != N)
    {
        TEST_FAIL ("1: %d children were added, lenght of it's children list is %d", 
                   N, len);
    }
    
    gtk_menu_shell_insert (GTK_MENU_SHELL (widget), child, POS);
    
    children = gtk_container_get_children (GTK_CONTAINER (widget));
    len = g_list_length (children);
    if (len != N + 1)
    {
        TEST_FAIL ("2: %d children were added, lenght of it's children list is %d", 
                   N + 1, len);
    }
    real_child = (GtkWidget*) g_list_nth_data (children, real_pos);
    if (real_child != child)
    {
        TEST_FAIL ("elem. no. %d in the children list differs from the one was appended to the menu shell", real_pos);
    }
    
    gtk_menu_popup (GTK_MENU (widget), NULL, NULL, NULL, NULL, 0, GDK_CURRENT_TIME);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef N
    #undef POS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_menu_shell_insert
 * Params: GtkMenuShell *menu_shell, GtkWidget *child
 * Returns: void
 * Assertion: Adds a new GtkMenuItem to the menu shell's item list at the position indicated by position.' 
 * Params Values: GtkMenuShell *menu_shell, GtkMenuItem*
 * Expected: GtkMenuShell*  
 */
static void test_purpose_11()
{
    #define N 10
    #define POS 5
    
    GtkWidget *widget;
    GtkWidget *child;
    GtkWidget *real_child;
    GList* children;
    gint i;
    gint len;
    gint real_pos;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_menu_new ();
    child = gtk_menu_item_new ();
    
    if (POS > N)
    {
        real_pos = N;
    } else {
        real_pos = POS;
    }
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_MENU_SHELL (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_widget_show (child);
    
    for (i = 0; i < N; i++)
    {
        GtkWidget* item = gtk_menu_item_new_with_label ("Item");
        gtk_menu_shell_append (GTK_MENU_SHELL (widget), item);
        gtk_widget_show (item);
    }
    
    children = gtk_container_get_children (GTK_CONTAINER (widget));
    len = g_list_length (children);
    if (len != N)
    {
        TEST_FAIL ("1: %d children were added, lenght of it's children list is %d", 
                   N, len);
    }
    
    gtk_menu_shell_insert (GTK_MENU_SHELL (widget), child, POS);
    
    children = gtk_container_get_children (GTK_CONTAINER (widget));
    len = g_list_length (children);
    if (len != N + 1)
    {
        TEST_FAIL ("2: %d children were added, lenght of it's children list is %d", 
                   N + 1, len);
    }
    real_child = (GtkWidget*) g_list_nth_data (children, real_pos);
    if (real_child != child)
    {
        TEST_FAIL ("elem. no. %d in the children list differs from the one was appended to the menu shell", real_pos);
    }
    
    gtk_menu_popup (GTK_MENU (widget), NULL, NULL, NULL, NULL, 0, GDK_CURRENT_TIME);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef N
    #undef POS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_menu_shell_insert
 * Params: GtkMenuShell *menu_shell, GtkWidget *child
 * Returns: void
 * Assertion: Adds a new GtkMenuItem to the menu shell's item list at the position indicated by position.' 
 * Params Values: GtkMenuShell *menu_shell, GtkMenuItem*
 * Expected: GtkMenuShell*  
 */
static void test_purpose_12()
{
    #define N 10
    #define POS 15
    
    GtkWidget *widget;
    GtkWidget *child;
    GtkWidget *real_child;
    GList* children;
    gint i;
    gint len;
    gint real_pos;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_menu_new ();
    child = gtk_menu_item_new ();
    
    if (POS > N)
    {
        real_pos = N;
    } else {
        real_pos = POS;
    }
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_MENU_SHELL (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_widget_show (child);
    
    for (i = 0; i < N; i++)
    {
        GtkWidget* item = gtk_menu_item_new_with_label ("Item");
        gtk_menu_shell_append (GTK_MENU_SHELL (widget), item);
        gtk_widget_show (item);
    }
    
    children = gtk_container_get_children (GTK_CONTAINER (widget));
    len = g_list_length (children);
    if (len != N)
    {
        TEST_FAIL ("1: %d children were added, lenght of it's children list is %d", 
                   N, len);
    }
    
    gtk_menu_shell_insert (GTK_MENU_SHELL (widget), child, POS);
    
    children = gtk_container_get_children (GTK_CONTAINER (widget));
    len = g_list_length (children);
    if (len != N + 1)
    {
        TEST_FAIL ("2: %d children were added, lenght of it's children list is %d", 
                   N + 1, len);
    }
    real_child = (GtkWidget*) g_list_nth_data (children, real_pos);
    if (real_child != child)
    {
        TEST_FAIL ("elem. no. %d in the children list differs from the one was appended to the menu shell", real_pos);
    }
    
    gtk_menu_popup (GTK_MENU (widget), NULL, NULL, NULL, NULL, 0, GDK_CURRENT_TIME);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef N
    #undef POS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_menu_shell_insert
 * Params: GtkMenuShell *menu_shell, GtkWidget *child
 * Returns: void
 * Assertion: Adds a new GtkMenuItem to the menu shell's item list at the position indicated by position.' 
 * Params Values: GtkMenuShell *menu_shell, GtkMenuItem*
 * Expected: GtkMenuShell*  
 */
static void test_purpose_13()
{
    #define N 5000
    #define POS 2500
    
    GtkWidget *widget;
    GtkWidget *child;
    GtkWidget *real_child;
    GList* children;
    gint i;
    gint len;
    gint real_pos;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_menu_new ();
    child = gtk_menu_item_new ();
    
    if (POS > N)
    {
        real_pos = N;
    } else {
        real_pos = POS;
    }
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_MENU_SHELL (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_widget_show (child);
    
    for (i = 0; i < N; i++)
    {
        GtkWidget* item = gtk_menu_item_new_with_label ("Item");
        gtk_menu_shell_append (GTK_MENU_SHELL (widget), item);
        gtk_widget_show (item);
    }
    
    children = gtk_container_get_children (GTK_CONTAINER (widget));
    len = g_list_length (children);
    if (len != N)
    {
        TEST_FAIL ("1: %d children were added, lenght of it's children list is %d", 
                   N, len);
    }
    
    gtk_menu_shell_insert (GTK_MENU_SHELL (widget), child, POS);
    
    children = gtk_container_get_children (GTK_CONTAINER (widget));
    len = g_list_length (children);
    if (len != N + 1)
    {
        TEST_FAIL ("2: %d children were added, lenght of it's children list is %d", 
                   N + 1, len);
    }
    real_child = (GtkWidget*) g_list_nth_data (children, real_pos);
    if (real_child != child)
    {
        TEST_FAIL ("elem. no. %d in the children list differs from the one was appended to the menu shell", real_pos);
    }
    
    gtk_menu_popup (GTK_MENU (widget), NULL, NULL, NULL, NULL, 0, GDK_CURRENT_TIME);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef N
    #undef POS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_menu_shell_activate_item 
 * Params: GtkMenuShell *menu_shell,GtkWidget *menu_item,gboolean force_deactivate
 * Returns: void
 * Assertion: Activates the menu item within the menu shell.
 * Params Values: GtkMenuShell*, GtkWidget*,gboolean
 * Expected: void  
 */
static void test_purpose_14()
{
    #define FORCE FALSE
    
    GtkWidget *widget;
    GtkWidget *child;
    gint i;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    deactivate = FALSE;
    
    widget = gtk_menu_new ();
    child = gtk_menu_item_new_with_label ("Menu Item");
    
    gtk_widget_show (child);
    
    for (i = 0; i < 5; i++)
    {
        GtkWidget* item = gtk_menu_item_new_with_label ("Item");
        gtk_menu_shell_append (GTK_MENU_SHELL (widget), item);
        gtk_widget_show (item);
    }
    
    gtk_menu_shell_append (GTK_MENU_SHELL (widget),child);
    
    g_signal_connect (G_OBJECT (widget), "deactivate", 
                      GTK_SIGNAL_FUNC (global_deactivate_signal), NULL);
    
    gtk_menu_shell_activate_item (GTK_MENU_SHELL (widget),child,FORCE);
    if (!gtk_widget_activate (child))
    {
        TEST_FAIL ("Menu item is not activated", NULL);
    }
    
    if (FORCE)
    {
        if (!deactivate)
        {
            TEST_FAIL ("Menu item is not deactivated after the item is activated", NULL);
        }
    }
    
    gtk_menu_popup (GTK_MENU (widget), NULL, NULL, NULL, NULL, 0, GDK_CURRENT_TIME);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef FORCE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_menu_shell_activate_item 
 * Params: GtkMenuShell *menu_shell,GtkWidget *menu_item,gboolean force_deactivate
 * Returns: void
 * Assertion: Activates the menu item within the menu shell.
 * Params Values: GtkMenuShell*, GtkWidget*,gboolean
 * Expected: void  
 */
static void test_purpose_15()
{
    #define FORCE TRUE
    
    GtkWidget *widget;
    GtkWidget *child;
    gint i;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    deactivate = FALSE;
    
    widget = gtk_menu_new ();
    child = gtk_menu_item_new_with_label ("Menu Item");
    
    gtk_widget_show (child);
    
    for (i = 0; i < 5; i++)
    {
        GtkWidget* item = gtk_menu_item_new_with_label ("Item");
        gtk_menu_shell_append (GTK_MENU_SHELL (widget), item);
        gtk_widget_show (item);
    }
    
    gtk_menu_shell_append (GTK_MENU_SHELL (widget),child);
    
    g_signal_connect (G_OBJECT (widget), "deactivate", 
                      GTK_SIGNAL_FUNC (global_deactivate_signal), NULL);
    
    gtk_menu_shell_activate_item (GTK_MENU_SHELL (widget),child,FORCE);
    if (!gtk_widget_activate (child))
    {
        TEST_FAIL ("Menu item is not activated", NULL);
    }
    
    if (FORCE)
    {
        if (!deactivate)
        {
            TEST_FAIL ("Menu item is not deactivated after the item is activated", NULL);
        }
    }
    
    gtk_menu_popup (GTK_MENU (widget), NULL, NULL, NULL, NULL, 0, GDK_CURRENT_TIME);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef FORCE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_menu_shell_deactivate
 * Params: GtkMenuShell *menu_shell
 * Returns: void
 * Assertion: Deactivates the menu shell. 
 * Params Values: GtkMenuShell*
 * Expected: void  
 */
static void test_purpose_16()
{
    GtkWidget *widget;
    GtkWidget *child;
    gint i;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    deactivate = FALSE;
    
    widget = gtk_menu_new ();
    child = gtk_menu_item_new_with_label ("Menu Item");
    
    gtk_widget_show (child);
    
    for (i = 0; i < 5; i++)
    {
        GtkWidget* item = gtk_menu_item_new_with_label ("Item");
        gtk_menu_shell_append (GTK_MENU_SHELL (widget), item);
        gtk_widget_show (item);
    }
    
    gtk_menu_shell_append (GTK_MENU_SHELL (widget),child);
    
    g_signal_connect (G_OBJECT (widget), "deactivate", 
                      GTK_SIGNAL_FUNC (global_deactivate_signal), NULL);
    
    gtk_menu_popup (GTK_MENU (widget), NULL, NULL, NULL, NULL, 0, GDK_CURRENT_TIME);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_menu_shell_deactivate (GTK_MENU_SHELL (widget));
    if (!deactivate)
    {
        TEST_FAIL ("Menu shell is not deactivated", NULL);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_menu_shell_deselect
 * Params: GtkMenuShell *menu_shell
 * Returns: void
 * Assertion: Deselects the currently selected item from the menu shell, if any.
 * Params Values: GtkMenuShell*
 * Expected: void  
 */
static void test_purpose_17()
{
    GtkWidget *widget;
    GtkWidget *child;
    GtkMenuShell *menu_shell;
    
    gint i;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    deactivate = FALSE;
    
    widget = gtk_menu_new ();
    child = gtk_menu_item_new_with_label ("Menu Item");
    
    gtk_widget_show (child);
    
    for (i = 0; i < 5; i++)
    {
        GtkWidget* item = gtk_menu_item_new_with_label ("Item");
        gtk_menu_shell_append (GTK_MENU_SHELL (widget), item);
        gtk_widget_show (item);
    }
    
    gtk_menu_shell_append (GTK_MENU_SHELL (widget),child);
    menu_shell = GTK_MENU_SHELL (widget);
    menu_shell->active_menu_item = child; 
    
    g_signal_connect (G_OBJECT (child), "deselect", 
                      GTK_SIGNAL_FUNC (global_deactivate_signal), NULL);
    
    gtk_menu_shell_deselect (GTK_MENU_SHELL (widget));
    if (!deactivate)
    {
        TEST_FAIL ("Menu shell is not deselect", NULL);
    }
    gtk_menu_popup (GTK_MENU (widget), NULL, NULL, NULL, NULL, 0, GDK_CURRENT_TIME);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_menu_shell_select_item 
 * Params: GtkMenuShell *menu_shell,GtkWidget *menu_item
 * Returns: void
 * Assertion: Selects the menu item from the menu shell.
 * Params Values: GtkMenuShell*, GtkWidget*
 * Expected: void  
 */
static void test_purpose_18()
{
    GtkWidget *widget;
    GtkWidget *child;
    gint i;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    selection = FALSE;
    widget = gtk_menu_new ();
    child = gtk_menu_item_new_with_label ("Menu Item");
    
    gtk_widget_show (child);
    
    for (i = 0; i < 5; i++)
    {
        GtkWidget* item = gtk_menu_item_new_with_label ("Item");
        gtk_menu_shell_append (GTK_MENU_SHELL (widget), item);
        gtk_widget_show (item);
    }
    
    gtk_menu_shell_append (GTK_MENU_SHELL (widget), child);
    
    g_signal_connect (G_OBJECT (child), "select", 
                      GTK_SIGNAL_FUNC (global_select_signal), NULL);
    
    gtk_menu_shell_select_item (GTK_MENU_SHELL (widget),GTK_WIDGET (child));
    if (!selection)
    {
        TEST_FAIL ("Menu item is not selected", NULL);
    }
    
    gtk_menu_popup (GTK_MENU (widget), NULL, NULL, NULL, NULL, 0, GDK_CURRENT_TIME);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_menu_shell_select_first
 * Params: GtkMenuShell *menu_shell, gboolean search_sensitive
 * Returns: void
 * Assertion: Select the first visible or selectable child of the menu shell; don't select tearoff items unless the only item is a tearoff item.'
 * Params Values: GtkMenuShell*, TRUE
 * Expected: void  
 */
static void test_purpose_19()
{
    #define ITEM_SENSITIVE TRUE
    #define SELECT_SENSITIVE TRUE
    
    GtkWidget *widget;
    GtkWidget *child;
    gint i;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    selection = FALSE;
    widget = gtk_menu_new ();
    child = gtk_menu_item_new_with_label ("Menu Item");
    gtk_widget_set_sensitive (child, ITEM_SENSITIVE);
    
    gtk_widget_show (child);
    gtk_menu_shell_append (GTK_MENU_SHELL (widget), child);
    
    for (i = 0; i < 5; i++)
    {
        GtkWidget* item = gtk_menu_item_new_with_label ("Item");
        gtk_menu_shell_append (GTK_MENU_SHELL (widget), item);
        gtk_widget_show (item);
    }
    
    gtk_menu_popup (GTK_MENU (widget), NULL, NULL, NULL, NULL, 0, GDK_CURRENT_TIME);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    g_signal_connect (G_OBJECT (child), "select", 
                      GTK_SIGNAL_FUNC (global_select_signal), NULL);
    
    gtk_menu_shell_select_first (GTK_MENU_SHELL (widget), SELECT_SENSITIVE);
    
    if (SELECT_SENSITIVE)
    {
        if (ITEM_SENSITIVE)
        {
            if (!selection)
            {
                TEST_FAIL ("ITEM_SENSITIVE = %d, SELECT_SENSITIVE = %d, selection = %d", ITEM_SENSITIVE, SELECT_SENSITIVE, selection);
            }
        } else {
            if (selection)
            {
                TEST_FAIL ("ITEM_SENSITIVE = %d, SELECT_SENSITIVE = %d, selection = %d", ITEM_SENSITIVE, SELECT_SENSITIVE, selection);
            }
        }
    } else {
        if (!selection)
        {
            TEST_FAIL ("ITEM_SENSITIVE = %d, SELECT_SENSITIVE = %d, selection = %d", ITEM_SENSITIVE, SELECT_SENSITIVE, selection);
        }
    }
    
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef ITEM_SENSITIVE
    #undef SELECT_SENSITIVE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_menu_shell_select_first
 * Params: GtkMenuShell *menu_shell, gboolean search_sensitive
 * Returns: void
 * Assertion: Select the first visible or selectable child of the menu shell; don't select tearoff items unless the only item is a tearoff item.'
 * Params Values: GtkMenuShell*, TRUE
 * Expected: void  
 */
static void test_purpose_20()
{
    #define ITEM_SENSITIVE TRUE
    #define SELECT_SENSITIVE FALSE
    
    GtkWidget *widget;
    GtkWidget *child;
    gint i;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    selection = FALSE;
    widget = gtk_menu_new ();
    child = gtk_menu_item_new_with_label ("Menu Item");
    gtk_widget_set_sensitive (child, ITEM_SENSITIVE);
    
    gtk_widget_show (child);
    gtk_menu_shell_append (GTK_MENU_SHELL (widget), child);
    
    for (i = 0; i < 5; i++)
    {
        GtkWidget* item = gtk_menu_item_new_with_label ("Item");
        gtk_menu_shell_append (GTK_MENU_SHELL (widget), item);
        gtk_widget_show (item);
    }
    
    gtk_menu_popup (GTK_MENU (widget), NULL, NULL, NULL, NULL, 0, GDK_CURRENT_TIME);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    g_signal_connect (G_OBJECT (child), "select", 
                      GTK_SIGNAL_FUNC (global_select_signal), NULL);
    
    gtk_menu_shell_select_first (GTK_MENU_SHELL (widget), SELECT_SENSITIVE);
    
    if (SELECT_SENSITIVE)
    {
        if (ITEM_SENSITIVE)
        {
            if (!selection)
            {
                TEST_FAIL ("ITEM_SENSITIVE = %d, SELECT_SENSITIVE = %d, selection = %d", ITEM_SENSITIVE, SELECT_SENSITIVE, selection);
            }
        } else {
            if (selection)
            {
                TEST_FAIL ("ITEM_SENSITIVE = %d, SELECT_SENSITIVE = %d, selection = %d", ITEM_SENSITIVE, SELECT_SENSITIVE, selection);
            }
        }
    } else {
        if (!selection)
        {
            TEST_FAIL ("ITEM_SENSITIVE = %d, SELECT_SENSITIVE = %d, selection = %d", ITEM_SENSITIVE, SELECT_SENSITIVE, selection);
        }
    }
    
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef ITEM_SENSITIVE
    #undef SELECT_SENSITIVE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_menu_shell_select_first
 * Params: GtkMenuShell *menu_shell, gboolean search_sensitive
 * Returns: void
 * Assertion: Select the first visible or selectable child of the menu shell; don't select tearoff items unless the only item is a tearoff item.'
 * Params Values: GtkMenuShell*, FALSE
 * Expected: void  
 */
static void test_purpose_21()
{
    #define ITEM_SENSITIVE FALSE
    #define SELECT_SENSITIVE TRUE
    
    GtkWidget *widget;
    GtkWidget *child;
    gint i;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    selection = FALSE;
    widget = gtk_menu_new ();
    child = gtk_menu_item_new_with_label ("Menu Item");
    gtk_widget_set_sensitive (child, ITEM_SENSITIVE);
    
    gtk_widget_show (child);
    gtk_menu_shell_append (GTK_MENU_SHELL (widget), child);
    
    for (i = 0; i < 5; i++)
    {
        GtkWidget* item = gtk_menu_item_new_with_label ("Item");
        gtk_menu_shell_append (GTK_MENU_SHELL (widget), item);
        gtk_widget_show (item);
    }
    
    gtk_menu_popup (GTK_MENU (widget), NULL, NULL, NULL, NULL, 0, GDK_CURRENT_TIME);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    g_signal_connect (G_OBJECT (child), "select", 
                      GTK_SIGNAL_FUNC (global_select_signal), NULL);
    
    gtk_menu_shell_select_first (GTK_MENU_SHELL (widget), SELECT_SENSITIVE);
    
    if (SELECT_SENSITIVE)
    {
        if (ITEM_SENSITIVE)
        {
            if (!selection)
            {
                TEST_FAIL ("ITEM_SENSITIVE = %d, SELECT_SENSITIVE = %d, selection = %d", ITEM_SENSITIVE, SELECT_SENSITIVE, selection);
            }
        } else {
            if (selection)
            {
                TEST_FAIL ("ITEM_SENSITIVE = %d, SELECT_SENSITIVE = %d, selection = %d", ITEM_SENSITIVE, SELECT_SENSITIVE, selection);
            }
        }
    } else {
        if (!selection)
        {
            TEST_FAIL ("ITEM_SENSITIVE = %d, SELECT_SENSITIVE = %d, selection = %d", ITEM_SENSITIVE, SELECT_SENSITIVE, selection);
        }
    }
    
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef ITEM_SENSITIVE
    #undef SELECT_SENSITIVE
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GtkMenuShell ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {test_purpose_11, 1},
    {test_purpose_12, 1},
    {test_purpose_13, 1},
    {test_purpose_14, 1},
    {test_purpose_15, 1},
    {test_purpose_16, 1},
    {test_purpose_17, 1},
    {test_purpose_18, 1},
    {test_purpose_19, 1},
    {test_purpose_20, 1},
    {test_purpose_21, 1},
    {NULL,0}
};
