/*
 * GtkProgressBar methods tests
 * Testing GtkProgressBar methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;

/*
 * Name: gtk_progress_bar_new
 * Params: void
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkProgressBar.
 * Params Values: <%0%> 
 * Expected: GtkProgressbar*  
 */
static void test_purpose_1()
{
    GtkWidget *widget;
    
    GtkAdjustment*  adjustment;
    GtkProgressBarOrientation orientation;
    GtkProgressBarStyle  bar_style;
    guint   activity_step;
    guint   activity_blocks; 
    gdouble fraction;
    gchararray text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_progress_bar_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_PROGRESS_BAR (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "orientation", &orientation, NULL);
    if (orientation != GTK_PROGRESS_LEFT_TO_RIGHT) 
    {
        TEST_FAIL ("orientation is %d, should be %d", 
                   orientation, GTK_PROGRESS_LEFT_TO_RIGHT);
    }
    
    g_object_get(GTK_OBJECT(widget), "bar-style", &bar_style, NULL);
    if (bar_style != GTK_PROGRESS_CONTINUOUS) 
    {
        TEST_FAIL ("bar_style is %d, should be %d", 
                   bar_style, GTK_PROGRESS_CONTINUOUS);
    }
    
    g_object_get(GTK_OBJECT(widget), "fraction", &fraction, NULL);
    if (fraction != 0) 
    {
        TEST_FAIL ("fraction is %d, should be 0", fraction);
    }
    
    g_object_get(GTK_OBJECT(widget), "activity-step", &activity_step, NULL);
    if (activity_step != 3) 
    {
        TEST_FAIL ("activity_step is %d, should be 3", activity_step);
    }
    
    g_object_get(GTK_OBJECT(widget), "activity-blocks", &activity_blocks, NULL);
    if (activity_blocks != 5) 
    {
        TEST_FAIL ("activity_blocks is %d, should be 5", activity_blocks);
    }
    
    g_object_get(GTK_OBJECT(widget), "text", &text, NULL);
    if (text != NULL) 
    {
        TEST_FAIL ("text = %s, should be NULL", text);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_progress_bar_set_text
 * Params: GtkProgressBar *pbar, const gchar *text
 * Returns: void
 * Assertion: Causes the given text to appear superimposed on the progress bar.
 * Params Values: newly created GtkProgressBar*, NULL
 * Expected: void
 * 
 * Name: gtk_progress_bar_get_text
 * Params: GtkProgressBar *pbar
 * Returns: G_CONST_RETURN gchar*
 * Assertion: Retrieves the text displayed superimposed on the progress bar, if any, otherwise NULL.
 * Params Values: newly created GtkProgressBar*
 * Expected: NULL  
 */
static void test_purpose_2()
{
    #define TEXT NULL
    
    GtkWidget *widget;
    gchar *text;
    G_CONST_RETURN gchar *real_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_progress_bar_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_PROGRESS_BAR (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    text = TEXT;
    gtk_progress_bar_set_text (GTK_PROGRESS_BAR (widget), text);
    
    real_text = gtk_progress_bar_get_text (GTK_PROGRESS_BAR (widget));
    
    if (text != NULL)
    {
        if (!real_text)
        {
            TEST_FAIL("Text is NULL, should be '%s'\n", text);
        } else if (strcmp (real_text, text)) {
            TEST_FAIL("Text = '%s', should be '%s'\n", real_text, text);
        }
    } else {
        if (real_text)
        {
            TEST_FAIL("Text is '%s', should be NULL\n", real_text);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_progress_bar_set_text
 * Params: GtkProgressBar *pbar, const gchar *text
 * Returns: void
 * Assertion: Causes the given text to appear superimposed on the progress bar.
 * Params Values: newly created GtkProgressBar*, ""
 * Expected: void
 * 
 * Name: gtk_progress_bar_get_text
 * Params: GtkProgressBar *pbar
 * Returns: G_CONST_RETURN gchar*
 * Assertion: Retrieves the text displayed superimposed on the progress bar, if any, otherwise NULL.
 * Params Values: newly created GtkProgressBar*
 * Expected: ""  
 */
static void test_purpose_3()
{
    #define TEXT ""
    
    GtkWidget *widget;
    gchar *text;
    G_CONST_RETURN gchar *real_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_progress_bar_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_PROGRESS_BAR (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    text = TEXT;
    gtk_progress_bar_set_text (GTK_PROGRESS_BAR (widget), text);
    
    real_text = gtk_progress_bar_get_text (GTK_PROGRESS_BAR (widget));
    
    if (text != NULL)
    {
        if (!real_text)
        {
            TEST_FAIL("Text is NULL, should be '%s'\n", text);
        } else if (strcmp (real_text, text)) {
            TEST_FAIL("Text = '%s', should be '%s'\n", real_text, text);
        }
    } else {
        if (real_text)
        {
            TEST_FAIL("Text is '%s', should be NULL\n", real_text);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_progress_bar_set_text
 * Params: GtkProgressBar *pbar, const gchar *text
 * Returns: void
 * Assertion: Causes the given text to appear superimposed on the progress bar.
 * Params Values: newly created GtkProgressBar*, " "
 * Expected: void
 * 
 * Name: gtk_progress_bar_get_text
 * Params: GtkProgressBar *pbar
 * Returns: G_CONST_RETURN gchar*
 * Assertion: Retrieves the text displayed superimposed on the progress bar, if any, otherwise NULL.
 * Params Values: newly created GtkProgressBar*
 * Expected: " "  
 */
static void test_purpose_4()
{
    #define TEXT " "
    
    GtkWidget *widget;
    gchar *text;
    G_CONST_RETURN gchar *real_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_progress_bar_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_PROGRESS_BAR (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    text = TEXT;
    gtk_progress_bar_set_text (GTK_PROGRESS_BAR (widget), text);
    
    real_text = gtk_progress_bar_get_text (GTK_PROGRESS_BAR (widget));
    
    if (text != NULL)
    {
        if (!real_text)
        {
            TEST_FAIL("Text is NULL, should be '%s'\n", text);
        } else if (strcmp (real_text, text)) {
            TEST_FAIL("Text = '%s', should be '%s'\n", real_text, text);
        }
    } else {
        if (real_text)
        {
            TEST_FAIL("Text is '%s', should be NULL\n", real_text);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_progress_bar_set_text
 * Params: GtkProgressBar *pbar, const gchar *text
 * Returns: void
 * Assertion: Causes the given text to appear superimposed on the progress bar.
 * Params Values: newly created GtkProgressBar*, "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
 * Expected: void
 * 
 * Name: gtk_progress_bar_get_text
 * Params: GtkProgressBar *pbar
 * Returns: G_CONST_RETURN gchar*
 * Assertion: Retrieves the text displayed superimposed on the progress bar, if any, otherwise NULL.
 * Params Values: newly created GtkProgressBar*
 * Expected: "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"  
 */
static void test_purpose_5()
{
    #define TEXT "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    
    GtkWidget *widget;
    gchar *text;
    G_CONST_RETURN gchar *real_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_progress_bar_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_PROGRESS_BAR (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    text = TEXT;
    gtk_progress_bar_set_text (GTK_PROGRESS_BAR (widget), text);
    
    real_text = gtk_progress_bar_get_text (GTK_PROGRESS_BAR (widget));
    
    if (text != NULL)
    {
        if (!real_text)
        {
            TEST_FAIL("Text is NULL, should be '%s'\n", text);
        } else if (strcmp (real_text, text)) {
            TEST_FAIL("Text = '%s', should be '%s'\n", real_text, text);
        }
    } else {
        if (real_text)
        {
            TEST_FAIL("Text is '%s', should be NULL\n", real_text);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_progress_bar_set_text
 * Params: GtkProgressBar *pbar, const gchar *text
 * Returns: void
 * Assertion: Causes the given text to appear superimposed on the progress bar.
 * Params Values: newly created GtkProgressBar*, "!@#$%^&*()_+|~=\";:'?<>`/"
 * Expected: void
 * 
 * Name: gtk_progress_bar_get_text
 * Params: GtkProgressBar *pbar
 * Returns: G_CONST_RETURN gchar*
 * Assertion: Retrieves the text displayed superimposed on the progress bar, if any, otherwise NULL.
 * Params Values: newly created GtkProgressBar*
 * Expected: "!@#$%^&*()_+|~=\";:'?<>`/"  
 */
static void test_purpose_6()
{
    #define TEXT "!@#$%^&*()_+|~=\";:'?<>`/"
    
    GtkWidget *widget;
    gchar *text;
    G_CONST_RETURN gchar *real_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_progress_bar_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_PROGRESS_BAR (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    text = TEXT;
    gtk_progress_bar_set_text (GTK_PROGRESS_BAR (widget), text);
    
    real_text = gtk_progress_bar_get_text (GTK_PROGRESS_BAR (widget));
    
    if (text != NULL)
    {
        if (!real_text)
        {
            TEST_FAIL("Text is NULL, should be '%s'\n", text);
        } else if (strcmp (real_text, text)) {
            TEST_FAIL("Text = '%s', should be '%s'\n", real_text, text);
        }
    } else {
        if (real_text)
        {
            TEST_FAIL("Text is '%s', should be NULL\n", real_text);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_progress_bar_set_text
 * Params: GtkProgressBar *pbar, const gchar *text
 * Returns: void
 * Assertion: Causes the given text to appear superimposed on the progress bar.
 * Params Values: newly created GtkProgressBar*, "_a_b"
 * Expected: void
 * 
 * Name: gtk_progress_bar_get_text
 * Params: GtkProgressBar *pbar
 * Returns: G_CONST_RETURN gchar*
 * Assertion: Retrieves the text displayed superimposed on the progress bar, if any, otherwise NULL.
 * Params Values: newly created GtkProgressBar*
 * Expected: "_a_b"  
 */
static void test_purpose_7()
{
    #define TEXT "_a_b"
    
    GtkWidget *widget;
    gchar *text;
    G_CONST_RETURN gchar *real_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_progress_bar_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_PROGRESS_BAR (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    text = TEXT;
    gtk_progress_bar_set_text (GTK_PROGRESS_BAR (widget), text);
    
    real_text = gtk_progress_bar_get_text (GTK_PROGRESS_BAR (widget));
    
    if (text != NULL)
    {
        if (!real_text)
        {
            TEST_FAIL("Text is NULL, should be '%s'\n", text);
        } else if (strcmp (real_text, text)) {
            TEST_FAIL("Text = '%s', should be '%s'\n", real_text, text);
        }
    } else {
        if (real_text)
        {
            TEST_FAIL("Text is '%s', should be NULL\n", real_text);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_progress_bar_set_text
 * Params: GtkProgressBar *pbar, const gchar *text
 * Returns: void
 * Assertion: Causes the given text to appear superimposed on the progress bar.
 * Params Values: newly created GtkProgressBar*, "\n\t\""
 * Expected: void
 * 
 * Name: gtk_progress_bar_get_text
 * Params: GtkProgressBar *pbar
 * Returns: G_CONST_RETURN gchar*
 * Assertion: Retrieves the text displayed superimposed on the progress bar, if any, otherwise NULL.
 * Params Values: newly created GtkProgressBar*
 * Expected: "\n\t\""  
 */
static void test_purpose_8()
{
    #define TEXT "\n\t\""
    
    GtkWidget *widget;
    gchar *text;
    G_CONST_RETURN gchar *real_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_progress_bar_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_PROGRESS_BAR (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    text = TEXT;
    gtk_progress_bar_set_text (GTK_PROGRESS_BAR (widget), text);
    
    real_text = gtk_progress_bar_get_text (GTK_PROGRESS_BAR (widget));
    
    if (text != NULL)
    {
        if (!real_text)
        {
            TEST_FAIL("Text is NULL, should be '%s'\n", text);
        } else if (strcmp (real_text, text)) {
            TEST_FAIL("Text = '%s', should be '%s'\n", real_text, text);
        }
    } else {
        if (real_text)
        {
            TEST_FAIL("Text is '%s', should be NULL\n", real_text);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_progress_bar_set_text
 * Params: GtkProgressBar *pbar, const gchar *text
 * Returns: void
 * Assertion: Causes the given text to appear superimposed on the progress bar.
 * Params Values: newly created GtkProgressBar*, "_\n\t\""
 * Expected: void
 * 
 * Name: gtk_progress_bar_get_text
 * Params: GtkProgressBar *pbar
 * Returns: G_CONST_RETURN gchar*
 * Assertion: Retrieves the text displayed superimposed on the progress bar, if any, otherwise NULL.
 * Params Values: newly created GtkProgressBar*
 * Expected: "_\n\t\""  
 */
static void test_purpose_9()
{
    #define TEXT "_\n\t\""
    
    GtkWidget *widget;
    gchar *text;
    G_CONST_RETURN gchar *real_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_progress_bar_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_PROGRESS_BAR (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    text = TEXT;
    gtk_progress_bar_set_text (GTK_PROGRESS_BAR (widget), text);
    
    real_text = gtk_progress_bar_get_text (GTK_PROGRESS_BAR (widget));
    
    if (text != NULL)
    {
        if (!real_text)
        {
            TEST_FAIL("Text is NULL, should be '%s'\n", text);
        } else if (strcmp (real_text, text)) {
            TEST_FAIL("Text = '%s', should be '%s'\n", real_text, text);
        }
    } else {
        if (real_text)
        {
            TEST_FAIL("Text is '%s', should be NULL\n", real_text);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_progress_bar_set_text
 * Params: GtkProgressBar *pbar, const gchar *text
 * Returns: void
 * Assertion: Causes the given text to appear superimposed on the progress bar.
 * Params Values: newly created GtkProgressBar*, "\b"
 * Expected: void
 * 
 * Name: gtk_progress_bar_get_text
 * Params: GtkProgressBar *pbar
 * Returns: G_CONST_RETURN gchar*
 * Assertion: Retrieves the text displayed superimposed on the progress bar, if any, otherwise NULL.
 * Params Values: newly created GtkProgressBar*
 * Expected: "\b"  
 */
static void test_purpose_10()
{
    #define TEXT "\b"
    
    GtkWidget *widget;
    gchar *text;
    G_CONST_RETURN gchar *real_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_progress_bar_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_PROGRESS_BAR (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    text = TEXT;
    gtk_progress_bar_set_text (GTK_PROGRESS_BAR (widget), text);
    
    real_text = gtk_progress_bar_get_text (GTK_PROGRESS_BAR (widget));
    
    if (text != NULL)
    {
        if (!real_text)
        {
            TEST_FAIL("Text is NULL, should be '%s'\n", text);
        } else if (strcmp (real_text, text)) {
            TEST_FAIL("Text = '%s', should be '%s'\n", real_text, text);
        }
    } else {
        if (real_text)
        {
            TEST_FAIL("Text is '%s', should be NULL\n", real_text);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_progress_bar_set_text
 * Params: GtkProgressBar *pbar, const gchar *text
 * Returns: void
 * Assertion: Causes the given text to appear superimposed on the progress bar.
 * Params Values: newly created GtkProgressBar*, "_\b"
 * Expected: void
 * 
 * Name: gtk_progress_bar_get_text
 * Params: GtkProgressBar *pbar
 * Returns: G_CONST_RETURN gchar*
 * Assertion: Retrieves the text displayed superimposed on the progress bar, if any, otherwise NULL.
 * Params Values: newly created GtkProgressBar*
 * Expected: "_\b"  
 */
static void test_purpose_11()
{
    #define TEXT "_\b"
    
    GtkWidget *widget;
    gchar *text;
    G_CONST_RETURN gchar *real_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_progress_bar_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_PROGRESS_BAR (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    text = TEXT;
    gtk_progress_bar_set_text (GTK_PROGRESS_BAR (widget), text);
    
    real_text = gtk_progress_bar_get_text (GTK_PROGRESS_BAR (widget));
    
    if (text != NULL)
    {
        if (!real_text)
        {
            TEST_FAIL("Text is NULL, should be '%s'\n", text);
        } else if (strcmp (real_text, text)) {
            TEST_FAIL("Text = '%s', should be '%s'\n", real_text, text);
        }
    } else {
        if (real_text)
        {
            TEST_FAIL("Text is '%s', should be NULL\n", real_text);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_progress_bar_set_fraction
 * Params: GtkProgressBar *pbar, gdouble *fraction
 * Returns: void
 * Assertion: Causes the progress bar to "fill in" the given fraction of the bar.
 * Params Values: newly created GtkProgressBar*, 0.0
 * Expected: void
 * 
 * Name: gtk_progress_bar_get_fraction
 * Params: GtkProgressBar *pbar
 * Returns: gdouble*
 * Assertion: Returns the current fraction of the task that's been completed.'
 * Params Values: newly created GtkProgressBar*
 * Expected: 0.0  
 */
static void test_purpose_12()
{
    #define FRACTION 0.0
    
    GtkWidget *widget;
    gdouble fraction;
    gdouble real_fraction;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_progress_bar_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_PROGRESS_BAR (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    fraction = (gdouble) FRACTION;
    gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR (widget), fraction);
    
    real_fraction = gtk_progress_bar_get_fraction (GTK_PROGRESS_BAR (widget));
    if (real_fraction != fraction)
    {
        TEST_FAIL("real_fraction = %lf, should be %lf\n", real_fraction, fraction);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef FRACTION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_progress_bar_set_fraction
 * Params: GtkProgressBar *pbar, gdouble *fraction
 * Returns: void
 * Assertion: Causes the progress bar to "fill in" the given fraction of the bar.
 * Params Values: newly created GtkProgressBar*, 0.7
 * Expected: void
 * 
 * Name: gtk_progress_bar_get_fraction
 * Params: GtkProgressBar *pbar
 * Returns: gdouble*
 * Assertion: Returns the current fraction of the task that's been completed.'
 * Params Values: newly created GtkProgressBar*
 * Expected: 0.7  
 */
static void test_purpose_13()
{
    #define FRACTION 0.7
    
    GtkWidget *widget;
    gdouble fraction;
    gdouble real_fraction;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_progress_bar_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_PROGRESS_BAR (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    fraction = (gdouble) FRACTION;
    gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR (widget), fraction);
    
    real_fraction = gtk_progress_bar_get_fraction (GTK_PROGRESS_BAR (widget));
    if (real_fraction != fraction)
    {
        TEST_FAIL("real_fraction = %lf, should be %lf\n", real_fraction, fraction);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef FRACTION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_progress_bar_set_fraction
 * Params: GtkProgressBar *pbar, gdouble *fraction
 * Returns: void
 * Assertion: Causes the progress bar to "fill in" the given fraction of the bar.
 * Params Values: newly created GtkProgressBar*, 1.0
 * Expected: void
 * 
 * Name: gtk_progress_bar_get_fraction
 * Params: GtkProgressBar *pbar
 * Returns: gdouble*
 * Assertion: Returns the current fraction of the task that's been completed.'
 * Params Values: newly created GtkProgressBar*
 * Expected: 1.0  
 */
static void test_purpose_14()
{
    #define FRACTION 1.0
    
    GtkWidget *widget;
    gdouble fraction;
    gdouble real_fraction;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_progress_bar_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_PROGRESS_BAR (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    fraction = (gdouble) FRACTION;
    gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR (widget), fraction);
    
    real_fraction = gtk_progress_bar_get_fraction (GTK_PROGRESS_BAR (widget));
    if (real_fraction != fraction)
    {
        TEST_FAIL("real_fraction = %lf, should be %lf\n", real_fraction, fraction);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef FRACTION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_progress_bar_set_pulse_step
 * Params: GtkProgressBar *pbar, gdouble *fraction
 * Returns: void
 * Assertion: Sets the fraction of total progress bar length to move the bouncing block for each call to gtk_progress_bar_pulse().
 * Params Values: newly created GtkProgressBar*, 0.0
 * Expected: void
 * 
 * Name: gtk_progress_bar_get_pulse_step
 * Params: GtkProgressBar *pbar
 * Returns: gdouble*
 * Assertion: Retrieves the pulse step set with gtk_progress_bar_set_pulse_step()
 * Params Values: newly created GtkProgressBar*
 * Expected: 0.0  
 */
static void test_purpose_15()
{
    #define PULSE_STEP 0.0
    #define FRACTION 0.3
    #define PULSE_NUM 6
    
    GtkWidget *widget;
    gdouble fraction;
    gdouble pulse_step;
    gdouble real_pulse_step;
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_progress_bar_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_PROGRESS_BAR (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    fraction = (gdouble) FRACTION;
    pulse_step = (gdouble) PULSE_STEP;
    
    gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR (widget), fraction);
    gtk_progress_bar_set_pulse_step (GTK_PROGRESS_BAR (widget), pulse_step);
    
    real_pulse_step = gtk_progress_bar_get_pulse_step (GTK_PROGRESS_BAR (widget));
    if (real_pulse_step != pulse_step)
    {
        TEST_FAIL("real_pulse_step = %lf, should be %lf\n", 
                  real_pulse_step, pulse_step);
    }
    
    for (i = 0; i < PULSE_NUM; i++)
    {
        gtk_progress_bar_pulse (GTK_PROGRESS_BAR (widget));
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef PULSE_STEP
    #undef FRACTION
    #undef PULSE_NUM
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_progress_bar_set_pulse_step
 * Params: GtkProgressBar *pbar, gdouble *fraction
 * Returns: void
 * Assertion: Sets the fraction of total progress bar length to move the bouncing block for each call to gtk_progress_bar_pulse().
 * Params Values: newly created GtkProgressBar*, 0.05
 * Expected: void
 * 
 * Name: gtk_progress_bar_get_pulse_step
 * Params: GtkProgressBar *pbar
 * Returns: gdouble*
 * Assertion: Retrieves the pulse step set with gtk_progress_bar_set_pulse_step()
 * Params Values: newly created GtkProgressBar*
 * Expected: 0.05  
 */
static void test_purpose_16()
{
    #define PULSE_STEP 0.05
    #define FRACTION 0.3
    #define PULSE_NUM 3
    
    GtkWidget *widget;
    gdouble fraction;
    gdouble pulse_step;
    gdouble real_pulse_step;
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_progress_bar_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_PROGRESS_BAR (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    fraction = (gdouble) FRACTION;
    pulse_step = (gdouble) PULSE_STEP;
    
    gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR (widget), fraction);
    gtk_progress_bar_set_pulse_step (GTK_PROGRESS_BAR (widget), pulse_step);
    
    real_pulse_step = gtk_progress_bar_get_pulse_step (GTK_PROGRESS_BAR (widget));
    if (real_pulse_step != pulse_step)
    {
        TEST_FAIL("real_pulse_step = %lf, should be %lf\n", 
                  real_pulse_step, pulse_step);
    }
    
    for (i = 0; i < PULSE_NUM; i++)
    {
        gtk_progress_bar_pulse (GTK_PROGRESS_BAR (widget));
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef PULSE_STEP
    #undef FRACTION
    #undef PULSE_NUM
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_progress_bar_set_pulse_step
 * Params: GtkProgressBar *pbar, gdouble *fraction
 * Returns: void
 * Assertion: Sets the fraction of total progress bar length to move the bouncing block for each call to gtk_progress_bar_pulse().
 * Params Values: newly created GtkProgressBar*, 0.1
 * Expected: void
 * 
 * Name: gtk_progress_bar_get_pulse_step
 * Params: GtkProgressBar *pbar
 * Returns: gdouble*
 * Assertion: Retrieves the pulse step set with gtk_progress_bar_set_pulse_step()
 * Params Values: newly created GtkProgressBar*
 * Expected: 0.1  
 */
static void test_purpose_17()
{
    #define PULSE_STEP 0.1
    #define FRACTION 0.7
    #define PULSE_NUM 2
    
    GtkWidget *widget;
    gdouble fraction;
    gdouble pulse_step;
    gdouble real_pulse_step;
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_progress_bar_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_PROGRESS_BAR (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    fraction = (gdouble) FRACTION;
    pulse_step = (gdouble) PULSE_STEP;
    
    gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR (widget), fraction);
    gtk_progress_bar_set_pulse_step (GTK_PROGRESS_BAR (widget), pulse_step);
    
    real_pulse_step = gtk_progress_bar_get_pulse_step (GTK_PROGRESS_BAR (widget));
    if (real_pulse_step != pulse_step)
    {
        TEST_FAIL("real_pulse_step = %lf, should be %lf\n", 
                  real_pulse_step, pulse_step);
    }
    
    for (i = 0; i < PULSE_NUM; i++)
    {
        gtk_progress_bar_pulse (GTK_PROGRESS_BAR (widget));
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef PULSE_STEP
    #undef FRACTION
    #undef PULSE_NUM
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_progress_bar_set_pulse_step
 * Params: GtkProgressBar *pbar, gdouble *fraction
 * Returns: void
 * Assertion: Sets the fraction of total progress bar length to move the bouncing block for each call to gtk_progress_bar_pulse().
 * Params Values: newly created GtkProgressBar*, 0.4
 * Expected: void
 * 
 * Name: gtk_progress_bar_get_pulse_step
 * Params: GtkProgressBar *pbar
 * Returns: gdouble*
 * Assertion: Retrieves the pulse step set with gtk_progress_bar_set_pulse_step()
 * Params Values: newly created GtkProgressBar*
 * Expected: 0.4  
 */
static void test_purpose_18()
{
    #define PULSE_STEP 0.4
    #define FRACTION 1.0
    #define PULSE_NUM 5
    
    GtkWidget *widget;
    gdouble fraction;
    gdouble pulse_step;
    gdouble real_pulse_step;
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_progress_bar_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_PROGRESS_BAR (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    fraction = (gdouble) FRACTION;
    pulse_step = (gdouble) PULSE_STEP;
    
    gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR (widget), fraction);
    gtk_progress_bar_set_pulse_step (GTK_PROGRESS_BAR (widget), pulse_step);
    
    real_pulse_step = gtk_progress_bar_get_pulse_step (GTK_PROGRESS_BAR (widget));
    if (real_pulse_step != pulse_step)
    {
        TEST_FAIL("real_pulse_step = %lf, should be %lf\n", 
                  real_pulse_step, pulse_step);
    }
    
    for (i = 0; i < PULSE_NUM; i++)
    {
        gtk_progress_bar_pulse (GTK_PROGRESS_BAR (widget));
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef PULSE_STEP
    #undef FRACTION
    #undef PULSE_NUM
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_progress_bar_set_orientation
 * Params: GtkProgressBar *pbar, GtkProgressBarOrientation *orientation
 * Returns: void
 * Assertion: Causes the progress bar to switch to a different orientation (left-to-right, right-to-left, top-to-bottom, or bottom-to-top).
 * Params Values: newly created GtkProgressBar*, GTK_PROGRESS_LEFT_TO_RIGHT
 * Expected: void
 * 
 * Name: gtk_progress_bar_get_orientation
 * Params: GtkProgressBar *pbar
 * Returns: GtkProgressBarOrientation
 * Assertion: Retrieves the current progress bar orientation.
 * Params Values: newly created GtkProgressBar*
 * Expected: GTK_PROGRESS_LEFT_TO_RIGHT  
 */
static void test_purpose_19()
{
    #define ORIENTATION GTK_PROGRESS_LEFT_TO_RIGHT
    
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_progress_bar_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_PROGRESS_BAR (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_progress_bar_set_orientation (GTK_PROGRESS_BAR (widget), ORIENTATION);
    
    if (gtk_progress_bar_get_orientation (GTK_PROGRESS_BAR (widget)) != ORIENTATION)
    {
        TEST_FAIL("Orientation =  %d, should be %d\n", gtk_progress_bar_get_orientation(GTK_PROGRESS_BAR (widget)), ORIENTATION);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef ORIENTATION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_progress_bar_set_orientation
 * Params: GtkProgressBar *pbar, GtkProgressBarOrientation *orientation
 * Returns: void
 * Assertion: Causes the progress bar to switch to a different orientation (left-to-right, right-to-left, top-to-bottom, or bottom-to-top).
 * Params Values: newly created GtkProgressBar*, GTK_PROGRESS_RIGHT_TO_LEFT
 * Expected: void
 * 
 * Name: gtk_progress_bar_get_orientation
 * Params: GtkProgressBar *pbar
 * Returns: GtkProgressBarOrientation
 * Assertion: Retrieves the current progress bar orientation.
 * Params Values: newly created GtkProgressBar*
 * Expected: GTK_PROGRESS_RIGHT_TO_LEFT  
 */
static void test_purpose_20()
{
    #define ORIENTATION GTK_PROGRESS_RIGHT_TO_LEFT
    
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_progress_bar_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_PROGRESS_BAR (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_progress_bar_set_orientation (GTK_PROGRESS_BAR (widget), ORIENTATION);
    
    if (gtk_progress_bar_get_orientation (GTK_PROGRESS_BAR (widget)) != ORIENTATION)
    {
        TEST_FAIL("Orientation =  %d, should be %d\n", gtk_progress_bar_get_orientation(GTK_PROGRESS_BAR (widget)), ORIENTATION);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef ORIENTATION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_progress_bar_set_orientation
 * Params: GtkProgressBar *pbar, GtkProgressBarOrientation *orientation
 * Returns: void
 * Assertion: Causes the progress bar to switch to a different orientation (left-to-right, right-to-left, top-to-bottom, or bottom-to-top).
 * Params Values: newly created GtkProgressBar*, GTK_PROGRESS_BOTTOM_TO_TOP
 * Expected: void
 * 
 * Name: gtk_progress_bar_get_orientation
 * Params: GtkProgressBar *pbar
 * Returns: GtkProgressBarOrientation
 * Assertion: Retrieves the current progress bar orientation.
 * Params Values: newly created GtkProgressBar*
 * Expected: GTK_PROGRESS_BOTTOM_TO_TOP  
 */
static void test_purpose_21()
{
    #define ORIENTATION GTK_PROGRESS_BOTTOM_TO_TOP
    
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_progress_bar_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_PROGRESS_BAR (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_progress_bar_set_orientation (GTK_PROGRESS_BAR (widget), ORIENTATION);
    
    if (gtk_progress_bar_get_orientation (GTK_PROGRESS_BAR (widget)) != ORIENTATION)
    {
        TEST_FAIL("Orientation =  %d, should be %d\n", gtk_progress_bar_get_orientation(GTK_PROGRESS_BAR (widget)), ORIENTATION);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef ORIENTATION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_progress_bar_set_orientation
 * Params: GtkProgressBar *pbar, GtkProgressBarOrientation *orientation
 * Returns: void
 * Assertion: Causes the progress bar to switch to a different orientation (left-to-right, right-to-left, top-to-bottom, or bottom-to-top).
 * Params Values: newly created GtkProgressBar*, GTK_PROGRESS_TOP_TO_BOTTOM
 * Expected: void
 * 
 * Name: gtk_progress_bar_get_orientation
 * Params: GtkProgressBar *pbar
 * Returns: GtkProgressBarOrientation
 * Assertion: Retrieves the current progress bar orientation.
 * Params Values: newly created GtkProgressBar*
 * Expected: GTK_PROGRESS_TOP_TO_BOTTOM  
 */
static void test_purpose_22()
{
    #define ORIENTATION GTK_PROGRESS_TOP_TO_BOTTOM
    
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_progress_bar_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_PROGRESS_BAR (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_progress_bar_set_orientation (GTK_PROGRESS_BAR (widget), ORIENTATION);
    
    if (gtk_progress_bar_get_orientation (GTK_PROGRESS_BAR (widget)) != ORIENTATION)
    {
        TEST_FAIL("Orientation =  %d, should be %d\n", gtk_progress_bar_get_orientation(GTK_PROGRESS_BAR (widget)), ORIENTATION);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef ORIENTATION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_progress_bar_pulse
 * Params: GtkProgressBar *pbar
 * Returns: void
 * Assertion: Each call to gtk_progress_bar_pulse() causes the block to move by a little bit (the amount of movement per pulse is determined by gtk_progress_bar_set_pulse_step()).
 * Params Values: newly created GtkProgressBar*, 0.0
 * Expected: void  
 */
static void test_purpose_23()
{
    #define PULSE_STEP 0.0
    #define FRACTION 0.3
    #define PULSE_NUM 6
    
    GtkWidget *widget;
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_progress_bar_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_PROGRESS_BAR (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR (widget), FRACTION);
    gtk_progress_bar_set_pulse_step (GTK_PROGRESS_BAR (widget), PULSE_STEP);
    
    for (i = 0; i < PULSE_NUM; i++)
    {
        gtk_progress_bar_pulse (GTK_PROGRESS_BAR (widget));
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef PULSE_STEP
    #undef FRACTION
    #undef PULSE_NUM
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_progress_bar_pulse
 * Params: GtkProgressBar *pbar
 * Returns: void
 * Assertion: Each call to gtk_progress_bar_pulse() causes the block to move by a little bit (the amount of movement per pulse is determined by gtk_progress_bar_set_pulse_step()).
 * Params Values: newly created GtkProgressBar*, 0.05
 * Expected: void  
 */
static void test_purpose_24()
{
    #define PULSE_STEP 0.05
    #define FRACTION 0.3
    #define PULSE_NUM 3
    
    GtkWidget *widget;
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_progress_bar_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_PROGRESS_BAR (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR (widget), FRACTION);
    gtk_progress_bar_set_pulse_step (GTK_PROGRESS_BAR (widget), PULSE_STEP);
    
    for (i = 0; i < PULSE_NUM; i++)
    {
        gtk_progress_bar_pulse (GTK_PROGRESS_BAR (widget));
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef PULSE_STEP
    #undef FRACTION
    #undef PULSE_NUM
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_progress_bar_pulse
 * Params: GtkProgressBar *pbar
 * Returns: void
 * Assertion: Each call to gtk_progress_bar_pulse() causes the block to move by a little bit (the amount of movement per pulse is determined by gtk_progress_bar_set_pulse_step()).
 * Params Values: newly created GtkProgressBar*, 0.1
 * Expected: void  
 */
static void test_purpose_25()
{
    #define PULSE_STEP 0.1
    #define FRACTION 0.7
    #define PULSE_NUM 2
    
    GtkWidget *widget;
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_progress_bar_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_PROGRESS_BAR (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR (widget), FRACTION);
    gtk_progress_bar_set_pulse_step (GTK_PROGRESS_BAR (widget), PULSE_STEP);
    
    for (i = 0; i < PULSE_NUM; i++)
    {
        gtk_progress_bar_pulse (GTK_PROGRESS_BAR (widget));
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef PULSE_STEP
    #undef FRACTION
    #undef PULSE_NUM
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_progress_bar_pulse
 * Params: GtkProgressBar *pbar
 * Returns: void
 * Assertion: Each call to gtk_progress_bar_pulse() causes the block to move by a little bit (the amount of movement per pulse is determined by gtk_progress_bar_set_pulse_step()).
 * Params Values: newly created GtkProgressBar*, 0.4
 * Expected: void  
 */
static void test_purpose_26()
{
    #define PULSE_STEP 0.4
    #define FRACTION 1.0
    #define PULSE_NUM 5
    
    GtkWidget *widget;
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_progress_bar_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_PROGRESS_BAR (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR (widget), FRACTION);
    gtk_progress_bar_set_pulse_step (GTK_PROGRESS_BAR (widget), PULSE_STEP);
    
    for (i = 0; i < PULSE_NUM; i++)
    {
        gtk_progress_bar_pulse (GTK_PROGRESS_BAR (widget));
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef PULSE_STEP
    #undef FRACTION
    #undef PULSE_NUM
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GtkProgressBar ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {test_purpose_11, 1},
    {test_purpose_12, 1},
    {test_purpose_13, 1},
    {test_purpose_14, 1},
    {test_purpose_15, 1},
    {test_purpose_16, 1},
    {test_purpose_17, 1},
    {test_purpose_18, 1},
    {test_purpose_19, 1},
    {test_purpose_20, 1},
    {test_purpose_21, 1},
    {test_purpose_22, 1},
    {test_purpose_23, 1},
    {test_purpose_24, 1},
    {test_purpose_25, 1},
    {test_purpose_26, 1},
    {NULL,0}
};
