/*
 * GtkTextTag methods tests
 * Testing GtkTextTag methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;
gboolean event_handler (GtkTextTag *tag, GObject *arg1, GdkEvent *event, 
                        GtkTextIter arg2, gpointer user_data)
{
    return TRUE;
}

/*
 * Name: gtk_text_tag_get_priority
 * Params: GtkTextTag *tag
 * Returns: qint
 * Assertion:Get the tag priority.
 * Params Values: a newly created GtkTextTag*
 * Expected: qint  
 */
static void test_purpose_1()
{
    #define PRIORITY 0    
    
    gint priority;
    GtkTextTag* tag;
    GtkTextTagTable* table;
    gchar buff[100];
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tag =  gtk_text_tag_new ("aaaa");
    
    if (!tag)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_TAG (tag))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    table = gtk_text_tag_table_new ();
    gtk_text_tag_table_add (table, tag);
    
    priority = PRIORITY;
    for (i = 0; i <= priority; i++)
    {
        sprintf (buff, "Tag %i", i);
        gtk_text_tag_table_add (tag->table, gtk_text_tag_new (buff));
    } 
    
    gtk_text_tag_set_priority (GTK_TEXT_TAG (tag), priority);
    if (gtk_text_tag_get_priority (GTK_TEXT_TAG (tag)) != priority)
    {
        TEST_FAIL ("priority is '%s', should be '%s'", gtk_text_tag_get_priority (GTK_TEXT_TAG (tag)), priority);
    }
    
    #undef PRIORITY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_tag_get_priority
 * Params: GtkTextTag *tag
 * Returns: qint
 * Assertion:Get the tag priority.
 * Params Values: a newly created GtkTextTag*
 * Expected: qint  
 */
static void test_purpose_2()
{
    #define PRIORITY 10    
    
    gint priority;
    GtkTextTag* tag;
    GtkTextTagTable* table;
    gchar buff[100];
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tag =  gtk_text_tag_new ("aaaa");
    
    if (!tag)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_TAG (tag))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    table = gtk_text_tag_table_new ();
    gtk_text_tag_table_add (table, tag);
    
    priority = PRIORITY;
    for (i = 0; i <= priority; i++)
    {
        sprintf (buff, "Tag %i", i);
        gtk_text_tag_table_add (tag->table, gtk_text_tag_new (buff));
    } 
    
    gtk_text_tag_set_priority (GTK_TEXT_TAG (tag), priority);
    if (gtk_text_tag_get_priority (GTK_TEXT_TAG (tag)) != priority)
    {
        TEST_FAIL ("priority is '%s', should be '%s'", gtk_text_tag_get_priority (GTK_TEXT_TAG (tag)), priority);
    }
    
    #undef PRIORITY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_tag_get_priority
 * Params: GtkTextTag *tag
 * Returns: qint
 * Assertion:Get the tag priority.
 * Params Values: a newly created GtkTextTag*
 * Expected: qint  
 */
static void test_purpose_3()
{
    #define PRIORITY gtk_text_tag_table_get_size (tag->table)
    
    gint priority;
    GtkTextTag* tag;
    GtkTextTagTable* table;
    gchar buff[100];
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tag =  gtk_text_tag_new ("aaaa");
    
    if (!tag)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_TAG (tag))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    table = gtk_text_tag_table_new ();
    gtk_text_tag_table_add (table, tag);
    
    priority = PRIORITY;
    for (i = 0; i <= priority; i++)
    {
        sprintf (buff, "Tag %i", i);
        gtk_text_tag_table_add (tag->table, gtk_text_tag_new (buff));
    } 
    
    gtk_text_tag_set_priority (GTK_TEXT_TAG (tag), priority);
    if (gtk_text_tag_get_priority (GTK_TEXT_TAG (tag)) != priority)
    {
        TEST_FAIL ("priority is '%s', should be '%s'", gtk_text_tag_get_priority (GTK_TEXT_TAG (tag)), priority);
    }
    
    #undef PRIORITY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_tag_set_priority
 * Params: GtkTextTag *tag, qint priority
 * Returns: void
 * Assertion: Sets the priority of a GtkTextTag. 
 * Params Values: a newly created GtkTextTag*, 1    
 * Expected: void
 * 
 * Name: gtk_text_tag_set_priority
 * Params: GtkTextTag *tag, qint priority
 * Returns: void
 * Assertion: Higher priority tags "win" if two tags both set the same text attribute. 
 * Params Values: a newly created GtkTextTag*, 1    
 * Expected: void  
 */
static void test_purpose_4()
{
    #define PRIORITY 1    
    
    gint priority;
    GtkTextTag* tag;
    GtkTextTag* low;
    GtkTextTagTable* table;
    gboolean editable;
    gchar buff[100];
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tag =  gtk_text_tag_new ("aaaa");
    
    if (!tag)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_TAG (tag))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    table = gtk_text_tag_table_new ();
    if (!table)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    priority = PRIORITY;
    for (i = 0; i <= priority; i++)
    {
        sprintf (buff, "Tag %i", i);
        gtk_text_tag_table_add (table, gtk_text_tag_new (buff));
    } 
    
    low =  gtk_text_tag_new ("low");
    gtk_text_tag_table_add (table, low);
    g_object_set (G_OBJECT (low), "editable", FALSE, NULL);
    gtk_text_tag_set_priority (GTK_TEXT_TAG (low), PRIORITY-1);
    
    gtk_text_tag_table_add (table, tag);
    g_object_set (G_OBJECT (tag), "editable", TRUE, NULL);
    gtk_text_tag_set_priority (GTK_TEXT_TAG (tag), PRIORITY);
    
    if (gtk_text_tag_get_priority (GTK_TEXT_TAG (tag)) != PRIORITY)
    {
        TEST_FAIL ("priority is '%s', should be '%s'", gtk_text_tag_get_priority (GTK_TEXT_TAG (tag)), PRIORITY);
    }
    
    
    #undef PRIORITY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_tag_set_priority
 * Params: GtkTextTag *tag, qint priority
 * Returns: void
 * Assertion: Sets the priority of a GtkTextTag. 
 * Params Values: a newly created GtkTextTag*, 10    
 * Expected: void
 * 
 * Name: gtk_text_tag_set_priority
 * Params: GtkTextTag *tag, qint priority
 * Returns: void
 * Assertion: Higher priority tags "win" if two tags both set the same text attribute. 
 * Params Values: a newly created GtkTextTag*, 10    
 * Expected: void  
 */
static void test_purpose_5()
{
    #define PRIORITY 10    
    
    gint priority;
    GtkTextTag* tag;
    GtkTextTag* low;
    GtkTextTagTable* table;
    gboolean editable;
    gchar buff[100];
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tag =  gtk_text_tag_new ("aaaa");
    
    if (!tag)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_TAG (tag))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    table = gtk_text_tag_table_new ();
    if (!table)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    priority = PRIORITY;
    for (i = 0; i <= priority; i++)
    {
        sprintf (buff, "Tag %i", i);
        gtk_text_tag_table_add (table, gtk_text_tag_new (buff));
    } 
    
    low =  gtk_text_tag_new ("low");
    gtk_text_tag_table_add (table, low);
    g_object_set (G_OBJECT (low), "editable", FALSE, NULL);
    gtk_text_tag_set_priority (GTK_TEXT_TAG (low), PRIORITY-1);
    
    gtk_text_tag_table_add (table, tag);
    g_object_set (G_OBJECT (tag), "editable", TRUE, NULL);
    gtk_text_tag_set_priority (GTK_TEXT_TAG (tag), PRIORITY);
    
    if (gtk_text_tag_get_priority (GTK_TEXT_TAG (tag)) != PRIORITY)
    {
        TEST_FAIL ("priority is '%s', should be '%s'", gtk_text_tag_get_priority (GTK_TEXT_TAG (tag)), PRIORITY);
    }
    
    
    #undef PRIORITY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_tag_set_priority
 * Params: GtkTextTag *tag, qint priority
 * Returns: void
 * Assertion: Sets the priority of a GtkTextTag. 
 * Params Values: a newly created GtkTextTag*, 100
 * Expected: void
 * 
 * Name: gtk_text_tag_set_priority
 * Params: GtkTextTag *tag, qint priority
 * Returns: void
 * Assertion: Higher priority tags "win" if two tags both set the same text attribute. 
 * Params Values: a newly created GtkTextTag*, 100
 * Expected: void  
 */
static void test_purpose_6()
{
    #define PRIORITY 100
    
    gint priority;
    GtkTextTag* tag;
    GtkTextTag* low;
    GtkTextTagTable* table;
    gboolean editable;
    gchar buff[100];
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tag =  gtk_text_tag_new ("aaaa");
    
    if (!tag)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_TAG (tag))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    table = gtk_text_tag_table_new ();
    if (!table)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    priority = PRIORITY;
    for (i = 0; i <= priority; i++)
    {
        sprintf (buff, "Tag %i", i);
        gtk_text_tag_table_add (table, gtk_text_tag_new (buff));
    } 
    
    low =  gtk_text_tag_new ("low");
    gtk_text_tag_table_add (table, low);
    g_object_set (G_OBJECT (low), "editable", FALSE, NULL);
    gtk_text_tag_set_priority (GTK_TEXT_TAG (low), PRIORITY-1);
    
    gtk_text_tag_table_add (table, tag);
    g_object_set (G_OBJECT (tag), "editable", TRUE, NULL);
    gtk_text_tag_set_priority (GTK_TEXT_TAG (tag), PRIORITY);
    
    if (gtk_text_tag_get_priority (GTK_TEXT_TAG (tag)) != PRIORITY)
    {
        TEST_FAIL ("priority is '%s', should be '%s'", gtk_text_tag_get_priority (GTK_TEXT_TAG (tag)), PRIORITY);
    }
    
    
    #undef PRIORITY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_tag_set_priority
 * Params: GtkTextTag *tag, qint priority
 * Returns: void
 * Assertion: Each tag in a table has a unique priority; setting the priority of one tag shifts the priorities of all the other tags in the table to maintain a unique priority for each tag.
 * Params Values: a newly created GtkTextTag*, 3
 * Expected: void  
 */
static void test_purpose_7()
{
    #define NUMBER 5
    #define PRIORITY 3
    
    GtkTextTag* tag;
    GtkTextTag* tag1;
    GtkTextTag* tag2;
    GtkTextTagTable* table;
    gchar buff[100];
    gint i;
    gint j;
    gint k;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tag =  gtk_text_tag_new ("aaaa");
    
    if (!tag)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_TAG (tag))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    table = gtk_text_tag_table_new ();
    gtk_text_tag_table_add (table, tag);
    
    for (k = 0; k <= NUMBER; k++)
    {
        sprintf (buff, "Tag %d", k);
        gtk_text_tag_table_add (table, gtk_text_tag_new (buff));
    } 
    
    gtk_text_tag_set_priority (GTK_TEXT_TAG (tag), PRIORITY);
    for (i = 0; i < NUMBER + 1; i++)
    {
        sprintf (buff, "Tag %d", i);
        tag1 = gtk_text_tag_table_lookup (table, buff);
        if (!tag1)
        {
            TEST_FAIL ("can't find tag named 'Tag %d'", i);
            continue;
        }
    
        for (j = i + 1; j < NUMBER + 1; j++)
        {
            sprintf (buff, "Tag %d", j);
            tag2 = gtk_text_tag_table_lookup (table, buff);
            if (!tag2)
            {
                TEST_FAIL ("can't find tag named 'Tag %d'", j);
                continue;
            }
    
            if (gtk_text_tag_get_priority (tag1) == gtk_text_tag_get_priority (tag2))
            {
                TEST_FAIL ("tags named 'Tag %d' and 'Tag %d' both have the same priority %d", i, j, gtk_text_tag_get_priority (tag2));
            }
                           
        }
    }
            
    #undef NUMBER
    #undef PRIORITY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_tag_set_priority
 * Params: GtkTextTag *tag, qint priority
 * Returns: void
 * Assertion: Each tag in a table has a unique priority; setting the priority of one tag shifts the priorities of all the other tags in the table to maintain a unique priority for each tag.
 * Params Values: a newly created GtkTextTag*, 5
 * Expected: void  
 */
static void test_purpose_8()
{
    #define NUMBER 5
    #define PRIORITY 5
    
    GtkTextTag* tag;
    GtkTextTag* tag1;
    GtkTextTag* tag2;
    GtkTextTagTable* table;
    gchar buff[100];
    gint i;
    gint j;
    gint k;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tag =  gtk_text_tag_new ("aaaa");
    
    if (!tag)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_TAG (tag))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    table = gtk_text_tag_table_new ();
    gtk_text_tag_table_add (table, tag);
    
    for (k = 0; k <= NUMBER; k++)
    {
        sprintf (buff, "Tag %d", k);
        gtk_text_tag_table_add (table, gtk_text_tag_new (buff));
    } 
    
    gtk_text_tag_set_priority (GTK_TEXT_TAG (tag), PRIORITY);
    for (i = 0; i < NUMBER + 1; i++)
    {
        sprintf (buff, "Tag %d", i);
        tag1 = gtk_text_tag_table_lookup (table, buff);
        if (!tag1)
        {
            TEST_FAIL ("can't find tag named 'Tag %d'", i);
            continue;
        }
    
        for (j = i + 1; j < NUMBER + 1; j++)
        {
            sprintf (buff, "Tag %d", j);
            tag2 = gtk_text_tag_table_lookup (table, buff);
            if (!tag2)
            {
                TEST_FAIL ("can't find tag named 'Tag %d'", j);
                continue;
            }
    
            if (gtk_text_tag_get_priority (tag1) == gtk_text_tag_get_priority (tag2))
            {
                TEST_FAIL ("tags named 'Tag %d' and 'Tag %d' both have the same priority %d", i, j, gtk_text_tag_get_priority (tag2));
            }
                           
        }
    }
            
    #undef NUMBER
    #undef PRIORITY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_tag_set_priority
 * Params: GtkTextTag *tag, qint priority
 * Returns: void
 * Assertion: Each tag in a table has a unique priority; setting the priority of one tag shifts the priorities of all the other tags in the table to maintain a unique priority for each tag.
 * Params Values: a newly created GtkTextTag*, 10
 * Expected: void  
 */
static void test_purpose_9()
{
    #define NUMBER 10
    #define PRIORITY 10
    
    GtkTextTag* tag;
    GtkTextTag* tag1;
    GtkTextTag* tag2;
    GtkTextTagTable* table;
    gchar buff[100];
    gint i;
    gint j;
    gint k;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tag =  gtk_text_tag_new ("aaaa");
    
    if (!tag)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_TAG (tag))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    table = gtk_text_tag_table_new ();
    gtk_text_tag_table_add (table, tag);
    
    for (k = 0; k <= NUMBER; k++)
    {
        sprintf (buff, "Tag %d", k);
        gtk_text_tag_table_add (table, gtk_text_tag_new (buff));
    } 
    
    gtk_text_tag_set_priority (GTK_TEXT_TAG (tag), PRIORITY);
    for (i = 0; i < NUMBER + 1; i++)
    {
        sprintf (buff, "Tag %d", i);
        tag1 = gtk_text_tag_table_lookup (table, buff);
        if (!tag1)
        {
            TEST_FAIL ("can't find tag named 'Tag %d'", i);
            continue;
        }
    
        for (j = i + 1; j < NUMBER + 1; j++)
        {
            sprintf (buff, "Tag %d", j);
            tag2 = gtk_text_tag_table_lookup (table, buff);
            if (!tag2)
            {
                TEST_FAIL ("can't find tag named 'Tag %d'", j);
                continue;
            }
    
            if (gtk_text_tag_get_priority (tag1) == gtk_text_tag_get_priority (tag2))
            {
                TEST_FAIL ("tags named 'Tag %d' and 'Tag %d' both have the same priority %d", i, j, gtk_text_tag_get_priority (tag2));
            }
                           
        }
    }
            
    #undef NUMBER
    #undef PRIORITY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_tag_set_priority
 * Params: GtkTextTag *tag, qint priority
 * Returns: void
 * Assertion: Each tag in a table has a unique priority; setting the priority of one tag shifts the priorities of all the other tags in the table to maintain a unique priority for each tag.
 * Params Values: a newly created GtkTextTag*, 0
 * Expected: void  
 */
static void test_purpose_10()
{
    #define NUMBER 10
    #define PRIORITY 0
    
    GtkTextTag* tag;
    GtkTextTag* tag1;
    GtkTextTag* tag2;
    GtkTextTagTable* table;
    gchar buff[100];
    gint i;
    gint j;
    gint k;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tag =  gtk_text_tag_new ("aaaa");
    
    if (!tag)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_TAG (tag))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    table = gtk_text_tag_table_new ();
    gtk_text_tag_table_add (table, tag);
    
    for (k = 0; k <= NUMBER; k++)
    {
        sprintf (buff, "Tag %d", k);
        gtk_text_tag_table_add (table, gtk_text_tag_new (buff));
    } 
    
    gtk_text_tag_set_priority (GTK_TEXT_TAG (tag), PRIORITY);
    for (i = 0; i < NUMBER + 1; i++)
    {
        sprintf (buff, "Tag %d", i);
        tag1 = gtk_text_tag_table_lookup (table, buff);
        if (!tag1)
        {
            TEST_FAIL ("can't find tag named 'Tag %d'", i);
            continue;
        }
    
        for (j = i + 1; j < NUMBER + 1; j++)
        {
            sprintf (buff, "Tag %d", j);
            tag2 = gtk_text_tag_table_lookup (table, buff);
            if (!tag2)
            {
                TEST_FAIL ("can't find tag named 'Tag %d'", j);
                continue;
            }
    
            if (gtk_text_tag_get_priority (tag1) == gtk_text_tag_get_priority (tag2))
            {
                TEST_FAIL ("tags named 'Tag %d' and 'Tag %d' both have the same priority %d", i, j, gtk_text_tag_get_priority (tag2));
            }
                           
        }
    }
            
    #undef NUMBER
    #undef PRIORITY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_tag_set_priority
 * Params: GtkTextTag *tag, qint priority
 * Returns: void
 * Assertion: When adding a tag to a tag table, it will be assigned the highest priority in the table by default; so normally the precedence of a set of tags is the order in which they were added to the table, or created with gtk_text_buffer_create_tag(), which adds the tag to the buffer's table automatically.'
 * Params Values: a newly created GtkTextTag*, <%1%>
 * Expected: void  
 */
static void test_purpose_11()
{
    #define NUMBER 5
    
    GtkTextTag* tag;
    GtkTextTag* tag1;
    GtkTextTagTable* table;
    gchar buff[100];
    gint i;
    gint k;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tag =  gtk_text_tag_new ("aaaa");
    
    if (!tag)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_TAG (tag))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    table = gtk_text_tag_table_new ();
    
    for (k = 0; k <= NUMBER; k++)
    {
        sprintf (buff, "Tag %d", k);
        gtk_text_tag_table_add (table, gtk_text_tag_new (buff));
    } 
    
    gtk_text_tag_table_add (table, tag);
    
    for (i = 0; i < NUMBER + 1; i++)
    {
        sprintf (buff, "Tag %d", i);
        tag1 = gtk_text_tag_table_lookup (table, buff);
        if (!tag1)
        {
            TEST_FAIL ("can't find tag named 'Tag %d'", i);
            continue;
        }
    
        if (gtk_text_tag_get_priority (tag) <= gtk_text_tag_get_priority (tag1))
        {
            TEST_FAIL ("tag named 'Tag %d' priority which is '%d' should be less than tag priority which is '%d'", 
                       i, gtk_text_tag_get_priority (tag1), 
                       gtk_text_tag_get_priority (tag));
        }
    }
            
    #undef NUMBER
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_tag_set_priority
 * Params: GtkTextTag *tag, qint priority
 * Returns: void
 * Assertion: When adding a tag to a tag table, it will be assigned the highest priority in the table by default; so normally the precedence of a set of tags is the order in which they were added to the table, or created with gtk_text_buffer_create_tag(), which adds the tag to the buffer's table automatically.'
 * Params Values: a newly created GtkTextTag*, <%1%>
 * Expected: void  
 */
static void test_purpose_12()
{
    #define NUMBER 49
    
    GtkTextTag* tag;
    GtkTextTag* tag1;
    GtkTextTagTable* table;
    gchar buff[100];
    gint i;
    gint k;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tag =  gtk_text_tag_new ("aaaa");
    
    if (!tag)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_TAG (tag))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    table = gtk_text_tag_table_new ();
    
    for (k = 0; k <= NUMBER; k++)
    {
        sprintf (buff, "Tag %d", k);
        gtk_text_tag_table_add (table, gtk_text_tag_new (buff));
    } 
    
    gtk_text_tag_table_add (table, tag);
    
    for (i = 0; i < NUMBER + 1; i++)
    {
        sprintf (buff, "Tag %d", i);
        tag1 = gtk_text_tag_table_lookup (table, buff);
        if (!tag1)
        {
            TEST_FAIL ("can't find tag named 'Tag %d'", i);
            continue;
        }
    
        if (gtk_text_tag_get_priority (tag) <= gtk_text_tag_get_priority (tag1))
        {
            TEST_FAIL ("tag named 'Tag %d' priority which is '%d' should be less than tag priority which is '%d'", 
                       i, gtk_text_tag_get_priority (tag1), 
                       gtk_text_tag_get_priority (tag));
        }
    }
            
    #undef NUMBER
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_tag_set_priority
 * Params: GtkTextTag *tag, qint priority
 * Returns: void
 * Assertion: When adding a tag to a tag table, it will be assigned the highest priority in the table by default; so normally the precedence of a set of tags is the order in which they were added to the table, or created with gtk_text_buffer_create_tag(), which adds the tag to the buffer's table automatically.'
 * Params Values: a newly created GtkTextTag*, <%1%>
 * Expected: void  
 */
static void test_purpose_13()
{
    #define NUMBER 1000
    
    GtkTextTag* tag;
    GtkTextTag* tag1;
    GtkTextTagTable* table;
    gchar buff[100];
    gint i;
    gint k;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tag =  gtk_text_tag_new ("aaaa");
    
    if (!tag)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_TAG (tag))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    table = gtk_text_tag_table_new ();
    
    for (k = 0; k <= NUMBER; k++)
    {
        sprintf (buff, "Tag %d", k);
        gtk_text_tag_table_add (table, gtk_text_tag_new (buff));
    } 
    
    gtk_text_tag_table_add (table, tag);
    
    for (i = 0; i < NUMBER + 1; i++)
    {
        sprintf (buff, "Tag %d", i);
        tag1 = gtk_text_tag_table_lookup (table, buff);
        if (!tag1)
        {
            TEST_FAIL ("can't find tag named 'Tag %d'", i);
            continue;
        }
    
        if (gtk_text_tag_get_priority (tag) <= gtk_text_tag_get_priority (tag1))
        {
            TEST_FAIL ("tag named 'Tag %d' priority which is '%d' should be less than tag priority which is '%d'", 
                       i, gtk_text_tag_get_priority (tag1), 
                       gtk_text_tag_get_priority (tag));
        }
    }
            
    #undef NUMBER
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_tag_event
 * Params: GtkTextTag *tag, GObject *event_object, GdkEvent *event, const GtkTextIter *iter
 * Returns: gboolean
 * Assertion: Emits the "event" signal on the GtkTextTag.
 * Params Values: a newly created GtkTextTag*, GObject *event_object, GdkEvent *event, const GtkTextIter *iter
 * Expected: TRUE  
 */
static void test_purpose_14()
{
    GtkTextTag* tag;
    GtkTextTagTable* table;
    GtkTextBuffer* buffer;
    GtkTextIter iter;
    gboolean res;
    GdkEvent event;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tag =  gtk_text_tag_new ("aaaa");
    
    if (!tag)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_TAG (tag))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    table = gtk_text_tag_table_new ();
    gtk_text_tag_table_add (table, tag);
    
    buffer = gtk_text_buffer_new (table);
    gtk_text_buffer_set_text (buffer, "qwerty", strlen ("qwerty"));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, 2);
    
    g_signal_connect (G_OBJECT (tag), "event",
                      GTK_SIGNAL_FUNC (event_handler), NULL);
    res = gtk_text_tag_event (tag, G_OBJECT (buffer), &event, &iter);
    if (!res)
    {
        TEST_FAIL ("event was not handled", NULL);
    }
            
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_attributes_new
 * Params: void
 * Returns: GtkTextAttributes*
 * Assertion: Creates a GtkTextAttributes, which describes a set of properties on some text.
 * Params Values: void 
 * Expected: a newly created GtkTextAttributes*  
 */
static void test_purpose_15()
{
    GtkTextAttributes* attr;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    attr =  gtk_text_attributes_new ();
    
    if (!attr)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_attributes_copy
 * Params: GtkTextAttributes *src
 * Returns: GtkTextAttributes*
 * Assertion: Copies src and returns a new GtkTextAttributes
 * Params Values: GtkTextAttributes *src
 * Expected: a newly created GtkTextAttributes* with the same values as src  
 */
static void test_purpose_16()
{
    GtkTextAttributes* attr;
    GtkTextAttributes* copy;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    attr =  gtk_text_attributes_new ();
    if (!attr)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    attr->refcount = 10;
    attr->appearance.rise = -49;
    attr->justification = GTK_JUSTIFY_FILL;
    attr->direction = GTK_TEXT_DIR_RTL;
    attr->font_scale = 45.6789;
    attr->left_margin = 5;
    attr->indent = 4;
    attr->right_margin = 3;
    attr->pixels_above_lines = 101;
    attr->pixels_below_lines = 102;
    attr->pixels_inside_wrap = 28;
    attr->tabs = NULL;
    attr->wrap_mode = GTK_WRAP_CHAR;
    attr->language = NULL;
    attr->invisible = 0;
    attr->bg_full_height = 1;
    attr->editable = 0;
    attr->realized = 1;
    attr->pad1 = 0;
    attr->pad2 = 1;
    attr->pad3 = 0;
    attr->pad4 = 1;
    
    copy = gtk_text_attributes_copy (attr);
    if (!copy)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (copy->appearance.rise != attr->appearance.rise)
    {
        TEST_FAIL ("copy->appearance.rise is %d, attr->appearance.rise is %d",
                   copy->appearance.rise, attr->appearance.rise);
    }
    if (copy->justification != attr->justification)
    {
        TEST_FAIL ("copy->justification is %d, attr->justification is %d", 
                   copy->justification, attr->justification);
    }
    if (copy->direction != attr->direction)
    {
        TEST_FAIL ("copy->direction is %d, attr->direction is %d",
                   copy->direction, attr->direction);
    }
    if (copy->font_scale != attr->font_scale)
    {
        TEST_FAIL ("copy->font_scale is %d, attr->font_scale is %d",
                   copy->font_scale, attr->font_scale);
    }
    if (copy->left_margin != attr->left_margin)
    {
        TEST_FAIL ("copy->font_scale is %lf, attr->font_scale is %lf",
                   copy->font_scale, attr->font_scale);
    }
    if (copy->left_margin != attr->left_margin)
    {
        TEST_FAIL ("copy->font_scale is %d, attr->font_scale is %d",
                   copy->font_scale, attr->font_scale);
    }
    if (copy->indent != attr->indent)
    {
        TEST_FAIL ("copy->indent is %d, attr->indent is %d",
                   copy->indent, attr->indent);
    }
    if (copy->right_margin != attr->right_margin)
    {
        TEST_FAIL ("copy->right_margin is %d, attr->right_margin is %d",
                   copy->right_margin, attr->right_margin);
    }
    if (copy->pixels_above_lines != attr->pixels_above_lines)
    {
        TEST_FAIL ("copy->pixels_above_lines is %d, attr->pixels_above_lines is %d",
                   copy->pixels_above_lines, attr->pixels_above_lines);
    }
    if (copy->pixels_below_lines != attr->pixels_below_lines)
    {
        TEST_FAIL ("copy->pixels_below_lines is %d, attr->pixels_below_lines is %d",
                   copy->pixels_below_lines, attr->pixels_below_lines);
    }
    if (copy->pixels_inside_wrap != attr->pixels_inside_wrap)
    {
        TEST_FAIL ("copy->pixels_inside_wrap is %d, attr->pixels_inside_wrap is %d", 
                   copy->pixels_inside_wrap, attr->pixels_inside_wrap);
    }
    if (copy->tabs != attr->tabs)
    {
        TEST_FAIL ("copy->tabs is %d, attr->tabs is %d",
                   copy->tabs, attr->tabs);
    }
    if (copy->wrap_mode != attr->wrap_mode)
    {
        TEST_FAIL ("copy->wrap_mode is %d, attr->wrap_mode is %d",
                   copy->wrap_mode, attr->wrap_mode);
    }
    if (copy->language != attr->language)
    {
        TEST_FAIL ("copy->language is %d, attr->language is %d",
                   copy->language, attr->language);
    }
    if (copy->invisible != attr->invisible)
    {
        TEST_FAIL ("copy->invisible is %d, attr->invisible is %d",
                   copy->invisible, attr->invisible);
    }
    if (copy->bg_full_height != attr->bg_full_height)
    {
        TEST_FAIL ("copy->bg_full_height is %d, attr->bg_full_height is %d",
                   copy->bg_full_height, attr->bg_full_height);
    }
    if (copy->editable != attr->editable)
    {
        TEST_FAIL ("copy->editable is %d, attr->editable is %d",
                   copy->editable, attr->editable);
    }
    if (copy->pad1 != attr->pad1)
    {
        TEST_FAIL ("copy->pad1 is %d, attr->pad1 is %d",
                   copy->pad1, attr->pad1);
    }
    if (copy->pad2 != attr->pad2)
    {
        TEST_FAIL ("copy->pad2 is %d, attr->pad2 is %d",
                   copy->pad2, attr->pad2);
    }
    if (copy->pad3 != attr->pad3)
    {
        TEST_FAIL ("copy->pad3 is %d, attr->pad3 is %d",
                   copy->pad3, attr->pad3);
    }
    if (copy->pad4 != attr->pad4)
    {
        TEST_FAIL ("copy->pad4 is %d, attr->pad4 is %d",
                   copy->pad4, attr->pad4);
    }
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_attributes_copy_values
 * Params: GtkTextAttributes *src, GtkTextAttributes *dest
 * Returns: void
 * Assertion: Copies the values from src to dest so that dest has the same values as src.
 * Params Values: GtkTextAttributes *src, GtkTextAttributes *dest
 * Expected: void  
 */
static void test_purpose_17()
{
    GtkTextAttributes* attr;
    GtkTextAttributes* copy;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    attr =  gtk_text_attributes_new ();
    if (!attr)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    copy =  gtk_text_attributes_new ();
    if (!copy)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    attr->refcount = 10;
    attr->appearance.rise = -49;
    attr->justification = GTK_JUSTIFY_FILL;
    attr->direction = GTK_TEXT_DIR_RTL;
    attr->font_scale = 45.6789;
    attr->left_margin = 5;
    attr->indent = 4;
    attr->right_margin = 3;
    attr->pixels_above_lines = 101;
    attr->pixels_below_lines = 102;
    attr->pixels_inside_wrap = 28;
    attr->tabs = NULL;
    attr->wrap_mode = GTK_WRAP_CHAR;
    attr->language = NULL;
    attr->invisible = 0;
    attr->bg_full_height = 1;
    attr->editable = 0;
    attr->realized = 1;
    attr->pad1 = 0;
    attr->pad2 = 1;
    attr->pad3 = 0;
    attr->pad4 = 1;
    
    gtk_text_attributes_copy_values (attr, copy);
    
    if (copy->appearance.rise != attr->appearance.rise)
    {
        TEST_FAIL ("copy->appearance.rise is %d, attr->appearance.rise is %d",
                   copy->appearance.rise, attr->appearance.rise);
    }
    if (copy->justification != attr->justification)
    {
        TEST_FAIL ("copy->justification is %d, attr->justification is %d", 
                   copy->justification, attr->justification);
    }
    if (copy->direction != attr->direction)
    {
        TEST_FAIL ("copy->direction is %d, attr->direction is %d",
                   copy->direction, attr->direction);
    }
    if (copy->font_scale != attr->font_scale)
    {
        TEST_FAIL ("copy->font_scale is %d, attr->font_scale is %d",
                   copy->font_scale, attr->font_scale);
    }
    if (copy->left_margin != attr->left_margin)
    {
        TEST_FAIL ("copy->font_scale is %lf, attr->font_scale is %lf",
                   copy->font_scale, attr->font_scale);
    }
    if (copy->left_margin != attr->left_margin)
    {
        TEST_FAIL ("copy->font_scale is %d, attr->font_scale is %d",
                   copy->font_scale, attr->font_scale);
    }
    if (copy->indent != attr->indent)
    {
        TEST_FAIL ("copy->indent is %d, attr->indent is %d",
                   copy->indent, attr->indent);
    }
    if (copy->right_margin != attr->right_margin)
    {
        TEST_FAIL ("copy->right_margin is %d, attr->right_margin is %d",
                   copy->right_margin, attr->right_margin);
    }
    if (copy->pixels_above_lines != attr->pixels_above_lines)
    {
        TEST_FAIL ("copy->pixels_above_lines is %d, attr->pixels_above_lines is %d",
                   copy->pixels_above_lines, attr->pixels_above_lines);
    }
    if (copy->pixels_below_lines != attr->pixels_below_lines)
    {
        TEST_FAIL ("copy->pixels_below_lines is %d, attr->pixels_below_lines is %d",
                   copy->pixels_below_lines, attr->pixels_below_lines);
    }
    if (copy->pixels_inside_wrap != attr->pixels_inside_wrap)
    {
        TEST_FAIL ("copy->pixels_inside_wrap is %d, attr->pixels_inside_wrap is %d", 
                   copy->pixels_inside_wrap, attr->pixels_inside_wrap);
    }
    if (copy->tabs != attr->tabs)
    {
        TEST_FAIL ("copy->tabs is %d, attr->tabs is %d",
                   copy->tabs, attr->tabs);
    }
    if (copy->wrap_mode != attr->wrap_mode)
    {
        TEST_FAIL ("copy->wrap_mode is %d, attr->wrap_mode is %d",
                   copy->wrap_mode, attr->wrap_mode);
    }
    if (copy->language != attr->language)
    {
        TEST_FAIL ("copy->language is %d, attr->language is %d",
                   copy->language, attr->language);
    }
    if (copy->invisible != attr->invisible)
    {
        TEST_FAIL ("copy->invisible is %d, attr->invisible is %d",
                   copy->invisible, attr->invisible);
    }
    if (copy->bg_full_height != attr->bg_full_height)
    {
        TEST_FAIL ("copy->bg_full_height is %d, attr->bg_full_height is %d",
                   copy->bg_full_height, attr->bg_full_height);
    }
    if (copy->editable != attr->editable)
    {
        TEST_FAIL ("copy->editable is %d, attr->editable is %d",
                   copy->editable, attr->editable);
    }
    if (copy->pad1 != attr->pad1)
    {
        TEST_FAIL ("copy->pad1 is %d, attr->pad1 is %d",
                   copy->pad1, attr->pad1);
    }
    if (copy->pad2 != attr->pad2)
    {
        TEST_FAIL ("copy->pad2 is %d, attr->pad2 is %d",
                   copy->pad2, attr->pad2);
    }
    if (copy->pad3 != attr->pad3)
    {
        TEST_FAIL ("copy->pad3 is %d, attr->pad3 is %d",
                   copy->pad3, attr->pad3);
    }
    if (copy->pad4 != attr->pad4)
    {
        TEST_FAIL ("copy->pad4 is %d, attr->pad4 is %d",
                   copy->pad4, attr->pad4);
    }
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_attributes_unref
 * Params: GtkTextAttributes *values
 * Returns: void
 * Assertion: Decrements the reference count on values, freeing the structure if the reference count reaches 0.
 * Params Values: GtkTextAttributes *values
 * Expected: void  
 */
static void test_purpose_18()
{
    GtkTextAttributes* attr;
    gint i;
    
    #define INITIAL_REF_COUNT 100
    #define UNREF_TIMES 5
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    attr =  gtk_text_attributes_new ();
    if (!attr)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    attr->refcount = INITIAL_REF_COUNT;
    for (i = 0; i < UNREF_TIMES; i++)
    {
        gtk_text_attributes_unref(attr);
    }
    
    if (attr->refcount != INITIAL_REF_COUNT - UNREF_TIMES)
    {
        TEST_FAIL ("refcount = %d, should be %d", attr->refcount,
                   INITIAL_REF_COUNT - UNREF_TIMES);
    }
    
    #undef INITIAL_REF_COUNT
    #undef UNREF_TIMES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_attributes_unref
 * Params: GtkTextAttributes *values
 * Returns: void
 * Assertion: Decrements the reference count on values, freeing the structure if the reference count reaches 0.
 * Params Values: GtkTextAttributes *values
 * Expected: void  
 */
static void test_purpose_19()
{
    GtkTextAttributes* attr;
    gint i;
    
    #define INITIAL_REF_COUNT 10
    #define UNREF_TIMES 9
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    attr =  gtk_text_attributes_new ();
    if (!attr)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    attr->refcount = INITIAL_REF_COUNT;
    for (i = 0; i < UNREF_TIMES; i++)
    {
        gtk_text_attributes_unref(attr);
    }
    
    if (attr->refcount != INITIAL_REF_COUNT - UNREF_TIMES)
    {
        TEST_FAIL ("refcount = %d, should be %d", attr->refcount,
                   INITIAL_REF_COUNT - UNREF_TIMES);
    }
    
    #undef INITIAL_REF_COUNT
    #undef UNREF_TIMES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_attributes_ref
 * Params: GtkTextAttributes *values
 * Returns: void
 * Assertion: Increments the reference count on values.
 * Params Values: GtkTextAttributes *values
 * Expected: void  
 */
static void test_purpose_20()
{
    GtkTextAttributes* attr;
    gint i;
    
    #define INITIAL_REF_COUNT 100
    #define REF_TIMES 5
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    attr =  gtk_text_attributes_new ();
    if (!attr)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    attr->refcount = INITIAL_REF_COUNT;
    for (i = 0; i < REF_TIMES; i++)
    {
        gtk_text_attributes_ref(attr);
    }
    
    if (attr->refcount != INITIAL_REF_COUNT + REF_TIMES)
    {
        TEST_FAIL ("refcount = %d, should be %d", attr->refcount,
                   INITIAL_REF_COUNT + REF_TIMES);
    }
    
    #undef INITIAL_REF_COUNT
    #undef REF_TIMES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_attributes_ref
 * Params: GtkTextAttributes *values
 * Returns: void
 * Assertion: Increments the reference count on values.
 * Params Values: GtkTextAttributes *values
 * Expected: void  
 */
static void test_purpose_21()
{
    GtkTextAttributes* attr;
    gint i;
    
    #define INITIAL_REF_COUNT 10
    #define REF_TIMES 11
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    attr =  gtk_text_attributes_new ();
    if (!attr)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    attr->refcount = INITIAL_REF_COUNT;
    for (i = 0; i < REF_TIMES; i++)
    {
        gtk_text_attributes_ref(attr);
    }
    
    if (attr->refcount != INITIAL_REF_COUNT + REF_TIMES)
    {
        TEST_FAIL ("refcount = %d, should be %d", attr->refcount,
                   INITIAL_REF_COUNT + REF_TIMES);
    }
    
    #undef INITIAL_REF_COUNT
    #undef REF_TIMES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_attributes_ref
 * Params: GtkTextAttributes *values
 * Returns: void
 * Assertion: Increments the reference count on values.
 * Params Values: GtkTextAttributes *values
 * Expected: void  
 */
static void test_purpose_22()
{
    GtkTextAttributes* attr;
    gint i;
    
    #define INITIAL_REF_COUNT 0
    #define REF_TIMES 4574
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    attr =  gtk_text_attributes_new ();
    if (!attr)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    attr->refcount = INITIAL_REF_COUNT;
    for (i = 0; i < REF_TIMES; i++)
    {
        gtk_text_attributes_ref(attr);
    }
    
    if (attr->refcount != INITIAL_REF_COUNT + REF_TIMES)
    {
        TEST_FAIL ("refcount = %d, should be %d", attr->refcount,
                   INITIAL_REF_COUNT + REF_TIMES);
    }
    
    #undef INITIAL_REF_COUNT
    #undef REF_TIMES
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GtkTextTag ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {test_purpose_11, 1},
    {test_purpose_12, 1},
    {test_purpose_13, 1},
    {test_purpose_14, 1},
    {test_purpose_15, 1},
    {test_purpose_16, 1},
    {test_purpose_17, 1},
    {test_purpose_18, 1},
    {test_purpose_19, 1},
    {test_purpose_20, 1},
    {test_purpose_21, 1},
    {test_purpose_22, 1},
    {NULL,0}
};
