/*
 * GtkToggleButton methods tests
 * Testing GtkToggleButton methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;
gint global_counter;

void global_toggled_signal (GtkToggleButton *togglebutton,gpointer user_data)
{
    global_counter++;
}

/*
 * Name:  gtk_toggle_button_new
 * Params: void
 * Returns: GtkWidget* 
 * Assertion: Creates a new toggle button.
 * Params Values: void
 * Expected: GtkToggleButton*  
 */
static void test_purpose_1()
{
    gboolean active;
    gboolean inconsistent;
    gboolean draw_indicator;
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_toggle_button_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TOGGLE_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "active", &active, NULL);
    if (active != FALSE) 
    {
        TEST_FAIL("active = %i", active);
    }
    
    g_object_get(GTK_OBJECT(widget), "inconsistent", &inconsistent, NULL);
    if (inconsistent != FALSE) 
    {
        TEST_FAIL("inconsistent = %i", inconsistent);
    }
    
    g_object_get(GTK_OBJECT(widget), "draw-indicator", &draw_indicator, NULL);
    if (draw_indicator != FALSE) 
    {
        TEST_FAIL("draw-indicator = %i", draw_indicator);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_toggle_button_new_with_label
 * Params: const gchar* name
 * Returns: GtkWidget*
 * Assertion: Creates a new toggle button with a text label.
 * Params Values: NULL
 * Expected: GtkToggleButton*  
 */
static void test_purpose_2()
{
    #define LABEL_TEXT NULL
    
    gboolean active;
    gboolean inconsistent;
    gboolean draw_indicator;
    
    GtkWidget* widget;
    GtkWidget* child;
    G_CONST_RETURN gchar* label_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_toggle_button_new_with_label (LABEL_TEXT);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TOGGLE_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    if (LABEL_TEXT)
    {
        child = gtk_bin_get_child (GTK_BIN (widget));
        if (!child)
        {
            TEST_FAIL ("GtkToggleButton without child was created", NULL);
            return;
        }
        if (!GTK_IS_LABEL (child)) {
            TEST_FAIL ("GtkToggleButton child should be of type GtkLabel", NULL);
            return;
        }
    
        label_text = gtk_label_get_text (GTK_LABEL(child));
        if (strcmp (label_text, LABEL_TEXT))
        {
            TEST_FAIL ("label_text is '%s', should be '%s'", label_text, LABEL_TEXT);
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "active", &active, NULL);
    if (active != FALSE) 
    {
        TEST_FAIL("active = %i", active);
    }
    
    g_object_get(GTK_OBJECT(widget), "inconsistent", &inconsistent, NULL);
    if (inconsistent != FALSE) 
    {
        TEST_FAIL("inconsistent = %i", inconsistent);
    }
    
    g_object_get(GTK_OBJECT(widget), "draw-indicator", &draw_indicator, NULL);
    if (draw_indicator != FALSE) 
    {
        TEST_FAIL("draw-indicator = %i", draw_indicator);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL_TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_toggle_button_new_with_label
 * Params: const gchar* name
 * Returns: GtkWidget*
 * Assertion: Creates a new toggle button with a text label.
 * Params Values: ""
 * Expected: GtkToggleButton*  
 */
static void test_purpose_3()
{
    #define LABEL_TEXT ""
    
    gboolean active;
    gboolean inconsistent;
    gboolean draw_indicator;
    
    GtkWidget* widget;
    GtkWidget* child;
    G_CONST_RETURN gchar* label_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_toggle_button_new_with_label (LABEL_TEXT);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TOGGLE_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    if (LABEL_TEXT)
    {
        child = gtk_bin_get_child (GTK_BIN (widget));
        if (!child)
        {
            TEST_FAIL ("GtkToggleButton without child was created", NULL);
            return;
        }
        if (!GTK_IS_LABEL (child)) {
            TEST_FAIL ("GtkToggleButton child should be of type GtkLabel", NULL);
            return;
        }
    
        label_text = gtk_label_get_text (GTK_LABEL(child));
        if (strcmp (label_text, LABEL_TEXT))
        {
            TEST_FAIL ("label_text is '%s', should be '%s'", label_text, LABEL_TEXT);
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "active", &active, NULL);
    if (active != FALSE) 
    {
        TEST_FAIL("active = %i", active);
    }
    
    g_object_get(GTK_OBJECT(widget), "inconsistent", &inconsistent, NULL);
    if (inconsistent != FALSE) 
    {
        TEST_FAIL("inconsistent = %i", inconsistent);
    }
    
    g_object_get(GTK_OBJECT(widget), "draw-indicator", &draw_indicator, NULL);
    if (draw_indicator != FALSE) 
    {
        TEST_FAIL("draw-indicator = %i", draw_indicator);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL_TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_toggle_button_new_with_label
 * Params: const gchar* name
 * Returns: GtkWidget*
 * Assertion: Creates a new toggle button with a text label.
 * Params Values: " "
 * Expected: GtkToggleButton*  
 */
static void test_purpose_4()
{
    #define LABEL_TEXT " "
    
    gboolean active;
    gboolean inconsistent;
    gboolean draw_indicator;
    
    GtkWidget* widget;
    GtkWidget* child;
    G_CONST_RETURN gchar* label_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_toggle_button_new_with_label (LABEL_TEXT);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TOGGLE_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    if (LABEL_TEXT)
    {
        child = gtk_bin_get_child (GTK_BIN (widget));
        if (!child)
        {
            TEST_FAIL ("GtkToggleButton without child was created", NULL);
            return;
        }
        if (!GTK_IS_LABEL (child)) {
            TEST_FAIL ("GtkToggleButton child should be of type GtkLabel", NULL);
            return;
        }
    
        label_text = gtk_label_get_text (GTK_LABEL(child));
        if (strcmp (label_text, LABEL_TEXT))
        {
            TEST_FAIL ("label_text is '%s', should be '%s'", label_text, LABEL_TEXT);
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "active", &active, NULL);
    if (active != FALSE) 
    {
        TEST_FAIL("active = %i", active);
    }
    
    g_object_get(GTK_OBJECT(widget), "inconsistent", &inconsistent, NULL);
    if (inconsistent != FALSE) 
    {
        TEST_FAIL("inconsistent = %i", inconsistent);
    }
    
    g_object_get(GTK_OBJECT(widget), "draw-indicator", &draw_indicator, NULL);
    if (draw_indicator != FALSE) 
    {
        TEST_FAIL("draw-indicator = %i", draw_indicator);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL_TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_toggle_button_new_with_label
 * Params: const gchar* name
 * Returns: GtkWidget*
 * Assertion: Creates a new toggle button with a text label.
 * Params Values: "Label"
 * Expected: GtkToggleButton*  
 */
static void test_purpose_5()
{
    #define LABEL_TEXT "Label"
    
    gboolean active;
    gboolean inconsistent;
    gboolean draw_indicator;
    
    GtkWidget* widget;
    GtkWidget* child;
    G_CONST_RETURN gchar* label_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_toggle_button_new_with_label (LABEL_TEXT);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TOGGLE_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    if (LABEL_TEXT)
    {
        child = gtk_bin_get_child (GTK_BIN (widget));
        if (!child)
        {
            TEST_FAIL ("GtkToggleButton without child was created", NULL);
            return;
        }
        if (!GTK_IS_LABEL (child)) {
            TEST_FAIL ("GtkToggleButton child should be of type GtkLabel", NULL);
            return;
        }
    
        label_text = gtk_label_get_text (GTK_LABEL(child));
        if (strcmp (label_text, LABEL_TEXT))
        {
            TEST_FAIL ("label_text is '%s', should be '%s'", label_text, LABEL_TEXT);
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "active", &active, NULL);
    if (active != FALSE) 
    {
        TEST_FAIL("active = %i", active);
    }
    
    g_object_get(GTK_OBJECT(widget), "inconsistent", &inconsistent, NULL);
    if (inconsistent != FALSE) 
    {
        TEST_FAIL("inconsistent = %i", inconsistent);
    }
    
    g_object_get(GTK_OBJECT(widget), "draw-indicator", &draw_indicator, NULL);
    if (draw_indicator != FALSE) 
    {
        TEST_FAIL("draw-indicator = %i", draw_indicator);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL_TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_toggle_button_new_with_label
 * Params: const gchar* name
 * Returns: GtkWidget*
 * Assertion: Creates a new toggle button with a text label.
 * Params Values: "\b\t\n"
 * Expected: GtkToggleButton*  
 */
static void test_purpose_6()
{
    #define LABEL_TEXT "\b\t\n"
    
    gboolean active;
    gboolean inconsistent;
    gboolean draw_indicator;
    
    GtkWidget* widget;
    GtkWidget* child;
    G_CONST_RETURN gchar* label_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_toggle_button_new_with_label (LABEL_TEXT);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TOGGLE_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    if (LABEL_TEXT)
    {
        child = gtk_bin_get_child (GTK_BIN (widget));
        if (!child)
        {
            TEST_FAIL ("GtkToggleButton without child was created", NULL);
            return;
        }
        if (!GTK_IS_LABEL (child)) {
            TEST_FAIL ("GtkToggleButton child should be of type GtkLabel", NULL);
            return;
        }
    
        label_text = gtk_label_get_text (GTK_LABEL(child));
        if (strcmp (label_text, LABEL_TEXT))
        {
            TEST_FAIL ("label_text is '%s', should be '%s'", label_text, LABEL_TEXT);
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "active", &active, NULL);
    if (active != FALSE) 
    {
        TEST_FAIL("active = %i", active);
    }
    
    g_object_get(GTK_OBJECT(widget), "inconsistent", &inconsistent, NULL);
    if (inconsistent != FALSE) 
    {
        TEST_FAIL("inconsistent = %i", inconsistent);
    }
    
    g_object_get(GTK_OBJECT(widget), "draw-indicator", &draw_indicator, NULL);
    if (draw_indicator != FALSE) 
    {
        TEST_FAIL("draw-indicator = %i", draw_indicator);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL_TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_toggle_button_new_with_label
 * Params: const gchar* name
 * Returns: GtkWidget*
 * Assertion: Creates a new toggle button with a text label.
 * Params Values: "!@#$%^&*"
 * Expected: GtkToggleButton*  
 */
static void test_purpose_7()
{
    #define LABEL_TEXT "!@#$%^&*"
    
    gboolean active;
    gboolean inconsistent;
    gboolean draw_indicator;
    
    GtkWidget* widget;
    GtkWidget* child;
    G_CONST_RETURN gchar* label_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_toggle_button_new_with_label (LABEL_TEXT);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TOGGLE_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    if (LABEL_TEXT)
    {
        child = gtk_bin_get_child (GTK_BIN (widget));
        if (!child)
        {
            TEST_FAIL ("GtkToggleButton without child was created", NULL);
            return;
        }
        if (!GTK_IS_LABEL (child)) {
            TEST_FAIL ("GtkToggleButton child should be of type GtkLabel", NULL);
            return;
        }
    
        label_text = gtk_label_get_text (GTK_LABEL(child));
        if (strcmp (label_text, LABEL_TEXT))
        {
            TEST_FAIL ("label_text is '%s', should be '%s'", label_text, LABEL_TEXT);
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "active", &active, NULL);
    if (active != FALSE) 
    {
        TEST_FAIL("active = %i", active);
    }
    
    g_object_get(GTK_OBJECT(widget), "inconsistent", &inconsistent, NULL);
    if (inconsistent != FALSE) 
    {
        TEST_FAIL("inconsistent = %i", inconsistent);
    }
    
    g_object_get(GTK_OBJECT(widget), "draw-indicator", &draw_indicator, NULL);
    if (draw_indicator != FALSE) 
    {
        TEST_FAIL("draw-indicator = %i", draw_indicator);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL_TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_toggle_button_new_with_label
 * Params: const gchar* name
 * Returns: GtkWidget*
 * Assertion: Creates a new toggle button with a text label.
 * Params Values: "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
 * Expected: GtkToggleButton*  
 */
static void test_purpose_8()
{
    #define LABEL_TEXT "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    
    gboolean active;
    gboolean inconsistent;
    gboolean draw_indicator;
    
    GtkWidget* widget;
    GtkWidget* child;
    G_CONST_RETURN gchar* label_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_toggle_button_new_with_label (LABEL_TEXT);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TOGGLE_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    if (LABEL_TEXT)
    {
        child = gtk_bin_get_child (GTK_BIN (widget));
        if (!child)
        {
            TEST_FAIL ("GtkToggleButton without child was created", NULL);
            return;
        }
        if (!GTK_IS_LABEL (child)) {
            TEST_FAIL ("GtkToggleButton child should be of type GtkLabel", NULL);
            return;
        }
    
        label_text = gtk_label_get_text (GTK_LABEL(child));
        if (strcmp (label_text, LABEL_TEXT))
        {
            TEST_FAIL ("label_text is '%s', should be '%s'", label_text, LABEL_TEXT);
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "active", &active, NULL);
    if (active != FALSE) 
    {
        TEST_FAIL("active = %i", active);
    }
    
    g_object_get(GTK_OBJECT(widget), "inconsistent", &inconsistent, NULL);
    if (inconsistent != FALSE) 
    {
        TEST_FAIL("inconsistent = %i", inconsistent);
    }
    
    g_object_get(GTK_OBJECT(widget), "draw-indicator", &draw_indicator, NULL);
    if (draw_indicator != FALSE) 
    {
        TEST_FAIL("draw-indicator = %i", draw_indicator);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL_TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_toggle_button_new_with_mnemonic
 * Params: const gchar* name
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkToggleButton containing a label.
 * Params Values: NULL
 * Expected: GtkToggleButton*  
 */
static void test_purpose_9()
{
    #define LABEL_TEXT NULL
    
    gboolean active;
    gboolean inconsistent;
    gboolean draw_indicator;
    
    GtkWidget* widget;
    GtkWidget* child;
    G_CONST_RETURN gchar* label_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_toggle_button_new_with_mnemonic (LABEL_TEXT);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TOGGLE_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    if (LABEL_TEXT)
    {
        child = gtk_bin_get_child (GTK_BIN (widget));
        if (!child)
        {
            TEST_FAIL ("GtkToggleButton without child was created", NULL);
            return;
        }
        if (!GTK_IS_LABEL (child)) {
            TEST_FAIL ("GtkToggleButton child should be of type GtkLabel", NULL);
            return;
        }
    
        g_object_get (GTK_OBJECT (child), "label", &label_text, NULL);
        if (strcmp (label_text, LABEL_TEXT))
        {
            TEST_FAIL ("label_text is '%s', should be '%s'", label_text, LABEL_TEXT);
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "active", &active, NULL);
    if (active != FALSE) 
    {
        TEST_FAIL("active = %i", active);
    }
    
    g_object_get(GTK_OBJECT(widget), "inconsistent", &inconsistent, NULL);
    if (inconsistent != FALSE) 
    {
        TEST_FAIL("inconsistent = %i", inconsistent);
    }
    
    g_object_get(GTK_OBJECT(widget), "draw-indicator", &draw_indicator, NULL);
    if (draw_indicator != FALSE) 
    {
        TEST_FAIL("draw-indicator = %i", draw_indicator);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL_TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_toggle_button_new_with_mnemonic
 * Params: const gchar* name
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkToggleButton containing a label.
 * Params Values: ""
 * Expected: GtkToggleButton*  
 */
static void test_purpose_10()
{
    #define LABEL_TEXT ""
    
    gboolean active;
    gboolean inconsistent;
    gboolean draw_indicator;
    
    GtkWidget* widget;
    GtkWidget* child;
    G_CONST_RETURN gchar* label_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_toggle_button_new_with_mnemonic (LABEL_TEXT);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TOGGLE_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    if (LABEL_TEXT)
    {
        child = gtk_bin_get_child (GTK_BIN (widget));
        if (!child)
        {
            TEST_FAIL ("GtkToggleButton without child was created", NULL);
            return;
        }
        if (!GTK_IS_LABEL (child)) {
            TEST_FAIL ("GtkToggleButton child should be of type GtkLabel", NULL);
            return;
        }
    
        g_object_get (GTK_OBJECT (child), "label", &label_text, NULL);
        if (strcmp (label_text, LABEL_TEXT))
        {
            TEST_FAIL ("label_text is '%s', should be '%s'", label_text, LABEL_TEXT);
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "active", &active, NULL);
    if (active != FALSE) 
    {
        TEST_FAIL("active = %i", active);
    }
    
    g_object_get(GTK_OBJECT(widget), "inconsistent", &inconsistent, NULL);
    if (inconsistent != FALSE) 
    {
        TEST_FAIL("inconsistent = %i", inconsistent);
    }
    
    g_object_get(GTK_OBJECT(widget), "draw-indicator", &draw_indicator, NULL);
    if (draw_indicator != FALSE) 
    {
        TEST_FAIL("draw-indicator = %i", draw_indicator);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL_TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_toggle_button_new_with_mnemonic
 * Params: const gchar* name
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkToggleButton containing a label.
 * Params Values: " "
 * Expected: GtkToggleButton*  
 */
static void test_purpose_11()
{
    #define LABEL_TEXT " "
    
    gboolean active;
    gboolean inconsistent;
    gboolean draw_indicator;
    
    GtkWidget* widget;
    GtkWidget* child;
    G_CONST_RETURN gchar* label_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_toggle_button_new_with_mnemonic (LABEL_TEXT);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TOGGLE_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    if (LABEL_TEXT)
    {
        child = gtk_bin_get_child (GTK_BIN (widget));
        if (!child)
        {
            TEST_FAIL ("GtkToggleButton without child was created", NULL);
            return;
        }
        if (!GTK_IS_LABEL (child)) {
            TEST_FAIL ("GtkToggleButton child should be of type GtkLabel", NULL);
            return;
        }
    
        g_object_get (GTK_OBJECT (child), "label", &label_text, NULL);
        if (strcmp (label_text, LABEL_TEXT))
        {
            TEST_FAIL ("label_text is '%s', should be '%s'", label_text, LABEL_TEXT);
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "active", &active, NULL);
    if (active != FALSE) 
    {
        TEST_FAIL("active = %i", active);
    }
    
    g_object_get(GTK_OBJECT(widget), "inconsistent", &inconsistent, NULL);
    if (inconsistent != FALSE) 
    {
        TEST_FAIL("inconsistent = %i", inconsistent);
    }
    
    g_object_get(GTK_OBJECT(widget), "draw-indicator", &draw_indicator, NULL);
    if (draw_indicator != FALSE) 
    {
        TEST_FAIL("draw-indicator = %i", draw_indicator);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL_TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_toggle_button_new_with_mnemonic
 * Params: const gchar* name
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkToggleButton containing a label.
 * Params Values: "_ "
 * Expected: GtkToggleButton*  
 */
static void test_purpose_12()
{
    #define LABEL_TEXT "_ "
    
    gboolean active;
    gboolean inconsistent;
    gboolean draw_indicator;
    
    GtkWidget* widget;
    GtkWidget* child;
    G_CONST_RETURN gchar* label_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_toggle_button_new_with_mnemonic (LABEL_TEXT);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TOGGLE_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    if (LABEL_TEXT)
    {
        child = gtk_bin_get_child (GTK_BIN (widget));
        if (!child)
        {
            TEST_FAIL ("GtkToggleButton without child was created", NULL);
            return;
        }
        if (!GTK_IS_LABEL (child)) {
            TEST_FAIL ("GtkToggleButton child should be of type GtkLabel", NULL);
            return;
        }
    
        g_object_get (GTK_OBJECT (child), "label", &label_text, NULL);
        if (strcmp (label_text, LABEL_TEXT))
        {
            TEST_FAIL ("label_text is '%s', should be '%s'", label_text, LABEL_TEXT);
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "active", &active, NULL);
    if (active != FALSE) 
    {
        TEST_FAIL("active = %i", active);
    }
    
    g_object_get(GTK_OBJECT(widget), "inconsistent", &inconsistent, NULL);
    if (inconsistent != FALSE) 
    {
        TEST_FAIL("inconsistent = %i", inconsistent);
    }
    
    g_object_get(GTK_OBJECT(widget), "draw-indicator", &draw_indicator, NULL);
    if (draw_indicator != FALSE) 
    {
        TEST_FAIL("draw-indicator = %i", draw_indicator);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL_TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_toggle_button_new_with_mnemonic
 * Params: const gchar* name
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkToggleButton containing a label.
 * Params Values: "Label"
 * Expected: GtkToggleButton*  
 */
static void test_purpose_13()
{
    #define LABEL_TEXT "Label"
    
    gboolean active;
    gboolean inconsistent;
    gboolean draw_indicator;
    
    GtkWidget* widget;
    GtkWidget* child;
    G_CONST_RETURN gchar* label_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_toggle_button_new_with_mnemonic (LABEL_TEXT);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TOGGLE_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    if (LABEL_TEXT)
    {
        child = gtk_bin_get_child (GTK_BIN (widget));
        if (!child)
        {
            TEST_FAIL ("GtkToggleButton without child was created", NULL);
            return;
        }
        if (!GTK_IS_LABEL (child)) {
            TEST_FAIL ("GtkToggleButton child should be of type GtkLabel", NULL);
            return;
        }
    
        g_object_get (GTK_OBJECT (child), "label", &label_text, NULL);
        if (strcmp (label_text, LABEL_TEXT))
        {
            TEST_FAIL ("label_text is '%s', should be '%s'", label_text, LABEL_TEXT);
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "active", &active, NULL);
    if (active != FALSE) 
    {
        TEST_FAIL("active = %i", active);
    }
    
    g_object_get(GTK_OBJECT(widget), "inconsistent", &inconsistent, NULL);
    if (inconsistent != FALSE) 
    {
        TEST_FAIL("inconsistent = %i", inconsistent);
    }
    
    g_object_get(GTK_OBJECT(widget), "draw-indicator", &draw_indicator, NULL);
    if (draw_indicator != FALSE) 
    {
        TEST_FAIL("draw-indicator = %i", draw_indicator);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL_TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_toggle_button_new_with_mnemonic
 * Params: const gchar* name
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkToggleButton containing a label.
 * Params Values: "L_abel"
 * Expected: GtkToggleButton*  
 */
static void test_purpose_14()
{
    #define LABEL_TEXT "L_abel"
    
    gboolean active;
    gboolean inconsistent;
    gboolean draw_indicator;
    
    GtkWidget* widget;
    GtkWidget* child;
    G_CONST_RETURN gchar* label_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_toggle_button_new_with_mnemonic (LABEL_TEXT);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TOGGLE_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    if (LABEL_TEXT)
    {
        child = gtk_bin_get_child (GTK_BIN (widget));
        if (!child)
        {
            TEST_FAIL ("GtkToggleButton without child was created", NULL);
            return;
        }
        if (!GTK_IS_LABEL (child)) {
            TEST_FAIL ("GtkToggleButton child should be of type GtkLabel", NULL);
            return;
        }
    
        g_object_get (GTK_OBJECT (child), "label", &label_text, NULL);
        if (strcmp (label_text, LABEL_TEXT))
        {
            TEST_FAIL ("label_text is '%s', should be '%s'", label_text, LABEL_TEXT);
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "active", &active, NULL);
    if (active != FALSE) 
    {
        TEST_FAIL("active = %i", active);
    }
    
    g_object_get(GTK_OBJECT(widget), "inconsistent", &inconsistent, NULL);
    if (inconsistent != FALSE) 
    {
        TEST_FAIL("inconsistent = %i", inconsistent);
    }
    
    g_object_get(GTK_OBJECT(widget), "draw-indicator", &draw_indicator, NULL);
    if (draw_indicator != FALSE) 
    {
        TEST_FAIL("draw-indicator = %i", draw_indicator);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL_TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_toggle_button_new_with_mnemonic
 * Params: const gchar* name
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkToggleButton containing a label.
 * Params Values: "\b\t\n"
 * Expected: GtkToggleButton*  
 */
static void test_purpose_15()
{
    #define LABEL_TEXT "\b\t\n"
    
    gboolean active;
    gboolean inconsistent;
    gboolean draw_indicator;
    
    GtkWidget* widget;
    GtkWidget* child;
    G_CONST_RETURN gchar* label_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_toggle_button_new_with_mnemonic (LABEL_TEXT);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TOGGLE_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    if (LABEL_TEXT)
    {
        child = gtk_bin_get_child (GTK_BIN (widget));
        if (!child)
        {
            TEST_FAIL ("GtkToggleButton without child was created", NULL);
            return;
        }
        if (!GTK_IS_LABEL (child)) {
            TEST_FAIL ("GtkToggleButton child should be of type GtkLabel", NULL);
            return;
        }
    
        g_object_get (GTK_OBJECT (child), "label", &label_text, NULL);
        if (strcmp (label_text, LABEL_TEXT))
        {
            TEST_FAIL ("label_text is '%s', should be '%s'", label_text, LABEL_TEXT);
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "active", &active, NULL);
    if (active != FALSE) 
    {
        TEST_FAIL("active = %i", active);
    }
    
    g_object_get(GTK_OBJECT(widget), "inconsistent", &inconsistent, NULL);
    if (inconsistent != FALSE) 
    {
        TEST_FAIL("inconsistent = %i", inconsistent);
    }
    
    g_object_get(GTK_OBJECT(widget), "draw-indicator", &draw_indicator, NULL);
    if (draw_indicator != FALSE) 
    {
        TEST_FAIL("draw-indicator = %i", draw_indicator);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL_TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_toggle_button_new_with_mnemonic
 * Params: const gchar* name
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkToggleButton containing a label.
 * Params Values: "!@#$%^&*"
 * Expected: GtkToggleButton*  
 */
static void test_purpose_16()
{
    #define LABEL_TEXT "!@#$%^&*"
    
    gboolean active;
    gboolean inconsistent;
    gboolean draw_indicator;
    
    GtkWidget* widget;
    GtkWidget* child;
    G_CONST_RETURN gchar* label_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_toggle_button_new_with_mnemonic (LABEL_TEXT);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TOGGLE_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    if (LABEL_TEXT)
    {
        child = gtk_bin_get_child (GTK_BIN (widget));
        if (!child)
        {
            TEST_FAIL ("GtkToggleButton without child was created", NULL);
            return;
        }
        if (!GTK_IS_LABEL (child)) {
            TEST_FAIL ("GtkToggleButton child should be of type GtkLabel", NULL);
            return;
        }
    
        g_object_get (GTK_OBJECT (child), "label", &label_text, NULL);
        if (strcmp (label_text, LABEL_TEXT))
        {
            TEST_FAIL ("label_text is '%s', should be '%s'", label_text, LABEL_TEXT);
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "active", &active, NULL);
    if (active != FALSE) 
    {
        TEST_FAIL("active = %i", active);
    }
    
    g_object_get(GTK_OBJECT(widget), "inconsistent", &inconsistent, NULL);
    if (inconsistent != FALSE) 
    {
        TEST_FAIL("inconsistent = %i", inconsistent);
    }
    
    g_object_get(GTK_OBJECT(widget), "draw-indicator", &draw_indicator, NULL);
    if (draw_indicator != FALSE) 
    {
        TEST_FAIL("draw-indicator = %i", draw_indicator);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL_TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_toggle_button_new_with_mnemonic
 * Params: const gchar* name
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkToggleButton containing a label.
 * Params Values: "!@_#$%^&*"
 * Expected: GtkToggleButton*  
 */
static void test_purpose_17()
{
    #define LABEL_TEXT "!@_#$%^&*"
    
    gboolean active;
    gboolean inconsistent;
    gboolean draw_indicator;
    
    GtkWidget* widget;
    GtkWidget* child;
    G_CONST_RETURN gchar* label_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_toggle_button_new_with_mnemonic (LABEL_TEXT);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TOGGLE_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    if (LABEL_TEXT)
    {
        child = gtk_bin_get_child (GTK_BIN (widget));
        if (!child)
        {
            TEST_FAIL ("GtkToggleButton without child was created", NULL);
            return;
        }
        if (!GTK_IS_LABEL (child)) {
            TEST_FAIL ("GtkToggleButton child should be of type GtkLabel", NULL);
            return;
        }
    
        g_object_get (GTK_OBJECT (child), "label", &label_text, NULL);
        if (strcmp (label_text, LABEL_TEXT))
        {
            TEST_FAIL ("label_text is '%s', should be '%s'", label_text, LABEL_TEXT);
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "active", &active, NULL);
    if (active != FALSE) 
    {
        TEST_FAIL("active = %i", active);
    }
    
    g_object_get(GTK_OBJECT(widget), "inconsistent", &inconsistent, NULL);
    if (inconsistent != FALSE) 
    {
        TEST_FAIL("inconsistent = %i", inconsistent);
    }
    
    g_object_get(GTK_OBJECT(widget), "draw-indicator", &draw_indicator, NULL);
    if (draw_indicator != FALSE) 
    {
        TEST_FAIL("draw-indicator = %i", draw_indicator);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL_TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_toggle_button_new_with_mnemonic
 * Params: const gchar* name
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkToggleButton containing a label.
 * Params Values: "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
 * Expected: GtkToggleButton*  
 */
static void test_purpose_18()
{
    #define LABEL_TEXT "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    
    gboolean active;
    gboolean inconsistent;
    gboolean draw_indicator;
    
    GtkWidget* widget;
    GtkWidget* child;
    G_CONST_RETURN gchar* label_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_toggle_button_new_with_mnemonic (LABEL_TEXT);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TOGGLE_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    if (LABEL_TEXT)
    {
        child = gtk_bin_get_child (GTK_BIN (widget));
        if (!child)
        {
            TEST_FAIL ("GtkToggleButton without child was created", NULL);
            return;
        }
        if (!GTK_IS_LABEL (child)) {
            TEST_FAIL ("GtkToggleButton child should be of type GtkLabel", NULL);
            return;
        }
    
        g_object_get (GTK_OBJECT (child), "label", &label_text, NULL);
        if (strcmp (label_text, LABEL_TEXT))
        {
            TEST_FAIL ("label_text is '%s', should be '%s'", label_text, LABEL_TEXT);
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "active", &active, NULL);
    if (active != FALSE) 
    {
        TEST_FAIL("active = %i", active);
    }
    
    g_object_get(GTK_OBJECT(widget), "inconsistent", &inconsistent, NULL);
    if (inconsistent != FALSE) 
    {
        TEST_FAIL("inconsistent = %i", inconsistent);
    }
    
    g_object_get(GTK_OBJECT(widget), "draw-indicator", &draw_indicator, NULL);
    if (draw_indicator != FALSE) 
    {
        TEST_FAIL("draw-indicator = %i", draw_indicator);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL_TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_toggle_button_new_with_mnemonic
 * Params: const gchar* name
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkToggleButton containing a label.
 * Params Values: "abcdefghijklm_nopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
 * Expected: GtkToggleButton*  
 */
static void test_purpose_19()
{
    #define LABEL_TEXT "abcdefghijklm_nopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    
    gboolean active;
    gboolean inconsistent;
    gboolean draw_indicator;
    
    GtkWidget* widget;
    GtkWidget* child;
    G_CONST_RETURN gchar* label_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_toggle_button_new_with_mnemonic (LABEL_TEXT);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TOGGLE_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    if (LABEL_TEXT)
    {
        child = gtk_bin_get_child (GTK_BIN (widget));
        if (!child)
        {
            TEST_FAIL ("GtkToggleButton without child was created", NULL);
            return;
        }
        if (!GTK_IS_LABEL (child)) {
            TEST_FAIL ("GtkToggleButton child should be of type GtkLabel", NULL);
            return;
        }
    
        g_object_get (GTK_OBJECT (child), "label", &label_text, NULL);
        if (strcmp (label_text, LABEL_TEXT))
        {
            TEST_FAIL ("label_text is '%s', should be '%s'", label_text, LABEL_TEXT);
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "active", &active, NULL);
    if (active != FALSE) 
    {
        TEST_FAIL("active = %i", active);
    }
    
    g_object_get(GTK_OBJECT(widget), "inconsistent", &inconsistent, NULL);
    if (inconsistent != FALSE) 
    {
        TEST_FAIL("inconsistent = %i", inconsistent);
    }
    
    g_object_get(GTK_OBJECT(widget), "draw-indicator", &draw_indicator, NULL);
    if (draw_indicator != FALSE) 
    {
        TEST_FAIL("draw-indicator = %i", draw_indicator);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL_TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_toggle_button_new_with_mnemonic
 * Params: const gchar* name
 * Returns: GtkWidget*
 * Assertion: The label will be created using gtk_label_new_with_mnemonic(), so underscores in label indicate the mnemonic for the button.
 * Params Values: "Te_xt"
 * Expected: GtkToggleButton*  
 */
static void test_purpose_20()
{
    #define LABEL_TEXT "Te_xt"
    #define KEY GDK_x
    
    GtkWidget* widget;
    GtkWidget* child;
    guint keyval;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_toggle_button_new_with_mnemonic (LABEL_TEXT);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TOGGLE_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (!GTK_IS_LABEL (child))
    {
        TEST_FAIL ("GtkLabel object should be menu item's child", NULL);
        return;
    } 
    
    keyval = gtk_label_get_mnemonic_keyval (GTK_LABEL (child));
    if (keyval != KEY)
    {
        TEST_FAIL ("keyval = %i, should be %i", keyval, KEY);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL_TEXT
    #undef KEY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_toggle_button_new_with_mnemonic
 * Params: const gchar* name
 * Returns: GtkWidget*
 * Assertion: The label will be created using gtk_label_new_with_mnemonic(), so underscores in label indicate the mnemonic for the button.
 * Params Values: "_Text"
 * Expected: GtkToggleButton*  
 */
static void test_purpose_21()
{
    #define LABEL_TEXT "_Text"
    #define KEY GDK_t
    
    GtkWidget* widget;
    GtkWidget* child;
    guint keyval;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_toggle_button_new_with_mnemonic (LABEL_TEXT);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TOGGLE_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (!GTK_IS_LABEL (child))
    {
        TEST_FAIL ("GtkLabel object should be menu item's child", NULL);
        return;
    } 
    
    keyval = gtk_label_get_mnemonic_keyval (GTK_LABEL (child));
    if (keyval != KEY)
    {
        TEST_FAIL ("keyval = %i, should be %i", keyval, KEY);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL_TEXT
    #undef KEY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_toggle_button_new_with_mnemonic
 * Params: const gchar* name
 * Returns: GtkWidget*
 * Assertion: The label will be created using gtk_label_new_with_mnemonic(), so underscores in label indicate the mnemonic for the button.
 * Params Values: "T_ext"
 * Expected: GtkToggleButton*  
 */
static void test_purpose_22()
{
    #define LABEL_TEXT "T_ext"
    #define KEY GDK_e
    
    GtkWidget* widget;
    GtkWidget* child;
    guint keyval;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_toggle_button_new_with_mnemonic (LABEL_TEXT);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TOGGLE_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (!GTK_IS_LABEL (child))
    {
        TEST_FAIL ("GtkLabel object should be menu item's child", NULL);
        return;
    } 
    
    keyval = gtk_label_get_mnemonic_keyval (GTK_LABEL (child));
    if (keyval != KEY)
    {
        TEST_FAIL ("keyval = %i, should be %i", keyval, KEY);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL_TEXT
    #undef KEY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_toggle_button_set_mode
 * Params: GtkToggleButton *toggle_button, gboolean draw_indicator
 * Returns: void
 * Assertion: Sets whether the button is displayed as a separate indicator and label.
 * Params Values: a newly created GtkToggleButton, FALSE
 * Expected: void
 * 
 * Name: gtk_toggle_button_get_mode
 * Params: GtkToggleButton *toggle_button
 * Returns: gboolean
 * Assertion: Retrieves whether the button is displayed as a separate indicator and label.
 * Params Values: a newly created GtkToggleButton
 * Expected: FALSE  
 */
static void test_purpose_23()
{
    #define DRAW_INDICATOR FALSE
    
    gboolean draw_indicator;
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_toggle_button_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TOGGLE_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_toggle_button_set_mode(GTK_TOGGLE_BUTTON (widget), DRAW_INDICATOR);
    
    g_object_get(GTK_OBJECT (widget), "draw-indicator", &draw_indicator, NULL);
    if (draw_indicator != DRAW_INDICATOR)
    {
        TEST_FAIL ("draw-indicator is %d, should be %d", draw_indicator,  DRAW_INDICATOR);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef DRAW_INDICATOR 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_toggle_button_set_mode
 * Params: GtkToggleButton *toggle_button, gboolean draw_indicator
 * Returns: void
 * Assertion: Sets whether the button is displayed as a separate indicator and label.
 * Params Values: a newly created GtkToggleButton, TRUE
 * Expected: void
 * 
 * Name: gtk_toggle_button_get_mode
 * Params: GtkToggleButton *toggle_button
 * Returns: gboolean
 * Assertion: Retrieves whether the button is displayed as a separate indicator and label.
 * Params Values: a newly created GtkToggleButton
 * Expected: TRUE  
 */
static void test_purpose_24()
{
    #define DRAW_INDICATOR TRUE
    
    gboolean draw_indicator;
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_toggle_button_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TOGGLE_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_toggle_button_set_mode(GTK_TOGGLE_BUTTON (widget), DRAW_INDICATOR);
    
    g_object_get(GTK_OBJECT (widget), "draw-indicator", &draw_indicator, NULL);
    if (draw_indicator != DRAW_INDICATOR)
    {
        TEST_FAIL ("draw-indicator is %d, should be %d", draw_indicator,  DRAW_INDICATOR);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef DRAW_INDICATOR 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_toggle_button_set_active
 * Params: GtkToggleButton *toggle_button
 * Returns: gboolean
 * Assertion: Sets the status of the toggle button.
 * Params Values: a newly created GtkToggleButton 
 * Expected: gboolean
 * 
 * Name:  gtk_toggle_button_get_active
 * Params: GtkToggleButton *toggle_button, gboolean is_active
 * Returns: void
 * Assertion: Queries a GtkToggleButton and returns it's current state.'
 * Params Values: a newly created GtkToggleButton, TRUE
 * Expected: void
 * 
 * Name:  gtk_toggle_button_get_active
 * Params: GtkToggleButton *toggle_button, gboolean is_active
 * Returns: void
 * Assertion: Returns TRUE if the toggle button is pressed in and FALSE if it is raised.
 * Params Values: a newly created GtkToggleButton, TRUE
 * Expected: void  
 */
static void test_purpose_25()
{
    #define IS_ACTIVE TRUE
    
    GtkWidget* widget;
    gboolean is_active;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_toggle_button_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TOGGLE_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    is_active = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget));
    if (is_active != FALSE)
    {
        TEST_FAIL ("is_active = %d, should be FALSE", is_active);
    }
    
    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON (widget), IS_ACTIVE);
    is_active = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget));
    if (is_active != IS_ACTIVE)
    {
        TEST_FAIL ("is_active = %d, should be %d", is_active, IS_ACTIVE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef IS_ACTIVE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_toggle_button_set_active
 * Params: GtkToggleButton *toggle_button
 * Returns: gboolean
 * Assertion: Sets the status of the toggle button.
 * Params Values: a newly created GtkToggleButton 
 * Expected: gboolean
 * 
 * Name:  gtk_toggle_button_get_active
 * Params: GtkToggleButton *toggle_button, gboolean is_active
 * Returns: void
 * Assertion: Queries a GtkToggleButton and returns it's current state.'
 * Params Values: a newly created GtkToggleButton, FALSE
 * Expected: void
 * 
 * Name:  gtk_toggle_button_get_active
 * Params: GtkToggleButton *toggle_button, gboolean is_active
 * Returns: void
 * Assertion: Returns TRUE if the toggle button is pressed in and FALSE if it is raised.
 * Params Values: a newly created GtkToggleButton, FALSE
 * Expected: void  
 */
static void test_purpose_26()
{
    #define IS_ACTIVE FALSE
    
    GtkWidget* widget;
    gboolean is_active;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_toggle_button_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TOGGLE_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    is_active = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget));
    if (is_active != FALSE)
    {
        TEST_FAIL ("is_active = %d, should be FALSE", is_active);
    }
    
    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON (widget), IS_ACTIVE);
    is_active = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget));
    if (is_active != IS_ACTIVE)
    {
        TEST_FAIL ("is_active = %d, should be %d", is_active, IS_ACTIVE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef IS_ACTIVE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_toggle_button_set_active
 * Params: GtkToggleButton *toggle_button, gboolean is_active
 * Returns: void
 * Assertion:  This action causes the toggled signal to be emitted.
 * Params Values: a newly created GtkToggleButton, TRUE
 * Expected: void  
 */
static void test_purpose_27()
{
    #define IS_ACTIVE TRUE
    
    GtkWidget* widget;
    gboolean is_active;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_counter = 0;
    widget = gtk_toggle_button_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TOGGLE_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    if (IS_ACTIVE == FALSE)
    {
        gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON (widget), TRUE);
    }
    
    g_signal_connect (G_OBJECT (widget), "toggled", 
                      GTK_SIGNAL_FUNC (global_toggled_signal), NULL);
    
    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON (widget), IS_ACTIVE);
    
    if (global_counter == 0)
    {
        TEST_FAIL ("'toggled' signal was not emitted", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef IS_ACTIVE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_toggle_button_set_active
 * Params: GtkToggleButton *toggle_button, gboolean is_active
 * Returns: void
 * Assertion:  This action causes the toggled signal to be emitted.
 * Params Values: a newly created GtkToggleButton, FALSE
 * Expected: void  
 */
static void test_purpose_28()
{
    #define IS_ACTIVE FALSE
    
    GtkWidget* widget;
    gboolean is_active;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_counter = 0;
    widget = gtk_toggle_button_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TOGGLE_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    if (IS_ACTIVE == FALSE)
    {
        gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON (widget), TRUE);
    }
    
    g_signal_connect (G_OBJECT (widget), "toggled", 
                      GTK_SIGNAL_FUNC (global_toggled_signal), NULL);
    
    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON (widget), IS_ACTIVE);
    
    if (global_counter == 0)
    {
        TEST_FAIL ("'toggled' signal was not emitted", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef IS_ACTIVE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_toggle_button_set_inconsistent
 * Params: GtkToggleButton *toggle_button
 * Returns: gboolean
 * Assertion: This function turns on "in between" display.
 * Params Values: a newly created GtkToggleButton 
 * Expected: gboolean
 * 
 * Name:  gtk_toggle_button_get_inconsistent
 * Params: GtkToggleButton *toggle_button, gboolean setting
 * Returns: void
 * Assertion: Gets the value set by gtk_toggle_button_set_inconsistent().
 * Params Values: a newly created GtkToggleButton, TRUE
 * Expected: void  
 */
static void test_purpose_29()
{
    #define SETTING TRUE
    
    GtkWidget* widget;
    gboolean inconsistent;
    gboolean setting;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_toggle_button_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TOGGLE_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    inconsistent = gtk_toggle_button_get_inconsistent(GTK_TOGGLE_BUTTON (widget));
    if (inconsistent != FALSE)
    {
        TEST_FAIL ("inconsistent = %d, default value is FALSE", 
                   inconsistent);
    }
    
    
    gtk_toggle_button_set_inconsistent (GTK_TOGGLE_BUTTON (widget), SETTING);
    setting = gtk_toggle_button_get_inconsistent(GTK_TOGGLE_BUTTON (widget));
    if (setting != SETTING)
    {
        TEST_FAIL ("inconsistent = %d, should be %d", setting, SETTING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef SETTING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_toggle_button_set_inconsistent
 * Params: GtkToggleButton *toggle_button
 * Returns: gboolean
 * Assertion: This function turns on "in between" display.
 * Params Values: a newly created GtkToggleButton 
 * Expected: gboolean
 * 
 * Name:  gtk_toggle_button_get_inconsistent
 * Params: GtkToggleButton *toggle_button, gboolean setting
 * Returns: void
 * Assertion: Gets the value set by gtk_toggle_button_set_inconsistent().
 * Params Values: a newly created GtkToggleButton, FALSE
 * Expected: void  
 */
static void test_purpose_30()
{
    #define SETTING FALSE
    
    GtkWidget* widget;
    gboolean inconsistent;
    gboolean setting;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_toggle_button_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TOGGLE_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    inconsistent = gtk_toggle_button_get_inconsistent(GTK_TOGGLE_BUTTON (widget));
    if (inconsistent != FALSE)
    {
        TEST_FAIL ("inconsistent = %d, default value is FALSE", 
                   inconsistent);
    }
    
    
    gtk_toggle_button_set_inconsistent (GTK_TOGGLE_BUTTON (widget), SETTING);
    setting = gtk_toggle_button_get_inconsistent(GTK_TOGGLE_BUTTON (widget));
    if (setting != SETTING)
    {
        TEST_FAIL ("inconsistent = %d, should be %d", setting, SETTING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef SETTING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_toggle_button_toggled 
 * Params: GtkToggleButton *toggle_button
 * Returns: void
 * Assertion: Emits the toggled signal on the GtkToggleButton.
 * Params Values: a newly created GtkToggleButton
 * Expected: void  
 */
static void test_purpose_31()
{
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_counter = 0;
    widget = gtk_toggle_button_new ();
    
    g_signal_connect (G_OBJECT (widget), "toggled", 
                        GTK_SIGNAL_FUNC (global_toggled_signal), NULL);
    
    gtk_toggle_button_toggled (GTK_TOGGLE_BUTTON (widget));
    if (global_counter == 0)
    {
        TEST_FAIL ("GtkToggleButton widget should emit 'toggled' signal", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GtkToggleButton ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {test_purpose_11, 1},
    {test_purpose_12, 1},
    {test_purpose_13, 1},
    {test_purpose_14, 1},
    {test_purpose_15, 1},
    {test_purpose_16, 1},
    {test_purpose_17, 1},
    {test_purpose_18, 1},
    {test_purpose_19, 1},
    {test_purpose_20, 1},
    {test_purpose_21, 1},
    {test_purpose_22, 1},
    {test_purpose_23, 1},
    {test_purpose_24, 1},
    {test_purpose_25, 1},
    {test_purpose_26, 1},
    {test_purpose_27, 1},
    {test_purpose_28, 1},
    {test_purpose_29, 1},
    {test_purpose_30, 1},
    {test_purpose_31, 1},
    {NULL,0}
};
