/*
 * GtkWindowGroup methods tests
 * Testing GtkWindowGroup methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;

/*
 * Name: gtk_window_group_new
 * Params: void
 * Returns: GtkWindowGroup*
 * Assertion: Creates a new GtkWindowGroup object.
 * Params Values: void
 * Expected: a newly created GtkWindowGroup* 
 * 
 * Name: gtk_window_group_new
 * Params: void
 * Returns: GtkWindowGroup*
 * Assertion: Grabs added with gtk_grab_add() only affect windows within the same GtkWindowGroup.
 * Params Values: void
 * Expected: a newly created GtkWindowGroup*   
 */
static void test_purpose_1()
{
    GtkWindowGroup* group;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    group = gtk_window_group_new ();
    if (!group)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_WINDOW_GROUP (group))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_window_group_add_window
 * Params: void
 * Returns: void
 * Assertion: Adds a window to a GtkWindowGroup.
 * Params Values: gtk_window_new (GTK_WINDOW_TOPLEVEL)
 * Expected: void  
 */
static void test_purpose_2()
{
    #define WINDOW gtk_window_new (GTK_WINDOW_TOPLEVEL)
    
    GtkWindowGroup* group;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    group = gtk_window_group_new ();
    if (!group)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_WINDOW_GROUP (group))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    window = WINDOW;
    if (!window)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    /******* VISUALISATION *******/
    TEST_VISUALIZE (window);
    /******* -------------  *******/  
    
    gtk_window_group_add_window (group, GTK_WINDOW (window));
    
    if (GTK_WINDOW (window)->group != group)
    {
        TEST_FAIL ("Test fails", NULL);
    }
    
    gtk_widget_destroy (window);
    
    #undef WINDOW
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_window_group_add_window
 * Params: void
 * Returns: void
 * Assertion: Adds a window to a GtkWindowGroup.
 * Params Values: gtk_window_new (GTK_WINDOW_POPUP)
 * Expected: void  
 */
static void test_purpose_3()
{
    #define WINDOW gtk_window_new (GTK_WINDOW_POPUP)
    
    GtkWindowGroup* group;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    group = gtk_window_group_new ();
    if (!group)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_WINDOW_GROUP (group))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    window = WINDOW;
    if (!window)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    /******* VISUALISATION *******/
    TEST_VISUALIZE (window);
    /******* -------------  *******/  
    
    gtk_window_group_add_window (group, GTK_WINDOW (window));
    
    if (GTK_WINDOW (window)->group != group)
    {
        TEST_FAIL ("Test fails", NULL);
    }
    
    gtk_widget_destroy (window);
    
    #undef WINDOW
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_window_group_remove_window
 * Params: GtkWindowGroup *window_group, GtkWindow* window
 * Returns: void
 * Assertion: Removes a window from a GtkWindowGroup.
 * Params Values: GtkWindowGroup *window_group, GtkWindow* window
 * Expected: void  
 */
static void test_purpose_4()
{
    #define WINDOW gtk_window_new (GTK_WINDOW_TOPLEVEL)
    
    GtkWindowGroup* group;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    group = gtk_window_group_new ();
    if (!group)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_WINDOW_GROUP (group))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    window = WINDOW;
    if (!window)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (window);
    /******* -------------  *******/  
    
    gtk_window_group_add_window (group, GTK_WINDOW (window));
    gtk_window_group_remove_window (group, GTK_WINDOW (window));
    
    if (GTK_WINDOW (window)->group == group)
    {
        TEST_FAIL ("Test fails", NULL);
    }
    
    gtk_widget_destroy (window);
    
    #undef WINDOW
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_window_group_remove_window
 * Params: GtkWindowGroup *window_group, GtkWindow* window
 * Returns: void
 * Assertion: Removes a window from a GtkWindowGroup.
 * Params Values: GtkWindowGroup *window_group, GtkWindow* window
 * Expected: void  
 */
static void test_purpose_5()
{
    #define WINDOW gtk_window_new (GTK_WINDOW_POPUP)
    
    GtkWindowGroup* group;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    group = gtk_window_group_new ();
    if (!group)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_WINDOW_GROUP (group))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    window = WINDOW;
    if (!window)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (window);
    /******* -------------  *******/  
    
    gtk_window_group_add_window (group, GTK_WINDOW (window));
    gtk_window_group_remove_window (group, GTK_WINDOW (window));
    
    if (GTK_WINDOW (window)->group == group)
    {
        TEST_FAIL ("Test fails", NULL);
    }
    
    gtk_widget_destroy (window);
    
    #undef WINDOW
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GtkWindowGroup ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {NULL,0}
};
