/*
 * MemAlloc methods tests
 * Testing MemAlloc methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;

/*
 * Name: g_malloc
 * Params: gulong n_bytes
 * Returns: gpointer
 * Assertion: Allocates n_bytes bytes of memory. If n_bytes is 0 it returns NULL.
 *            n_bytes : the number of bytes to allocate.
 *            Returns : a pointer to the allocated memory. 
 * Params Values: 10
 * Expected: gpointer  
 */
static void test_purpose_1()
{
    #define BYTES    10
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gpointer p = g_malloc(BYTES);
    if (BYTES == 0){
        if (p != NULL){
            TEST_FAIL("g_malloc: failed", NULL);
        }
    }
    else{
        if (p == NULL){
            TEST_FAIL("g_malloc: failed", NULL);
        }
    }
    g_free(p);
    #undef BYTES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_malloc
 * Params: gulong n_bytes
 * Returns: gpointer
 * Assertion: Allocates n_bytes bytes of memory. If n_bytes is 0 it returns NULL.
 *            n_bytes : the number of bytes to allocate.
 *            Returns : a pointer to the allocated memory. 
 * Params Values: 0
 * Expected: gpointer  
 */
static void test_purpose_2()
{
    #define BYTES    0
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gpointer p = g_malloc(BYTES);
    if (BYTES == 0){
        if (p != NULL){
            TEST_FAIL("g_malloc: failed", NULL);
        }
    }
    else{
        if (p == NULL){
            TEST_FAIL("g_malloc: failed", NULL);
        }
    }
    g_free(p);
    #undef BYTES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_malloc0
 * Params: gulong n_bytes
 * Returns: gpointer
 * Assertion: Allocates n_bytes bytes of memory, initialized to 0's. If n_bytes is 0 it returns NULL.
 *            n_bytes : the number of bytes to allocate.
 *            Returns : a pointer to the allocated memory. 
 * Params Values: 10
 * Expected: gpointer  
 */
static void test_purpose_3()
{
    #define BYTES    10
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gint i;
    
    gpointer p = g_malloc0(BYTES);
    
    if (BYTES == 0){
        if (p != NULL){
            TEST_FAIL("g_malloc0: failed", NULL);
        }
    }
    else{
        if (p == NULL){
            TEST_FAIL("g_malloc0: failed", NULL);
        }
        else{
            for (i = 0; i < BYTES; i++){
                if (*(gchar *)(p + i) != 0){
                    TEST_FAIL("g_malloc0: should be initialized 0", NULL);
                    break;
                }
            }
        }
    }
    g_free(p);
    #undef BYTES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_malloc0
 * Params: gulong n_bytes
 * Returns: gpointer
 * Assertion: Allocates n_bytes bytes of memory, initialized to 0's. If n_bytes is 0 it returns NULL.
 *            n_bytes : the number of bytes to allocate.
 *            Returns : a pointer to the allocated memory. 
 * Params Values: 0
 * Expected: gpointer  
 */
static void test_purpose_4()
{
    #define BYTES    0
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gint i;
    
    gpointer p = g_malloc0(BYTES);
    
    if (BYTES == 0){
        if (p != NULL){
            TEST_FAIL("g_malloc0: failed", NULL);
        }
    }
    else{
        if (p == NULL){
            TEST_FAIL("g_malloc0: failed", NULL);
        }
        else{
            for (i = 0; i < BYTES; i++){
                if (*(gchar *)(p + i) != 0){
                    TEST_FAIL("g_malloc0: should be initialized 0", NULL);
                    break;
                }
            }
        }
    }
    g_free(p);
    #undef BYTES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_memdup
 * Params: gconstpointer mem, guint byte_size
 * Returns: gpointer
 * Assertion: Allocates byte_size bytes of memory, and copies byte_size bytes into it from mem. If mem is NULL it returns NULL.
 *            mem : the memory to copy.
 *            byte_size : the number of bytes to copy.
 *            Returns : a pointer to the newly-allocated copy of the memory, or NULL if mem is NULL. 
 * Params Values: "Hello", 3
 * Expected: gpointer  
 */
static void test_purpose_5()
{
    #define MEM    "Hello"
    #define SIZE   3
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gpointer *p = g_memdup(MEM, SIZE);
    if (SIZE == 0){
        if (p != NULL){
            TEST_FAIL("g_memdup: failed", NULL);
        }
    }
    else{
        if (p == NULL){
            TEST_FAIL("g_memdup: failed", NULL);
        }
        else{
            if (strncmp((gchar *)p, MEM, SIZE) != 0){
                TEST_FAIL("g_memdup: failed", NULL);
            }
        }
    }
    g_free(p);
    #undef MEM
    #undef SIZE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_memdup
 * Params: gconstpointer mem, guint byte_size
 * Returns: gpointer
 * Assertion: Allocates byte_size bytes of memory, and copies byte_size bytes into it from mem. If mem is NULL it returns NULL.
 *            mem : the memory to copy.
 *            byte_size : the number of bytes to copy.
 *            Returns : a pointer to the newly-allocated copy of the memory, or NULL if mem is NULL. 
 * Params Values: "hello", 0
 * Expected: gpointer  
 */
static void test_purpose_6()
{
    #define MEM    "hello"
    #define SIZE   0
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gpointer *p = g_memdup(MEM, SIZE);
    if (SIZE == 0){
        if (p != NULL){
            TEST_FAIL("g_memdup: failed", NULL);
        }
    }
    else{
        if (p == NULL){
            TEST_FAIL("g_memdup: failed", NULL);
        }
        else{
            if (strncmp((gchar *)p, MEM, SIZE) != 0){
                TEST_FAIL("g_memdup: failed", NULL);
            }
        }
    }
    g_free(p);
    #undef MEM
    #undef SIZE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_realloc
 * Params: gpointer mem, gulong n_bytes
 * Returns: gpointer
 * Assertion: Reallocates the memory pointed to by mem, so that it now has space for n_bytes bytes of memory. It returns the new address of the memory, which may have been moved. mem may be NULL, in which case it's considered to have zero-length. n_bytes may be 0, in which case NULL will be returned.
 *            mem : the memory to reallocate.
 *            n_bytes : new size of the memory in bytes.
 *            Returns : the new address of the allocated memory.  
 * Params Values: mem, 10
 * Expected: gpointer  
 */
static void test_purpose_7()
{
    #define MEM    mem
    #define BYTES  10
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gpointer mem = g_malloc(1);
    gpointer p = g_realloc(MEM, BYTES);
    if (MEM == NULL){
        if (p == NULL){
            TEST_FAIL("g_realloc: failed", NULL);
        }
    }
    else if (BYTES == 0){
        if (p != NULL){
            TEST_FAIL("g_realloc: failed", NULL);
        }
    }
    else{
        if (p == NULL){
            TEST_FAIL("g_realloc: failed", NULL);
        }
    }
    g_free(p);
    #undef MEM
    #undef BYTES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_realloc
 * Params: gpointer mem, gulong n_bytes
 * Returns: gpointer
 * Assertion: Reallocates the memory pointed to by mem, so that it now has space for n_bytes bytes of memory. It returns the new address of the memory, which may have been moved. mem may be NULL, in which case it's considered to have zero-length. n_bytes may be 0, in which case NULL will be returned.
 *            mem : the memory to reallocate.
 *            n_bytes : new size of the memory in bytes.
 *            Returns : the new address of the allocated memory.  
 * Params Values: NULL, 10
 * Expected: gpointer  
 */
static void test_purpose_8()
{
    #define MEM    NULL
    #define BYTES  10
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gpointer mem = g_malloc(1);
    gpointer p = g_realloc(MEM, BYTES);
    if (MEM == NULL){
        if (p == NULL){
            TEST_FAIL("g_realloc: failed", NULL);
        }
    }
    else if (BYTES == 0){
        if (p != NULL){
            TEST_FAIL("g_realloc: failed", NULL);
        }
    }
    else{
        if (p == NULL){
            TEST_FAIL("g_realloc: failed", NULL);
        }
    }
    g_free(p);
    #undef MEM
    #undef BYTES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_realloc
 * Params: gpointer mem, gulong n_bytes
 * Returns: gpointer
 * Assertion: Reallocates the memory pointed to by mem, so that it now has space for n_bytes bytes of memory. It returns the new address of the memory, which may have been moved. mem may be NULL, in which case it's considered to have zero-length. n_bytes may be 0, in which case NULL will be returned.
 *            mem : the memory to reallocate.
 *            n_bytes : new size of the memory in bytes.
 *            Returns : the new address of the allocated memory.  
 * Params Values: mem, 0
 * Expected: gpointer  
 */
static void test_purpose_9()
{
    #define MEM    mem
    #define BYTES  0
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gpointer mem = g_malloc(1);
    gpointer p = g_realloc(MEM, BYTES);
    if (MEM == NULL){
        if (p == NULL){
            TEST_FAIL("g_realloc: failed", NULL);
        }
    }
    else if (BYTES == 0){
        if (p != NULL){
            TEST_FAIL("g_realloc: failed", NULL);
        }
    }
    else{
        if (p == NULL){
            TEST_FAIL("g_realloc: failed", NULL);
        }
    }
    g_free(p);
    #undef MEM
    #undef BYTES
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for MemAlloc ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {NULL,0}
};
