/*
 * GtkTable methods tests
 * Testing GtkTable methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;

/*
 * Name: gtk_table_new 
 * Params: guint rows, guint columns, gboolean homogeneous
 * Returns: GtkWidget*
 * Assertion: Used to create a new table widget.
 * Params Values: 65535, 65535, TRUE 
 * Expected: GtkTable*  
 */
static void test_purpose_1()
{
    #define ROWS 65535
    #define COLUMNS 65535
    #define HOMOGENEOUS TRUE
    GtkWidget* widget;
    guint rows;
    guint columns;
    gboolean homogeneous;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_table_new (ROWS, COLUMNS, HOMOGENEOUS);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TABLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "n-rows", &rows, NULL);
    if(ROWS !=0)
    {
        if (rows != ROWS)
        {
            TEST_FAIL ("n-rows is %u, should be %u", rows, ROWS);
        }
    }
    else if (rows != 1)
    {
        TEST_FAIL ("n-rows is %u, should be %u", rows, ROWS);
    }
    
    g_object_get(GTK_OBJECT(widget), "n-columns", &columns, NULL);
    if(COLUMNS !=0)
    {
        if (columns != COLUMNS)
        {
            TEST_FAIL ("n-columns is %u, should be %u", columns, COLUMNS);
        }
    }
    else if (columns != 1)
    {
        TEST_FAIL ("n-columns is %u, should be %u", columns, COLUMNS);
    }
    
    g_object_get(GTK_OBJECT(widget), "homogeneous", &homogeneous, NULL);
    if (homogeneous != HOMOGENEOUS)
    {
        TEST_FAIL ("homogeneous is %u, should be %u", homogeneous, HOMOGENEOUS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef ROWS 
    #undef COLUMNS
    #undef HOMOGENEOUS 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_table_new 
 * Params: guint rows, guint columns, gboolean homogeneous
 * Returns: GtkWidget*
 * Assertion: Used to create a new table widget.
 * Params Values: 1, 65535, TRUE 
 * Expected: GtkTable*  
 */
static void test_purpose_2()
{
    #define ROWS 1
    #define COLUMNS 65535
    #define HOMOGENEOUS TRUE
    GtkWidget* widget;
    guint rows;
    guint columns;
    gboolean homogeneous;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_table_new (ROWS, COLUMNS, HOMOGENEOUS);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TABLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "n-rows", &rows, NULL);
    if(ROWS !=0)
    {
        if (rows != ROWS)
        {
            TEST_FAIL ("n-rows is %u, should be %u", rows, ROWS);
        }
    }
    else if (rows != 1)
    {
        TEST_FAIL ("n-rows is %u, should be %u", rows, ROWS);
    }
    
    g_object_get(GTK_OBJECT(widget), "n-columns", &columns, NULL);
    if(COLUMNS !=0)
    {
        if (columns != COLUMNS)
        {
            TEST_FAIL ("n-columns is %u, should be %u", columns, COLUMNS);
        }
    }
    else if (columns != 1)
    {
        TEST_FAIL ("n-columns is %u, should be %u", columns, COLUMNS);
    }
    
    g_object_get(GTK_OBJECT(widget), "homogeneous", &homogeneous, NULL);
    if (homogeneous != HOMOGENEOUS)
    {
        TEST_FAIL ("homogeneous is %u, should be %u", homogeneous, HOMOGENEOUS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef ROWS 
    #undef COLUMNS
    #undef HOMOGENEOUS 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_table_new 
 * Params: guint rows, guint columns, gboolean homogeneous
 * Returns: GtkWidget*
 * Assertion: Used to create a new table widget.
 * Params Values: 65535, 1, TRUE 
 * Expected: GtkTable*  
 */
static void test_purpose_3()
{
    #define ROWS 65535
    #define COLUMNS 1
    #define HOMOGENEOUS TRUE
    GtkWidget* widget;
    guint rows;
    guint columns;
    gboolean homogeneous;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_table_new (ROWS, COLUMNS, HOMOGENEOUS);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TABLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "n-rows", &rows, NULL);
    if(ROWS !=0)
    {
        if (rows != ROWS)
        {
            TEST_FAIL ("n-rows is %u, should be %u", rows, ROWS);
        }
    }
    else if (rows != 1)
    {
        TEST_FAIL ("n-rows is %u, should be %u", rows, ROWS);
    }
    
    g_object_get(GTK_OBJECT(widget), "n-columns", &columns, NULL);
    if(COLUMNS !=0)
    {
        if (columns != COLUMNS)
        {
            TEST_FAIL ("n-columns is %u, should be %u", columns, COLUMNS);
        }
    }
    else if (columns != 1)
    {
        TEST_FAIL ("n-columns is %u, should be %u", columns, COLUMNS);
    }
    
    g_object_get(GTK_OBJECT(widget), "homogeneous", &homogeneous, NULL);
    if (homogeneous != HOMOGENEOUS)
    {
        TEST_FAIL ("homogeneous is %u, should be %u", homogeneous, HOMOGENEOUS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef ROWS 
    #undef COLUMNS
    #undef HOMOGENEOUS 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_table_new 
 * Params: guint rows, guint columns, gboolean homogeneous
 * Returns: GtkWidget*
 * Assertion: Used to create a new table widget.
 * Params Values: 1, 65535, FALSE 
 * Expected: GtkTable*  
 */
static void test_purpose_4()
{
    #define ROWS 1
    #define COLUMNS 65535
    #define HOMOGENEOUS FALSE
    GtkWidget* widget;
    guint rows;
    guint columns;
    gboolean homogeneous;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_table_new (ROWS, COLUMNS, HOMOGENEOUS);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TABLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "n-rows", &rows, NULL);
    if(ROWS !=0)
    {
        if (rows != ROWS)
        {
            TEST_FAIL ("n-rows is %u, should be %u", rows, ROWS);
        }
    }
    else if (rows != 1)
    {
        TEST_FAIL ("n-rows is %u, should be %u", rows, ROWS);
    }
    
    g_object_get(GTK_OBJECT(widget), "n-columns", &columns, NULL);
    if(COLUMNS !=0)
    {
        if (columns != COLUMNS)
        {
            TEST_FAIL ("n-columns is %u, should be %u", columns, COLUMNS);
        }
    }
    else if (columns != 1)
    {
        TEST_FAIL ("n-columns is %u, should be %u", columns, COLUMNS);
    }
    
    g_object_get(GTK_OBJECT(widget), "homogeneous", &homogeneous, NULL);
    if (homogeneous != HOMOGENEOUS)
    {
        TEST_FAIL ("homogeneous is %u, should be %u", homogeneous, HOMOGENEOUS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef ROWS 
    #undef COLUMNS
    #undef HOMOGENEOUS 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_table_new 
 * Params: guint rows, guint columns, gboolean homogeneous
 * Returns: GtkWidget*
 * Assertion: Used to create a new table widget.
 * Params Values: 65535, 1, FALSE 
 * Expected: GtkTable*  
 */
static void test_purpose_5()
{
    #define ROWS 65535
    #define COLUMNS 1
    #define HOMOGENEOUS FALSE
    GtkWidget* widget;
    guint rows;
    guint columns;
    gboolean homogeneous;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_table_new (ROWS, COLUMNS, HOMOGENEOUS);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TABLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "n-rows", &rows, NULL);
    if(ROWS !=0)
    {
        if (rows != ROWS)
        {
            TEST_FAIL ("n-rows is %u, should be %u", rows, ROWS);
        }
    }
    else if (rows != 1)
    {
        TEST_FAIL ("n-rows is %u, should be %u", rows, ROWS);
    }
    
    g_object_get(GTK_OBJECT(widget), "n-columns", &columns, NULL);
    if(COLUMNS !=0)
    {
        if (columns != COLUMNS)
        {
            TEST_FAIL ("n-columns is %u, should be %u", columns, COLUMNS);
        }
    }
    else if (columns != 1)
    {
        TEST_FAIL ("n-columns is %u, should be %u", columns, COLUMNS);
    }
    
    g_object_get(GTK_OBJECT(widget), "homogeneous", &homogeneous, NULL);
    if (homogeneous != HOMOGENEOUS)
    {
        TEST_FAIL ("homogeneous is %u, should be %u", homogeneous, HOMOGENEOUS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef ROWS 
    #undef COLUMNS
    #undef HOMOGENEOUS 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_table_new 
 * Params: guint rows, guint columns, gboolean homogeneous
 * Returns: GtkWidget*
 * Assertion: Used to create a new table widget.
 * Params Values: 0, 1, FALSE 
 * Expected: GtkTable*  
 */
static void test_purpose_6()
{
    #define ROWS 0
    #define COLUMNS 1
    #define HOMOGENEOUS FALSE
    GtkWidget* widget;
    guint rows;
    guint columns;
    gboolean homogeneous;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_table_new (ROWS, COLUMNS, HOMOGENEOUS);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TABLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "n-rows", &rows, NULL);
    if(ROWS !=0)
    {
        if (rows != ROWS)
        {
            TEST_FAIL ("n-rows is %u, should be %u", rows, ROWS);
        }
    }
    else if (rows != 1)
    {
        TEST_FAIL ("n-rows is %u, should be %u", rows, ROWS);
    }
    
    g_object_get(GTK_OBJECT(widget), "n-columns", &columns, NULL);
    if(COLUMNS !=0)
    {
        if (columns != COLUMNS)
        {
            TEST_FAIL ("n-columns is %u, should be %u", columns, COLUMNS);
        }
    }
    else if (columns != 1)
    {
        TEST_FAIL ("n-columns is %u, should be %u", columns, COLUMNS);
    }
    
    g_object_get(GTK_OBJECT(widget), "homogeneous", &homogeneous, NULL);
    if (homogeneous != HOMOGENEOUS)
    {
        TEST_FAIL ("homogeneous is %u, should be %u", homogeneous, HOMOGENEOUS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef ROWS 
    #undef COLUMNS
    #undef HOMOGENEOUS 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_table_new 
 * Params: guint rows, guint columns, gboolean homogeneous
 * Returns: GtkWidget*
 * Assertion: Used to create a new table widget.
 * Params Values: 0, 0, TRUE 
 * Expected: GtkTable*  
 */
static void test_purpose_7()
{
    #define ROWS 0
    #define COLUMNS 0
    #define HOMOGENEOUS TRUE
    GtkWidget* widget;
    guint rows;
    guint columns;
    gboolean homogeneous;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_table_new (ROWS, COLUMNS, HOMOGENEOUS);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TABLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "n-rows", &rows, NULL);
    if(ROWS !=0)
    {
        if (rows != ROWS)
        {
            TEST_FAIL ("n-rows is %u, should be %u", rows, ROWS);
        }
    }
    else if (rows != 1)
    {
        TEST_FAIL ("n-rows is %u, should be %u", rows, ROWS);
    }
    
    g_object_get(GTK_OBJECT(widget), "n-columns", &columns, NULL);
    if(COLUMNS !=0)
    {
        if (columns != COLUMNS)
        {
            TEST_FAIL ("n-columns is %u, should be %u", columns, COLUMNS);
        }
    }
    else if (columns != 1)
    {
        TEST_FAIL ("n-columns is %u, should be %u", columns, COLUMNS);
    }
    
    g_object_get(GTK_OBJECT(widget), "homogeneous", &homogeneous, NULL);
    if (homogeneous != HOMOGENEOUS)
    {
        TEST_FAIL ("homogeneous is %u, should be %u", homogeneous, HOMOGENEOUS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef ROWS 
    #undef COLUMNS
    #undef HOMOGENEOUS 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_table_set_row_spacing
 * Params: GtkTable *table, guint row, guint spacing
 * Returns: void
 * Assertion: Changes the space between a given table row and its surrounding rows.
 * Params Values: newly created GtkTable*, 0, 0
 * Expected: void
 * 
 * Name: gtk_table_get_row_spacing
 * Params: GtkTable *table, guint row
 * Returns: guint
 * Assertion: Gets the amount of space between row row, and row row + 1.
 * Params Values: newly created GtkTable*
 * Expected: 0  
 */
static void test_purpose_8()
{
    #define TABLE gtk_table_new (65535, 65535, TRUE)
    #define ROW 0
    #define SPACING  0
    
    GtkWidget *widget;
    guint spacing;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = TABLE;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TABLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_table_set_row_spacing (GTK_TABLE (widget), ROW, SPACING);
    spacing = gtk_table_get_row_spacing (GTK_TABLE (widget), ROW);
    if (spacing != SPACING)
    {
        TEST_FAIL("GtkTable row spacing = %i, should be %i\n", spacing, SPACING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TABLE 
    #undef ROW 
    #undef SPACING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_table_set_row_spacing
 * Params: GtkTable *table, guint row, guint spacing
 * Returns: void
 * Assertion: Changes the space between a given table row and its surrounding rows.
 * Params Values: newly created GtkTable*, 1, 0
 * Expected: void
 * 
 * Name: gtk_table_get_row_spacing
 * Params: GtkTable *table, guint row
 * Returns: guint
 * Assertion: Gets the amount of space between row row, and row row + 1.
 * Params Values: newly created GtkTable*
 * Expected: 0  
 */
static void test_purpose_9()
{
    #define TABLE gtk_table_new (65535, 0, TRUE)
    #define ROW 1
    #define SPACING  0
    
    GtkWidget *widget;
    guint spacing;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = TABLE;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TABLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_table_set_row_spacing (GTK_TABLE (widget), ROW, SPACING);
    spacing = gtk_table_get_row_spacing (GTK_TABLE (widget), ROW);
    if (spacing != SPACING)
    {
        TEST_FAIL("GtkTable row spacing = %i, should be %i\n", spacing, SPACING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TABLE 
    #undef ROW 
    #undef SPACING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_table_set_row_spacing
 * Params: GtkTable *table, guint row, guint spacing
 * Returns: void
 * Assertion: Changes the space between a given table row and its surrounding rows.
 * Params Values: newly created GtkTable*, 1, 1
 * Expected: void
 * 
 * Name: gtk_table_get_row_spacing
 * Params: GtkTable *table, guint row
 * Returns: guint
 * Assertion: Gets the amount of space between row row, and row row + 1.
 * Params Values: newly created GtkTable*
 * Expected: 1  
 */
static void test_purpose_10()
{
    #define TABLE gtk_table_new (65535, 65535, FALSE)
    #define ROW 1
    #define SPACING  1
    
    GtkWidget *widget;
    guint spacing;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = TABLE;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TABLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_table_set_row_spacing (GTK_TABLE (widget), ROW, SPACING);
    spacing = gtk_table_get_row_spacing (GTK_TABLE (widget), ROW);
    if (spacing != SPACING)
    {
        TEST_FAIL("GtkTable row spacing = %i, should be %i\n", spacing, SPACING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TABLE 
    #undef ROW 
    #undef SPACING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_table_set_row_spacing
 * Params: GtkTable *table, guint row, guint spacing
 * Returns: void
 * Assertion: Changes the space between a given table row and its surrounding rows.
 * Params Values: newly created GtkTable*, 65533, 1
 * Expected: void
 * 
 * Name: gtk_table_get_row_spacing
 * Params: GtkTable *table, guint row
 * Returns: guint
 * Assertion: Gets the amount of space between row row, and row row + 1.
 * Params Values: newly created GtkTable*
 * Expected: 1  
 */
static void test_purpose_11()
{
    #define TABLE gtk_table_new (65535, 1, FALSE)
    #define ROW 65533
    #define SPACING  1
    
    GtkWidget *widget;
    guint spacing;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = TABLE;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TABLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_table_set_row_spacing (GTK_TABLE (widget), ROW, SPACING);
    spacing = gtk_table_get_row_spacing (GTK_TABLE (widget), ROW);
    if (spacing != SPACING)
    {
        TEST_FAIL("GtkTable row spacing = %i, should be %i\n", spacing, SPACING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TABLE 
    #undef ROW 
    #undef SPACING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_table_set_col_spacing
 * Params: GtkTable *table, guint col, guint spacing
 * Returns: void
 * Assertion: Alters the amount of space between a given table column and the adjacent columns.
 * Params Values: newly created GtkTable*, 0, 0
 * Expected: void
 * 
 * Name: gtk_table_get_col_spacing
 * Params: GtkTable *table, guint col
 * Returns: guint
 * Assertion: Gets the amount of space between column col, and column col + 1.
 * Params Values: newly created GtkTable*
 * Expected: 0  
 */
static void test_purpose_12()
{
    #define TABLE gtk_table_new (65535, 65535, TRUE)
    #define COL 0
    #define SPACING  0
    
    GtkWidget *widget;
    guint spacing;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = TABLE;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TABLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_table_set_col_spacing (GTK_TABLE (widget), COL, SPACING);
    spacing = gtk_table_get_col_spacing (GTK_TABLE (widget), COL);
    if (spacing != SPACING)
    {
        TEST_FAIL("GtkTable col spacing = %i, should be %i\n", spacing, SPACING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TABLE 
    #undef COL 
    #undef SPACING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_table_set_col_spacing
 * Params: GtkTable *table, guint col, guint spacing
 * Returns: void
 * Assertion: Alters the amount of space between a given table column and the adjacent columns.
 * Params Values: newly created GtkTable*, 1, 0
 * Expected: void
 * 
 * Name: gtk_table_get_col_spacing
 * Params: GtkTable *table, guint col
 * Returns: guint
 * Assertion: Gets the amount of space between column col, and column col + 1.
 * Params Values: newly created GtkTable*
 * Expected: 0  
 */
static void test_purpose_13()
{
    #define TABLE gtk_table_new (1, 65535, TRUE)
    #define COL 1
    #define SPACING  0
    
    GtkWidget *widget;
    guint spacing;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = TABLE;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TABLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_table_set_col_spacing (GTK_TABLE (widget), COL, SPACING);
    spacing = gtk_table_get_col_spacing (GTK_TABLE (widget), COL);
    if (spacing != SPACING)
    {
        TEST_FAIL("GtkTable col spacing = %i, should be %i\n", spacing, SPACING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TABLE 
    #undef COL 
    #undef SPACING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_table_set_col_spacing
 * Params: GtkTable *table, guint col, guint spacing
 * Returns: void
 * Assertion: Alters the amount of space between a given table column and the adjacent columns.
 * Params Values: newly created GtkTable*, 1, 1
 * Expected: void
 * 
 * Name: gtk_table_get_col_spacing
 * Params: GtkTable *table, guint col
 * Returns: guint
 * Assertion: Gets the amount of space between column col, and column col + 1.
 * Params Values: newly created GtkTable*
 * Expected: 1  
 */
static void test_purpose_14()
{
    #define TABLE gtk_table_new (65535, 65535, FALSE)
    #define COL 1
    #define SPACING  1
    
    GtkWidget *widget;
    guint spacing;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = TABLE;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TABLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_table_set_col_spacing (GTK_TABLE (widget), COL, SPACING);
    spacing = gtk_table_get_col_spacing (GTK_TABLE (widget), COL);
    if (spacing != SPACING)
    {
        TEST_FAIL("GtkTable col spacing = %i, should be %i\n", spacing, SPACING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TABLE 
    #undef COL 
    #undef SPACING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_table_set_col_spacing
 * Params: GtkTable *table, guint col, guint spacing
 * Returns: void
 * Assertion: Alters the amount of space between a given table column and the adjacent columns.
 * Params Values: newly created GtkTable*, 0, 0
 * Expected: void
 * 
 * Name: gtk_table_get_col_spacing
 * Params: GtkTable *table, guint col
 * Returns: guint
 * Assertion: Gets the amount of space between column col, and column col + 1.
 * Params Values: newly created GtkTable*
 * Expected: 0  
 */
static void test_purpose_15()
{
    #define TABLE gtk_table_new (1, 65535, FALSE)
    #define COL 0
    #define SPACING  0
    
    GtkWidget *widget;
    guint spacing;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = TABLE;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TABLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_table_set_col_spacing (GTK_TABLE (widget), COL, SPACING);
    spacing = gtk_table_get_col_spacing (GTK_TABLE (widget), COL);
    if (spacing != SPACING)
    {
        TEST_FAIL("GtkTable col spacing = %i, should be %i\n", spacing, SPACING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TABLE 
    #undef COL 
    #undef SPACING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_table_set_col_spacing
 * Params: GtkTable *table, guint col, guint spacing
 * Returns: void
 * Assertion: Alters the amount of space between a given table column and the adjacent columns.
 * Params Values: newly created GtkTable*, 0, 65
 * Expected: void
 * 
 * Name: gtk_table_get_col_spacing
 * Params: GtkTable *table, guint col
 * Returns: guint
 * Assertion: Gets the amount of space between column col, and column col + 1.
 * Params Values: newly created GtkTable*
 * Expected: 65  
 */
static void test_purpose_16()
{
    #define TABLE gtk_table_new (1, 65535, TRUE)
    #define COL 0
    #define SPACING  65
    
    GtkWidget *widget;
    guint spacing;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = TABLE;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TABLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_table_set_col_spacing (GTK_TABLE (widget), COL, SPACING);
    spacing = gtk_table_get_col_spacing (GTK_TABLE (widget), COL);
    if (spacing != SPACING)
    {
        TEST_FAIL("GtkTable col spacing = %i, should be %i\n", spacing, SPACING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TABLE 
    #undef COL 
    #undef SPACING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_table_set_col_spacing
 * Params: GtkTable *table, guint col, guint spacing
 * Returns: void
 * Assertion: Alters the amount of space between a given table column and the adjacent columns.
 * Params Values: newly created GtkTable*, 0, 1
 * Expected: void
 * 
 * Name: gtk_table_get_col_spacing
 * Params: GtkTable *table, guint col
 * Returns: guint
 * Assertion: Gets the amount of space between column col, and column col + 1.
 * Params Values: newly created GtkTable*
 * Expected: 1  
 */
static void test_purpose_17()
{
    #define TABLE gtk_table_new (1, 1, FALSE)
    #define COL 0
    #define SPACING  1
    
    GtkWidget *widget;
    guint spacing;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = TABLE;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TABLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_table_set_col_spacing (GTK_TABLE (widget), COL, SPACING);
    spacing = gtk_table_get_col_spacing (GTK_TABLE (widget), COL);
    if (spacing != SPACING)
    {
        TEST_FAIL("GtkTable col spacing = %i, should be %i\n", spacing, SPACING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TABLE 
    #undef COL 
    #undef SPACING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_table_set_col_spacing
 * Params: GtkTable *table, guint col, guint spacing
 * Returns: void
 * Assertion: Alters the amount of space between a given table column and the adjacent columns.
 * Params Values: newly created GtkTable*, 0, 65
 * Expected: void
 * 
 * Name: gtk_table_get_col_spacing
 * Params: GtkTable *table, guint col
 * Returns: guint
 * Assertion: Gets the amount of space between column col, and column col + 1.
 * Params Values: newly created GtkTable*
 * Expected: 65  
 */
static void test_purpose_18()
{
    #define TABLE gtk_table_new (1, 1, FALSE)
    #define COL 0
    #define SPACING  65
    
    GtkWidget *widget;
    guint spacing;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = TABLE;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TABLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_table_set_col_spacing (GTK_TABLE (widget), COL, SPACING);
    spacing = gtk_table_get_col_spacing (GTK_TABLE (widget), COL);
    if (spacing != SPACING)
    {
        TEST_FAIL("GtkTable col spacing = %i, should be %i\n", spacing, SPACING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TABLE 
    #undef COL 
    #undef SPACING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_table_set_row_spacings
 * Params: GtkTable *table, guint spacing
 * Returns: void
 * Assertion: Sets the space between every row in table equal to spacing.
 * Params Values: newly created GtkTable*, 0
 * Expected: void  
 */
static void test_purpose_19()
{
    #define TABLE gtk_table_new (65535, 65535, TRUE)
    #define SPACING  0
    
    GtkWidget *widget;
    guint spacing;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = TABLE;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TABLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_table_set_row_spacings (GTK_TABLE (widget), SPACING);
    g_object_get(GTK_OBJECT(widget), "row-spacing", &spacing, NULL);
    if (spacing != SPACING)
    {
        TEST_FAIL("GtkTable row spacing = %i, should be %i\n", spacing, SPACING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TABLE 
    #undef SPACING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_table_set_row_spacings
 * Params: GtkTable *table, guint spacing
 * Returns: void
 * Assertion: Sets the space between every row in table equal to spacing.
 * Params Values: newly created GtkTable*, 0
 * Expected: void  
 */
static void test_purpose_20()
{
    #define TABLE gtk_table_new (1, 0, TRUE)
    #define SPACING  0
    
    GtkWidget *widget;
    guint spacing;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = TABLE;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TABLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_table_set_row_spacings (GTK_TABLE (widget), SPACING);
    g_object_get(GTK_OBJECT(widget), "row-spacing", &spacing, NULL);
    if (spacing != SPACING)
    {
        TEST_FAIL("GtkTable row spacing = %i, should be %i\n", spacing, SPACING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TABLE 
    #undef SPACING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_table_set_row_spacings
 * Params: GtkTable *table, guint spacing
 * Returns: void
 * Assertion: Sets the space between every row in table equal to spacing.
 * Params Values: newly created GtkTable*, 1
 * Expected: void  
 */
static void test_purpose_21()
{
    #define TABLE gtk_table_new (7, 0, FALSE)
    #define SPACING  1
    
    GtkWidget *widget;
    guint spacing;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = TABLE;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TABLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_table_set_row_spacings (GTK_TABLE (widget), SPACING);
    g_object_get(GTK_OBJECT(widget), "row-spacing", &spacing, NULL);
    if (spacing != SPACING)
    {
        TEST_FAIL("GtkTable row spacing = %i, should be %i\n", spacing, SPACING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TABLE 
    #undef SPACING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_table_get_default_row_spacing
 * Params: GtkTable *table
 * Returns: guint
 * Assertion: Gets the default row spacing for the table.
 * Params Values: newly created GtkTable*
 * Expected: 0  
 */
static void test_purpose_22()
{
    #define TABLE gtk_table_new (6500, 6500, TRUE)
    #define SPACING  0
    
    GtkWidget *widget;
    guint spacing;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = TABLE;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TABLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_object_set(GTK_OBJECT(widget), "row-spacing", SPACING, NULL);
    spacing = gtk_table_get_default_row_spacing (GTK_TABLE (widget));
    if (spacing != SPACING)
    {
        TEST_FAIL("spacing = %i, should be %i\n", spacing, SPACING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TABLE 
    #undef SPACING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_table_get_default_row_spacing
 * Params: GtkTable *table
 * Returns: guint
 * Assertion: Gets the default row spacing for the table.
 * Params Values: newly created GtkTable*
 * Expected: 1  
 */
static void test_purpose_23()
{
    #define TABLE gtk_table_new (6500, 6500, TRUE)
    #define SPACING  1
    
    GtkWidget *widget;
    guint spacing;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = TABLE;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TABLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_object_set(GTK_OBJECT(widget), "row-spacing", SPACING, NULL);
    spacing = gtk_table_get_default_row_spacing (GTK_TABLE (widget));
    if (spacing != SPACING)
    {
        TEST_FAIL("spacing = %i, should be %i\n", spacing, SPACING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TABLE 
    #undef SPACING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_table_get_default_row_spacing
 * Params: GtkTable *table
 * Returns: guint
 * Assertion: Gets the default row spacing for the table.
 * Params Values: newly created GtkTable*
 * Expected: 0  
 */
static void test_purpose_24()
{
    #define TABLE gtk_table_new (6500, 0, TRUE)
    #define SPACING  0
    
    GtkWidget *widget;
    guint spacing;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = TABLE;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TABLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_object_set(GTK_OBJECT(widget), "row-spacing", SPACING, NULL);
    spacing = gtk_table_get_default_row_spacing (GTK_TABLE (widget));
    if (spacing != SPACING)
    {
        TEST_FAIL("spacing = %i, should be %i\n", spacing, SPACING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TABLE 
    #undef SPACING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_table_get_default_row_spacing
 * Params: GtkTable *table
 * Returns: guint
 * Assertion: Gets the default row spacing for the table.
 * Params Values: newly created GtkTable*
 * Expected: 1  
 */
static void test_purpose_25()
{
    #define TABLE gtk_table_new (6500, 0, FALSE)
    #define SPACING  1
    
    GtkWidget *widget;
    guint spacing;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = TABLE;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TABLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_object_set(GTK_OBJECT(widget), "row-spacing", SPACING, NULL);
    spacing = gtk_table_get_default_row_spacing (GTK_TABLE (widget));
    if (spacing != SPACING)
    {
        TEST_FAIL("spacing = %i, should be %i\n", spacing, SPACING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TABLE 
    #undef SPACING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_table_get_default_row_spacing
 * Params: GtkTable *table
 * Returns: guint
 * Assertion: Gets the default row spacing for the table.
 * Params Values: newly created GtkTable*
 * Expected: 0  
 */
static void test_purpose_26()
{
    #define TABLE gtk_table_new (1, 0, TRUE)
    #define SPACING  0
    
    GtkWidget *widget;
    guint spacing;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = TABLE;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TABLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_object_set(GTK_OBJECT(widget), "row-spacing", SPACING, NULL);
    spacing = gtk_table_get_default_row_spacing (GTK_TABLE (widget));
    if (spacing != SPACING)
    {
        TEST_FAIL("spacing = %i, should be %i\n", spacing, SPACING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TABLE 
    #undef SPACING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_table_get_default_row_spacing
 * Params: GtkTable *table
 * Returns: guint
 * Assertion: Gets the default row spacing for the table.
 * Params Values: newly created GtkTable*
 * Expected: 1  
 */
static void test_purpose_27()
{
    #define TABLE gtk_table_new (7, 0, FALSE)
    #define SPACING  1
    
    GtkWidget *widget;
    guint spacing;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = TABLE;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TABLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_object_set(GTK_OBJECT(widget), "row-spacing", SPACING, NULL);
    spacing = gtk_table_get_default_row_spacing (GTK_TABLE (widget));
    if (spacing != SPACING)
    {
        TEST_FAIL("spacing = %i, should be %i\n", spacing, SPACING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TABLE 
    #undef SPACING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_table_get_default_row_spacing
 * Params: GtkTable *table
 * Returns: guint
 * Assertion: Gets the default row spacing for the table.
 * Params Values: newly created GtkTable*
 * Expected: 65  
 */
static void test_purpose_28()
{
    #define TABLE gtk_table_new (100, 1, TRUE)
    #define SPACING  65
    
    GtkWidget *widget;
    guint spacing;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = TABLE;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TABLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_object_set(GTK_OBJECT(widget), "row-spacing", SPACING, NULL);
    spacing = gtk_table_get_default_row_spacing (GTK_TABLE (widget));
    if (spacing != SPACING)
    {
        TEST_FAIL("spacing = %i, should be %i\n", spacing, SPACING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TABLE 
    #undef SPACING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_table_get_default_row_spacing
 * Params: GtkTable *table
 * Returns: guint
 * Assertion: Gets the default row spacing for the table.
 * Params Values: newly created GtkTable*
 * Expected: 40  
 */
static void test_purpose_29()
{
    #define TABLE gtk_table_new (777, 1, FALSE)
    #define SPACING  40
    
    GtkWidget *widget;
    guint spacing;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = TABLE;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TABLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_object_set(GTK_OBJECT(widget), "row-spacing", SPACING, NULL);
    spacing = gtk_table_get_default_row_spacing (GTK_TABLE (widget));
    if (spacing != SPACING)
    {
        TEST_FAIL("spacing = %i, should be %i\n", spacing, SPACING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TABLE 
    #undef SPACING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_table_set_col_spacings
 * Params: GtkTable *table, guint spacing
 * Returns: void
 * Assertion: Sets the space between every column in table equal to spacing.
 * Params Values: newly created GtkTable*, 0
 * Expected: void  
 */
static void test_purpose_30()
{
    #define TABLE gtk_table_new (6500, 6500, TRUE)
    #define SPACING  0
    
    GtkWidget *widget;
    guint spacing;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = TABLE;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TABLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_table_set_col_spacings (GTK_TABLE (widget), SPACING);
    g_object_get(GTK_OBJECT(widget), "column-spacing", &spacing, NULL);
    if (spacing != SPACING)
    {
        TEST_FAIL("GtkTable column spacing = %i, should be %i\n", spacing, SPACING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TABLE 
    #undef SPACING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_table_set_col_spacings
 * Params: GtkTable *table, guint spacing
 * Returns: void
 * Assertion: Sets the space between every column in table equal to spacing.
 * Params Values: newly created GtkTable*, 1
 * Expected: void  
 */
static void test_purpose_31()
{
    #define TABLE gtk_table_new (6500, 6500, TRUE)
    #define SPACING  1
    
    GtkWidget *widget;
    guint spacing;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = TABLE;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TABLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_table_set_col_spacings (GTK_TABLE (widget), SPACING);
    g_object_get(GTK_OBJECT(widget), "column-spacing", &spacing, NULL);
    if (spacing != SPACING)
    {
        TEST_FAIL("GtkTable column spacing = %i, should be %i\n", spacing, SPACING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TABLE 
    #undef SPACING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_table_set_col_spacings
 * Params: GtkTable *table, guint spacing
 * Returns: void
 * Assertion: Sets the space between every column in table equal to spacing.
 * Params Values: newly created GtkTable*, 0
 * Expected: void  
 */
static void test_purpose_32()
{
    #define TABLE gtk_table_new (6500, 6500, FALSE)
    #define SPACING  0
    
    GtkWidget *widget;
    guint spacing;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = TABLE;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TABLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_table_set_col_spacings (GTK_TABLE (widget), SPACING);
    g_object_get(GTK_OBJECT(widget), "column-spacing", &spacing, NULL);
    if (spacing != SPACING)
    {
        TEST_FAIL("GtkTable column spacing = %i, should be %i\n", spacing, SPACING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TABLE 
    #undef SPACING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_table_set_col_spacings
 * Params: GtkTable *table, guint spacing
 * Returns: void
 * Assertion: Sets the space between every column in table equal to spacing.
 * Params Values: newly created GtkTable*, 1
 * Expected: void  
 */
static void test_purpose_33()
{
    #define TABLE gtk_table_new (6500, 6500, FALSE)
    #define SPACING  1
    
    GtkWidget *widget;
    guint spacing;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = TABLE;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TABLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_table_set_col_spacings (GTK_TABLE (widget), SPACING);
    g_object_get(GTK_OBJECT(widget), "column-spacing", &spacing, NULL);
    if (spacing != SPACING)
    {
        TEST_FAIL("GtkTable column spacing = %i, should be %i\n", spacing, SPACING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TABLE 
    #undef SPACING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_table_set_col_spacings
 * Params: GtkTable *table, guint spacing
 * Returns: void
 * Assertion: Sets the space between every column in table equal to spacing.
 * Params Values: newly created GtkTable*, 0
 * Expected: void  
 */
static void test_purpose_34()
{
    #define TABLE gtk_table_new (1, 6500, TRUE)
    #define SPACING  0
    
    GtkWidget *widget;
    guint spacing;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = TABLE;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TABLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_table_set_col_spacings (GTK_TABLE (widget), SPACING);
    g_object_get(GTK_OBJECT(widget), "column-spacing", &spacing, NULL);
    if (spacing != SPACING)
    {
        TEST_FAIL("GtkTable column spacing = %i, should be %i\n", spacing, SPACING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TABLE 
    #undef SPACING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_table_set_col_spacings
 * Params: GtkTable *table, guint spacing
 * Returns: void
 * Assertion: Sets the space between every column in table equal to spacing.
 * Params Values: newly created GtkTable*, 1
 * Expected: void  
 */
static void test_purpose_35()
{
    #define TABLE gtk_table_new (1, 6500, FALSE)
    #define SPACING  1
    
    GtkWidget *widget;
    guint spacing;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = TABLE;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TABLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_table_set_col_spacings (GTK_TABLE (widget), SPACING);
    g_object_get(GTK_OBJECT(widget), "column-spacing", &spacing, NULL);
    if (spacing != SPACING)
    {
        TEST_FAIL("GtkTable column spacing = %i, should be %i\n", spacing, SPACING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TABLE 
    #undef SPACING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_table_set_col_spacings
 * Params: GtkTable *table, guint spacing
 * Returns: void
 * Assertion: Sets the space between every column in table equal to spacing.
 * Params Values: newly created GtkTable*, 0
 * Expected: void  
 */
static void test_purpose_36()
{
    #define TABLE gtk_table_new (0, 1, TRUE)
    #define SPACING  0
    
    GtkWidget *widget;
    guint spacing;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = TABLE;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TABLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_table_set_col_spacings (GTK_TABLE (widget), SPACING);
    g_object_get(GTK_OBJECT(widget), "column-spacing", &spacing, NULL);
    if (spacing != SPACING)
    {
        TEST_FAIL("GtkTable column spacing = %i, should be %i\n", spacing, SPACING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TABLE 
    #undef SPACING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_table_set_col_spacings
 * Params: GtkTable *table, guint spacing
 * Returns: void
 * Assertion: Sets the space between every column in table equal to spacing.
 * Params Values: newly created GtkTable*, 1
 * Expected: void  
 */
static void test_purpose_37()
{
    #define TABLE gtk_table_new (0, 7, FALSE)
    #define SPACING  1
    
    GtkWidget *widget;
    guint spacing;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = TABLE;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TABLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_table_set_col_spacings (GTK_TABLE (widget), SPACING);
    g_object_get(GTK_OBJECT(widget), "column-spacing", &spacing, NULL);
    if (spacing != SPACING)
    {
        TEST_FAIL("GtkTable column spacing = %i, should be %i\n", spacing, SPACING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TABLE 
    #undef SPACING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_table_set_col_spacings
 * Params: GtkTable *table, guint spacing
 * Returns: void
 * Assertion: Sets the space between every column in table equal to spacing.
 * Params Values: newly created GtkTable*, 65
 * Expected: void  
 */
static void test_purpose_38()
{
    #define TABLE gtk_table_new (1, 100, TRUE)
    #define SPACING  65
    
    GtkWidget *widget;
    guint spacing;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = TABLE;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TABLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_table_set_col_spacings (GTK_TABLE (widget), SPACING);
    g_object_get(GTK_OBJECT(widget), "column-spacing", &spacing, NULL);
    if (spacing != SPACING)
    {
        TEST_FAIL("GtkTable column spacing = %i, should be %i\n", spacing, SPACING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TABLE 
    #undef SPACING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_table_get_default_col_spacing
 * Params: GtkTable *table
 * Returns: guint
 * Assertion: Gets the default column spacing for the table.
 * Params Values: newly created GtkTable*
 * Expected: 0  
 */
static void test_purpose_39()
{
    #define TABLE gtk_table_new (6500, 6500, FALSE)
    #define SPACING  0
    
    GtkWidget *widget;
    guint spacing;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = TABLE;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TABLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_object_set(GTK_OBJECT(widget), "column-spacing", SPACING, NULL);
    spacing = gtk_table_get_default_col_spacing (GTK_TABLE (widget));
    if (spacing != SPACING)
    {
        TEST_FAIL("spacing = %i, should be %i\n", spacing, SPACING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TABLE 
    #undef SPACING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_table_get_default_col_spacing
 * Params: GtkTable *table
 * Returns: guint
 * Assertion: Gets the default column spacing for the table.
 * Params Values: newly created GtkTable*
 * Expected: 1  
 */
static void test_purpose_40()
{
    #define TABLE gtk_table_new (6500, 6500, FALSE)
    #define SPACING  1
    
    GtkWidget *widget;
    guint spacing;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = TABLE;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TABLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_object_set(GTK_OBJECT(widget), "column-spacing", SPACING, NULL);
    spacing = gtk_table_get_default_col_spacing (GTK_TABLE (widget));
    if (spacing != SPACING)
    {
        TEST_FAIL("spacing = %i, should be %i\n", spacing, SPACING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TABLE 
    #undef SPACING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_table_get_default_col_spacing
 * Params: GtkTable *table
 * Returns: guint
 * Assertion: Gets the default column spacing for the table.
 * Params Values: newly created GtkTable*
 * Expected: 0  
 */
static void test_purpose_41()
{
    #define TABLE gtk_table_new (1, 6500, TRUE)
    #define SPACING  0
    
    GtkWidget *widget;
    guint spacing;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = TABLE;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TABLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_object_set(GTK_OBJECT(widget), "column-spacing", SPACING, NULL);
    spacing = gtk_table_get_default_col_spacing (GTK_TABLE (widget));
    if (spacing != SPACING)
    {
        TEST_FAIL("spacing = %i, should be %i\n", spacing, SPACING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TABLE 
    #undef SPACING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_table_get_default_col_spacing
 * Params: GtkTable *table
 * Returns: guint
 * Assertion: Gets the default column spacing for the table.
 * Params Values: newly created GtkTable*
 * Expected: 1  
 */
static void test_purpose_42()
{
    #define TABLE gtk_table_new (1, 6500, FALSE)
    #define SPACING  1
    
    GtkWidget *widget;
    guint spacing;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = TABLE;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TABLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_object_set(GTK_OBJECT(widget), "column-spacing", SPACING, NULL);
    spacing = gtk_table_get_default_col_spacing (GTK_TABLE (widget));
    if (spacing != SPACING)
    {
        TEST_FAIL("spacing = %i, should be %i\n", spacing, SPACING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TABLE 
    #undef SPACING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_table_get_default_col_spacing
 * Params: GtkTable *table
 * Returns: guint
 * Assertion: Gets the default column spacing for the table.
 * Params Values: newly created GtkTable*
 * Expected: 0  
 */
static void test_purpose_43()
{
    #define TABLE gtk_table_new (0, 1, TRUE)
    #define SPACING  0
    
    GtkWidget *widget;
    guint spacing;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = TABLE;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TABLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_object_set(GTK_OBJECT(widget), "column-spacing", SPACING, NULL);
    spacing = gtk_table_get_default_col_spacing (GTK_TABLE (widget));
    if (spacing != SPACING)
    {
        TEST_FAIL("spacing = %i, should be %i\n", spacing, SPACING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TABLE 
    #undef SPACING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_table_get_default_col_spacing
 * Params: GtkTable *table
 * Returns: guint
 * Assertion: Gets the default column spacing for the table.
 * Params Values: newly created GtkTable*
 * Expected: 1  
 */
static void test_purpose_44()
{
    #define TABLE gtk_table_new (0, 7, FALSE)
    #define SPACING  1
    
    GtkWidget *widget;
    guint spacing;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = TABLE;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TABLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_object_set(GTK_OBJECT(widget), "column-spacing", SPACING, NULL);
    spacing = gtk_table_get_default_col_spacing (GTK_TABLE (widget));
    if (spacing != SPACING)
    {
        TEST_FAIL("spacing = %i, should be %i\n", spacing, SPACING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TABLE 
    #undef SPACING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_table_get_default_col_spacing
 * Params: GtkTable *table
 * Returns: guint
 * Assertion: Gets the default column spacing for the table.
 * Params Values: newly created GtkTable*
 * Expected: 65  
 */
static void test_purpose_45()
{
    #define TABLE gtk_table_new (1, 100, TRUE)
    #define SPACING  65
    
    GtkWidget *widget;
    guint spacing;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = TABLE;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TABLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_object_set(GTK_OBJECT(widget), "column-spacing", SPACING, NULL);
    spacing = gtk_table_get_default_col_spacing (GTK_TABLE (widget));
    if (spacing != SPACING)
    {
        TEST_FAIL("spacing = %i, should be %i\n", spacing, SPACING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TABLE 
    #undef SPACING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_table_set_homogeneous
 * Params: GtkTable *table,  gboolean homogeneous
 * Returns: void
 * Assertion: Changes the homogenous property of table cells, ie. whether all cells are an equal size or not.
 * Params Values: newly created GtkTable*, TRUE
 * Expected: void
 * 
 * Name: gtk_table_get_homogeneous
 * Params: GtkTable *table
 * Returns: gboolean
 * Assertion: Returns whether the table cells are all constrained to the same width and height.
 * Params Values: newly created GtkTable*, TRUE
 * Expected: void  
 */
static void test_purpose_46()
{
    #define HOMOGENEOUS TRUE
    
    GtkWidget *widget;
    gboolean homogeneous;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_table_new (2, 2, TRUE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TABLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_table_set_homogeneous (GTK_TABLE (widget), HOMOGENEOUS);
    g_object_get(GTK_OBJECT(widget), "homogeneous", &homogeneous, NULL);
    if (homogeneous != HOMOGENEOUS)
    {
        TEST_FAIL("GtkTable homogeneous = %i, should be %i\n", homogeneous, HOMOGENEOUS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef HOMOGENEOUS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_table_set_homogeneous
 * Params: GtkTable *table,  gboolean homogeneous
 * Returns: void
 * Assertion: Changes the homogenous property of table cells, ie. whether all cells are an equal size or not.
 * Params Values: newly created GtkTable*, FALSE
 * Expected: void
 * 
 * Name: gtk_table_get_homogeneous
 * Params: GtkTable *table
 * Returns: gboolean
 * Assertion: Returns whether the table cells are all constrained to the same width and height.
 * Params Values: newly created GtkTable*, FALSE
 * Expected: void  
 */
static void test_purpose_47()
{
    #define HOMOGENEOUS FALSE
    
    GtkWidget *widget;
    gboolean homogeneous;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_table_new (2, 2, TRUE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TABLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_table_set_homogeneous (GTK_TABLE (widget), HOMOGENEOUS);
    g_object_get(GTK_OBJECT(widget), "homogeneous", &homogeneous, NULL);
    if (homogeneous != HOMOGENEOUS)
    {
        TEST_FAIL("GtkTable homogeneous = %i, should be %i\n", homogeneous, HOMOGENEOUS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef HOMOGENEOUS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_table_resize    
 * Params: GtkTable *table, guint rows, guint columns
 * Returns: GtkWidget*
 * Assertion: If you need to change a table's size after it has been created, this function allows you to do so.'
 * Params Values: a newly created GtkTable*, 6500, 6500
 * Expected: GtkTable*  
 */
static void test_purpose_48()
{
    #define ROWS 6500
    #define COLUMNS 6500
    GtkWidget* widget;
    guint rows;
    guint columns;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_table_new (2, 2, FALSE);
    
    gtk_table_resize (GTK_TABLE (widget),ROWS,COLUMNS);    
    
    g_object_get(GTK_OBJECT(widget), "n-rows", &rows, NULL);
    if (rows != ROWS)
    {
        TEST_FAIL ("n-rows is %u, should be %u", rows, ROWS);
    }
    
    g_object_get(GTK_OBJECT(widget), "n-columns", &columns, NULL);
    if (columns != COLUMNS)
    {
        TEST_FAIL ("n-columns is %u, should be %u", columns, COLUMNS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef ROWS 
    #undef COLUMNS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_table_resize    
 * Params: GtkTable *table, guint rows, guint columns
 * Returns: GtkWidget*
 * Assertion: If you need to change a table's size after it has been created, this function allows you to do so.'
 * Params Values: a newly created GtkTable*, 1, 6500
 * Expected: GtkTable*  
 */
static void test_purpose_49()
{
    #define ROWS 1
    #define COLUMNS 6500
    GtkWidget* widget;
    guint rows;
    guint columns;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_table_new (2, 2, FALSE);
    
    gtk_table_resize (GTK_TABLE (widget),ROWS,COLUMNS);    
    
    g_object_get(GTK_OBJECT(widget), "n-rows", &rows, NULL);
    if (rows != ROWS)
    {
        TEST_FAIL ("n-rows is %u, should be %u", rows, ROWS);
    }
    
    g_object_get(GTK_OBJECT(widget), "n-columns", &columns, NULL);
    if (columns != COLUMNS)
    {
        TEST_FAIL ("n-columns is %u, should be %u", columns, COLUMNS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef ROWS 
    #undef COLUMNS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_table_resize    
 * Params: GtkTable *table, guint rows, guint columns
 * Returns: GtkWidget*
 * Assertion: If you need to change a table's size after it has been created, this function allows you to do so.'
 * Params Values: a newly created GtkTable*, 6500, 1
 * Expected: GtkTable*  
 */
static void test_purpose_50()
{
    #define ROWS 6500
    #define COLUMNS 1
    GtkWidget* widget;
    guint rows;
    guint columns;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_table_new (2, 2, FALSE);
    
    gtk_table_resize (GTK_TABLE (widget),ROWS,COLUMNS);    
    
    g_object_get(GTK_OBJECT(widget), "n-rows", &rows, NULL);
    if (rows != ROWS)
    {
        TEST_FAIL ("n-rows is %u, should be %u", rows, ROWS);
    }
    
    g_object_get(GTK_OBJECT(widget), "n-columns", &columns, NULL);
    if (columns != COLUMNS)
    {
        TEST_FAIL ("n-columns is %u, should be %u", columns, COLUMNS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef ROWS 
    #undef COLUMNS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_table_resize    
 * Params: GtkTable *table, guint rows, guint columns
 * Returns: GtkWidget*
 * Assertion: If you need to change a table's size after it has been created, this function allows you to do so.'
 * Params Values: a newly created GtkTable*, 1, 6500
 * Expected: GtkTable*  
 */
static void test_purpose_51()
{
    #define ROWS 1
    #define COLUMNS 6500
    GtkWidget* widget;
    guint rows;
    guint columns;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_table_new (2, 2, FALSE);
    
    gtk_table_resize (GTK_TABLE (widget),ROWS,COLUMNS);    
    
    g_object_get(GTK_OBJECT(widget), "n-rows", &rows, NULL);
    if (rows != ROWS)
    {
        TEST_FAIL ("n-rows is %u, should be %u", rows, ROWS);
    }
    
    g_object_get(GTK_OBJECT(widget), "n-columns", &columns, NULL);
    if (columns != COLUMNS)
    {
        TEST_FAIL ("n-columns is %u, should be %u", columns, COLUMNS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef ROWS 
    #undef COLUMNS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_table_resize    
 * Params: GtkTable *table, guint rows, guint columns
 * Returns: GtkWidget*
 * Assertion: If you need to change a table's size after it has been created, this function allows you to do so.'
 * Params Values: a newly created GtkTable*, 6500, 1
 * Expected: GtkTable*  
 */
static void test_purpose_52()
{
    #define ROWS 6500
    #define COLUMNS 1
    GtkWidget* widget;
    guint rows;
    guint columns;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_table_new (2, 2, FALSE);
    
    gtk_table_resize (GTK_TABLE (widget),ROWS,COLUMNS);    
    
    g_object_get(GTK_OBJECT(widget), "n-rows", &rows, NULL);
    if (rows != ROWS)
    {
        TEST_FAIL ("n-rows is %u, should be %u", rows, ROWS);
    }
    
    g_object_get(GTK_OBJECT(widget), "n-columns", &columns, NULL);
    if (columns != COLUMNS)
    {
        TEST_FAIL ("n-columns is %u, should be %u", columns, COLUMNS);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef ROWS 
    #undef COLUMNS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_table_attach
 * Params: GtkTable *table,GtkWidget *child,guint left_attach,guint right_attach,guint top_attach,guint bottom_attach,GtkAttachOptions xoptions,GtkAttachOptions yoptions,guint xpadding,guint ypadding
 * Returns: void
 * Assertion: Adds a widget to a table. 
 * Params Values: a newly created GtkTable*, gtk_button_new_with_label ("button");,1,3,1,3,GTK_EXPAND,GTK_FILL,1,1
 * Expected: void  
 */
static void test_purpose_53()
{
    #define CHILD gtk_button_new_with_label ("button");
    #define LEFT_ATTACH 1
    #define RIGHT_ATTACH 3
    #define TOP_ATTACH 1
    #define BOTTOM_ATTACH 3
    #define XOPTIONS GTK_EXPAND
    #define YOPTIONS GTK_FILL
    #define XPADDING 1
    #define YPADDING 1
    #define TABLE gtk_table_new (4, 4, FALSE)
    
    GtkWidget* widget;
    GtkWidget* table;
    GtkWidget* parent;
    guint left_attach;
    GtkAttachOptions x_options;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    table = TABLE;
    widget = CHILD;
    
    gtk_table_attach (GTK_TABLE (table),
                      widget,
                      LEFT_ATTACH,RIGHT_ATTACH,  TOP_ATTACH,BOTTOM_ATTACH, 
                      XOPTIONS,                  YOPTIONS,
                      XPADDING,                  YPADDING
                      );
    
    parent = gtk_widget_get_parent (widget);
    if (parent != table)
    {
        TEST_FAIL ("Widget is not added to a table",NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (table);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CHILD
    #undef LEFT_ATTACH 
    #undef RIGHT_ATTACH
    #undef TOP_ATTACH
    #undef BOTTOM_ATTACH
    #undef XOPTIONS 
    #undef YOPTIONS 
    #undef XPADDING 
    #undef YPADDING 
    #undef TABLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_table_attach
 * Params: GtkTable *table,GtkWidget *child,guint left_attach,guint right_attach,guint top_attach,guint bottom_attach,GtkAttachOptions xoptions,GtkAttachOptions yoptions,guint xpadding,guint ypadding
 * Returns: void
 * Assertion: Adds a widget to a table. 
 * Params Values: a newly created GtkTable*, gtk_button_new_with_label ("button");,0,3,0,3,GTK_EXPAND,GTK_FILL,1,1
 * Expected: void  
 */
static void test_purpose_54()
{
    #define CHILD gtk_button_new_with_label ("button");
    #define LEFT_ATTACH 0
    #define RIGHT_ATTACH 3
    #define TOP_ATTACH 0
    #define BOTTOM_ATTACH 3
    #define XOPTIONS GTK_EXPAND
    #define YOPTIONS GTK_FILL
    #define XPADDING 1
    #define YPADDING 1
    #define TABLE gtk_table_new (4, 4, FALSE)
    
    GtkWidget* widget;
    GtkWidget* table;
    GtkWidget* parent;
    guint left_attach;
    GtkAttachOptions x_options;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    table = TABLE;
    widget = CHILD;
    
    gtk_table_attach (GTK_TABLE (table),
                      widget,
                      LEFT_ATTACH,RIGHT_ATTACH,  TOP_ATTACH,BOTTOM_ATTACH, 
                      XOPTIONS,                  YOPTIONS,
                      XPADDING,                  YPADDING
                      );
    
    parent = gtk_widget_get_parent (widget);
    if (parent != table)
    {
        TEST_FAIL ("Widget is not added to a table",NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (table);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CHILD
    #undef LEFT_ATTACH 
    #undef RIGHT_ATTACH
    #undef TOP_ATTACH
    #undef BOTTOM_ATTACH
    #undef XOPTIONS 
    #undef YOPTIONS 
    #undef XPADDING 
    #undef YPADDING 
    #undef TABLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_table_attach
 * Params: GtkTable *table,GtkWidget *child,guint left_attach,guint right_attach,guint top_attach,guint bottom_attach,GtkAttachOptions xoptions,GtkAttachOptions yoptions,guint xpadding,guint ypadding
 * Returns: void
 * Assertion: Adds a widget to a table. 
 * Params Values: a newly created GtkTable*, gtk_button_new_with_label ("button");,2,4,1,3,GTK_EXPAND,GTK_FILL,1,1
 * Expected: void  
 */
static void test_purpose_55()
{
    #define CHILD gtk_button_new_with_label ("button");
    #define LEFT_ATTACH 2
    #define RIGHT_ATTACH 4
    #define TOP_ATTACH 1
    #define BOTTOM_ATTACH 3
    #define XOPTIONS GTK_EXPAND
    #define YOPTIONS GTK_FILL
    #define XPADDING 1
    #define YPADDING 1
    #define TABLE gtk_table_new (6500, 6500, FALSE)
    
    GtkWidget* widget;
    GtkWidget* table;
    GtkWidget* parent;
    guint left_attach;
    GtkAttachOptions x_options;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    table = TABLE;
    widget = CHILD;
    
    gtk_table_attach (GTK_TABLE (table),
                      widget,
                      LEFT_ATTACH,RIGHT_ATTACH,  TOP_ATTACH,BOTTOM_ATTACH, 
                      XOPTIONS,                  YOPTIONS,
                      XPADDING,                  YPADDING
                      );
    
    parent = gtk_widget_get_parent (widget);
    if (parent != table)
    {
        TEST_FAIL ("Widget is not added to a table",NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (table);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CHILD
    #undef LEFT_ATTACH 
    #undef RIGHT_ATTACH
    #undef TOP_ATTACH
    #undef BOTTOM_ATTACH
    #undef XOPTIONS 
    #undef YOPTIONS 
    #undef XPADDING 
    #undef YPADDING 
    #undef TABLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_table_attach
 * Params: GtkTable *table,GtkWidget *child,guint left_attach,guint right_attach,guint top_attach,guint bottom_attach,GtkAttachOptions xoptions,GtkAttachOptions yoptions,guint xpadding,guint ypadding
 * Returns: void
 * Assertion: Adds a widget to a table. 
 * Params Values: a newly created GtkTable*, gtk_button_new_with_label ("button");,0,1,0,1,GTK_EXPAND,GTK_FILL,1,1
 * Expected: void  
 */
static void test_purpose_56()
{
    #define CHILD gtk_button_new_with_label ("button");
    #define LEFT_ATTACH 0
    #define RIGHT_ATTACH 1
    #define TOP_ATTACH 0
    #define BOTTOM_ATTACH 1
    #define XOPTIONS GTK_EXPAND
    #define YOPTIONS GTK_FILL
    #define XPADDING 1
    #define YPADDING 1
    #define TABLE gtk_table_new (6500, 6500, FALSE)
    
    GtkWidget* widget;
    GtkWidget* table;
    GtkWidget* parent;
    guint left_attach;
    GtkAttachOptions x_options;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    table = TABLE;
    widget = CHILD;
    
    gtk_table_attach (GTK_TABLE (table),
                      widget,
                      LEFT_ATTACH,RIGHT_ATTACH,  TOP_ATTACH,BOTTOM_ATTACH, 
                      XOPTIONS,                  YOPTIONS,
                      XPADDING,                  YPADDING
                      );
    
    parent = gtk_widget_get_parent (widget);
    if (parent != table)
    {
        TEST_FAIL ("Widget is not added to a table",NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (table);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CHILD
    #undef LEFT_ATTACH 
    #undef RIGHT_ATTACH
    #undef TOP_ATTACH
    #undef BOTTOM_ATTACH
    #undef XOPTIONS 
    #undef YOPTIONS 
    #undef XPADDING 
    #undef YPADDING 
    #undef TABLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_table_attach
 * Params: GtkTable *table,GtkWidget *child,guint left_attach,guint right_attach,guint top_attach,guint bottom_attach,GtkAttachOptions xoptions,GtkAttachOptions yoptions,guint xpadding,guint ypadding
 * Returns: void
 * Assertion: Adds a widget to a table. 
 * Params Values: a newly created GtkTable*, gtk_button_new_with_label ("button");,0,6499,0,6499,GTK_EXPAND,GTK_FILL,1,1
 * Expected: void  
 */
static void test_purpose_57()
{
    #define CHILD gtk_button_new_with_label ("button");
    #define LEFT_ATTACH 0
    #define RIGHT_ATTACH 6499
    #define TOP_ATTACH 0
    #define BOTTOM_ATTACH 6499
    #define XOPTIONS GTK_EXPAND
    #define YOPTIONS GTK_FILL
    #define XPADDING 1
    #define YPADDING 1
    #define TABLE gtk_table_new (6500, 6500, FALSE)
    
    GtkWidget* widget;
    GtkWidget* table;
    GtkWidget* parent;
    guint left_attach;
    GtkAttachOptions x_options;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    table = TABLE;
    widget = CHILD;
    
    gtk_table_attach (GTK_TABLE (table),
                      widget,
                      LEFT_ATTACH,RIGHT_ATTACH,  TOP_ATTACH,BOTTOM_ATTACH, 
                      XOPTIONS,                  YOPTIONS,
                      XPADDING,                  YPADDING
                      );
    
    parent = gtk_widget_get_parent (widget);
    if (parent != table)
    {
        TEST_FAIL ("Widget is not added to a table",NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (table);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CHILD
    #undef LEFT_ATTACH 
    #undef RIGHT_ATTACH
    #undef TOP_ATTACH
    #undef BOTTOM_ATTACH
    #undef XOPTIONS 
    #undef YOPTIONS 
    #undef XPADDING 
    #undef YPADDING 
    #undef TABLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_table_attach
 * Params: GtkTable *table,GtkWidget *child,guint left_attach,guint right_attach,guint top_attach,guint bottom_attach,GtkAttachOptions xoptions,GtkAttachOptions yoptions,guint xpadding,guint ypadding
 * Returns: void
 * Assertion: Adds a widget to a table. 
 * Params Values: a newly created GtkTable*, gtk_button_new_with_label ("button");,6498,6499,6498,6499,GTK_EXPAND,GTK_FILL,1,1
 * Expected: void  
 */
static void test_purpose_58()
{
    #define CHILD gtk_button_new_with_label ("button");
    #define LEFT_ATTACH 6498
    #define RIGHT_ATTACH 6499
    #define TOP_ATTACH 6498
    #define BOTTOM_ATTACH 6499
    #define XOPTIONS GTK_EXPAND
    #define YOPTIONS GTK_FILL
    #define XPADDING 1
    #define YPADDING 1
    #define TABLE gtk_table_new (6500, 6500, FALSE)
    
    GtkWidget* widget;
    GtkWidget* table;
    GtkWidget* parent;
    guint left_attach;
    GtkAttachOptions x_options;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    table = TABLE;
    widget = CHILD;
    
    gtk_table_attach (GTK_TABLE (table),
                      widget,
                      LEFT_ATTACH,RIGHT_ATTACH,  TOP_ATTACH,BOTTOM_ATTACH, 
                      XOPTIONS,                  YOPTIONS,
                      XPADDING,                  YPADDING
                      );
    
    parent = gtk_widget_get_parent (widget);
    if (parent != table)
    {
        TEST_FAIL ("Widget is not added to a table",NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (table);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CHILD
    #undef LEFT_ATTACH 
    #undef RIGHT_ATTACH
    #undef TOP_ATTACH
    #undef BOTTOM_ATTACH
    #undef XOPTIONS 
    #undef YOPTIONS 
    #undef XPADDING 
    #undef YPADDING 
    #undef TABLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_table_attach
 * Params: GtkTable *table,GtkWidget *child,guint left_attach,guint right_attach,guint top_attach,guint bottom_attach,GtkAttachOptions xoptions,GtkAttachOptions yoptions,guint xpadding,guint ypadding
 * Returns: void
 * Assertion: Adds a widget to a table. 
 * Params Values: a newly created GtkTable*, gtk_button_new_with_label ("button");,0,10,10,1000,GTK_EXPAND,GTK_SHRINK,1,1
 * Expected: void  
 */
static void test_purpose_59()
{
    #define CHILD gtk_button_new_with_label ("button");
    #define LEFT_ATTACH 0
    #define RIGHT_ATTACH 10
    #define TOP_ATTACH 10
    #define BOTTOM_ATTACH 1000
    #define XOPTIONS GTK_EXPAND
    #define YOPTIONS GTK_SHRINK
    #define XPADDING 1
    #define YPADDING 1
    #define TABLE gtk_table_new (6500, 6500, FALSE)
    
    GtkWidget* widget;
    GtkWidget* table;
    GtkWidget* parent;
    guint left_attach;
    GtkAttachOptions x_options;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    table = TABLE;
    widget = CHILD;
    
    gtk_table_attach (GTK_TABLE (table),
                      widget,
                      LEFT_ATTACH,RIGHT_ATTACH,  TOP_ATTACH,BOTTOM_ATTACH, 
                      XOPTIONS,                  YOPTIONS,
                      XPADDING,                  YPADDING
                      );
    
    parent = gtk_widget_get_parent (widget);
    if (parent != table)
    {
        TEST_FAIL ("Widget is not added to a table",NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (table);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CHILD
    #undef LEFT_ATTACH 
    #undef RIGHT_ATTACH
    #undef TOP_ATTACH
    #undef BOTTOM_ATTACH
    #undef XOPTIONS 
    #undef YOPTIONS 
    #undef XPADDING 
    #undef YPADDING 
    #undef TABLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_table_attach
 * Params: GtkTable *table,GtkWidget *child,guint left_attach,guint right_attach,guint top_attach,guint bottom_attach,GtkAttachOptions xoptions,GtkAttachOptions yoptions,guint xpadding,guint ypadding
 * Returns: void
 * Assertion: The number of 'cells' that a widget will occupy is specified by left_attach, right_attach, top_attach and bottom_attach.
 * Params Values: a newly created GtkTable*, gtk_button_new_with_label ("button"),2,3,1,3,GTK_EXPAND,GTK_FILL,1,1
 * Expected: void  
 */
static void test_purpose_60()
{
    #define CHILD gtk_button_new_with_label ("button")
    #define LEFT_ATTACH 2
    #define RIGHT_ATTACH 3
    #define TOP_ATTACH 1
    #define BOTTOM_ATTACH 3
    #define XOPTIONS GTK_EXPAND
    #define YOPTIONS GTK_FILL
    #define XPADDING 1
    #define YPADDING 1
    #define TABLE gtk_table_new (4, 4, FALSE)
    
    GtkWidget* widget;
    GtkWidget* table;
    GtkWidget* parent;
    guint left_attach;
    guint right_attach;
    guint top_attach;
    guint bottom_attach;
    GtkAttachOptions x_options;
    GtkAttachOptions y_options;
    guint xpadding;
    guint ypadding;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    table = TABLE;
    widget = CHILD;
    
    gtk_table_attach (GTK_TABLE (table),
                      widget,
                      LEFT_ATTACH,RIGHT_ATTACH,  TOP_ATTACH,BOTTOM_ATTACH, 
                      XOPTIONS,                  YOPTIONS,
                      XPADDING,                  YPADDING
                      );
    
    gtk_container_child_get (GTK_CONTAINER (table), widget, 
                             "left_attach", &left_attach, 
                             NULL);
    if (left_attach != LEFT_ATTACH)
    {
        TEST_FAIL ("left_attach is '%d', should be '%d'",left_attach,LEFT_ATTACH);
    }
    
    gtk_container_child_get (GTK_CONTAINER (table), widget,
                             "right_attach", &right_attach,
                             NULL);
    if (right_attach != RIGHT_ATTACH)
    {
        TEST_FAIL ("right_attach is '%d', should be '%d'",right_attach,RIGHT_ATTACH);
    }
    
    gtk_container_child_get (GTK_CONTAINER (table), widget,
                             "top_attach", &top_attach,
                             NULL);
    if (top_attach != TOP_ATTACH)
    {
        TEST_FAIL ("top_attach is '%d', should be '%d'",top_attach,TOP_ATTACH);
    }
    
    gtk_container_child_get (GTK_CONTAINER (table), widget, 
                             "bottom_attach", &bottom_attach,
                             NULL);
    if (bottom_attach != BOTTOM_ATTACH)
    {
        TEST_FAIL ("bottom_attach is '%d', should be '%d'",bottom_attach,BOTTOM_ATTACH);
    }
    
    gtk_container_child_get (GTK_CONTAINER (table), widget, 
                             "x_options", &x_options,
                             NULL);
    if (x_options != XOPTIONS)
    {
        TEST_FAIL ("x_options is '%d', should be '%d'",x_options,XOPTIONS);
    }
    
    gtk_container_child_get (GTK_CONTAINER (table), widget, 
                             "y_options", &y_options,
                             NULL);
    if (y_options != YOPTIONS)
    {
        TEST_FAIL ("y_options is '%d', should be '%d'",y_options,YOPTIONS);
    }
    
    gtk_container_child_get (GTK_CONTAINER (table), widget,
                             "x_padding", &xpadding,
                             NULL);
    if (xpadding != XPADDING)
    {
        TEST_FAIL ("xpadding is '%d', should be '%d'",xpadding,XPADDING);
    }
    
    gtk_container_child_get (GTK_CONTAINER (table), widget, 
                             "y_padding", &ypadding,
                             NULL);
    if (ypadding != YPADDING)
    {
        TEST_FAIL ("ypadding is '%d', should be '%d'",ypadding,YPADDING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (table);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CHILD
    #undef LEFT_ATTACH 
    #undef RIGHT_ATTACH
    #undef TOP_ATTACH
    #undef BOTTOM_ATTACH
    #undef XOPTIONS 
    #undef YOPTIONS 
    #undef XPADDING 
    #undef YPADDING 
    #undef TABLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_table_attach
 * Params: GtkTable *table,GtkWidget *child,guint left_attach,guint right_attach,guint top_attach,guint bottom_attach,GtkAttachOptions xoptions,GtkAttachOptions yoptions,guint xpadding,guint ypadding
 * Returns: void
 * Assertion: The number of 'cells' that a widget will occupy is specified by left_attach, right_attach, top_attach and bottom_attach.
 * Params Values: a newly created GtkTable*, gtk_button_new_with_label ("button"),0,3,0,3,GTK_EXPAND,GTK_FILL,1,1
 * Expected: void  
 */
static void test_purpose_61()
{
    #define CHILD gtk_button_new_with_label ("button")
    #define LEFT_ATTACH 0
    #define RIGHT_ATTACH 3
    #define TOP_ATTACH 0
    #define BOTTOM_ATTACH 3
    #define XOPTIONS GTK_EXPAND
    #define YOPTIONS GTK_FILL
    #define XPADDING 1
    #define YPADDING 1
    #define TABLE gtk_table_new (4, 4, FALSE)
    
    GtkWidget* widget;
    GtkWidget* table;
    GtkWidget* parent;
    guint left_attach;
    guint right_attach;
    guint top_attach;
    guint bottom_attach;
    GtkAttachOptions x_options;
    GtkAttachOptions y_options;
    guint xpadding;
    guint ypadding;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    table = TABLE;
    widget = CHILD;
    
    gtk_table_attach (GTK_TABLE (table),
                      widget,
                      LEFT_ATTACH,RIGHT_ATTACH,  TOP_ATTACH,BOTTOM_ATTACH, 
                      XOPTIONS,                  YOPTIONS,
                      XPADDING,                  YPADDING
                      );
    
    gtk_container_child_get (GTK_CONTAINER (table), widget, 
                             "left_attach", &left_attach, 
                             NULL);
    if (left_attach != LEFT_ATTACH)
    {
        TEST_FAIL ("left_attach is '%d', should be '%d'",left_attach,LEFT_ATTACH);
    }
    
    gtk_container_child_get (GTK_CONTAINER (table), widget,
                             "right_attach", &right_attach,
                             NULL);
    if (right_attach != RIGHT_ATTACH)
    {
        TEST_FAIL ("right_attach is '%d', should be '%d'",right_attach,RIGHT_ATTACH);
    }
    
    gtk_container_child_get (GTK_CONTAINER (table), widget,
                             "top_attach", &top_attach,
                             NULL);
    if (top_attach != TOP_ATTACH)
    {
        TEST_FAIL ("top_attach is '%d', should be '%d'",top_attach,TOP_ATTACH);
    }
    
    gtk_container_child_get (GTK_CONTAINER (table), widget, 
                             "bottom_attach", &bottom_attach,
                             NULL);
    if (bottom_attach != BOTTOM_ATTACH)
    {
        TEST_FAIL ("bottom_attach is '%d', should be '%d'",bottom_attach,BOTTOM_ATTACH);
    }
    
    gtk_container_child_get (GTK_CONTAINER (table), widget, 
                             "x_options", &x_options,
                             NULL);
    if (x_options != XOPTIONS)
    {
        TEST_FAIL ("x_options is '%d', should be '%d'",x_options,XOPTIONS);
    }
    
    gtk_container_child_get (GTK_CONTAINER (table), widget, 
                             "y_options", &y_options,
                             NULL);
    if (y_options != YOPTIONS)
    {
        TEST_FAIL ("y_options is '%d', should be '%d'",y_options,YOPTIONS);
    }
    
    gtk_container_child_get (GTK_CONTAINER (table), widget,
                             "x_padding", &xpadding,
                             NULL);
    if (xpadding != XPADDING)
    {
        TEST_FAIL ("xpadding is '%d', should be '%d'",xpadding,XPADDING);
    }
    
    gtk_container_child_get (GTK_CONTAINER (table), widget, 
                             "y_padding", &ypadding,
                             NULL);
    if (ypadding != YPADDING)
    {
        TEST_FAIL ("ypadding is '%d', should be '%d'",ypadding,YPADDING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (table);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CHILD
    #undef LEFT_ATTACH 
    #undef RIGHT_ATTACH
    #undef TOP_ATTACH
    #undef BOTTOM_ATTACH
    #undef XOPTIONS 
    #undef YOPTIONS 
    #undef XPADDING 
    #undef YPADDING 
    #undef TABLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_table_attach
 * Params: GtkTable *table,GtkWidget *child,guint left_attach,guint right_attach,guint top_attach,guint bottom_attach,GtkAttachOptions xoptions,GtkAttachOptions yoptions,guint xpadding,guint ypadding
 * Returns: void
 * Assertion: The number of 'cells' that a widget will occupy is specified by left_attach, right_attach, top_attach and bottom_attach.
 * Params Values: a newly created GtkTable*, gtk_button_new_with_label ("button"),2,4,1,3,GTK_EXPAND,GTK_FILL,1,1
 * Expected: void  
 */
static void test_purpose_62()
{
    #define CHILD gtk_button_new_with_label ("button")
    #define LEFT_ATTACH 2
    #define RIGHT_ATTACH 4
    #define TOP_ATTACH 1
    #define BOTTOM_ATTACH 3
    #define XOPTIONS GTK_EXPAND
    #define YOPTIONS GTK_FILL
    #define XPADDING 1
    #define YPADDING 1
    #define TABLE gtk_table_new (6500, 6500, FALSE)
    
    GtkWidget* widget;
    GtkWidget* table;
    GtkWidget* parent;
    guint left_attach;
    guint right_attach;
    guint top_attach;
    guint bottom_attach;
    GtkAttachOptions x_options;
    GtkAttachOptions y_options;
    guint xpadding;
    guint ypadding;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    table = TABLE;
    widget = CHILD;
    
    gtk_table_attach (GTK_TABLE (table),
                      widget,
                      LEFT_ATTACH,RIGHT_ATTACH,  TOP_ATTACH,BOTTOM_ATTACH, 
                      XOPTIONS,                  YOPTIONS,
                      XPADDING,                  YPADDING
                      );
    
    gtk_container_child_get (GTK_CONTAINER (table), widget, 
                             "left_attach", &left_attach, 
                             NULL);
    if (left_attach != LEFT_ATTACH)
    {
        TEST_FAIL ("left_attach is '%d', should be '%d'",left_attach,LEFT_ATTACH);
    }
    
    gtk_container_child_get (GTK_CONTAINER (table), widget,
                             "right_attach", &right_attach,
                             NULL);
    if (right_attach != RIGHT_ATTACH)
    {
        TEST_FAIL ("right_attach is '%d', should be '%d'",right_attach,RIGHT_ATTACH);
    }
    
    gtk_container_child_get (GTK_CONTAINER (table), widget,
                             "top_attach", &top_attach,
                             NULL);
    if (top_attach != TOP_ATTACH)
    {
        TEST_FAIL ("top_attach is '%d', should be '%d'",top_attach,TOP_ATTACH);
    }
    
    gtk_container_child_get (GTK_CONTAINER (table), widget, 
                             "bottom_attach", &bottom_attach,
                             NULL);
    if (bottom_attach != BOTTOM_ATTACH)
    {
        TEST_FAIL ("bottom_attach is '%d', should be '%d'",bottom_attach,BOTTOM_ATTACH);
    }
    
    gtk_container_child_get (GTK_CONTAINER (table), widget, 
                             "x_options", &x_options,
                             NULL);
    if (x_options != XOPTIONS)
    {
        TEST_FAIL ("x_options is '%d', should be '%d'",x_options,XOPTIONS);
    }
    
    gtk_container_child_get (GTK_CONTAINER (table), widget, 
                             "y_options", &y_options,
                             NULL);
    if (y_options != YOPTIONS)
    {
        TEST_FAIL ("y_options is '%d', should be '%d'",y_options,YOPTIONS);
    }
    
    gtk_container_child_get (GTK_CONTAINER (table), widget,
                             "x_padding", &xpadding,
                             NULL);
    if (xpadding != XPADDING)
    {
        TEST_FAIL ("xpadding is '%d', should be '%d'",xpadding,XPADDING);
    }
    
    gtk_container_child_get (GTK_CONTAINER (table), widget, 
                             "y_padding", &ypadding,
                             NULL);
    if (ypadding != YPADDING)
    {
        TEST_FAIL ("ypadding is '%d', should be '%d'",ypadding,YPADDING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (table);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CHILD
    #undef LEFT_ATTACH 
    #undef RIGHT_ATTACH
    #undef TOP_ATTACH
    #undef BOTTOM_ATTACH
    #undef XOPTIONS 
    #undef YOPTIONS 
    #undef XPADDING 
    #undef YPADDING 
    #undef TABLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_table_attach
 * Params: GtkTable *table,GtkWidget *child,guint left_attach,guint right_attach,guint top_attach,guint bottom_attach,GtkAttachOptions xoptions,GtkAttachOptions yoptions,guint xpadding,guint ypadding
 * Returns: void
 * Assertion: The number of 'cells' that a widget will occupy is specified by left_attach, right_attach, top_attach and bottom_attach.
 * Params Values: a newly created GtkTable*, gtk_button_new_with_label ("button"),0,1,0,1,GTK_EXPAND,GTK_FILL,1,1
 * Expected: void  
 */
static void test_purpose_63()
{
    #define CHILD gtk_button_new_with_label ("button")
    #define LEFT_ATTACH 0
    #define RIGHT_ATTACH 1
    #define TOP_ATTACH 0
    #define BOTTOM_ATTACH 1
    #define XOPTIONS GTK_EXPAND
    #define YOPTIONS GTK_FILL
    #define XPADDING 1
    #define YPADDING 1
    #define TABLE gtk_table_new (6500, 6500, FALSE)
    
    GtkWidget* widget;
    GtkWidget* table;
    GtkWidget* parent;
    guint left_attach;
    guint right_attach;
    guint top_attach;
    guint bottom_attach;
    GtkAttachOptions x_options;
    GtkAttachOptions y_options;
    guint xpadding;
    guint ypadding;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    table = TABLE;
    widget = CHILD;
    
    gtk_table_attach (GTK_TABLE (table),
                      widget,
                      LEFT_ATTACH,RIGHT_ATTACH,  TOP_ATTACH,BOTTOM_ATTACH, 
                      XOPTIONS,                  YOPTIONS,
                      XPADDING,                  YPADDING
                      );
    
    gtk_container_child_get (GTK_CONTAINER (table), widget, 
                             "left_attach", &left_attach, 
                             NULL);
    if (left_attach != LEFT_ATTACH)
    {
        TEST_FAIL ("left_attach is '%d', should be '%d'",left_attach,LEFT_ATTACH);
    }
    
    gtk_container_child_get (GTK_CONTAINER (table), widget,
                             "right_attach", &right_attach,
                             NULL);
    if (right_attach != RIGHT_ATTACH)
    {
        TEST_FAIL ("right_attach is '%d', should be '%d'",right_attach,RIGHT_ATTACH);
    }
    
    gtk_container_child_get (GTK_CONTAINER (table), widget,
                             "top_attach", &top_attach,
                             NULL);
    if (top_attach != TOP_ATTACH)
    {
        TEST_FAIL ("top_attach is '%d', should be '%d'",top_attach,TOP_ATTACH);
    }
    
    gtk_container_child_get (GTK_CONTAINER (table), widget, 
                             "bottom_attach", &bottom_attach,
                             NULL);
    if (bottom_attach != BOTTOM_ATTACH)
    {
        TEST_FAIL ("bottom_attach is '%d', should be '%d'",bottom_attach,BOTTOM_ATTACH);
    }
    
    gtk_container_child_get (GTK_CONTAINER (table), widget, 
                             "x_options", &x_options,
                             NULL);
    if (x_options != XOPTIONS)
    {
        TEST_FAIL ("x_options is '%d', should be '%d'",x_options,XOPTIONS);
    }
    
    gtk_container_child_get (GTK_CONTAINER (table), widget, 
                             "y_options", &y_options,
                             NULL);
    if (y_options != YOPTIONS)
    {
        TEST_FAIL ("y_options is '%d', should be '%d'",y_options,YOPTIONS);
    }
    
    gtk_container_child_get (GTK_CONTAINER (table), widget,
                             "x_padding", &xpadding,
                             NULL);
    if (xpadding != XPADDING)
    {
        TEST_FAIL ("xpadding is '%d', should be '%d'",xpadding,XPADDING);
    }
    
    gtk_container_child_get (GTK_CONTAINER (table), widget, 
                             "y_padding", &ypadding,
                             NULL);
    if (ypadding != YPADDING)
    {
        TEST_FAIL ("ypadding is '%d', should be '%d'",ypadding,YPADDING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (table);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CHILD
    #undef LEFT_ATTACH 
    #undef RIGHT_ATTACH
    #undef TOP_ATTACH
    #undef BOTTOM_ATTACH
    #undef XOPTIONS 
    #undef YOPTIONS 
    #undef XPADDING 
    #undef YPADDING 
    #undef TABLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_table_attach
 * Params: GtkTable *table,GtkWidget *child,guint left_attach,guint right_attach,guint top_attach,guint bottom_attach,GtkAttachOptions xoptions,GtkAttachOptions yoptions,guint xpadding,guint ypadding
 * Returns: void
 * Assertion: The number of 'cells' that a widget will occupy is specified by left_attach, right_attach, top_attach and bottom_attach.
 * Params Values: a newly created GtkTable*, gtk_button_new_with_label ("button"),0,6499,0,6499,GTK_EXPAND,GTK_FILL,1,1
 * Expected: void  
 */
static void test_purpose_64()
{
    #define CHILD gtk_button_new_with_label ("button")
    #define LEFT_ATTACH 0
    #define RIGHT_ATTACH 6499
    #define TOP_ATTACH 0
    #define BOTTOM_ATTACH 6499
    #define XOPTIONS GTK_EXPAND
    #define YOPTIONS GTK_FILL
    #define XPADDING 1
    #define YPADDING 1
    #define TABLE gtk_table_new (6500, 6500, FALSE)
    
    GtkWidget* widget;
    GtkWidget* table;
    GtkWidget* parent;
    guint left_attach;
    guint right_attach;
    guint top_attach;
    guint bottom_attach;
    GtkAttachOptions x_options;
    GtkAttachOptions y_options;
    guint xpadding;
    guint ypadding;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    table = TABLE;
    widget = CHILD;
    
    gtk_table_attach (GTK_TABLE (table),
                      widget,
                      LEFT_ATTACH,RIGHT_ATTACH,  TOP_ATTACH,BOTTOM_ATTACH, 
                      XOPTIONS,                  YOPTIONS,
                      XPADDING,                  YPADDING
                      );
    
    gtk_container_child_get (GTK_CONTAINER (table), widget, 
                             "left_attach", &left_attach, 
                             NULL);
    if (left_attach != LEFT_ATTACH)
    {
        TEST_FAIL ("left_attach is '%d', should be '%d'",left_attach,LEFT_ATTACH);
    }
    
    gtk_container_child_get (GTK_CONTAINER (table), widget,
                             "right_attach", &right_attach,
                             NULL);
    if (right_attach != RIGHT_ATTACH)
    {
        TEST_FAIL ("right_attach is '%d', should be '%d'",right_attach,RIGHT_ATTACH);
    }
    
    gtk_container_child_get (GTK_CONTAINER (table), widget,
                             "top_attach", &top_attach,
                             NULL);
    if (top_attach != TOP_ATTACH)
    {
        TEST_FAIL ("top_attach is '%d', should be '%d'",top_attach,TOP_ATTACH);
    }
    
    gtk_container_child_get (GTK_CONTAINER (table), widget, 
                             "bottom_attach", &bottom_attach,
                             NULL);
    if (bottom_attach != BOTTOM_ATTACH)
    {
        TEST_FAIL ("bottom_attach is '%d', should be '%d'",bottom_attach,BOTTOM_ATTACH);
    }
    
    gtk_container_child_get (GTK_CONTAINER (table), widget, 
                             "x_options", &x_options,
                             NULL);
    if (x_options != XOPTIONS)
    {
        TEST_FAIL ("x_options is '%d', should be '%d'",x_options,XOPTIONS);
    }
    
    gtk_container_child_get (GTK_CONTAINER (table), widget, 
                             "y_options", &y_options,
                             NULL);
    if (y_options != YOPTIONS)
    {
        TEST_FAIL ("y_options is '%d', should be '%d'",y_options,YOPTIONS);
    }
    
    gtk_container_child_get (GTK_CONTAINER (table), widget,
                             "x_padding", &xpadding,
                             NULL);
    if (xpadding != XPADDING)
    {
        TEST_FAIL ("xpadding is '%d', should be '%d'",xpadding,XPADDING);
    }
    
    gtk_container_child_get (GTK_CONTAINER (table), widget, 
                             "y_padding", &ypadding,
                             NULL);
    if (ypadding != YPADDING)
    {
        TEST_FAIL ("ypadding is '%d', should be '%d'",ypadding,YPADDING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (table);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CHILD
    #undef LEFT_ATTACH 
    #undef RIGHT_ATTACH
    #undef TOP_ATTACH
    #undef BOTTOM_ATTACH
    #undef XOPTIONS 
    #undef YOPTIONS 
    #undef XPADDING 
    #undef YPADDING 
    #undef TABLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_table_attach
 * Params: GtkTable *table,GtkWidget *child,guint left_attach,guint right_attach,guint top_attach,guint bottom_attach,GtkAttachOptions xoptions,GtkAttachOptions yoptions,guint xpadding,guint ypadding
 * Returns: void
 * Assertion: The number of 'cells' that a widget will occupy is specified by left_attach, right_attach, top_attach and bottom_attach.
 * Params Values: a newly created GtkTable*, gtk_button_new_with_label ("button"),6498,6499,6498,6499,GTK_EXPAND,GTK_FILL,1,1
 * Expected: void  
 */
static void test_purpose_65()
{
    #define CHILD gtk_button_new_with_label ("button")
    #define LEFT_ATTACH 6498
    #define RIGHT_ATTACH 6499
    #define TOP_ATTACH 6498
    #define BOTTOM_ATTACH 6499
    #define XOPTIONS GTK_EXPAND
    #define YOPTIONS GTK_FILL
    #define XPADDING 1
    #define YPADDING 1
    #define TABLE gtk_table_new (6500, 6500, FALSE)
    
    GtkWidget* widget;
    GtkWidget* table;
    GtkWidget* parent;
    guint left_attach;
    guint right_attach;
    guint top_attach;
    guint bottom_attach;
    GtkAttachOptions x_options;
    GtkAttachOptions y_options;
    guint xpadding;
    guint ypadding;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    table = TABLE;
    widget = CHILD;
    
    gtk_table_attach (GTK_TABLE (table),
                      widget,
                      LEFT_ATTACH,RIGHT_ATTACH,  TOP_ATTACH,BOTTOM_ATTACH, 
                      XOPTIONS,                  YOPTIONS,
                      XPADDING,                  YPADDING
                      );
    
    gtk_container_child_get (GTK_CONTAINER (table), widget, 
                             "left_attach", &left_attach, 
                             NULL);
    if (left_attach != LEFT_ATTACH)
    {
        TEST_FAIL ("left_attach is '%d', should be '%d'",left_attach,LEFT_ATTACH);
    }
    
    gtk_container_child_get (GTK_CONTAINER (table), widget,
                             "right_attach", &right_attach,
                             NULL);
    if (right_attach != RIGHT_ATTACH)
    {
        TEST_FAIL ("right_attach is '%d', should be '%d'",right_attach,RIGHT_ATTACH);
    }
    
    gtk_container_child_get (GTK_CONTAINER (table), widget,
                             "top_attach", &top_attach,
                             NULL);
    if (top_attach != TOP_ATTACH)
    {
        TEST_FAIL ("top_attach is '%d', should be '%d'",top_attach,TOP_ATTACH);
    }
    
    gtk_container_child_get (GTK_CONTAINER (table), widget, 
                             "bottom_attach", &bottom_attach,
                             NULL);
    if (bottom_attach != BOTTOM_ATTACH)
    {
        TEST_FAIL ("bottom_attach is '%d', should be '%d'",bottom_attach,BOTTOM_ATTACH);
    }
    
    gtk_container_child_get (GTK_CONTAINER (table), widget, 
                             "x_options", &x_options,
                             NULL);
    if (x_options != XOPTIONS)
    {
        TEST_FAIL ("x_options is '%d', should be '%d'",x_options,XOPTIONS);
    }
    
    gtk_container_child_get (GTK_CONTAINER (table), widget, 
                             "y_options", &y_options,
                             NULL);
    if (y_options != YOPTIONS)
    {
        TEST_FAIL ("y_options is '%d', should be '%d'",y_options,YOPTIONS);
    }
    
    gtk_container_child_get (GTK_CONTAINER (table), widget,
                             "x_padding", &xpadding,
                             NULL);
    if (xpadding != XPADDING)
    {
        TEST_FAIL ("xpadding is '%d', should be '%d'",xpadding,XPADDING);
    }
    
    gtk_container_child_get (GTK_CONTAINER (table), widget, 
                             "y_padding", &ypadding,
                             NULL);
    if (ypadding != YPADDING)
    {
        TEST_FAIL ("ypadding is '%d', should be '%d'",ypadding,YPADDING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (table);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CHILD
    #undef LEFT_ATTACH 
    #undef RIGHT_ATTACH
    #undef TOP_ATTACH
    #undef BOTTOM_ATTACH
    #undef XOPTIONS 
    #undef YOPTIONS 
    #undef XPADDING 
    #undef YPADDING 
    #undef TABLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_table_attach
 * Params: GtkTable *table,GtkWidget *child,guint left_attach,guint right_attach,guint top_attach,guint bottom_attach,GtkAttachOptions xoptions,GtkAttachOptions yoptions,guint xpadding,guint ypadding
 * Returns: void
 * Assertion: The number of 'cells' that a widget will occupy is specified by left_attach, right_attach, top_attach and bottom_attach.
 * Params Values: a newly created GtkTable*, gtk_button_new_with_label ("button"),0,10,10,1000,GTK_EXPAND,GTK_SHRINK,1,1
 * Expected: void  
 */
static void test_purpose_66()
{
    #define CHILD gtk_button_new_with_label ("button")
    #define LEFT_ATTACH 0
    #define RIGHT_ATTACH 10
    #define TOP_ATTACH 10
    #define BOTTOM_ATTACH 1000
    #define XOPTIONS GTK_EXPAND
    #define YOPTIONS GTK_SHRINK
    #define XPADDING 1
    #define YPADDING 1
    #define TABLE gtk_table_new (6500, 6500, FALSE)
    
    GtkWidget* widget;
    GtkWidget* table;
    GtkWidget* parent;
    guint left_attach;
    guint right_attach;
    guint top_attach;
    guint bottom_attach;
    GtkAttachOptions x_options;
    GtkAttachOptions y_options;
    guint xpadding;
    guint ypadding;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    table = TABLE;
    widget = CHILD;
    
    gtk_table_attach (GTK_TABLE (table),
                      widget,
                      LEFT_ATTACH,RIGHT_ATTACH,  TOP_ATTACH,BOTTOM_ATTACH, 
                      XOPTIONS,                  YOPTIONS,
                      XPADDING,                  YPADDING
                      );
    
    gtk_container_child_get (GTK_CONTAINER (table), widget, 
                             "left_attach", &left_attach, 
                             NULL);
    if (left_attach != LEFT_ATTACH)
    {
        TEST_FAIL ("left_attach is '%d', should be '%d'",left_attach,LEFT_ATTACH);
    }
    
    gtk_container_child_get (GTK_CONTAINER (table), widget,
                             "right_attach", &right_attach,
                             NULL);
    if (right_attach != RIGHT_ATTACH)
    {
        TEST_FAIL ("right_attach is '%d', should be '%d'",right_attach,RIGHT_ATTACH);
    }
    
    gtk_container_child_get (GTK_CONTAINER (table), widget,
                             "top_attach", &top_attach,
                             NULL);
    if (top_attach != TOP_ATTACH)
    {
        TEST_FAIL ("top_attach is '%d', should be '%d'",top_attach,TOP_ATTACH);
    }
    
    gtk_container_child_get (GTK_CONTAINER (table), widget, 
                             "bottom_attach", &bottom_attach,
                             NULL);
    if (bottom_attach != BOTTOM_ATTACH)
    {
        TEST_FAIL ("bottom_attach is '%d', should be '%d'",bottom_attach,BOTTOM_ATTACH);
    }
    
    gtk_container_child_get (GTK_CONTAINER (table), widget, 
                             "x_options", &x_options,
                             NULL);
    if (x_options != XOPTIONS)
    {
        TEST_FAIL ("x_options is '%d', should be '%d'",x_options,XOPTIONS);
    }
    
    gtk_container_child_get (GTK_CONTAINER (table), widget, 
                             "y_options", &y_options,
                             NULL);
    if (y_options != YOPTIONS)
    {
        TEST_FAIL ("y_options is '%d', should be '%d'",y_options,YOPTIONS);
    }
    
    gtk_container_child_get (GTK_CONTAINER (table), widget,
                             "x_padding", &xpadding,
                             NULL);
    if (xpadding != XPADDING)
    {
        TEST_FAIL ("xpadding is '%d', should be '%d'",xpadding,XPADDING);
    }
    
    gtk_container_child_get (GTK_CONTAINER (table), widget, 
                             "y_padding", &ypadding,
                             NULL);
    if (ypadding != YPADDING)
    {
        TEST_FAIL ("ypadding is '%d', should be '%d'",ypadding,YPADDING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (table);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CHILD
    #undef LEFT_ATTACH 
    #undef RIGHT_ATTACH
    #undef TOP_ATTACH
    #undef BOTTOM_ATTACH
    #undef XOPTIONS 
    #undef YOPTIONS 
    #undef XPADDING 
    #undef YPADDING 
    #undef TABLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_table_attach_defaults
 * Params: GtkTable *table,GtkWidget *child,guint left_attach,guint right_attach,guint top_attach,guint bottom_attach
 * Returns: void
 * Assertion:As there are many options associated with gtk_table_attach(), this convenience function provides the programmer with a means to add children to a table with identical padding and expansion options. 
 * Params Values: a newly created GtkTable*, gtk_button_new_with_label ("button"),2,3,1,3,gtk_table_new (4, 4, FALSE)
 * Expected: void  
 */
static void test_purpose_67()
{
    #define CHILD gtk_button_new_with_label ("button")
    #define LEFT_ATTACH 2
    #define RIGHT_ATTACH 3
    #define TOP_ATTACH 1
    #define BOTTOM_ATTACH 3
    #define TABLE gtk_table_new (4, 4, FALSE)
    
    GtkWidget* widget;
    GtkWidget* table;
    GtkWidget* parent;
    guint left_attach;
    guint right_attach;
    guint top_attach;
    guint bottom_attach;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    table = TABLE;
    widget = CHILD;
    
    gtk_table_attach_defaults (GTK_TABLE (table),
                               widget,
                               LEFT_ATTACH,RIGHT_ATTACH,  TOP_ATTACH,BOTTOM_ATTACH
                               );
    
    gtk_container_child_get (GTK_CONTAINER (table), widget,
                             "left_attach", &left_attach,
                             NULL);
    if (left_attach != LEFT_ATTACH)
    {
        TEST_FAIL ("left_attach is '%d', should be '%d'",left_attach,LEFT_ATTACH);
    }
    
    gtk_container_child_get (GTK_CONTAINER (table), widget,
                             "right_attach", &right_attach,
                             NULL);
    if (right_attach != RIGHT_ATTACH)
    {
        TEST_FAIL ("right_attach is '%d', should be '%d'",right_attach,RIGHT_ATTACH);
    }
    
    gtk_container_child_get (GTK_CONTAINER (table), widget,
                             "top_attach", &top_attach,
                             NULL);
    if (top_attach != TOP_ATTACH)
    {
        TEST_FAIL ("top_attach is '%d', should be '%d'",top_attach,TOP_ATTACH);
    }
    
    gtk_container_child_get (GTK_CONTAINER (table), widget,
                             "bottom_attach", &bottom_attach,
                             NULL);
    if (bottom_attach != BOTTOM_ATTACH)
    {
        TEST_FAIL ("bottom_attach is '%d', should be '%d'",bottom_attach,BOTTOM_ATTACH);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (table);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CHILD
    #undef LEFT_ATTACH 
    #undef RIGHT_ATTACH
    #undef TOP_ATTACH
    #undef BOTTOM_ATTACH
    #undef TABLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_table_attach_defaults
 * Params: GtkTable *table,GtkWidget *child,guint left_attach,guint right_attach,guint top_attach,guint bottom_attach
 * Returns: void
 * Assertion:As there are many options associated with gtk_table_attach(), this convenience function provides the programmer with a means to add children to a table with identical padding and expansion options. 
 * Params Values: a newly created GtkTable*, gtk_button_new_with_label ("button"),0,3,0,3,gtk_table_new (4, 4, FALSE)
 * Expected: void  
 */
static void test_purpose_68()
{
    #define CHILD gtk_button_new_with_label ("button")
    #define LEFT_ATTACH 0
    #define RIGHT_ATTACH 3
    #define TOP_ATTACH 0
    #define BOTTOM_ATTACH 3
    #define TABLE gtk_table_new (4, 4, FALSE)
    
    GtkWidget* widget;
    GtkWidget* table;
    GtkWidget* parent;
    guint left_attach;
    guint right_attach;
    guint top_attach;
    guint bottom_attach;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    table = TABLE;
    widget = CHILD;
    
    gtk_table_attach_defaults (GTK_TABLE (table),
                               widget,
                               LEFT_ATTACH,RIGHT_ATTACH,  TOP_ATTACH,BOTTOM_ATTACH
                               );
    
    gtk_container_child_get (GTK_CONTAINER (table), widget,
                             "left_attach", &left_attach,
                             NULL);
    if (left_attach != LEFT_ATTACH)
    {
        TEST_FAIL ("left_attach is '%d', should be '%d'",left_attach,LEFT_ATTACH);
    }
    
    gtk_container_child_get (GTK_CONTAINER (table), widget,
                             "right_attach", &right_attach,
                             NULL);
    if (right_attach != RIGHT_ATTACH)
    {
        TEST_FAIL ("right_attach is '%d', should be '%d'",right_attach,RIGHT_ATTACH);
    }
    
    gtk_container_child_get (GTK_CONTAINER (table), widget,
                             "top_attach", &top_attach,
                             NULL);
    if (top_attach != TOP_ATTACH)
    {
        TEST_FAIL ("top_attach is '%d', should be '%d'",top_attach,TOP_ATTACH);
    }
    
    gtk_container_child_get (GTK_CONTAINER (table), widget,
                             "bottom_attach", &bottom_attach,
                             NULL);
    if (bottom_attach != BOTTOM_ATTACH)
    {
        TEST_FAIL ("bottom_attach is '%d', should be '%d'",bottom_attach,BOTTOM_ATTACH);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (table);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CHILD
    #undef LEFT_ATTACH 
    #undef RIGHT_ATTACH
    #undef TOP_ATTACH
    #undef BOTTOM_ATTACH
    #undef TABLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_table_attach_defaults
 * Params: GtkTable *table,GtkWidget *child,guint left_attach,guint right_attach,guint top_attach,guint bottom_attach
 * Returns: void
 * Assertion:As there are many options associated with gtk_table_attach(), this convenience function provides the programmer with a means to add children to a table with identical padding and expansion options. 
 * Params Values: a newly created GtkTable*, gtk_button_new_with_label ("button"),2,4,1,3,gtk_table_new (6500, 6500, FALSE)
 * Expected: void  
 */
static void test_purpose_69()
{
    #define CHILD gtk_button_new_with_label ("button")
    #define LEFT_ATTACH 2
    #define RIGHT_ATTACH 4
    #define TOP_ATTACH 1
    #define BOTTOM_ATTACH 3
    #define TABLE gtk_table_new (6500, 6500, FALSE)
    
    GtkWidget* widget;
    GtkWidget* table;
    GtkWidget* parent;
    guint left_attach;
    guint right_attach;
    guint top_attach;
    guint bottom_attach;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    table = TABLE;
    widget = CHILD;
    
    gtk_table_attach_defaults (GTK_TABLE (table),
                               widget,
                               LEFT_ATTACH,RIGHT_ATTACH,  TOP_ATTACH,BOTTOM_ATTACH
                               );
    
    gtk_container_child_get (GTK_CONTAINER (table), widget,
                             "left_attach", &left_attach,
                             NULL);
    if (left_attach != LEFT_ATTACH)
    {
        TEST_FAIL ("left_attach is '%d', should be '%d'",left_attach,LEFT_ATTACH);
    }
    
    gtk_container_child_get (GTK_CONTAINER (table), widget,
                             "right_attach", &right_attach,
                             NULL);
    if (right_attach != RIGHT_ATTACH)
    {
        TEST_FAIL ("right_attach is '%d', should be '%d'",right_attach,RIGHT_ATTACH);
    }
    
    gtk_container_child_get (GTK_CONTAINER (table), widget,
                             "top_attach", &top_attach,
                             NULL);
    if (top_attach != TOP_ATTACH)
    {
        TEST_FAIL ("top_attach is '%d', should be '%d'",top_attach,TOP_ATTACH);
    }
    
    gtk_container_child_get (GTK_CONTAINER (table), widget,
                             "bottom_attach", &bottom_attach,
                             NULL);
    if (bottom_attach != BOTTOM_ATTACH)
    {
        TEST_FAIL ("bottom_attach is '%d', should be '%d'",bottom_attach,BOTTOM_ATTACH);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (table);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CHILD
    #undef LEFT_ATTACH 
    #undef RIGHT_ATTACH
    #undef TOP_ATTACH
    #undef BOTTOM_ATTACH
    #undef TABLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_table_attach_defaults
 * Params: GtkTable *table,GtkWidget *child,guint left_attach,guint right_attach,guint top_attach,guint bottom_attach
 * Returns: void
 * Assertion:As there are many options associated with gtk_table_attach(), this convenience function provides the programmer with a means to add children to a table with identical padding and expansion options. 
 * Params Values: a newly created GtkTable*, gtk_button_new_with_label ("button"),0,1,0,1,gtk_table_new (6500, 6500, FALSE)
 * Expected: void  
 */
static void test_purpose_70()
{
    #define CHILD gtk_button_new_with_label ("button")
    #define LEFT_ATTACH 0
    #define RIGHT_ATTACH 1
    #define TOP_ATTACH 0
    #define BOTTOM_ATTACH 1
    #define TABLE gtk_table_new (6500, 6500, FALSE)
    
    GtkWidget* widget;
    GtkWidget* table;
    GtkWidget* parent;
    guint left_attach;
    guint right_attach;
    guint top_attach;
    guint bottom_attach;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    table = TABLE;
    widget = CHILD;
    
    gtk_table_attach_defaults (GTK_TABLE (table),
                               widget,
                               LEFT_ATTACH,RIGHT_ATTACH,  TOP_ATTACH,BOTTOM_ATTACH
                               );
    
    gtk_container_child_get (GTK_CONTAINER (table), widget,
                             "left_attach", &left_attach,
                             NULL);
    if (left_attach != LEFT_ATTACH)
    {
        TEST_FAIL ("left_attach is '%d', should be '%d'",left_attach,LEFT_ATTACH);
    }
    
    gtk_container_child_get (GTK_CONTAINER (table), widget,
                             "right_attach", &right_attach,
                             NULL);
    if (right_attach != RIGHT_ATTACH)
    {
        TEST_FAIL ("right_attach is '%d', should be '%d'",right_attach,RIGHT_ATTACH);
    }
    
    gtk_container_child_get (GTK_CONTAINER (table), widget,
                             "top_attach", &top_attach,
                             NULL);
    if (top_attach != TOP_ATTACH)
    {
        TEST_FAIL ("top_attach is '%d', should be '%d'",top_attach,TOP_ATTACH);
    }
    
    gtk_container_child_get (GTK_CONTAINER (table), widget,
                             "bottom_attach", &bottom_attach,
                             NULL);
    if (bottom_attach != BOTTOM_ATTACH)
    {
        TEST_FAIL ("bottom_attach is '%d', should be '%d'",bottom_attach,BOTTOM_ATTACH);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (table);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CHILD
    #undef LEFT_ATTACH 
    #undef RIGHT_ATTACH
    #undef TOP_ATTACH
    #undef BOTTOM_ATTACH
    #undef TABLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_table_attach_defaults
 * Params: GtkTable *table,GtkWidget *child,guint left_attach,guint right_attach,guint top_attach,guint bottom_attach
 * Returns: void
 * Assertion:As there are many options associated with gtk_table_attach(), this convenience function provides the programmer with a means to add children to a table with identical padding and expansion options. 
 * Params Values: a newly created GtkTable*, gtk_button_new_with_label ("button"),0,6499,0,6499,gtk_table_new (6500, 6500, FALSE)
 * Expected: void  
 */
static void test_purpose_71()
{
    #define CHILD gtk_button_new_with_label ("button")
    #define LEFT_ATTACH 0
    #define RIGHT_ATTACH 6499
    #define TOP_ATTACH 0
    #define BOTTOM_ATTACH 6499
    #define TABLE gtk_table_new (6500, 6500, FALSE)
    
    GtkWidget* widget;
    GtkWidget* table;
    GtkWidget* parent;
    guint left_attach;
    guint right_attach;
    guint top_attach;
    guint bottom_attach;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    table = TABLE;
    widget = CHILD;
    
    gtk_table_attach_defaults (GTK_TABLE (table),
                               widget,
                               LEFT_ATTACH,RIGHT_ATTACH,  TOP_ATTACH,BOTTOM_ATTACH
                               );
    
    gtk_container_child_get (GTK_CONTAINER (table), widget,
                             "left_attach", &left_attach,
                             NULL);
    if (left_attach != LEFT_ATTACH)
    {
        TEST_FAIL ("left_attach is '%d', should be '%d'",left_attach,LEFT_ATTACH);
    }
    
    gtk_container_child_get (GTK_CONTAINER (table), widget,
                             "right_attach", &right_attach,
                             NULL);
    if (right_attach != RIGHT_ATTACH)
    {
        TEST_FAIL ("right_attach is '%d', should be '%d'",right_attach,RIGHT_ATTACH);
    }
    
    gtk_container_child_get (GTK_CONTAINER (table), widget,
                             "top_attach", &top_attach,
                             NULL);
    if (top_attach != TOP_ATTACH)
    {
        TEST_FAIL ("top_attach is '%d', should be '%d'",top_attach,TOP_ATTACH);
    }
    
    gtk_container_child_get (GTK_CONTAINER (table), widget,
                             "bottom_attach", &bottom_attach,
                             NULL);
    if (bottom_attach != BOTTOM_ATTACH)
    {
        TEST_FAIL ("bottom_attach is '%d', should be '%d'",bottom_attach,BOTTOM_ATTACH);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (table);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CHILD
    #undef LEFT_ATTACH 
    #undef RIGHT_ATTACH
    #undef TOP_ATTACH
    #undef BOTTOM_ATTACH
    #undef TABLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_table_attach_defaults
 * Params: GtkTable *table,GtkWidget *child,guint left_attach,guint right_attach,guint top_attach,guint bottom_attach
 * Returns: void
 * Assertion:As there are many options associated with gtk_table_attach(), this convenience function provides the programmer with a means to add children to a table with identical padding and expansion options. 
 * Params Values: a newly created GtkTable*, gtk_button_new_with_label ("button"),6498,6499,6498,6499,gtk_table_new (6500, 6500, FALSE)
 * Expected: void  
 */
static void test_purpose_72()
{
    #define CHILD gtk_button_new_with_label ("button")
    #define LEFT_ATTACH 6498
    #define RIGHT_ATTACH 6499
    #define TOP_ATTACH 6498
    #define BOTTOM_ATTACH 6499
    #define TABLE gtk_table_new (6500, 6500, FALSE)
    
    GtkWidget* widget;
    GtkWidget* table;
    GtkWidget* parent;
    guint left_attach;
    guint right_attach;
    guint top_attach;
    guint bottom_attach;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    table = TABLE;
    widget = CHILD;
    
    gtk_table_attach_defaults (GTK_TABLE (table),
                               widget,
                               LEFT_ATTACH,RIGHT_ATTACH,  TOP_ATTACH,BOTTOM_ATTACH
                               );
    
    gtk_container_child_get (GTK_CONTAINER (table), widget,
                             "left_attach", &left_attach,
                             NULL);
    if (left_attach != LEFT_ATTACH)
    {
        TEST_FAIL ("left_attach is '%d', should be '%d'",left_attach,LEFT_ATTACH);
    }
    
    gtk_container_child_get (GTK_CONTAINER (table), widget,
                             "right_attach", &right_attach,
                             NULL);
    if (right_attach != RIGHT_ATTACH)
    {
        TEST_FAIL ("right_attach is '%d', should be '%d'",right_attach,RIGHT_ATTACH);
    }
    
    gtk_container_child_get (GTK_CONTAINER (table), widget,
                             "top_attach", &top_attach,
                             NULL);
    if (top_attach != TOP_ATTACH)
    {
        TEST_FAIL ("top_attach is '%d', should be '%d'",top_attach,TOP_ATTACH);
    }
    
    gtk_container_child_get (GTK_CONTAINER (table), widget,
                             "bottom_attach", &bottom_attach,
                             NULL);
    if (bottom_attach != BOTTOM_ATTACH)
    {
        TEST_FAIL ("bottom_attach is '%d', should be '%d'",bottom_attach,BOTTOM_ATTACH);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (table);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CHILD
    #undef LEFT_ATTACH 
    #undef RIGHT_ATTACH
    #undef TOP_ATTACH
    #undef BOTTOM_ATTACH
    #undef TABLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_table_attach_defaults
 * Params: GtkTable *table,GtkWidget *child,guint left_attach,guint right_attach,guint top_attach,guint bottom_attach
 * Returns: void
 * Assertion:As there are many options associated with gtk_table_attach(), this convenience function provides the programmer with a means to add children to a table with identical padding and expansion options. 
 * Params Values: a newly created GtkTable*, gtk_button_new_with_label ("button"),0,10,10,1000,gtk_table_new (6500, 6500, FALSE)
 * Expected: void  
 */
static void test_purpose_73()
{
    #define CHILD gtk_button_new_with_label ("button")
    #define LEFT_ATTACH 0
    #define RIGHT_ATTACH 10
    #define TOP_ATTACH 10
    #define BOTTOM_ATTACH 1000
    #define TABLE gtk_table_new (6500, 6500, FALSE)
    
    GtkWidget* widget;
    GtkWidget* table;
    GtkWidget* parent;
    guint left_attach;
    guint right_attach;
    guint top_attach;
    guint bottom_attach;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    table = TABLE;
    widget = CHILD;
    
    gtk_table_attach_defaults (GTK_TABLE (table),
                               widget,
                               LEFT_ATTACH,RIGHT_ATTACH,  TOP_ATTACH,BOTTOM_ATTACH
                               );
    
    gtk_container_child_get (GTK_CONTAINER (table), widget,
                             "left_attach", &left_attach,
                             NULL);
    if (left_attach != LEFT_ATTACH)
    {
        TEST_FAIL ("left_attach is '%d', should be '%d'",left_attach,LEFT_ATTACH);
    }
    
    gtk_container_child_get (GTK_CONTAINER (table), widget,
                             "right_attach", &right_attach,
                             NULL);
    if (right_attach != RIGHT_ATTACH)
    {
        TEST_FAIL ("right_attach is '%d', should be '%d'",right_attach,RIGHT_ATTACH);
    }
    
    gtk_container_child_get (GTK_CONTAINER (table), widget,
                             "top_attach", &top_attach,
                             NULL);
    if (top_attach != TOP_ATTACH)
    {
        TEST_FAIL ("top_attach is '%d', should be '%d'",top_attach,TOP_ATTACH);
    }
    
    gtk_container_child_get (GTK_CONTAINER (table), widget,
                             "bottom_attach", &bottom_attach,
                             NULL);
    if (bottom_attach != BOTTOM_ATTACH)
    {
        TEST_FAIL ("bottom_attach is '%d', should be '%d'",bottom_attach,BOTTOM_ATTACH);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (table);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CHILD
    #undef LEFT_ATTACH 
    #undef RIGHT_ATTACH
    #undef TOP_ATTACH
    #undef BOTTOM_ATTACH
    #undef TABLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_table_get_default_row_spacing
 * Params: GtkTable *table
 * Returns: guint
 * Assertion: This is the spacing that will be used for newly added rows.
 * Params Values: newly created GtkTable*
 * Expected: 100  
 */
static void test_purpose_74()
{
    #define TABLE gtk_table_new (6500, 6500, TRUE)
    #define SPACING  100
    #define NEW_ROW  70
    #define NEW_COL  70
    
    GtkWidget *widget;
    guint spacing;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = TABLE;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TABLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_table_set_row_spacings (GTK_TABLE (widget), SPACING);
    
    gtk_table_resize (GTK_TABLE (widget), NEW_ROW, NEW_COL);
    
    spacing = gtk_table_get_default_row_spacing (GTK_TABLE (widget));
    if (spacing != SPACING)
    {
        TEST_FAIL("spacing = %i, should be %i\n", spacing, SPACING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TABLE 
    #undef SPACING
    #undef NEW_ROW
    #undef NEW_COL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_table_get_default_row_spacing
 * Params: GtkTable *table
 * Returns: guint
 * Assertion: This is the spacing that will be used for newly added rows.
 * Params Values: newly created GtkTable*
 * Expected: 100  
 */
static void test_purpose_75()
{
    #define TABLE gtk_table_new (6500, 6500, FALSE)
    #define SPACING  100
    #define NEW_ROW  70
    #define NEW_COL  70
    
    GtkWidget *widget;
    guint spacing;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = TABLE;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TABLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_table_set_row_spacings (GTK_TABLE (widget), SPACING);
    
    gtk_table_resize (GTK_TABLE (widget), NEW_ROW, NEW_COL);
    
    spacing = gtk_table_get_default_row_spacing (GTK_TABLE (widget));
    if (spacing != SPACING)
    {
        TEST_FAIL("spacing = %i, should be %i\n", spacing, SPACING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TABLE 
    #undef SPACING
    #undef NEW_ROW
    #undef NEW_COL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_table_get_default_row_spacing
 * Params: GtkTable *table
 * Returns: guint
 * Assertion: This is the spacing that will be used for newly added rows.
 * Params Values: newly created GtkTable*
 * Expected: 100  
 */
static void test_purpose_76()
{
    #define TABLE gtk_table_new (6500, 0, TRUE)
    #define SPACING  100
    #define NEW_ROW  70
    #define NEW_COL  10
    
    GtkWidget *widget;
    guint spacing;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = TABLE;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TABLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_table_set_row_spacings (GTK_TABLE (widget), SPACING);
    
    gtk_table_resize (GTK_TABLE (widget), NEW_ROW, NEW_COL);
    
    spacing = gtk_table_get_default_row_spacing (GTK_TABLE (widget));
    if (spacing != SPACING)
    {
        TEST_FAIL("spacing = %i, should be %i\n", spacing, SPACING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TABLE 
    #undef SPACING
    #undef NEW_ROW
    #undef NEW_COL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_table_get_default_row_spacing
 * Params: GtkTable *table
 * Returns: guint
 * Assertion: This is the spacing that will be used for newly added rows.
 * Params Values: newly created GtkTable*
 * Expected: 100  
 */
static void test_purpose_77()
{
    #define TABLE gtk_table_new (6500, 0, FALSE)
    #define SPACING  100
    #define NEW_ROW  70
    #define NEW_COL  10
    
    GtkWidget *widget;
    guint spacing;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = TABLE;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TABLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_table_set_row_spacings (GTK_TABLE (widget), SPACING);
    
    gtk_table_resize (GTK_TABLE (widget), NEW_ROW, NEW_COL);
    
    spacing = gtk_table_get_default_row_spacing (GTK_TABLE (widget));
    if (spacing != SPACING)
    {
        TEST_FAIL("spacing = %i, should be %i\n", spacing, SPACING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TABLE 
    #undef SPACING
    #undef NEW_ROW
    #undef NEW_COL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_table_get_default_row_spacing
 * Params: GtkTable *table
 * Returns: guint
 * Assertion: This is the spacing that will be used for newly added rows.
 * Params Values: newly created GtkTable*
 * Expected: 100  
 */
static void test_purpose_78()
{
    #define TABLE gtk_table_new (6500, 1, TRUE)
    #define SPACING  100
    #define NEW_ROW  70
    #define NEW_COL  70
    
    GtkWidget *widget;
    guint spacing;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = TABLE;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TABLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_table_set_row_spacings (GTK_TABLE (widget), SPACING);
    
    gtk_table_resize (GTK_TABLE (widget), NEW_ROW, NEW_COL);
    
    spacing = gtk_table_get_default_row_spacing (GTK_TABLE (widget));
    if (spacing != SPACING)
    {
        TEST_FAIL("spacing = %i, should be %i\n", spacing, SPACING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TABLE 
    #undef SPACING
    #undef NEW_ROW
    #undef NEW_COL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_table_get_default_row_spacing
 * Params: GtkTable *table
 * Returns: guint
 * Assertion: This is the spacing that will be used for newly added rows.
 * Params Values: newly created GtkTable*
 * Expected: 100  
 */
static void test_purpose_79()
{
    #define TABLE gtk_table_new (6500, 1, FALSE)
    #define SPACING  100
    #define NEW_ROW  70
    #define NEW_COL  70
    
    GtkWidget *widget;
    guint spacing;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = TABLE;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TABLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_table_set_row_spacings (GTK_TABLE (widget), SPACING);
    
    gtk_table_resize (GTK_TABLE (widget), NEW_ROW, NEW_COL);
    
    spacing = gtk_table_get_default_row_spacing (GTK_TABLE (widget));
    if (spacing != SPACING)
    {
        TEST_FAIL("spacing = %i, should be %i\n", spacing, SPACING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TABLE 
    #undef SPACING
    #undef NEW_ROW
    #undef NEW_COL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_table_get_default_row_spacing
 * Params: GtkTable *table
 * Returns: guint
 * Assertion: This is the spacing that will be used for newly added rows.
 * Params Values: newly created GtkTable*
 * Expected: 100  
 */
static void test_purpose_80()
{
    #define TABLE gtk_table_new (1, 0, TRUE)
    #define SPACING  100
    #define NEW_ROW  10
    #define NEW_COL  10
    
    GtkWidget *widget;
    guint spacing;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = TABLE;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TABLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_table_set_row_spacings (GTK_TABLE (widget), SPACING);
    
    gtk_table_resize (GTK_TABLE (widget), NEW_ROW, NEW_COL);
    
    spacing = gtk_table_get_default_row_spacing (GTK_TABLE (widget));
    if (spacing != SPACING)
    {
        TEST_FAIL("spacing = %i, should be %i\n", spacing, SPACING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TABLE 
    #undef SPACING
    #undef NEW_ROW
    #undef NEW_COL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_table_get_default_row_spacing
 * Params: GtkTable *table
 * Returns: guint
 * Assertion: This is the spacing that will be used for newly added rows.
 * Params Values: newly created GtkTable*
 * Expected: 100  
 */
static void test_purpose_81()
{
    #define TABLE gtk_table_new (7, 0, FALSE)
    #define SPACING  100
    #define NEW_ROW  10
    #define NEW_COL  10
    
    GtkWidget *widget;
    guint spacing;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = TABLE;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TABLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_table_set_row_spacings (GTK_TABLE (widget), SPACING);
    
    gtk_table_resize (GTK_TABLE (widget), NEW_ROW, NEW_COL);
    
    spacing = gtk_table_get_default_row_spacing (GTK_TABLE (widget));
    if (spacing != SPACING)
    {
        TEST_FAIL("spacing = %i, should be %i\n", spacing, SPACING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TABLE 
    #undef SPACING
    #undef NEW_ROW
    #undef NEW_COL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_table_get_default_row_spacing
 * Params: GtkTable *table
 * Returns: guint
 * Assertion: This is the spacing that will be used for newly added rows.
 * Params Values: newly created GtkTable*
 * Expected: 100  
 */
static void test_purpose_82()
{
    #define TABLE gtk_table_new (100, 1, TRUE)
    #define SPACING  100
    #define NEW_ROW  10
    #define NEW_COL  10
    
    GtkWidget *widget;
    guint spacing;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = TABLE;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TABLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_table_set_row_spacings (GTK_TABLE (widget), SPACING);
    
    gtk_table_resize (GTK_TABLE (widget), NEW_ROW, NEW_COL);
    
    spacing = gtk_table_get_default_row_spacing (GTK_TABLE (widget));
    if (spacing != SPACING)
    {
        TEST_FAIL("spacing = %i, should be %i\n", spacing, SPACING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TABLE 
    #undef SPACING
    #undef NEW_ROW
    #undef NEW_COL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_table_get_default_row_spacing
 * Params: GtkTable *table
 * Returns: guint
 * Assertion: This is the spacing that will be used for newly added rows.
 * Params Values: newly created GtkTable*
 * Expected: 100  
 */
static void test_purpose_83()
{
    #define TABLE gtk_table_new (777, 1, FALSE)
    #define SPACING  100
    #define NEW_ROW  10
    #define NEW_COL  10
    
    GtkWidget *widget;
    guint spacing;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = TABLE;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TABLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_table_set_row_spacings (GTK_TABLE (widget), SPACING);
    
    gtk_table_resize (GTK_TABLE (widget), NEW_ROW, NEW_COL);
    
    spacing = gtk_table_get_default_row_spacing (GTK_TABLE (widget));
    if (spacing != SPACING)
    {
        TEST_FAIL("spacing = %i, should be %i\n", spacing, SPACING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TABLE 
    #undef SPACING
    #undef NEW_ROW
    #undef NEW_COL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_table_get_default_col_spacing
 * Params: GtkTable *table
 * Returns: guint
 * Assertion: This is the spacing that will be used for newly added columns.
 * Params Values: newly created GtkTable*
 * Expected: 100  
 */
static void test_purpose_84()
{
    #define TABLE gtk_table_new (6500, 6500, TRUE)
    #define SPACING  100
    #define NEW_ROW  70
    #define NEW_COL  70
    
    GtkWidget *widget;
    guint spacing;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = TABLE;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TABLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_table_set_col_spacings (GTK_TABLE (widget), SPACING);
    
    gtk_table_resize (GTK_TABLE (widget), NEW_ROW, NEW_COL);
    
    spacing = gtk_table_get_default_col_spacing (GTK_TABLE (widget));
    if (spacing != SPACING)
    {
        TEST_FAIL("spacing = %i, should be %i\n", spacing, SPACING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TABLE 
    #undef SPACING
    #undef NEW_ROW
    #undef NEW_COL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_table_get_default_col_spacing
 * Params: GtkTable *table
 * Returns: guint
 * Assertion: This is the spacing that will be used for newly added columns.
 * Params Values: newly created GtkTable*
 * Expected: 100  
 */
static void test_purpose_85()
{
    #define TABLE gtk_table_new (6500, 6500, FALSE)
    #define SPACING  100
    #define NEW_ROW  70
    #define NEW_COL  70
    
    GtkWidget *widget;
    guint spacing;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = TABLE;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TABLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_table_set_col_spacings (GTK_TABLE (widget), SPACING);
    
    gtk_table_resize (GTK_TABLE (widget), NEW_ROW, NEW_COL);
    
    spacing = gtk_table_get_default_col_spacing (GTK_TABLE (widget));
    if (spacing != SPACING)
    {
        TEST_FAIL("spacing = %i, should be %i\n", spacing, SPACING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TABLE 
    #undef SPACING
    #undef NEW_ROW
    #undef NEW_COL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_table_get_default_col_spacing
 * Params: GtkTable *table
 * Returns: guint
 * Assertion: This is the spacing that will be used for newly added columns.
 * Params Values: newly created GtkTable*
 * Expected: 100  
 */
static void test_purpose_86()
{
    #define TABLE gtk_table_new (6500, 0, TRUE)
    #define SPACING  100
    #define NEW_ROW  70
    #define NEW_COL  10
    
    GtkWidget *widget;
    guint spacing;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = TABLE;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TABLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_table_set_col_spacings (GTK_TABLE (widget), SPACING);
    
    gtk_table_resize (GTK_TABLE (widget), NEW_ROW, NEW_COL);
    
    spacing = gtk_table_get_default_col_spacing (GTK_TABLE (widget));
    if (spacing != SPACING)
    {
        TEST_FAIL("spacing = %i, should be %i\n", spacing, SPACING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TABLE 
    #undef SPACING
    #undef NEW_ROW
    #undef NEW_COL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_table_get_default_col_spacing
 * Params: GtkTable *table
 * Returns: guint
 * Assertion: This is the spacing that will be used for newly added columns.
 * Params Values: newly created GtkTable*
 * Expected: 100  
 */
static void test_purpose_87()
{
    #define TABLE gtk_table_new (6500, 0, FALSE)
    #define SPACING  100
    #define NEW_ROW  70
    #define NEW_COL  10
    
    GtkWidget *widget;
    guint spacing;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = TABLE;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TABLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_table_set_col_spacings (GTK_TABLE (widget), SPACING);
    
    gtk_table_resize (GTK_TABLE (widget), NEW_ROW, NEW_COL);
    
    spacing = gtk_table_get_default_col_spacing (GTK_TABLE (widget));
    if (spacing != SPACING)
    {
        TEST_FAIL("spacing = %i, should be %i\n", spacing, SPACING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TABLE 
    #undef SPACING
    #undef NEW_ROW
    #undef NEW_COL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_table_get_default_col_spacing
 * Params: GtkTable *table
 * Returns: guint
 * Assertion: This is the spacing that will be used for newly added columns.
 * Params Values: newly created GtkTable*
 * Expected: 100  
 */
static void test_purpose_88()
{
    #define TABLE gtk_table_new (6500, 1, TRUE)
    #define SPACING  100
    #define NEW_ROW  70
    #define NEW_COL  70
    
    GtkWidget *widget;
    guint spacing;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = TABLE;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TABLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_table_set_col_spacings (GTK_TABLE (widget), SPACING);
    
    gtk_table_resize (GTK_TABLE (widget), NEW_ROW, NEW_COL);
    
    spacing = gtk_table_get_default_col_spacing (GTK_TABLE (widget));
    if (spacing != SPACING)
    {
        TEST_FAIL("spacing = %i, should be %i\n", spacing, SPACING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TABLE 
    #undef SPACING
    #undef NEW_ROW
    #undef NEW_COL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_table_get_default_col_spacing
 * Params: GtkTable *table
 * Returns: guint
 * Assertion: This is the spacing that will be used for newly added columns.
 * Params Values: newly created GtkTable*
 * Expected: 100  
 */
static void test_purpose_89()
{
    #define TABLE gtk_table_new (6500, 1, FALSE)
    #define SPACING  100
    #define NEW_ROW  70
    #define NEW_COL  70
    
    GtkWidget *widget;
    guint spacing;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = TABLE;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TABLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_table_set_col_spacings (GTK_TABLE (widget), SPACING);
    
    gtk_table_resize (GTK_TABLE (widget), NEW_ROW, NEW_COL);
    
    spacing = gtk_table_get_default_col_spacing (GTK_TABLE (widget));
    if (spacing != SPACING)
    {
        TEST_FAIL("spacing = %i, should be %i\n", spacing, SPACING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TABLE 
    #undef SPACING
    #undef NEW_ROW
    #undef NEW_COL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_table_get_default_col_spacing
 * Params: GtkTable *table
 * Returns: guint
 * Assertion: This is the spacing that will be used for newly added columns.
 * Params Values: newly created GtkTable*
 * Expected: 100  
 */
static void test_purpose_90()
{
    #define TABLE gtk_table_new (1, 0, TRUE)
    #define SPACING  100
    #define NEW_ROW  10
    #define NEW_COL  10
    
    GtkWidget *widget;
    guint spacing;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = TABLE;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TABLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_table_set_col_spacings (GTK_TABLE (widget), SPACING);
    
    gtk_table_resize (GTK_TABLE (widget), NEW_ROW, NEW_COL);
    
    spacing = gtk_table_get_default_col_spacing (GTK_TABLE (widget));
    if (spacing != SPACING)
    {
        TEST_FAIL("spacing = %i, should be %i\n", spacing, SPACING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TABLE 
    #undef SPACING
    #undef NEW_ROW
    #undef NEW_COL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_table_get_default_col_spacing
 * Params: GtkTable *table
 * Returns: guint
 * Assertion: This is the spacing that will be used for newly added columns.
 * Params Values: newly created GtkTable*
 * Expected: 100  
 */
static void test_purpose_91()
{
    #define TABLE gtk_table_new (7, 0, FALSE)
    #define SPACING  100
    #define NEW_ROW  10
    #define NEW_COL  10
    
    GtkWidget *widget;
    guint spacing;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = TABLE;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TABLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_table_set_col_spacings (GTK_TABLE (widget), SPACING);
    
    gtk_table_resize (GTK_TABLE (widget), NEW_ROW, NEW_COL);
    
    spacing = gtk_table_get_default_col_spacing (GTK_TABLE (widget));
    if (spacing != SPACING)
    {
        TEST_FAIL("spacing = %i, should be %i\n", spacing, SPACING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TABLE 
    #undef SPACING
    #undef NEW_ROW
    #undef NEW_COL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_table_get_default_col_spacing
 * Params: GtkTable *table
 * Returns: guint
 * Assertion: This is the spacing that will be used for newly added columns.
 * Params Values: newly created GtkTable*
 * Expected: 100  
 */
static void test_purpose_92()
{
    #define TABLE gtk_table_new (100, 1, TRUE)
    #define SPACING  100
    #define NEW_ROW  10
    #define NEW_COL  10
    
    GtkWidget *widget;
    guint spacing;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = TABLE;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TABLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_table_set_col_spacings (GTK_TABLE (widget), SPACING);
    
    gtk_table_resize (GTK_TABLE (widget), NEW_ROW, NEW_COL);
    
    spacing = gtk_table_get_default_col_spacing (GTK_TABLE (widget));
    if (spacing != SPACING)
    {
        TEST_FAIL("spacing = %i, should be %i\n", spacing, SPACING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TABLE 
    #undef SPACING
    #undef NEW_ROW
    #undef NEW_COL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_table_get_default_col_spacing
 * Params: GtkTable *table
 * Returns: guint
 * Assertion: This is the spacing that will be used for newly added columns.
 * Params Values: newly created GtkTable*
 * Expected: 100  
 */
static void test_purpose_93()
{
    #define TABLE gtk_table_new (777, 1, FALSE)
    #define SPACING  100
    #define NEW_ROW  10
    #define NEW_COL  10
    
    GtkWidget *widget;
    guint spacing;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = TABLE;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TABLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_table_set_col_spacings (GTK_TABLE (widget), SPACING);
    
    gtk_table_resize (GTK_TABLE (widget), NEW_ROW, NEW_COL);
    
    spacing = gtk_table_get_default_col_spacing (GTK_TABLE (widget));
    if (spacing != SPACING)
    {
        TEST_FAIL("spacing = %i, should be %i\n", spacing, SPACING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TABLE 
    #undef SPACING
    #undef NEW_ROW
    #undef NEW_COL
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GtkTable ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {test_purpose_11, 1},
    {test_purpose_12, 1},
    {test_purpose_13, 1},
    {test_purpose_14, 1},
    {test_purpose_15, 1},
    {test_purpose_16, 1},
    {test_purpose_17, 1},
    {test_purpose_18, 1},
    {test_purpose_19, 1},
    {test_purpose_20, 1},
    {test_purpose_21, 1},
    {test_purpose_22, 1},
    {test_purpose_23, 1},
    {test_purpose_24, 1},
    {test_purpose_25, 1},
    {test_purpose_26, 1},
    {test_purpose_27, 1},
    {test_purpose_28, 1},
    {test_purpose_29, 1},
    {test_purpose_30, 1},
    {test_purpose_31, 1},
    {test_purpose_32, 1},
    {test_purpose_33, 1},
    {test_purpose_34, 1},
    {test_purpose_35, 1},
    {test_purpose_36, 1},
    {test_purpose_37, 1},
    {test_purpose_38, 1},
    {test_purpose_39, 1},
    {test_purpose_40, 1},
    {test_purpose_41, 1},
    {test_purpose_42, 1},
    {test_purpose_43, 1},
    {test_purpose_44, 1},
    {test_purpose_45, 1},
    {test_purpose_46, 1},
    {test_purpose_47, 1},
    {test_purpose_48, 1},
    {test_purpose_49, 1},
    {test_purpose_50, 1},
    {test_purpose_51, 1},
    {test_purpose_52, 1},
    {test_purpose_53, 1},
    {test_purpose_54, 1},
    {test_purpose_55, 1},
    {test_purpose_56, 1},
    {test_purpose_57, 1},
    {test_purpose_58, 1},
    {test_purpose_59, 1},
    {test_purpose_60, 1},
    {test_purpose_61, 1},
    {test_purpose_62, 1},
    {test_purpose_63, 1},
    {test_purpose_64, 1},
    {test_purpose_65, 1},
    {test_purpose_66, 1},
    {test_purpose_67, 1},
    {test_purpose_68, 1},
    {test_purpose_69, 1},
    {test_purpose_70, 1},
    {test_purpose_71, 1},
    {test_purpose_72, 1},
    {test_purpose_73, 1},
    {test_purpose_74, 1},
    {test_purpose_75, 1},
    {test_purpose_76, 1},
    {test_purpose_77, 1},
    {test_purpose_78, 1},
    {test_purpose_79, 1},
    {test_purpose_80, 1},
    {test_purpose_81, 1},
    {test_purpose_82, 1},
    {test_purpose_83, 1},
    {test_purpose_84, 1},
    {test_purpose_85, 1},
    {test_purpose_86, 1},
    {test_purpose_87, 1},
    {test_purpose_88, 1},
    {test_purpose_89, 1},
    {test_purpose_90, 1},
    {test_purpose_91, 1},
    {test_purpose_92, 1},
    {test_purpose_93, 1},
    {NULL,0}
};
